"""
File: /http/_http_constants.py
Created Date: Tuesday July 29th 2025
Author: Harsh Kumar <fyo9329@gmail.com>
-----
Last Modified: Wednesday September 3rd 2025
Modified By: the developer formerly known as Harsh Kumar at <fyo9329@gmail.com>
-----
"""

DEFAULT_BASE_URL = "https://toolsapi.lumen-labs.ai/api"
DEFAULT_TIMEOUT = 30.0
DEFAULT_HEADERS = {
    "Content-Type": "application/json"
}