"""
File: /constants.py
Created Date: Monday July 28th 2025
Author: Harsh Kumar <fyo9329@gmail.com>
-----
Last Modified: Friday August 29th 2025
Modified By: the developer formerly known as Harsh Kumar at <fyo9329@gmail.com>
-----
"""

from enum import Enum

class Action:
    """
    Constants for all available actions across providers and services.
    """
    # Gmail actions
    GMAIL_SEND_EMAIL = "GMAIL_SEND_EMAIL"
    GMAIL_REPLY_TO_THREAD = "GMAIL_REPLY_TO_THREAD"
    GMAIL_FETCH_MESSAGES_BY_THREAD = "GMAIL_FETCH_MESSAGES_BY_THREAD"
    GMAIL_SEND_DRAFT = "GMAIL_SEND_DRAFT"
    GMAIL_SEARCH_PEOPLE = "GMAIL_SEARCH_PEOPLE"
    GMAIL_DELETE_DRAFT = "GMAIL_DELETE_DRAFT"
    GMAIL_DELETE_MESSAGE = "GMAIL_DELETE_MESSAGE"
    GMAIL_FETCH_EMAILS = "GMAIL_FETCH_EMAILS"
    GMAIL_GET_GMAIL_ATTACHMENT = "GMAIL_GET_GMAIL_ATTACHMENT"
    GMAIL_GET_CONTACTS = "GMAIL_GET_CONTACTS"
    GMAIL_LIST_DRAFTS = "GMAIL_LIST_DRAFTS"
    GMAIL_MOVE_TO_TRASH = "GMAIL_MOVE_TO_TRASH"
    GMAIL_PATCH_LABEL = "GMAIL_PATCH_LABEL"
    GMAIL_MODIFY_EMAIL_LABELS = "GMAIL_MODIFY_EMAIL_LABELS"
    GMAIL_CREATE_LABEL = "GMAIL_CREATE_LABEL"
    GMAIL_GET_PEOPLE = "GMAIL_GET_PEOPLE"
    GMAIL_GET_PROFILE = "GMAIL_GET_PROFILE"
    GMAIL_LIST_GMAIL_LABELS = "GMAIL_LIST_GMAIL_LABELS"
    GMAIL_LIST_THREADS = "GMAIL_LIST_THREADS"
    GMAIL_MODIFY_THREAD_LABELS = "GMAIL_MODIFY_THREAD_LABELS"
    GMAIL_REMOVE_LABEL = "GMAIL_REMOVE_LABEL"
    GMAIL_FETCH_MESSAGE_BY_MESSAGE_ID = "GMAIL_FETCH_MESSAGE_BY_MESSAGE_ID"
    GMAIL_CREATE_DRAFT = "GMAIL_CREATE_DRAFT"

    # Calendar actions
    CALENDAR_CREATE_EVENT = "CALENDAR_CREATE_EVENT"
    CALENDAR_DELETE_EVENT = "CALENDAR_DELETE_EVENT"
    CALENDAR_LIST_EVENTS = "CALENDAR_LIST_EVENTS"
    CALENDAR_UPDATE_ACL_RULE = "CALENDAR_UPDATE_ACL_RULE"
    CALENDAR_UPDATE_CALENDAR_LIST_ENTRY = "CALENDAR_UPDATE_CALENDAR_LIST_ENTRY"
    CALENDAR_GET_EVENT_INSTANCES = "CALENDAR_GET_EVENT_INSTANCES"
    CALENDAR_CREATE_CALENDAR = "CALENDAR_CREATE_CALENDAR"
    CALENDAR_DELETE_CALENDAR = "CALENDAR_DELETE_CALENDAR"
    CALENDAR_UPDATE_CALENDAR = "CALENDAR_UPDATE_CALENDAR"
    CALENDAR_INSERT_CALENDAR_INTO_LIST = "CALENDAR_INSERT_CALENDAR_INTO_LIST"
    CALENDAR_GET_CALENDAR = "CALENDAR_GET_CALENDAR"
    CALENDAR_QUERY_FREE_BUSY = "CALENDAR_QUERY_FREE_BUSY"
    CALENDAR_PATCH_CALENDAR = "CALENDAR_PATCH_CALENDAR"
    CALENDAR_PATCH_EVENT = "CALENDAR_PATCH_EVENT"
    CALENDAR_QUICK_ADD_EVENT = "CALENDAR_QUICK_ADD_EVENT"
    CALENDAR_SYNC_EVENTS = "CALENDAR_SYNC_EVENTS"
    CALENDAR_CLEAR_CALENDAR = "CALENDAR_CLEAR_CALENDAR"
    CALENDAR_MOVE_EVENT = "CALENDAR_MOVE_EVENT"
    CALENDAR_FIND_FREE_SLOTS = "CALENDAR_FIND_FREE_SLOTS"
    CALENDAR_LIST_ACL_RULES = "CALENDAR_LIST_ACL_RULES"
    CALENDAR_LIST_GOOGLE_CALENDARS = "CALENDAR_LIST_GOOGLE_CALENDARS"
    CALENDAR_REMOVE_ATTENDEE_FROM_EVENT = "CALENDAR_REMOVE_ATTENDEE_FROM_EVENT"
    CALENDAR_LIST_SETTINGS = "CALENDAR_LIST_SETTINGS"
    CALENDAR_GET_CURRENT_DATE_AND_TIME = "CALENDAR_GET_CURRENT_DATE_AND_TIME"
    CALENDAR_UPDATE_EVENT = "CALENDAR_UPDATE_EVENT"

    
    # Drive actions
    DRIVE_DELETE_FILE = "DRIVE_DELETE_FILE"
    DRIVE_CREATE_COMMENT = "DRIVE_CREATE_COMMENT"
    DRIVE_CREATE_SHARED_DRIVE = "DRIVE_CREATE_SHARED_DRIVE"
    DRIVE_CREATE_FILE_OR_FOLDER = "DRIVE_CREATE_FILE_OR_FOLDER"
    DRIVE_CREATE_REPLY = "DRIVE_CREATE_REPLY"
    DRIVE_CREATE_SHORTCUT = "DRIVE_CREATE_SHORTCUT"
    DRIVE_DELETE_COMMENT = "DRIVE_DELETE_COMMENT"
    DRIVE_DELETE_SHARED_DRIVE = "DRIVE_DELETE_SHARED_DRIVE"
    DRIVE_DELETE_PERMISSION = "DRIVE_DELETE_PERMISSION"
    DRIVE_DELETE_REPLY = "DRIVE_DELETE_REPLY"
    DRIVE_EMPTY_TRASH = "DRIVE_EMPTY_TRASH"
    DRIVE_MODIFY_FILE_LABELS = "DRIVE_MODIFY_FILE_LABELS"
    DRIVE_GENERATE_FILE_IDS = "DRIVE_GENERATE_FILE_IDS"
    DRIVE_GET_ABOUT_INFORMATION = "DRIVE_GET_ABOUT_INFORMATION"
    DRIVE_GET_CHANGES_START_PAGE_TOKEN = "DRIVE_GET_CHANGES_START_PAGE_TOKEN"
    DRIVE_GET_COMMENT = "DRIVE_GET_COMMENT"
    DRIVE_GET_SHARED_DRIVE = "DRIVE_GET_SHARED_DRIVE"
    DRIVE_GET_FILE_METADATA = "DRIVE_GET_FILE_METADATA"
    DRIVE_GET_PERMISSION = "DRIVE_GET_PERMISSION"
    DRIVE_GET_REPLY = "DRIVE_GET_REPLY"
    DRIVE_GET_REVISION = "DRIVE_GET_REVISION"
    DRIVE_HIDE_SHARED_DRIVE = "DRIVE_HIDE_SHARED_DRIVE"
    DRIVE_LIST_CHANGES = "DRIVE_LIST_CHANGES"
    DRIVE_LIST_COMMENTS = "DRIVE_LIST_COMMENTS"
    DRIVE_LIST_FILES_AND_FOLDERS = "DRIVE_LIST_FILES_AND_FOLDERS"
    DRIVE_LIST_FILE_LABELS = "DRIVE_LIST_FILE_LABELS"
    DRIVE_LIST_PERMISSIONS = "DRIVE_LIST_PERMISSIONS"
    DRIVE_LIST_REPLIES = "DRIVE_LIST_REPLIES"
    DRIVE_LIST_REVISIONS = "DRIVE_LIST_REVISIONS"
    DRIVE_LIST_SHARED_DRIVES = "DRIVE_LIST_SHARED_DRIVES"
    DRIVE_MOVE_FILE = "DRIVE_MOVE_FILE"
    DRIVE_UNTRASH_FILE = "DRIVE_UNTRASH_FILE"
    DRIVE_UPDATE_COMMENT = "DRIVE_UPDATE_COMMENT"
    DRIVE_UPDATE_SHARED_DRIVE = "DRIVE_UPDATE_SHARED_DRIVE"
    DRIVE_FIND_FILE = "DRIVE_FIND_FILE"
    DRIVE_FIND_FOLDER = "DRIVE_FIND_FOLDER"
    DRIVE_COPY_FILE = "DRIVE_COPY_FILE"
    DRIVE_CREATE_TEXT_FILE = "DRIVE_CREATE_TEXT_FILE"
    DRIVE_UPDATE_FILE_METADATA = "DRIVE_UPDATE_FILE_METADATA"
    DRIVE_UPDATE_REPLY = "DRIVE_UPDATE_REPLY"
    DRIVE_UPDATE_FILE_REVISION = "DRIVE_UPDATE_FILE_REVISION"
    DRIVE_UPDATE_PERMISSION = "DRIVE_UPDATE_PERMISSION"
    DRIVE_UNHIDE_SHARED_DRIVE = "DRIVE_UNHIDE_SHARED_DRIVE"
    DRIVE_ADD_FILE_SHARING_PREFERENCE = "DRIVE_ADD_FILE_SHARING_PREFERENCE"
    DRIVE_DELETE_FOLDER = "DRIVE_DELETE_FOLDER"
    DRIVE_UPLOAD_FILE = "DRIVE_UPLOAD_FILE"
    DRIVE_EDIT_FILE = "DRIVE_EDIT_FILE"

    # Docs actions
    DOCS_CREATE_DOCUMENT = "DOCS_CREATE_DOCUMENT"
    DOCS_GET_DOCUMENT = "DOCS_GET_DOCUMENT"
    DOCS_CREATE_PARAGRAPH_BULLETS = "DOCS_CREATE_PARAGRAPH_BULLETS"
    DOCS_DELETE_PARAGRAPH_BULLETS = "DOCS_DELETE_PARAGRAPH_BULLETS"
    DOCS_INSERT_TABLE = "DOCS_INSERT_TABLE"
    DOCS_DELETE_TABLE = "DOCS_DELETE_TABLE"
    DOCS_INSERT_TABLE_ROW = "DOCS_INSERT_TABLE_ROW"
    DOCS_DELETE_TABLE_ROW = "DOCS_DELETE_TABLE_ROW"
    DOCS_INSERT_TABLE_COLUMN = "DOCS_INSERT_TABLE_COLUMN"
    DOCS_DELETE_TABLE_COLUMN = "DOCS_DELETE_TABLE_COLUMN"
    DOCS_CREATE_HEADER = "DOCS_CREATE_HEADER"
    DOCS_DELETE_HEADER = "DOCS_DELETE_HEADER"
    DOCS_CREATE_FOOTER = "DOCS_CREATE_FOOTER"
    DOCS_DELETE_FOOTER = "DOCS_DELETE_FOOTER"
    DOCS_CREATE_FOOTNOTE = "DOCS_CREATE_FOOTNOTE"
    DOCS_CREATE_NAMED_RANGE = "DOCS_CREATE_NAMED_RANGE"
    DOCS_DELETE_NAMED_RANGE = "DOCS_DELETE_NAMED_RANGE"
    DOCS_UPDATE_TEXT_STYLE = "DOCS_UPDATE_TEXT_STYLE"
    DOCS_UPDATE_PARAGRAPH_STYLE = "DOCS_UPDATE_PARAGRAPH_STYLE"
    DOCS_INSERT_PAGE_BREAK = "DOCS_INSERT_PAGE_BREAK"
    DOCS_INSERT_SECTION_BREAK = "DOCS_INSERT_SECTION_BREAK"
    DOCS_INSERT_INLINE_IMAGE = "DOCS_INSERT_INLINE_IMAGE"
    DOCS_REPLACE_IMAGE = "DOCS_REPLACE_IMAGE"
    DOCS_UNMERGE_TABLE_CELLS = "DOCS_UNMERGE_TABLE_CELLS"
    DOCS_UPDATE_DOCUMENT_STYLE = "DOCS_UPDATE_DOCUMENT_STYLE"
    DOCS_UPDATE_TABLE_ROW_STYLE = "DOCS_UPDATE_TABLE_ROW_STYLE"
    DOCS_COPY_DOCUMENT = "DOCS_COPY_DOCUMENT"
    DOCS_INSERT_TEXT = "DOCS_INSERT_TEXT"
    DOCS_DELETE_CONTENT_RANGE = "DOCS_DELETE_CONTENT_RANGE"
    DOCS_REPLACE_ALL_TEXT = "DOCS_REPLACE_ALL_TEXT"
    DOCS_SEARCH_DOCUMENTS = "DOCS_SEARCH_DOCUMENTS"
    DOCS_CREATE_DOCUMENT_MARKDOWN = "DOCS_CREATE_DOCUMENT_MARKDOWN"

    # Meet actions
    MEET_GET_CONFERENCE_RECORD = "MEET_GET_CONFERENCE_RECORD"
    MEET_GET_PARTICIPANT_SESSION = "MEET_GET_PARTICIPANT_SESSION"
    MEET_LIST_PARTICIPANT_SESSIONS = "MEET_LIST_PARTICIPANT_SESSIONS"
    MEET_LIST_CONFERENCE_RECORDS = "MEET_LIST_CONFERENCE_RECORDS"
    MEET_UPDATE_GOOGLE_MEET_SPACE = "MEET_UPDATE_GOOGLE_MEET_SPACE"
    MEET_CREATE_MEET_SPACE = "MEET_CREATE_MEET_SPACE"
    MEET_GET_MEET_SPACE_DETAILS = "MEET_GET_MEET_SPACE_DETAILS"
    MEET_GET_RECORDINGS_BY_CONFERENCE_RECORD = "MEET_GET_RECORDINGS_BY_CONFERENCE_RECORD"
    MEET_GET_TRANSCRIPTS_BY_CONFERENCE_RECORD = "MEET_GET_TRANSCRIPTS_BY_CONFERENCE_RECORD"

    # Firecrawl actions
    FIRECRAWL_SCRAPE_URL = "FIRECRAWL_SCRAPE_URL"
    FIRECRAWL_START_CRAWL = "FIRECRAWL_START_CRAWL"
    FIRECRAWL_GET_CRAWL_STATUS = "FIRECRAWL_GET_CRAWL_STATUS"
    FIRECRAWL_CANCEL_CRAWL = "FIRECRAWL_CANCEL_CRAWL"
    FIRECRAWL_MAP_URLS = "FIRECRAWL_MAP_URLS"
    FIRECRAWL_EXTRACT_DATA = "FIRECRAWL_EXTRACT_DATA"
    FIRECRAWL_SEARCH_WEB = "FIRECRAWL_SEARCH_WEB"

    # Serpapi actions
    SERPAPI_BAIDU_SEARCH = "SERPAPI_BAIDU_SEARCH"
    SERPAPI_BING_SEARCH = "SERPAPI_BING_SEARCH"
    SERPAPI_EBAY_SEARCH = "SERPAPI_EBAY_SEARCH"
    SERPAPI_GOOGLE_DOMAINS_LIST = "SERPAPI_GOOGLE_DOMAINS_LIST"
    SERPAPI_GOOGLE_JOBS_SEARCH = "SERPAPI_GOOGLE_JOBS_SEARCH"
    SERPAPI_GOOGLE_LIGHT_SEARCH = "SERPAPI_GOOGLE_LIGHT_SEARCH"
    SERPAPI_HOTEL_SEARCH = "SERPAPI_HOTEL_SEARCH"
    SERPAPI_LIST_LOCATIONS = "SERPAPI_LIST_LOCATIONS"
    SERPAPI_GOOGLE_PLAY_SEARCH = "SERPAPI_GOOGLE_PLAY_SEARCH"
    SERPAPI_WALMART_SEARCH = "SERPAPI_WALMART_SEARCH"
    SERPAPI_YAHOO_SEARCH = "SERPAPI_YAHOO_SEARCH"
    SERPAPI_YANDEX_SEARCH = "SERPAPI_YANDEX_SEARCH"
    SERPAPI_YOUTUBE_SEARCH = "SERPAPI_YOUTUBE_SEARCH"
    SERPAPI_DUCKDUCKGO_SEARCH = "SERPAPI_DUCKDUCKGO_SEARCH"
    SERPAPI_GOOGLE_EVENTS_SEARCH = "SERPAPI_GOOGLE_EVENTS_SEARCH"
    SERPAPI_GOOGLE_FINANCE_SEARCH = "SERPAPI_GOOGLE_FINANCE_SEARCH"
    SERPAPI_GOOGLE_MAPS_SEARCH = "SERPAPI_GOOGLE_MAPS_SEARCH"
    SERPAPI_GOOGLE_IMAGES_SEARCH = "SERPAPI_GOOGLE_IMAGES_SEARCH"
    SERPAPI_GOOGLE_NEWS_SEARCH = "SERPAPI_GOOGLE_NEWS_SEARCH"
    SERPAPI_GOOGLE_SCHOLAR_SEARCH = "SERPAPI_GOOGLE_SCHOLAR_SEARCH"
    SERPAPI_GOOGLE_SEARCH = "SERPAPI_GOOGLE_SEARCH"
    SERPAPI_GOOGLE_SHOPPING_SEARCH = "SERPAPI_GOOGLE_SHOPPING_SEARCH"
    SERPAPI_GOOGLE_TRENDS_SEARCH = "SERPAPI_GOOGLE_TRENDS_SEARCH"

    # Notion actions
    NOTION_CREATE_COMMENT = "NOTION_CREATE_COMMENT"
    NOTION_ADD_MULTIPLE_CONTENT_BLOCKS = "NOTION_ADD_MULTIPLE_CONTENT_BLOCKS"
    NOTION_DELETE_BLOCK = "NOTION_DELETE_BLOCK"
    NOTION_FETCH_BLOCK_CHILDREN = "NOTION_FETCH_BLOCK_CHILDREN"
    NOTION_FETCH_COMMENTS = "NOTION_FETCH_COMMENTS"
    NOTION_CREATE_DATABASE = "NOTION_CREATE_DATABASE"
    NOTION_CREATE_PAGE = "NOTION_CREATE_PAGE"
    NOTION_FETCH_DATABASE = "NOTION_FETCH_DATABASE"
    NOTION_FETCH_DATABASE_ROW = "NOTION_FETCH_DATABASE_ROW"
    NOTION_INSERT_DATABASE_ROW = "NOTION_INSERT_DATABASE_ROW"
    NOTION_QUERY_DATABASE = "NOTION_QUERY_DATABASE"
    NOTION_RETRIEVE_DATABASE_PROPERTY = "NOTION_RETRIEVE_DATABASE_PROPERTY"
    NOTION_GET_ABOUT_ME = "NOTION_GET_ABOUT_ME"
    NOTION_GET_ABOUT_USER = "NOTION_GET_ABOUT_USER"
    NOTION_LIST_USERS = "NOTION_LIST_USERS"
    NOTION_RETRIEVE_COMMENT = "NOTION_RETRIEVE_COMMENT"
    NOTION_UPDATE_DATABASE_SCHEMA = "NOTION_UPDATE_DATABASE_SCHEMA"
    NOTION_UPDATE_ROW_DATABASE = "NOTION_UPDATE_ROW_DATABASE"
    NOTION_SEARCH_NOTION_PAGE = "NOTION_SEARCH_NOTION_PAGE"
    NOTION_UPDATE_PAGE = "NOTION_UPDATE_PAGE"
    NOTION_ADD_CONTENT_TO_NOTION_PAGE = "NOTION_ADD_CONTENT_TO_NOTION_PAGE"
    NOTION_APPEND_COMPLEX_BLOCKS = "NOTION_APPEND_COMPLEX_BLOCKS"
    NOTION_DUPLICATE_PAGE = "NOTION_DUPLICATE_PAGE"
    NOTION_FETCH_NOTION_BLOCK_METADATA = "NOTION_FETCH_NOTION_BLOCK_METADATA"
    NOTION_UPDATE_BLOCK = "NOTION_UPDATE_BLOCK"
    NOTION_FETCH_NOTION_DATA = "NOTION_FETCH_NOTION_DATA"
    NOTION_GET_PAGE_PROPERTY = "NOTION_GET_PAGE_PROPERTY"

    # Airtable actions
    AIRTABLE_LIST_BASES = "AIRTABLE_LIST_BASES"
    AIRTABLE_CREATE_BASE = "AIRTABLE_CREATE_BASE"
    AIRTABLE_GET_BASE_SCHEMA = "AIRTABLE_GET_BASE_SCHEMA"
    AIRTABLE_CREATE_TABLE = "AIRTABLE_CREATE_TABLE"
    AIRTABLE_CREATE_FIELD = "AIRTABLE_CREATE_FIELD"
    AIRTABLE_CREATE_RECORD = "AIRTABLE_CREATE_RECORD"
    AIRTABLE_CREATE_MULTIPLE_RECORDS = "AIRTABLE_CREATE_MULTIPLE_RECORDS"
    AIRTABLE_GET_RECORD = "AIRTABLE_GET_RECORD"
    AIRTABLE_LIST_RECORDS = "AIRTABLE_LIST_RECORDS"
    AIRTABLE_UPDATE_RECORD = "AIRTABLE_UPDATE_RECORD"
    AIRTABLE_UPDATE_MULTIPLE_RECORDS = "AIRTABLE_UPDATE_MULTIPLE_RECORDS"
    AIRTABLE_DELETE_RECORD = "AIRTABLE_DELETE_RECORD"
    AIRTABLE_DELETE_MULTIPLE_RECORDS = "AIRTABLE_DELETE_MULTIPLE_RECORDS"
    AIRTABLE_CREATE_COMMENT = "AIRTABLE_CREATE_COMMENT"
    AIRTABLE_DELETE_COMMENT = "AIRTABLE_DELETE_COMMENT"
    AIRTABLE_LIST_COMMENTS = "AIRTABLE_LIST_COMMENTS"
    AIRTABLE_GET_USER_INFORMATION = "AIRTABLE_GET_USER_INFORMATION"

    # Github actions
    GITHUB_ADD_ASSIGNEES_TO_ISSUE = "GITHUB_ADD_ASSIGNEES_TO_ISSUE"
    GITHUB_ADD_REPOSITORY_COLLABORATOR = "GITHUB_ADD_REPOSITORY_COLLABORATOR"
    GITHUB_ADD_LABELS_TO_ISSUE = "GITHUB_ADD_LABELS_TO_ISSUE"
    GITHUB_CREATE_ISSUE = "GITHUB_CREATE_ISSUE"
    GITHUB_CREATE_ISSUE_COMMENT = "GITHUB_CREATE_ISSUE_COMMENT"
    GITHUB_CREATE_PULL_REQUEST = "GITHUB_CREATE_PULL_REQUEST"
    GITHUB_CREATE_REPOSITORY = "GITHUB_CREATE_REPOSITORY"
    GITHUB_CREATE_OR_UPDATE_FILE = "GITHUB_CREATE_OR_UPDATE_FILE"
    GITHUB_GET_PULL_REQUEST = "GITHUB_GET_PULL_REQUEST"
    GITHUB_LIST_REPOSITORY_ISSUES = "GITHUB_LIST_REPOSITORY_ISSUES"
    GITHUB_STAR_REPOSITORY = "GITHUB_STAR_REPOSITORY"
    GITHUB_DELETE_REPOSITORY = "GITHUB_DELETE_REPOSITORY"
    GITHUB_LIST_REPOSITORIES_STARRED_BY_AUTHENTICATED_USER = "GITHUB_LIST_REPOSITORIES_STARRED_BY_AUTHENTICATED_USER"
    GITHUB_LIST_STARGAZERS = "GITHUB_LIST_STARGAZERS"
    GITHUB_STAR_REPOSITORY_FOR_AUTHENTICATED_USER = "GITHUB_STAR_REPOSITORY_FOR_AUTHENTICATED_USER"
    GITHUB_CHECK_IF_REPOSITORY_IS_STARRED_BY_AUTHENTICATED_USER = "GITHUB_CHECK_IF_REPOSITORY_IS_STARRED_BY_AUTHENTICATED_USER"
    GITHUB_CHECK_IF_GIST_IS_STARRED = "GITHUB_CHECK_IF_GIST_IS_STARRED"
    GITHUB_BLOCK_USER = "GITHUB_BLOCK_USER"
    GITHUB_CHECK_IF_USER_BLOCKED_BY_AUTHENTICATED_USER = "GITHUB_CHECK_IF_USER_BLOCKED_BY_AUTHENTICATED_USER"
    GITHUB_CHECK_PRIVATE_VULNERABILITY_REPORTING_STATUS = "GITHUB_CHECK_PRIVATE_VULNERABILITY_REPORTING_STATUS"
    GITHUB_CHECK_TEAM_PERMISSIONS_FOR_PROJECT = "GITHUB_CHECK_TEAM_PERMISSIONS_FOR_PROJECT"
    GITHUB_CHECK_TEAM_PERMISSIONS_FOR_REPOSITORY = "GITHUB_CHECK_TEAM_PERMISSIONS_FOR_REPOSITORY"
    GITHUB_CLEAR_REPOSITORY_CACHE_BY_KEY = "GITHUB_CLEAR_REPOSITORY_CACHE_BY_KEY"
    GITHUB_CLEAR_SELF_HOSTED_RUNNER_ORG_LABELS = "GITHUB_CLEAR_SELF_HOSTED_RUNNER_ORG_LABELS"
    GITHUB_CONFIGURE_JIT_RUNNER_FOR_ORG = "GITHUB_CONFIGURE_JIT_RUNNER_FOR_ORG"
    GITHUB_CONFIGURE_OIDC_SUBJECT_CLAIM_TEMPLATE = "GITHUB_CONFIGURE_OIDC_SUBJECT_CLAIM_TEMPLATE"
    GITHUB_CONVERT_ORG_MEMBER_TO_OUTSIDE_COLLABORATOR = "GITHUB_CONVERT_ORG_MEMBER_TO_OUTSIDE_COLLABORATOR"
    GITHUB_CREATE_AUTOLINK_REFERENCE_FOR_REPOSITORY = "GITHUB_CREATE_AUTOLINK_REFERENCE_FOR_REPOSITORY"
    GITHUB_CREATE_ENVIRONMENT_VARIABLE = "GITHUB_CREATE_ENVIRONMENT_VARIABLE"
    GITHUB_CREATE_ORGANIZATION_PROJECT = "GITHUB_CREATE_ORGANIZATION_PROJECT"
    GITHUB_CREATE_ORGANIZATION_VARIABLE = "GITHUB_CREATE_ORGANIZATION_VARIABLE"
    GITHUB_DELETE_DEPLOYMENT_BRANCH_POLICY = "GITHUB_DELETE_DEPLOYMENT_BRANCH_POLICY"
    GITHUB_DELETE_DEPLOY_KEY = "GITHUB_DELETE_DEPLOY_KEY"
    GITHUB_DELETE_DISCUSSION = "GITHUB_DELETE_DISCUSSION"
    GITHUB_DELETE_DISCUSSION_COMMENT = "GITHUB_DELETE_DISCUSSION_COMMENT"
    GITHUB_DELETE_FILE = "GITHUB_DELETE_FILE"
    GITHUB_DELETE_GIST = "GITHUB_DELETE_GIST"
    GITHUB_DELETE_GIST_COMMENT = "GITHUB_DELETE_GIST_COMMENT"
    GITHUB_DELETE_GITHUB_PAGES_SITE = "GITHUB_DELETE_GITHUB_PAGES_SITE"
    GITHUB_DELETE_LABEL = "GITHUB_DELETE_LABEL"
    GITHUB_DELETE_MILESTONE = "GITHUB_DELETE_MILESTONE"
    GITHUB_DELETE_PACKAGE_FOR_ORGANIZATION = "GITHUB_DELETE_PACKAGE_FOR_ORGANIZATION"
    GITHUB_DELETE_PACKAGE_FOR_USER = "GITHUB_DELETE_PACKAGE_FOR_USER"
    GITHUB_DELETE_PACKAGE_FOR_AUTHENTICATED_USER = "GITHUB_DELETE_PACKAGE_FOR_AUTHENTICATED_USER"
    GITHUB_DELETE_PACKAGE_VERSION_FOR_AUTHENTICATED_USER = "GITHUB_DELETE_PACKAGE_VERSION_FOR_AUTHENTICATED_USER"
    GITHUB_DELETE_PENDING_REVIEW_FOR_PULL_REQUEST = "GITHUB_DELETE_PENDING_REVIEW_FOR_PULL_REQUEST"
    GITHUB_DELETE_PROJECT = "GITHUB_DELETE_PROJECT"
    GITHUB_DELETE_PROJECT_CARD = "GITHUB_DELETE_PROJECT_CARD"
    GITHUB_DELETE_PROJECT_COLUMN = "GITHUB_DELETE_PROJECT_COLUMN"
    GITHUB_DELETE_PULL_REQUEST_COMMENT_REACTION = "GITHUB_DELETE_PULL_REQUEST_COMMENT_REACTION"
    GITHUB_DELETE_REFERENCE = "GITHUB_DELETE_REFERENCE"
    GITHUB_DELETE_RELEASE = "GITHUB_DELETE_RELEASE"
    GITHUB_DELETE_RELEASE_ASSET = "GITHUB_DELETE_RELEASE_ASSET"
    GITHUB_DELETE_RELEASE_REACTION = "GITHUB_DELETE_RELEASE_REACTION"
    GITHUB_DELETE_REPOSITORY_INVITATION = "GITHUB_DELETE_REPOSITORY_INVITATION"
    GITHUB_DELETE_REPOSITORY_RULESET = "GITHUB_DELETE_REPOSITORY_RULESET"
    GITHUB_DELETE_REPOSITORY_SECRET = "GITHUB_DELETE_REPOSITORY_SECRET"
    GITHUB_DELETE_REPOSITORY_SUBSCRIPTION = "GITHUB_DELETE_REPOSITORY_SUBSCRIPTION"
    GITHUB_DELETE_REPOSITORY_VARIABLE = "GITHUB_DELETE_REPOSITORY_VARIABLE"
    GITHUB_DELETE_REVIEW_COMMENT_FOR_PULL_REQUEST = "GITHUB_DELETE_REVIEW_COMMENT_FOR_PULL_REQUEST"
    GITHUB_DELETE_SECRET_FOR_AUTHENTICATED_USER = "GITHUB_DELETE_SECRET_FOR_AUTHENTICATED_USER"
    GITHUB_DELETE_SELF_HOSTED_RUNNER_FROM_ORGANIZATION = "GITHUB_DELETE_SELF_HOSTED_RUNNER_FROM_ORGANIZATION"
    GITHUB_DELETE_SELF_HOSTED_RUNNER_FROM_REPOSITORY = "GITHUB_DELETE_SELF_HOSTED_RUNNER_FROM_REPOSITORY"
    GITHUB_DELETE_TAG_PROTECTION_FOR_REPOSITORY = "GITHUB_DELETE_TAG_PROTECTION_FOR_REPOSITORY"
    GITHUB_DELETE_TEAM = "GITHUB_DELETE_TEAM"
    GITHUB_DELETE_THREAD_SUBSCRIPTION = "GITHUB_DELETE_THREAD_SUBSCRIPTION"
    GITHUB_DELETE_WORKFLOW_RUN = "GITHUB_DELETE_WORKFLOW_RUN"
    GITHUB_ENABLE_WORKFLOW = "GITHUB_ENABLE_WORKFLOW"
    GITHUB_ENABLE_GITHUB_ACTIONS_SELECTED_REPOSITORIES = "GITHUB_ENABLE_GITHUB_ACTIONS_SELECTED_REPOSITORIES"
    GITHUB_ENABLE_PRIVATE_VULNERABILITY_REPORTING = "GITHUB_ENABLE_PRIVATE_VULNERABILITY_REPORTING"
    GITHUB_ENABLE_REPOSITORY_ACTIONS = "GITHUB_ENABLE_REPOSITORY_ACTIONS"
    GITHUB_EXPORT_CODESPACE_FOR_AUTHENTICATED_USER = "GITHUB_EXPORT_CODESPACE_FOR_AUTHENTICATED_USER"
    GITHUB_EXPORT_REPOSITORY_SBOM = "GITHUB_EXPORT_REPOSITORY_SBOM"
    GITHUB_FOLLOW_USER = "GITHUB_FOLLOW_USER"
    GITHUB_FORCE_CANCEL_WORKFLOW_RUN = "GITHUB_FORCE_CANCEL_WORKFLOW_RUN"
    GITHUB_FORK_GIST = "GITHUB_FORK_GIST"
    GITHUB_GENERATE_RELEASE_NOTES = "GITHUB_GENERATE_RELEASE_NOTES"
    GITHUB_GET_ACCESS_RESTRICTIONS = "GITHUB_GET_ACCESS_RESTRICTIONS"
    GITHUB_GET_ADMIN_BRANCH_PROTECTION = "GITHUB_GET_ADMIN_BRANCH_PROTECTION"
    GITHUB_GET_ALL_API_VERSIONS = "GITHUB_GET_ALL_API_VERSIONS"
    GITHUB_GET_ALL_AUTOLINKS_OF_REPOSITORY = "GITHUB_GET_ALL_AUTOLINKS_OF_REPOSITORY"
    GITHUB_GET_ALL_CODES_OF_CONDUCT = "GITHUB_GET_ALL_CODES_OF_CONDUCT"
    GITHUB_GET_ALL_LICENSES = "GITHUB_GET_ALL_LICENSES"
    GITHUB_GET_ALL_CONTRIBUTOR_COMMIT_ACTIVITY = "GITHUB_GET_ALL_CONTRIBUTOR_COMMIT_ACTIVITY"
    GITHUB_GET_ALL_CUSTOM_PROPERTIES_FOR_ORGANIZATION = "GITHUB_GET_ALL_CUSTOM_PROPERTIES_FOR_ORGANIZATION"
    GITHUB_GET_ALL_CUSTOM_PROPERTY_VALUES_FOR_REPOSITORY = "GITHUB_GET_ALL_CUSTOM_PROPERTY_VALUES_FOR_REPOSITORY"
    GITHUB_GET_ALL_DEPLOYMENT_PROTECTION_RULES = "GITHUB_GET_ALL_DEPLOYMENT_PROTECTION_RULES"
    GITHUB_GET_ALL_GITIGNORE_TEMPLATES = "GITHUB_GET_ALL_GITIGNORE_TEMPLATES"
    GITHUB_GET_ALL_ORGANIZATION_ROLES = "GITHUB_GET_ALL_ORGANIZATION_ROLES"
    GITHUB_GET_ALL_REPOSITORY_RULESETS = "GITHUB_GET_ALL_REPOSITORY_RULESETS"
    GITHUB_GET_ALL_REPOSITORY_TOPICS = "GITHUB_GET_ALL_REPOSITORY_TOPICS"
    GITHUB_GET_ALL_REQUESTED_REVIEWERS_FOR_PULL_REQUEST = "GITHUB_GET_ALL_REQUESTED_REVIEWERS_FOR_PULL_REQUEST"
    GITHUB_GET_ALL_STATUS_CHECK_CONTEXTS = "GITHUB_GET_ALL_STATUS_CHECK_CONTEXTS"
    GITHUB_GET_APP = "GITHUB_GET_APP"
    GITHUB_GET_ARTIFACT = "GITHUB_GET_ARTIFACT"
    GITHUB_GET_ASSIGNMENT = "GITHUB_GET_ASSIGNMENT"
    GITHUB_GET_AUTOLINK_REFERENCE_OF_REPOSITORY = "GITHUB_GET_AUTOLINK_REFERENCE_OF_REPOSITORY"
    GITHUB_GET_ENVIRONMENT = "GITHUB_GET_ENVIRONMENT"
    GITHUB_GET_ENVIRONMENT_PUBLIC_KEY = "GITHUB_GET_ENVIRONMENT_PUBLIC_KEY"
    GITHUB_GET_ENVIRONMENT_SECRET = "GITHUB_GET_ENVIRONMENT_SECRET"
    GITHUB_GET_ENVIRONMENT_VARIABLE = "GITHUB_GET_ENVIRONMENT_VARIABLE"
    GITHUB_GET_ISSUE = "GITHUB_GET_ISSUE"
    GITHUB_GET_ISSUE_COMMENT = "GITHUB_GET_ISSUE_COMMENT"
    GITHUB_GET_ISSUE_EVENT = "GITHUB_GET_ISSUE_EVENT"
    GITHUB_GET_ORGANIZATION = "GITHUB_GET_ORGANIZATION"
    GITHUB_GET_ORGANIZATION_PUBLIC_KEY = "GITHUB_GET_ORGANIZATION_PUBLIC_KEY"
    GITHUB_GET_ORGANIZATION_ROLE = "GITHUB_GET_ORGANIZATION_ROLE"
    GITHUB_GET_ORGANIZATION_SECRET = "GITHUB_GET_ORGANIZATION_SECRET"
    GITHUB_GET_ORGANIZATION_VARIABLE = "GITHUB_GET_ORGANIZATION_VARIABLE"
    GITHUB_GET_APPS_WITH_ACCESS_TO_PROTECTED_BRANCH = "GITHUB_GET_APPS_WITH_ACCESS_TO_PROTECTED_BRANCH"
    GITHUB_GET_ASSIGNMENT_GRADES = "GITHUB_GET_ASSIGNMENT_GRADES"
    GITHUB_GET_BLOB = "GITHUB_GET_BLOB"
    GITHUB_GET_BRANCH = "GITHUB_GET_BRANCH"
    GITHUB_GET_CHECK_RUN = "GITHUB_GET_CHECK_RUN"
    GITHUB_DELETE_BRANCH_PROTECTION = "GITHUB_DELETE_BRANCH_PROTECTION"
    GITHUB_DELETE_COMMIT_SIGNATURE_PROTECTION = "GITHUB_DELETE_COMMIT_SIGNATURE_PROTECTION"
    GITHUB_DELETE_DEPENDABOT_SECRET = "GITHUB_DELETE_DEPENDABOT_SECRET"
    GITHUB_DELETE_ACTIONS_CACHE = "GITHUB_DELETE_ACTIONS_CACHE"
    GITHUB_DELETE_PACKAGE_VERSION_FOR_ORGANIZATION = "GITHUB_DELETE_PACKAGE_VERSION_FOR_ORGANIZATION"
    GITHUB_DELETE_PACKAGE_VERSION_FOR_USER = "GITHUB_DELETE_PACKAGE_VERSION_FOR_USER"
    GITHUB_DELETE_PULL_REQUEST_REVIEW_PROTECTION = "GITHUB_DELETE_PULL_REQUEST_REVIEW_PROTECTION"
    GITHUB_DELETE_CODESPACE_SECRET = "GITHUB_DELETE_CODESPACE_SECRET"
    GITHUB_DELETE_SOCIAL_ACCOUNTS_FOR_AUTHENTICATED_USER = "GITHUB_DELETE_SOCIAL_ACCOUNTS_FOR_AUTHENTICATED_USER"
    GITHUB_DELETE_TEAM_DISCUSSION_COMMENT_REACTION = "GITHUB_DELETE_TEAM_DISCUSSION_COMMENT_REACTION"
    GITHUB_DELETE_TEAM_DISCUSSION_REACTION = "GITHUB_DELETE_TEAM_DISCUSSION_REACTION"
    GITHUB_DELETE_WORKFLOW_RUN_LOGS = "GITHUB_DELETE_WORKFLOW_RUN_LOGS"
    GITHUB_DISABLE_CUSTOM_PROTECTION_RULE_FOR_ENVIRONMENT = "GITHUB_DISABLE_CUSTOM_PROTECTION_RULE_FOR_ENVIRONMENT"
    GITHUB_DISABLE_WORKFLOW = "GITHUB_DISABLE_WORKFLOW"
    GITHUB_DISABLE_PRIVATE_VULNERABILITY_REPORTING = "GITHUB_DISABLE_PRIVATE_VULNERABILITY_REPORTING"
    GITHUB_DISABLE_REPOSITORY_ACTIONS_IN_ORGANIZATION = "GITHUB_DISABLE_REPOSITORY_ACTIONS_IN_ORGANIZATION"
    GITHUB_DISMISS_PULL_REQUEST_REVIEW = "GITHUB_DISMISS_PULL_REQUEST_REVIEW"
    GITHUB_DOWNLOAD_ARTIFACT = "GITHUB_DOWNLOAD_ARTIFACT"
    GITHUB_DOWNLOAD_REPOSITORY_TARBALL = "GITHUB_DOWNLOAD_REPOSITORY_TARBALL"
    GITHUB_DOWNLOAD_REPOSITORY_ZIPBALL = "GITHUB_DOWNLOAD_REPOSITORY_ZIPBALL"
    GITHUB_DOWNLOAD_JOB_LOGS_FOR_WORKFLOW_RUN = "GITHUB_DOWNLOAD_JOB_LOGS_FOR_WORKFLOW_RUN"
    GITHUB_DOWNLOAD_WORKFLOW_RUN_ATTEMPT_LOGS = "GITHUB_DOWNLOAD_WORKFLOW_RUN_ATTEMPT_LOGS"
    GITHUB_DOWNLOAD_WORKFLOW_RUN_LOGS = "GITHUB_DOWNLOAD_WORKFLOW_RUN_LOGS"
    GITHUB_GET_ME = "GITHUB_GET_ME"
    GITHUB_SEARCH_ISSUES = "GITHUB_SEARCH_ISSUES"
    GITHUB_LIST_ISSUES = "GITHUB_LIST_ISSUES"
    GITHUB_ADD_ISSUE_COMMENT = "GITHUB_ADD_ISSUE_COMMENT"
    GITHUB_UPDATE_ISSUE = "GITHUB_UPDATE_ISSUE"
    GITHUB_LIST_PULL_REQUESTS = "GITHUB_LIST_PULL_REQUESTS"
    GITHUB_GET_PULL_REQUEST_FILES = "GITHUB_GET_PULL_REQUEST_FILES"
    GITHUB_GET_PULL_REQUEST_COMMENTS = "GITHUB_GET_PULL_REQUEST_COMMENTS"
    GITHUB_GET_PULL_REQUEST_REVIEWS = "GITHUB_GET_PULL_REQUEST_REVIEWS"
    GITHUB_MERGE_PULL_REQUEST = "GITHUB_MERGE_PULL_REQUEST"
    GITHUB_UPDATE_PULL_REQUEST_BRANCH = "GITHUB_UPDATE_PULL_REQUEST_BRANCH"
    GITHUB_CREATE_PULL_REQUEST_REVIEW = "GITHUB_CREATE_PULL_REQUEST_REVIEW"
    GITHUB_UPDATE_PULL_REQUEST = "GITHUB_UPDATE_PULL_REQUEST"
    GITHUB_SEARCH_REPOSITORIES = "GITHUB_SEARCH_REPOSITORIES"
    GITHUB_GET_FILE_CONTENTS = "GITHUB_GET_FILE_CONTENTS"
    GITHUB_LIST_COMMITS = "GITHUB_LIST_COMMITS"
    GITHUB_FORK_REPOSITORY = "GITHUB_FORK_REPOSITORY"
    GITHUB_CREATE_BRANCH = "GITHUB_CREATE_BRANCH"
    GITHUB_SEARCH_CODE = "GITHUB_SEARCH_CODE"
    GITHUB_SEARCH_USERS = "GITHUB_SEARCH_USERS"
    GITHUB_GET_COMMIT = "GITHUB_GET_COMMIT"

    # Slack actions
    SLACK_SEND_MESSAGE = "SLACK_SEND_MESSAGE"
    SLACK_UPDATE_MESSAGE = "SLACK_UPDATE_MESSAGE"
    SLACK_SCHEDULE_MESSAGE = "SLACK_SCHEDULE_MESSAGE"
    SLACK_FETCH_CONVERSATION_HISTORY = "SLACK_FETCH_CONVERSATION_HISTORY"
    SLACK_SEARCH_MESSAGES = "SLACK_SEARCH_MESSAGES"
    SLACK_CREATE_CHANNEL = "SLACK_CREATE_CHANNEL"
    SLACK_ARCHIVE_CHANNEL = "SLACK_ARCHIVE_CHANNEL"
    SLACK_FIND_CHANNELS = "SLACK_FIND_CHANNELS"
    SLACK_FIND_USERS = "SLACK_FIND_USERS"
    SLACK_ADD_STAR = "SLACK_ADD_STAR"
    SLACK_ADD_EMOJI = "SLACK_ADD_EMOJI"
    SLACK_CREATE_USER_GROUP = "SLACK_CREATE_USER_GROUP"
    SLACK_ADD_REMOTE_FILE = "SLACK_ADD_REMOTE_FILE"
    SLACK_DELETE_MESSAGE = "SLACK_DELETE_MESSAGE"
    SLACK_UNARCHIVE_CHANNEL = "SLACK_UNARCHIVE_CHANNEL"
    SLACK_RENAME_CHANNEL = "SLACK_RENAME_CHANNEL"
    SLACK_SET_CHANNEL_PURPOSE = "SLACK_SET_CHANNEL_PURPOSE"
    SLACK_SET_CHANNEL_TOPIC = "SLACK_SET_CHANNEL_TOPIC"
    SLACK_GET_CHANNEL_INFO = "SLACK_GET_CHANNEL_INFO"
    SLACK_LIST_CHANNELS = "SLACK_LIST_CHANNELS"
    SLACK_GET_CHANNEL_HISTORY = "SLACK_GET_CHANNEL_HISTORY"
    SLACK_KICK_USER_FROM_CHANNEL = "SLACK_KICK_USER_FROM_CHANNEL"
    SLACK_JOIN_CHANNEL = "SLACK_JOIN_CHANNEL"
    SLACK_LEAVE_CHANNEL = "SLACK_LEAVE_CHANNEL"
    SLACK_LIST_USERS = "SLACK_LIST_USERS"
    SLACK_LOOKUP_USER_BY_EMAIL = "SLACK_LOOKUP_USER_BY_EMAIL"
    SLACK_SET_USER_PRESENCE = "SLACK_SET_USER_PRESENCE"
    SLACK_ADD_REACTION = "SLACK_ADD_REACTION"
    SLACK_REMOVE_REACTION = "SLACK_REMOVE_REACTION"
    SLACK_GET_REACTIONS = "SLACK_GET_REACTIONS"
    SLACK_GET_CONVERSATION_REPLIES = "SLACK_GET_CONVERSATION_REPLIES"
    SLACK_PIN_MESSAGE = "SLACK_PIN_MESSAGE"
    SLACK_UNPIN_MESSAGE = "SLACK_UNPIN_MESSAGE"
    SLACK_LIST_PINS = "SLACK_LIST_PINS"
    SLACK_CREATE_REMINDER = "SLACK_CREATE_REMINDER"
    SLACK_DELETE_REMINDER = "SLACK_DELETE_REMINDER"
    SLACK_COMPLETE_REMINDER = "SLACK_COMPLETE_REMINDER"
    SLACK_LIST_REMINDERS = "SLACK_LIST_REMINDERS"
    SLACK_GET_REMINDER_INFO = "SLACK_GET_REMINDER_INFO"
    SLACK_GET_USER_IDENTITY = "SLACK_GET_USER_IDENTITY"
    SLACK_GET_CONVERSATION_INFO = "SLACK_GET_CONVERSATION_INFO"
    SLACK_GET_CONVERSATION_MEMBERS = "SLACK_GET_CONVERSATION_MEMBERS"
    SLACK_GET_USER_DND_STATUS = "SLACK_GET_USER_DND_STATUS"
    SLACK_GET_FILE_INFO = "SLACK_GET_FILE_INFO"
    SLACK_GET_USER_INFO = "SLACK_GET_USER_INFO"
    SLACK_GET_MESSAGE_PERMALINK = "SLACK_GET_MESSAGE_PERMALINK"
    SLACK_GET_TEAM_PROFILE = "SLACK_GET_TEAM_PROFILE"
    SLACK_GET_USER_PROFILE = "SLACK_GET_USER_PROFILE"
    SLACK_REVOKE_FILE_PUBLIC_URL = "SLACK_REVOKE_FILE_PUBLIC_URL"
    SLACK_SEND_EPHEMERAL_MESSAGE = "SLACK_SEND_EPHEMERAL_MESSAGE"
    SLACK_SET_CONVERSATION_PURPOSE = "SLACK_SET_CONVERSATION_PURPOSE"
    SLACK_SET_DND_DURATION = "SLACK_SET_DND_DURATION"
    SLACK_MARK_CONVERSATION_READ = "SLACK_MARK_CONVERSATION_READ"
    SLACK_SET_USER_PROFILE = "SLACK_SET_USER_PROFILE"
    SLACK_SET_CONVERSATION_TOPIC = "SLACK_SET_CONVERSATION_TOPIC"
    SLACK_SEND_ME_MESSAGE = "SLACK_SEND_ME_MESSAGE"
    SLACK_UPLOAD_FILE = "SLACK_UPLOAD_FILE"
    SLACK_GET_REMOTE_FILE = "SLACK_GET_REMOTE_FILE"
    SLACK_GET_TEAM_DND_STATUS = "SLACK_GET_TEAM_DND_STATUS"
    SLACK_GET_USER_PRESENCE = "SLACK_GET_USER_PRESENCE"
    SLACK_INVITE_USERS_TO_CHANNEL = "SLACK_INVITE_USERS_TO_CHANNEL"
    SLACK_JOIN_CONVERSATION = "SLACK_JOIN_CONVERSATION"
    SLACK_LEAVE_CONVERSATION = "SLACK_LEAVE_CONVERSATION"
    SLACK_LIST_PINNED_ITEMS = "SLACK_LIST_PINNED_ITEMS"
    SLACK_LIST_STARRED_ITEMS = "SLACK_LIST_STARRED_ITEMS"
    SLACK_LIST_CONVERSATIONS = "SLACK_LIST_CONVERSATIONS"
    SLACK_LIST_USERGROUP_USERS = "SLACK_LIST_USERGROUP_USERS"
    SLACK_LIST_FILES = "SLACK_LIST_FILES"
    SLACK_LIST_REMOTE_FILES = "SLACK_LIST_REMOTE_FILES"
    SLACK_LIST_SCHEDULED_MESSAGES = "SLACK_LIST_SCHEDULED_MESSAGES"
    SLACK_LIST_TEAM_EMOJIS = "SLACK_LIST_TEAM_EMOJIS"
    SLACK_LIST_USERGROUPS = "SLACK_LIST_USERGROUPS"
    SLACK_LIST_USER_REACTIONS = "SLACK_LIST_USER_REACTIONS"
    SLACK_OPEN_DM = "SLACK_OPEN_DM"
    SLACK_PIN_ITEM = "SLACK_PIN_ITEM"
    SLACK_REMOVE_REMOTE_FILE = "SLACK_REMOVE_REMOTE_FILE"
    SLACK_REMOVE_STAR = "SLACK_REMOVE_STAR"
    SLACK_REMOVE_USER_FROM_CONVERSATION = "SLACK_REMOVE_USER_FROM_CONVERSATION"
    SLACK_RENAME_EMOJI = "SLACK_RENAME_EMOJI"
    SLACK_RENAME_CONVERSATION = "SLACK_RENAME_CONVERSATION"

    # Brevo actions
    BREVO_CREATE_COMPANY = "CREATE_COMPANY"
    BREVO_CREATE_OR_UPDATE_EMAIL_TEMPLATE = "CREATE_OR_UPDATE_EMAIL_TEMPLATE"
    BREVO_CREATE_SMS_CAMPAIGN = "CREATE_SMS_CAMPAIGN"
    BREVO_DELETE_COMPANY = "DELETE_COMPANY"
    BREVO_DELETE_CONTACT = "DELETE_CONTACT"
    BREVO_DELETE_EMAIL_TEMPLATE = "DELETE_EMAIL_TEMPLATE"
    BREVO_DELETE_SMS_CAMPAIGN = "DELETE_SMS_CAMPAIGN"
    BREVO_FIND_CONTACT = "FIND_CONTACT"
    BREVO_GET_ACCOUNT_INFORMATION = "GET_ACCOUNT_INFORMATION"
    BREVO_GET_ALL_CONTACTS = "GET_ALL_CONTACTS"
    BREVO_GET_ALL_EMAIL_TEMPLATES = "GET_ALL_EMAIL_TEMPLATES"
    BREVO_GET_ALL_SENDERS = "GET_ALL_SENDERS"
    BREVO_GET_COMPANY_DETAILS = "GET_COMPANY_DETAILS"
    BREVO_GET_CONTACT_DETAILS = "GET_CONTACT_DETAILS"
    BREVO_GET_SMS_CAMPAIGNS = "GET_SMS_CAMPAIGNS"
    BREVO_GET_SMS_CAMPAIGN_DETAILS = "GET_SMS_CAMPAIGN_DETAILS"
    BREVO_LIST_ALL_COMPANIES = "LIST_ALL_COMPANIES"
    BREVO_LIST_EMAIL_CAMPAIGNS = "LIST_EMAIL_CAMPAIGNS"
    BREVO_UPDATE_EMAIL_CAMPAIGN = "UPDATE_EMAIL_CAMPAIGN"

    # Youtube actions
    YOUTUBE_LIST_CAPTIONS = "YOUTUBE_LIST_CAPTIONS"
    YOUTUBE_UPDATE_THUMBNAIL = "YOUTUBE_UPDATE_THUMBNAIL"
    YOUTUBE_GET_CHANNEL_ID_BY_HANDLE = "YOUTUBE_GET_CHANNEL_ID_BY_HANDLE"
    YOUTUBE_GET_CHANNEL_STATISTICS = "YOUTUBE_GET_CHANNEL_STATISTICS"
    YOUTUBE_LIST_CHANNEL_VIDEOS = "YOUTUBE_LIST_CHANNEL_VIDEOS"
    YOUTUBE_LIST_USER_PLAYLISTS = "YOUTUBE_LIST_USER_PLAYLISTS"
    YOUTUBE_LIST_USER_SUBSCRIPTIONS = "YOUTUBE_LIST_USER_SUBSCRIPTIONS"
    YOUTUBE_DOWNLOAD_CAPTION_TRACK = "YOUTUBE_DOWNLOAD_CAPTION_TRACK"
    YOUTUBE_SEARCH_YOUTUBE = "YOUTUBE_SEARCH_YOUTUBE"
    YOUTUBE_SUBSCRIBE_TO_CHANNEL = "YOUTUBE_SUBSCRIBE_TO_CHANNEL"
    YOUTUBE_UPDATE_VIDEO = "YOUTUBE_UPDATE_VIDEO"
    YOUTUBE_UPLOAD_VIDEO = "YOUTUBE_UPLOAD_VIDEO"
    YOUTUBE_GET_VIDEO_DETAILS = "YOUTUBE_GET_VIDEO_DETAILS"

    # Calendly actions
    CALENDLY_GET_USER = "CALENDLY_GET_USER"
    CALENDLY_GET_CURRENT_USER = "CALENDLY_GET_CURRENT_USER"
    CALENDLY_CANCEL_EVENT = "CALENDLY_CANCEL_EVENT"
    CALENDLY_GET_EVENT = "CALENDLY_GET_EVENT"
    CALENDLY_LIST_EVENTS = "CALENDLY_LIST_EVENTS"
    CALENDLY_GET_EVENT_TYPE = "CALENDLY_GET_EVENT_TYPE"
    CALENDLY_LIST_EVENT_TYPE_AVAILABLE_TIMES = "CALENDLY_LIST_EVENT_TYPE_AVAILABLE_TIMES"
    CALENDLY_CREATE_ONE_OFF_EVENT_TYPE = "CALENDLY_CREATE_ONE_OFF_EVENT_TYPE"
    CALENDLY_GET_EVENT_INVITEE = "CALENDLY_GET_EVENT_INVITEE"
    CALENDLY_LIST_EVENT_INVITEES = "CALENDLY_LIST_EVENT_INVITEES"
    CALENDLY_CREATE_INVITEE_NO_SHOW = "CALENDLY_CREATE_INVITEE_NO_SHOW"
    CALENDLY_GET_INVITEE_NO_SHOW = "CALENDLY_GET_INVITEE_NO_SHOW"
    CALENDLY_DELETE_INVITEE_NO_SHOW = "CALENDLY_DELETE_INVITEE_NO_SHOW"
    CALENDLY_CREATE_SCHEDULING_LINK = "CALENDLY_CREATE_SCHEDULING_LINK"
    CALENDLY_CREATE_SINGLE_USE_SCHEDULING_LINK = "CALENDLY_CREATE_SINGLE_USE_SCHEDULING_LINK"
    CALENDLY_CREATE_SHARE = "CALENDLY_CREATE_SHARE"
    CALENDLY_GET_USER_AVAILABILITY_SCHEDULE = "CALENDLY_GET_USER_AVAILABILITY_SCHEDULE"
    CALENDLY_CREATE_WEBHOOK_SUBSCRIPTION = "CALENDLY_CREATE_WEBHOOK_SUBSCRIPTION"
    CALENDLY_GET_WEBHOOK_SUBSCRIPTION = "CALENDLY_GET_WEBHOOK_SUBSCRIPTION"
    CALENDLY_DELETE_WEBHOOK_SUBSCRIPTION = "CALENDLY_DELETE_WEBHOOK_SUBSCRIPTION"
    CALENDLY_GET_ORGANIZATION_INVITATION = "CALENDLY_GET_ORGANIZATION_INVITATION"
    CALENDLY_INVITE_USER_TO_ORGANIZATION = "CALENDLY_INVITE_USER_TO_ORGANIZATION"
    CALENDLY_GET_ORGANIZATION_MEMBERSHIP = "CALENDLY_GET_ORGANIZATION_MEMBERSHIP"
    CALENDLY_GET_GROUP = "CALENDLY_GET_GROUP"
    CALENDLY_GET_GROUP_RELATIONSHIP = "CALENDLY_GET_GROUP_RELATIONSHIP"
    CALENDLY_GET_ROUTING_FORM = "CALENDLY_GET_ROUTING_FORM"
    CALENDLY_LIST_ACTIVITY_LOG_ENTRIES = "CALENDLY_LIST_ACTIVITY_LOG_ENTRIES"
    CALENDLY_DELETE_INVITEE_DATA = "CALENDLY_DELETE_INVITEE_DATA"
    CALENDLY_DELETE_SCHEDULED_EVENT_DATA = "CALENDLY_DELETE_SCHEDULED_EVENT_DATA"
    CALENDLY_LIST_EVENT_TYPE_HOSTS = "CALENDLY_LIST_EVENT_TYPE_HOSTS"
    CALENDLY_LIST_GROUPS = "CALENDLY_LIST_GROUPS"
    CALENDLY_LIST_GROUP_RELATIONSHIPS = "CALENDLY_LIST_GROUP_RELATIONSHIPS"
    CALENDLY_LIST_ORGANIZATION_INVITATIONS = "CALENDLY_LIST_ORGANIZATION_INVITATIONS"
    CALENDLY_LIST_ORGANIZATION_MEMBERSHIPS = "CALENDLY_LIST_ORGANIZATION_MEMBERSHIPS"
    CALENDLY_LIST_OUTGOING_COMMUNICATIONS = "CALENDLY_LIST_OUTGOING_COMMUNICATIONS"
    CALENDLY_LIST_ROUTING_FORMS = "CALENDLY_LIST_ROUTING_FORMS"
    CALENDLY_LIST_USER_AVAILABILITY_SCHEDULES = "CALENDLY_LIST_USER_AVAILABILITY_SCHEDULES"
    CALENDLY_LIST_USER_BUSY_TIMES = "CALENDLY_LIST_USER_BUSY_TIMES"
    CALENDLY_LIST_USER_EVENT_TYPES = "CALENDLY_LIST_USER_EVENT_TYPES"
    CALENDLY_LIST_WEBHOOK_SUBSCRIPTIONS = "CALENDLY_LIST_WEBHOOK_SUBSCRIPTIONS"
    CALENDLY_REMOVE_USER_FROM_ORGANIZATION = "CALENDLY_REMOVE_USER_FROM_ORGANIZATION"
    CALENDLY_REVOKE_ORGANIZATION_INVITATION = "CALENDLY_REVOKE_ORGANIZATION_INVITATION"

    # Agentql actions
    AGENTQL_QUERY_STRUCTURED_DATA = "AGENTQL_QUERY_STRUCTURED_DATA"

    # Apollo actions
    APOLLO_ADD_CONTACTS_TO_SEQUENCE = "add_contacts_to_sequence"
    APOLLO_BULK_ORGANIZATION_ENRICHMENT = "bulk_organization_enrichment"
    APOLLO_BULK_PEOPLE_ENRICHMENT = "bulk_people_enrichment"
    APOLLO_BULK_UPDATE_ACCOUNT_STAGE = "bulk_update_account_stage"
    APOLLO_GET_LABELS = "get_labels"
    APOLLO_GET_OPPORTUNITY_STAGES = "get_opportunity_stages"
    APOLLO_GET_ORGANIZATION_JOB_POSTINGS = "get_organization_job_postings"
    APOLLO_GET_TYPED_CUSTOM_FIELDS = "get_typed_custom_fields"
    APOLLO_LIST_EMAIL_ACCOUNTS = "list_email_accounts"
    APOLLO_PEOPLE_SEARCH = "apollo_people_search"
    APOLLO_SEARCH_TASKS = "search_tasks"
    APOLLO_UPDATE_CONTACT_OWNERSHIP = "update_contact_ownership"
    APOLLO_UPDATE_CONTACT_STAGE = "update_contact_stage"
    APOLLO_UPDATE_CONTACT_STATUS_IN_SEQUENCE = "update_contact_status_in_sequence"
    APOLLO_CREATE_ACCOUNT = "create_apollo_account"
    APOLLO_CREATE_CONTACT = "create_apollo_contact"
    APOLLO_CREATE_DEAL = "create_apollo_deal"
    APOLLO_CREATE_TASK = "create_apollo_task"
    APOLLO_LIST_ACCOUNT_STAGES = "list_apollo_account_stages"
    APOLLO_LIST_CONTACT_STAGES = "list_apollo_contact_stages"
    APOLLO_LIST_DEALS = "list_apollo_deals"
    APOLLO_LIST_USERS = "list_apollo_users"
    APOLLO_ENRICH_ORGANIZATION_DATA = "enrich_organization_data"
    APOLLO_SEARCH_ORGANIZATIONS = "search_organizations_in_apollo"
    APOLLO_ENRICH_PERSON = "enrich_person_with_apollo"
    APOLLO_SEARCH_ACCOUNTS = "search_apollo_accounts"
    APOLLO_SEARCH_CONTACTS = "search_apollo_contacts"
    APOLLO_UPDATE_ACCOUNT = "update_apollo_account"
    APOLLO_UPDATE_CONTACT = "update_apollo_contact"
    APOLLO_UPDATE_DEAL = "update_apollo_deal"

    # Bannerbear actions
    BANNERBEAR_GET_ACCOUNT_INFO = "BANNERBEAR_GET_ACCOUNT_INFO"
    BANNERBEAR_GET_AVAILABLE_FONTS = "BANNERBEAR_GET_AVAILABLE_FONTS"
    BANNERBEAR_GET_SIGNED_BASES = "BANNERBEAR_GET_SIGNED_BASES"
    BANNERBEAR_GET_TEMPLATE_SET_DETAILS = "BANNERBEAR_GET_TEMPLATE_SET_DETAILS"
    BANNERBEAR_JOIN_PDFS = "BANNERBEAR_JOIN_PDFS"
    BANNERBEAR_LIST_IMAGES = "BANNERBEAR_LIST_IMAGES"
    BANNERBEAR_LIST_TEMPLATES = "BANNERBEAR_LIST_TEMPLATES"
    BANNERBEAR_LIST_VIDEOS = "BANNERBEAR_LIST_VIDEOS"

    # Bitquery actions
    BITQUERY_COMBINED_DATABASE_QUERY = "BITQUERY_COMBINED_DATABASE_QUERY"
    BITQUERY_ALIASES_METRIC = "BITQUERY_ALIASES_METRIC"
    BITQUERY_ARCHIVE_DATABASE_QUERY = "BITQUERY_ARCHIVE_DATABASE_QUERY"
    BITQUERY_CONDITIONAL_METRICS_SNIPPET = "BITQUERY_CONDITIONAL_METRICS_SNIPPET"
    BITQUERY_COUNT_DISTINCT_METRIC = "BITQUERY_COUNT_DISTINCT_METRIC"
    BITQUERY_COUNT_METRIC = "BITQUERY_COUNT_METRIC"
    BITQUERY_DATABASE_SELECTION = "BITQUERY_DATABASE_SELECTION"
    BITQUERY_EARLY_ACCESS_PROGRAM_QUERY = "BITQUERY_EARLY_ACCESS_PROGRAM_QUERY"
    BITQUERY_MEMPOOL_SUBSCRIPTION = "BITQUERY_MEMPOOL_SUBSCRIPTION"
    BITQUERY_NETWORK_SELECTION = "BITQUERY_NETWORK_SELECTION"
    BITQUERY_OPTIONS_QUERY = "BITQUERY_OPTIONS_QUERY"
    BITQUERY_PRICE_ASYMMETRY_METRIC = "BITQUERY_PRICE_ASYMMETRY_METRIC"
    BITQUERY_QUANTILE_METRIC = "BITQUERY_QUANTILE_METRIC"
    BITQUERY_REALTIME_DATABASE_QUERY = "BITQUERY_REALTIME_DATABASE_QUERY"
    BITQUERY_SELECT_BY_METRIC = "BITQUERY_SELECT_BY_METRIC"
    BITQUERY_STATISTICS_METRIC = "BITQUERY_STATISTICS_METRIC"
    BITQUERY_SUM_METRIC = "BITQUERY_SUM_METRIC"
    BITQUERY_UNIQ_METRIC = "BITQUERY_UNIQ_METRIC"

    # Botsonic actions
    BOTSONIC_GET_ALL_BOTS = "BOTSONIC_GET_ALL_BOTS"
    BOTSONIC_GET_SPECIFIC_BOT = "BOTSONIC_GET_SPECIFIC_BOT"
    BOTSONIC_CREATE_BOT = "BOTSONIC_CREATE_BOT"
    BOTSONIC_UPDATE_BOT = "BOTSONIC_UPDATE_BOT"
    BOTSONIC_DELETE_BOT = "BOTSONIC_DELETE_BOT"
    BOTSONIC_GET_BOT_API_KEY = "BOTSONIC_GET_BOT_API_KEY"

    # Cal actions
    CAL_GET_BOOKING = "CAL_GET_BOOKING"
    CAL_GET_ALL_BOOKINGS = "CAL_GET_ALL_BOOKINGS"
    CAL_GET_ORGANIZATION_BOOKINGS = "CAL_GET_ORGANIZATION_BOOKINGS"
    CAL_GET_ORGANIZATION_TEAM_BOOKINGS = "CAL_GET_ORGANIZATION_TEAM_BOOKINGS"
    CAL_GET_ORGANIZATION_USER_BOOKINGS = "CAL_GET_ORGANIZATION_USER_BOOKINGS"
    CAL_CREATE_BOOKING = "CAL_CREATE_BOOKING"
    CAL_CONFIRM_BOOKING = "CAL_CONFIRM_BOOKING"
    CAL_CANCEL_BOOKING = "CAL_CANCEL_BOOKING"
    CAL_RESCHEDULE_BOOKING = "CAL_RESCHEDULE_BOOKING"
    CAL_REASSIGN_BOOKING_TO_HOST = "CAL_REASSIGN_BOOKING_TO_HOST"
    CAL_REASSIGN_BOOKING_AUTO = "CAL_REASSIGN_BOOKING_AUTO"
    CAL_MARK_BOOKING_ABSENT = "CAL_MARK_BOOKING_ABSENT"
    CAL_DECLINE_BOOKING = "CAL_DECLINE_BOOKING"
    CAL_GET_ADD_TO_CALENDAR_LINKS = "CAL_GET_ADD_TO_CALENDAR_LINKS"
    CAL_GET_EVENT_TYPE = "CAL_GET_EVENT_TYPE"
    CAL_GET_ALL_EVENT_TYPES = "CAL_GET_ALL_EVENT_TYPES"
    CAL_GET_TEAM_EVENT_TYPES = "CAL_GET_TEAM_EVENT_TYPES"
    CAL_GET_TEAM_EVENT_TYPE = "CAL_GET_TEAM_EVENT_TYPE"
    CAL_CREATE_EVENT_TYPE = "CAL_CREATE_EVENT_TYPE"
    CAL_FIND_AVAILABLE_SLOTS = "CAL_FIND_AVAILABLE_SLOTS"
    CAL_GET_MY_PROFILE = "CAL_GET_MY_PROFILE"
    CAL_GET_ALL_USERS = "CAL_GET_ALL_USERS"
    CAL_GET_MANAGED_USER = "CAL_GET_MANAGED_USER"
    CAL_GET_ALL_MANAGED_USERS = "CAL_GET_ALL_MANAGED_USERS"
    CAL_GET_MEMBERSHIP = "CAL_GET_MEMBERSHIP"
    CAL_GET_ALL_MEMBERSHIPS = "CAL_GET_ALL_MEMBERSHIPS"
    CAL_GET_USER_TEAM_MEMBERSHIPS = "CAL_GET_USER_TEAM_MEMBERSHIPS"
    CAL_CREATE_MEMBERSHIP = "CAL_CREATE_MEMBERSHIP"
    CAL_UPDATE_MEMBERSHIP = "CAL_UPDATE_MEMBERSHIP"
    CAL_DELETE_MEMBERSHIP = "CAL_DELETE_MEMBERSHIP"
    CAL_GET_MANAGED_ORGANIZATION = "CAL_GET_MANAGED_ORGANIZATION"
    CAL_GET_ALL_ORGANIZATIONS = "CAL_GET_ALL_ORGANIZATIONS"
    CAL_CREATE_SUB_ORGANIZATION = "CAL_CREATE_SUB_ORGANIZATION"
    CAL_GET_TEAMS = "CAL_GET_TEAMS"
    CAL_GET_TEAM = "CAL_GET_TEAM"
    CAL_GET_ALL_TEAMS = "CAL_GET_ALL_TEAMS"
    CAL_GET_ALL_TEAM_EVENT_TYPES = "CAL_GET_ALL_TEAM_EVENT_TYPES"
    CAL_GET_ORGANIZATION_ROUTING_FORMS = "CAL_GET_ORGANIZATION_ROUTING_FORMS"
    CAL_GET_TEAM_ROUTING_FORMS = "CAL_GET_TEAM_ROUTING_FORMS"
    CAL_GET_ORGANIZATION_TEAM_BOOKINGS_LEGACY = "CAL_GET_ORGANIZATION_TEAM_BOOKINGS_LEGACY"
    CAL_GET_CALENDAR_BUSY_TIMES = "CAL_GET_CALENDAR_BUSY_TIMES"
    CAL_CHECK_CALENDAR_CONNECTION = "CAL_CHECK_CALENDAR_CONNECTION"
    CAL_DISCONNECT_CALENDAR = "CAL_DISCONNECT_CALENDAR"
    CAL_SYNC_CALENDAR_CREDENTIALS = "CAL_SYNC_CALENDAR_CREDENTIALS"
    CAL_GET_ALL_CALENDARS = "CAL_GET_ALL_CALENDARS"
    CAL_GET_ALL_SCHEDULES = "CAL_GET_ALL_SCHEDULES"
    CAL_GET_SCHEDULE = "CAL_GET_SCHEDULE"
    CAL_GET_DEFAULT_SCHEDULE = "CAL_GET_DEFAULT_SCHEDULE"
    CAL_GET_TEAM_MEMBER_SCHEDULES = "CAL_GET_TEAM_MEMBER_SCHEDULES"
    CAL_GET_USER_OOO_ENTRIES = "CAL_GET_USER_OOO_ENTRIES"
    CAL_GET_ORG_USERS_OOO_ENTRIES = "CAL_GET_ORG_USERS_OOO_ENTRIES"
    CAL_CREATE_OOO_ENTRY = "CAL_CREATE_OOO_ENTRY"
    CAL_CHECK_TEAM_STRIPE_CONNECTION = "CAL_CHECK_TEAM_STRIPE_CONNECTION"
    CAL_CHECK_STRIPE_CONNECTION = "CAL_CHECK_STRIPE_CONNECTION"
    CAL_SAVE_TEAM_STRIPE_CREDENTIALS = "CAL_SAVE_TEAM_STRIPE_CREDENTIALS"
    CAL_SAVE_STRIPE_CREDENTIALS = "CAL_SAVE_STRIPE_CREDENTIALS"
    CAL_GET_TEAM_STRIPE_CONNECT_URL = "CAL_GET_TEAM_STRIPE_CONNECT_URL"
    CAL_GET_STRIPE_CONNECT_URL = "CAL_GET_STRIPE_CONNECT_URL"
    CAL_LIST_CONFERENCING_APPLICATIONS = "CAL_LIST_CONFERENCING_APPLICATIONS"
    CAL_LIST_TEAM_CONFERENCING_APPLICATIONS = "CAL_LIST_TEAM_CONFERENCING_APPLICATIONS"
    CAL_GET_DEFAULT_CONFERENCING_APPLICATION = "CAL_GET_DEFAULT_CONFERENCING_APPLICATION"
    CAL_GET_TEAM_DEFAULT_CONFERENCING_APPLICATION = "CAL_GET_TEAM_DEFAULT_CONFERENCING_APPLICATION"
    CAL_SET_DEFAULT_CONFERENCING_APPLICATION = "CAL_SET_DEFAULT_CONFERENCING_APPLICATION"
    CAL_SET_TEAM_DEFAULT_CONFERENCING_APPLICATION = "CAL_SET_TEAM_DEFAULT_CONFERENCING_APPLICATION"
    CAL_CREATE_PHONE_CALL = "CAL_CREATE_PHONE_CALL"
    CAL_GET_ALL_ATTRIBUTES = "CAL_GET_ALL_ATTRIBUTES"
    CAL_GET_ATTRIBUTE = "CAL_GET_ATTRIBUTE"
    CAL_CREATE_ATTRIBUTE = "CAL_CREATE_ATTRIBUTE"
    CAL_ASSIGN_ATTRIBUTE_TO_USER = "CAL_ASSIGN_ATTRIBUTE_TO_USER"
    CAL_GET_ALL_ATTRIBUTE_OPTIONS = "CAL_GET_ALL_ATTRIBUTE_OPTIONS"
    CAL_GET_ATTRIBUTE_OPTIONS_BY_ID = "CAL_GET_ATTRIBUTE_OPTIONS_BY_ID"
    CAL_GET_ATTRIBUTE_OPTIONS_BY_SLUG = "CAL_GET_ATTRIBUTE_OPTIONS_BY_SLUG"
    CAL_GET_USER_ATTRIBUTE_OPTIONS = "CAL_GET_USER_ATTRIBUTE_OPTIONS"
    CAL_GET_ROUTING_FORM_RESPONSES = "CAL_GET_ROUTING_FORM_RESPONSES"
    CAL_UPDATE_ROUTING_FORM_RESPONSE = "CAL_UPDATE_ROUTING_FORM_RESPONSE"
    CAL_GET_ALL_WEBHOOKS = "CAL_GET_ALL_WEBHOOKS"
    CAL_GET_WEBHOOK = "CAL_GET_WEBHOOK"
    CAL_DELETE_ALL_WEBHOOKS = "CAL_DELETE_ALL_WEBHOOKS"
    CAL_REFRESH_API_KEY = "CAL_REFRESH_API_KEY"
    CAL_REFRESH_MANAGED_USER_TOKENS = "CAL_REFRESH_MANAGED_USER_TOKENS"
    CAL_UPDATE_ORGANIZATION_DELEGATION_CREDENTIALS = "CAL_UPDATE_ORGANIZATION_DELEGATION_CREDENTIALS"
    CAL_RESERVE_SLOT = "CAL_RESERVE_SLOT"
    CAL_GET_RESERVED_SLOT = "CAL_GET_RESERVED_SLOT"
    CAL_GET_EVENT_TYPE_WEBHOOK = "CAL_GET_EVENT_TYPE_WEBHOOK"
    CAL_GET_ALL_EVENT_TYPE_WEBHOOKS = "CAL_GET_ALL_EVENT_TYPE_WEBHOOKS"
    CAL_CREATE_OR_UPDATE_WEBHOOK = "CAL_CREATE_OR_UPDATE_WEBHOOK"

    # Canva actions
    CANVA_REVOKE_OAUTH_TOKEN = "CANVA_REVOKE_OAUTH_TOKEN"
    CANVA_LIST_BRAND_TEMPLATES = "CANVA_LIST_BRAND_TEMPLATES"
    CANVA_CREATE_DESIGN = "CANVA_CREATE_DESIGN"
    CANVA_CREATE_COMMENT_REPLY = "CANVA_CREATE_COMMENT_REPLY"
    CANVA_CREATE_DESIGN_COMMENT = "CANVA_CREATE_DESIGN_COMMENT"
    CANVA_CREATE_FOLDER = "CANVA_CREATE_FOLDER"
    CANVA_DELETE_ASSET = "CANVA_DELETE_ASSET"
    CANVA_EXCHANGE_OAUTH_TOKEN = "CANVA_EXCHANGE_OAUTH_TOKEN"
    CANVA_GET_ASSET_UPLOAD_JOB = "CANVA_GET_ASSET_UPLOAD_JOB"
    CANVA_GET_CURRENT_USER = "CANVA_GET_CURRENT_USER"
    CANVA_GET_DESIGN = "CANVA_GET_DESIGN"
    CANVA_GET_DESIGN_EXPORT_JOB = "CANVA_GET_DESIGN_EXPORT_JOB"
    CANVA_CREATE_DESIGN_EXPORT_JOB = "CANVA_CREATE_DESIGN_EXPORT_JOB"
    CANVA_CREATE_AUTOFILL_JOB = "CANVA_CREATE_AUTOFILL_JOB"
    CANVA_LIST_DESIGN_PAGES = "CANVA_LIST_DESIGN_PAGES"
    CANVA_LIST_FOLDER_ITEMS = "CANVA_LIST_FOLDER_ITEMS"
    CANVA_LIST_DESIGNS = "CANVA_LIST_DESIGNS"
    CANVA_MOVE_ITEM_TO_FOLDER = "CANVA_MOVE_ITEM_TO_FOLDER"
    CANVA_DELETE_FOLDER = "CANVA_DELETE_FOLDER"
    CANVA_GET_APP_PUBLIC_KEYS = "CANVA_GET_APP_PUBLIC_KEYS"
    CANVA_GET_ASSET = "CANVA_GET_ASSET"
    CANVA_GET_DESIGN_COMMENT = "CANVA_GET_DESIGN_COMMENT"
    CANVA_GET_BRAND_TEMPLATE_DATASET = "CANVA_GET_BRAND_TEMPLATE_DATASET"
    CANVA_GET_BRAND_TEMPLATE = "CANVA_GET_BRAND_TEMPLATE"
    CANVA_GET_AUTOFILL_JOB = "CANVA_GET_AUTOFILL_JOB"
    CANVA_GET_DESIGN_IMPORT_JOB = "CANVA_GET_DESIGN_IMPORT_JOB"
    CANVA_GET_FOLDER = "CANVA_GET_FOLDER"
    CANVA_UPDATE_ASSET = "CANVA_UPDATE_ASSET"
    CANVA_UPDATE_FOLDER = "CANVA_UPDATE_FOLDER"
    CANVA_VALIDATE_OAUTH_TOKEN = "CANVA_VALIDATE_OAUTH_TOKEN"

    # Clerk actions
    CLERK_LIST_ALL_USERS = "CLERK_LIST_ALL_USERS"
    CLERK_COUNT_USERS = "CLERK_COUNT_USERS"
    CLERK_RETRIEVE_USER = "CLERK_RETRIEVE_USER"
    CLERK_CREATE_USER = "CLERK_CREATE_USER"
    CLERK_UPDATE_USER = "CLERK_UPDATE_USER"
    CLERK_DELETE_USER = "CLERK_DELETE_USER"
    CLERK_LOCK_USER = "CLERK_LOCK_USER"
    CLERK_UNLOCK_USER = "CLERK_UNLOCK_USER"
    CLERK_BAN_USER = "CLERK_BAN_USER"
    CLERK_UNBAN_USER = "CLERK_UNBAN_USER"
    CLERK_VERIFY_USER_PASSWORD = "CLERK_VERIFY_USER_PASSWORD"
    CLERK_VERIFY_TOTP_OR_BACKUP_CODE = "CLERK_VERIFY_TOTP_OR_BACKUP_CODE"
    CLERK_DISABLE_USER_MFA = "CLERK_DISABLE_USER_MFA"
    CLERK_DISABLE_USER_BACKUP_CODES = "CLERK_DISABLE_USER_BACKUP_CODES"
    CLERK_DELETE_USER_TOTPS = "CLERK_DELETE_USER_TOTPS"
    CLERK_DELETE_USER_PASSKEY = "CLERK_DELETE_USER_PASSKEY"
    CLERK_DELETE_USER_WEB3_WALLET = "CLERK_DELETE_USER_WEB3_WALLET"
    CLERK_SET_USER_PROFILE_IMAGE = "CLERK_SET_USER_PROFILE_IMAGE"
    CLERK_DELETE_USER_PROFILE_IMAGE = "CLERK_DELETE_USER_PROFILE_IMAGE"
    CLERK_RETRIEVE_USER_ORGANIZATION_MEMBERSHIPS = "CLERK_RETRIEVE_USER_ORGANIZATION_MEMBERSHIPS"
    CLERK_RETRIEVE_USER_INVITATIONS = "CLERK_RETRIEVE_USER_INVITATIONS"
    CLERK_MERGE_AND_UPDATE_USER_METADATA = "CLERK_MERGE_AND_UPDATE_USER_METADATA"
    CLERK_RETRIEVE_ORGANIZATION = "CLERK_RETRIEVE_ORGANIZATION"
    CLERK_GET_LIST_OF_ORGANIZATIONS = "CLERK_GET_LIST_OF_ORGANIZATIONS"
    CLERK_CREATE_ORGANIZATION = "CLERK_CREATE_ORGANIZATION"
    CLERK_UPDATE_ORGANIZATION = "CLERK_UPDATE_ORGANIZATION"
    CLERK_DELETE_ORGANIZATION = "CLERK_DELETE_ORGANIZATION"
    CLERK_UPLOAD_ORGANIZATION_LOGO = "CLERK_UPLOAD_ORGANIZATION_LOGO"
    CLERK_DELETE_ORGANIZATION_LOGO = "CLERK_DELETE_ORGANIZATION_LOGO"
    CLERK_MERGE_AND_UPDATE_ORGANIZATION_METADATA = "CLERK_MERGE_AND_UPDATE_ORGANIZATION_METADATA"
    CLERK_LIST_INVITATIONS = "CLERK_LIST_INVITATIONS"
    CLERK_RETRIEVE_ORGANIZATION_INVITATIONS = "CLERK_RETRIEVE_ORGANIZATION_INVITATIONS"
    CLERK_GET_ORGANIZATION_INVITATIONS_FOR_CURRENT_INSTANCE = "CLERK_GET_ORGANIZATION_INVITATIONS_FOR_CURRENT_INSTANCE"
    CLERK_RETRIEVE_ORGANIZATION_INVITATION_BY_ID = "CLERK_RETRIEVE_ORGANIZATION_INVITATION_BY_ID"
    CLERK_CREATE_INVITATION = "CLERK_CREATE_INVITATION"
    CLERK_CREATE_MULTIPLE_INVITATIONS = "CLERK_CREATE_MULTIPLE_INVITATIONS"
    CLERK_BULK_CREATE_AND_SEND_ORGANIZATION_INVITATIONS = "CLERK_BULK_CREATE_AND_SEND_ORGANIZATION_INVITATIONS"
    CLERK_CREATE_AND_SEND_ORGANIZATION_INVITATION = "CLERK_CREATE_AND_SEND_ORGANIZATION_INVITATION"
    CLERK_REVOKE_INVITATION = "CLERK_REVOKE_INVITATION"
    CLERK_REVOKE_PENDING_ORGANIZATION_INVITATION = "CLERK_REVOKE_PENDING_ORGANIZATION_INVITATION"
    CLERK_LIST_WAITLIST_ENTRIES = "CLERK_LIST_WAITLIST_ENTRIES"
    CLERK_CREATE_WAITLIST_ENTRY = "CLERK_CREATE_WAITLIST_ENTRY"
    CLERK_LIST_ALLOWLIST_IDENTIFIERS = "CLERK_LIST_ALLOWLIST_IDENTIFIERS"
    CLERK_ADD_IDENTIFIER_TO_ALLOWLIST = "CLERK_ADD_IDENTIFIER_TO_ALLOWLIST"
    CLERK_DELETE_IDENTIFIER_FROM_ALLOWLIST = "CLERK_DELETE_IDENTIFIER_FROM_ALLOWLIST"
    CLERK_LIST_BLOCKLIST_IDENTIFIERS = "CLERK_LIST_BLOCKLIST_IDENTIFIERS"
    CLERK_ADD_IDENTIFIER_TO_BLOCKLIST = "CLERK_ADD_IDENTIFIER_TO_BLOCKLIST"
    CLERK_DELETE_IDENTIFIER_FROM_BLOCKLIST = "CLERK_DELETE_IDENTIFIER_FROM_BLOCKLIST"
    CLERK_RETRIEVE_EMAIL_ADDRESS = "CLERK_RETRIEVE_EMAIL_ADDRESS"
    CLERK_CREATE_EMAIL_ADDRESS = "CLERK_CREATE_EMAIL_ADDRESS"
    CLERK_DELETE_EMAIL_ADDRESS = "CLERK_DELETE_EMAIL_ADDRESS"
    CLERK_UPDATE_EMAIL_ADDRESS = "CLERK_UPDATE_EMAIL_ADDRESS"
    CLERK_RETRIEVE_OAUTH_ACCESS_TOKEN = "CLERK_RETRIEVE_OAUTH_ACCESS_TOKEN"

    # Close actions
    CLOSE_GET_ORGANIZATION_DETAILS = "CLOSE_GET_ORGANIZATION_DETAILS"
    CLOSE_FILTER_LEADS = "CLOSE_FILTER_LEADS"
    CLOSE_LIST_OPPORTUNITIES = "CLOSE_LIST_OPPORTUNITIES"
    CLOSE_LIST_CONTACTS = "CLOSE_LIST_CONTACTS"
    CLOSE_FETCH_SINGLE_CONTACT = "CLOSE_FETCH_SINGLE_CONTACT"
    CLOSE_RETRIEVE_SINGLE_LEAD = "CLOSE_RETRIEVE_SINGLE_LEAD"
    CLOSE_LIST_LEADS = "CLOSE_LIST_LEADS"
    CLOSE_RETRIEVE_OPPORTUNITY = "CLOSE_RETRIEVE_OPPORTUNITY"
    CLOSE_MERGE_LEADS = "CLOSE_MERGE_LEADS"
    CLOSE_CREATE_NEW_CONTACT = "CLOSE_CREATE_NEW_CONTACT"
    CLOSE_CREATE_LEAD = "CLOSE_CREATE_LEAD"
    CLOSE_CREATE_OPPORTUNITY = "CLOSE_CREATE_OPPORTUNITY"
    CLOSE_UPDATE_CONTACT = "CLOSE_UPDATE_CONTACT"
    CLOSE_UPDATE_LEAD = "CLOSE_UPDATE_LEAD"
    CLOSE_UPDATE_OPPORTUNITY = "CLOSE_UPDATE_OPPORTUNITY"
    CLOSE_UPDATE_ORGANIZATION = "CLOSE_UPDATE_ORGANIZATION"
    CLOSE_DELETE_OPPORTUNITY = "CLOSE_DELETE_OPPORTUNITY"
    CLOSE_DELETE_LEAD = "CLOSE_DELETE_LEAD"
    CLOSE_DELETE_CONTACT = "CLOSE_DELETE_CONTACT"

    # Exa actions
    EXA_GET_LLM_ANSWER = "EXA_GET_LLM_ANSWER"
    EXA_SEARCH = "EXA_SEARCH"
    EXA_GET_CONTENTS = "EXA_GET_CONTENTS"
    EXA_FIND_SIMILAR_LINKS = "EXA_FIND_SIMILAR_LINKS"

    # Figma actions
    FIGMA_GET_FILE_JSON = "FIGMA_GET_FILE_JSON"
    FIGMA_GET_COMPONENT = "FIGMA_GET_COMPONENT"
    FIGMA_EXTRACT_DESIGN_TOKENS = "FIGMA_EXTRACT_DESIGN_TOKENS"
    FIGMA_DESIGN_TOKENS_TO_TAILWIND = "FIGMA_DESIGN_TOKENS_TO_TAILWIND"
    FIGMA_RENDER_IMAGES_OF_FILE_NODES = "FIGMA_RENDER_IMAGES_OF_FILE_NODES"
    FIGMA_DOWNLOAD_FIGMA_IMAGES = "FIGMA_DOWNLOAD_FIGMA_IMAGES"
    FIGMA_GET_FILE_COMPONENTS = "FIGMA_GET_FILE_COMPONENTS"
    FIGMA_GET_FILE_COMPONENT_SETS = "FIGMA_GET_FILE_COMPONENT_SETS"
    FIGMA_GET_LOCAL_VARIABLES = "FIGMA_GET_LOCAL_VARIABLES"
    FIGMA_GET_PUBLISHED_VARIABLES = "FIGMA_GET_PUBLISHED_VARIABLES"
    FIGMA_CREATE_MODIFY_DELETE_VARIABLES = "FIGMA_CREATE_MODIFY_DELETE_VARIABLES"
    FIGMA_EXTRACT_PROTOTYPE_INTERACTIONS = "FIGMA_EXTRACT_PROTOTYPE_INTERACTIONS"
    FIGMA_DISCOVER_FIGMA_RESOURCES = "FIGMA_DISCOVER_FIGMA_RESOURCES"
    FIGMA_GET_CURRENT_USER = "FIGMA_GET_CURRENT_USER"
    FIGMA_GET_PROJECTS_IN_TEAM = "FIGMA_GET_PROJECTS_IN_TEAM"
    FIGMA_GET_FILES_IN_PROJECT = "FIGMA_GET_FILES_IN_PROJECT"
    FIGMA_GET_VERSIONS_OF_FILE = "FIGMA_GET_VERSIONS_OF_FILE"
    FIGMA_GET_COMMENTS_IN_FILE = "FIGMA_GET_COMMENTS_IN_FILE"
    FIGMA_ADD_COMMENT_TO_FILE = "FIGMA_ADD_COMMENT_TO_FILE"
    FIGMA_DELETE_COMMENT = "FIGMA_DELETE_COMMENT"
    FIGMA_CREATE_WEBHOOK = "FIGMA_CREATE_WEBHOOK"
    FIGMA_GET_TEAM_WEBHOOKS = "FIGMA_GET_TEAM_WEBHOOKS"
    FIGMA_GET_WEBHOOK = "FIGMA_GET_WEBHOOK"
    FIGMA_DELETE_WEBHOOK = "FIGMA_DELETE_WEBHOOK"
    FIGMA_DELETE_DEV_RESOURCE = "FIGMA_DELETE_DEV_RESOURCE"
    FIGMA_DETECT_BACKGROUND = "FIGMA_DETECT_BACKGROUND"
    FIGMA_GET_ACTIVITY_LOGS = "FIGMA_GET_ACTIVITY_LOGS"
    FIGMA_GET_COMMENTS = "FIGMA_GET_COMMENTS"
    FIGMA_GET_COMPONENT_SET = "FIGMA_GET_COMPONENT_SET"
    FIGMA_GET_DEV_RESOURCES = "FIGMA_GET_DEV_RESOURCES"
    FIGMA_GET_FILE_STYLES = "FIGMA_GET_FILE_STYLES"
    FIGMA_GET_IMAGE_FILLS = "FIGMA_GET_IMAGE_FILLS"
    FIGMA_GET_LIBRARY_ANALYTICS_COMPONENT_ACTION_DATA = "FIGMA_GET_LIBRARY_ANALYTICS_COMPONENT_ACTION_DATA"
    FIGMA_GET_LIBRARY_ANALYTICS_COMPONENT_USAGE_DATA = "FIGMA_GET_LIBRARY_ANALYTICS_COMPONENT_USAGE_DATA"
    FIGMA_GET_LIBRARY_ANALYTICS_STYLE_ACTION_DATA = "FIGMA_GET_LIBRARY_ANALYTICS_STYLE_ACTION_DATA"
    FIGMA_GET_LIBRARY_ANALYTICS_STYLE_USAGE_DATA = "FIGMA_GET_LIBRARY_ANALYTICS_STYLE_USAGE_DATA"
    FIGMA_GET_LIBRARY_ANALYTICS_VARIABLE_ACTION_DATA = "FIGMA_GET_LIBRARY_ANALYTICS_VARIABLE_ACTION_DATA"
    FIGMA_GET_LIBRARY_ANALYTICS_VARIABLE_USAGE_DATA = "FIGMA_GET_LIBRARY_ANALYTICS_VARIABLE_USAGE_DATA"
    FIGMA_GET_PAYMENTS = "FIGMA_GET_PAYMENTS"
    FIGMA_GET_REACTIONS = "FIGMA_GET_REACTIONS"
    FIGMA_GET_STYLE = "FIGMA_GET_STYLE"
    FIGMA_GET_TEAM_COMPONENTS = "FIGMA_GET_TEAM_COMPONENTS"
    FIGMA_GET_TEAM_COMPONENT_SETS = "FIGMA_GET_TEAM_COMPONENT_SETS"
    FIGMA_GET_TEAM_STYLES = "FIGMA_GET_TEAM_STYLES"
    FIGMA_GET_VERSIONS = "FIGMA_GET_VERSIONS"
    FIGMA_GET_WEBHOOK_REQUESTS = "FIGMA_GET_WEBHOOK_REQUESTS"
    FIGMA_RENDER_IMAGES = "FIGMA_RENDER_IMAGES"
    FIGMA_UPDATE_WEBHOOK = "FIGMA_UPDATE_WEBHOOK"
    FIGMA_UPDATE_DEV_RESOURCES = "FIGMA_UPDATE_DEV_RESOURCES"

    # Firefiles actions
    FIREFILES_DELETE_TRANSCRIPT = "FIREFILES_DELETE_TRANSCRIPT"
    FIREFILES_UPLOAD_AUDIO = "FIREFILES_UPLOAD_AUDIO"
    FIREFILES_ADD_TO_LIVE = "FIREFILES_ADD_TO_LIVE"
    FIREFILES_SET_USER_ROLE = "FIREFILES_SET_USER_ROLE"
    FIREFILES_QUERY_USERS = "FIREFILES_QUERY_USERS"
    FIREFILES_QUERY_BITE_DETAILS = "FIREFILES_QUERY_BITE_DETAILS"
    FIREFILES_CREATE_BITE = "FIREFILES_CREATE_BITE"
    FIREFILES_QUERY_AI_APPS_OUTPUTS = "FIREFILES_QUERY_AI_APPS_OUTPUTS"
    FIREFILES_QUERY_TRANSCRIPTS = "FIREFILES_QUERY_TRANSCRIPTS"
    FIREFILES_QUERY_TRANSCRIPT_DETAILS = "FIREFILES_QUERY_TRANSCRIPT_DETAILS"
    FIREFILES_QUERY_USER_DETAILS = "FIREFILES_QUERY_USER_DETAILS"
    FIREFILES_QUERY_BITES = "FIREFILES_QUERY_BITES"

    # Folk actions
    FOLK_GET_CURRENT_USER = "FOLK_GET_CURRENT_USER"
    FOLK_GET_USER = "FOLK_GET_USER"
    FOLK_LIST_PEOPLE_IN_WORKSPACE = "FOLK_LIST_PEOPLE_IN_WORKSPACE"
    FOLK_GET_NOTE = "FOLK_GET_NOTE"
    FOLK_LIST_NOTES_IN_WORKSPACE = "FOLK_LIST_NOTES_IN_WORKSPACE"
    FOLK_GET_COMPANY = "FOLK_GET_COMPANY"
    FOLK_LIST_GROUP_CUSTOM_FIELDS_FOR_ENTITY_TYPE = "FOLK_LIST_GROUP_CUSTOM_FIELDS_FOR_ENTITY_TYPE"
    FOLK_GET_DEAL = "FOLK_GET_DEAL"
    FOLK_RETRIEVE_REMINDER = "FOLK_RETRIEVE_REMINDER"
    FOLK_LIST_REMINDERS_IN_WORKSPACE = "FOLK_LIST_REMINDERS_IN_WORKSPACE"
    FOLK_GET_PERSON = "FOLK_GET_PERSON"
    FOLK_LIST_USERS = "FOLK_LIST_USERS"
    FOLK_LIST_WORKSPACE_GROUPS = "FOLK_LIST_WORKSPACE_GROUPS"
    FOLK_LIST_DEALS_IN_WORKSPACE_GROUP = "FOLK_LIST_DEALS_IN_WORKSPACE_GROUP"
    FOLK_LIST_COMPANIES = "FOLK_LIST_COMPANIES"
    FOLK_CREATE_PERSON = "FOLK_CREATE_PERSON"
    FOLK_CREATE_NOTE_IN_WORKSPACE = "FOLK_CREATE_NOTE_IN_WORKSPACE"
    FOLK_CREATE_COMPANY = "FOLK_CREATE_COMPANY"
    FOLK_CREATE_INTERACTION = "FOLK_CREATE_INTERACTION"
    FOLK_CREATE_DEAL_IN_WORKSPACE = "FOLK_CREATE_DEAL_IN_WORKSPACE"
    FOLK_CREATE_REMINDER = "FOLK_CREATE_REMINDER"
    FOLK_DELETE_NOTE = "FOLK_DELETE_NOTE"
    FOLK_DELETE_COMPANY = "FOLK_DELETE_COMPANY"
    FOLK_DELETE_DEAL = "FOLK_DELETE_DEAL"
    FOLK_DELETE_REMINDER = "FOLK_DELETE_REMINDER"
    FOLK_DELETE_PERSON = "FOLK_DELETE_PERSON"
    FOLK_UPDATE_NOTE = "FOLK_UPDATE_NOTE"
    FOLK_UPDATE_COMPANY = "FOLK_UPDATE_COMPANY"
    FOLK_UPDATE_DEAL = "FOLK_UPDATE_DEAL"
    FOLK_UPDATE_PERSON = "FOLK_UPDATE_PERSON"
    FOLK_UPDATE_REMINDER = "FOLK_UPDATE_REMINDER"

    # Front actions
    FRONT_GET_MESSAGE = "FRONT_GET_MESSAGE"
    FRONT_GET_MESSAGE_SEEN_STATUS = "FRONT_GET_MESSAGE_SEEN_STATUS"
    FRONT_MARK_MESSAGE_SEEN = "FRONT_MARK_MESSAGE_SEEN"
    FRONT_CREATE_MESSAGE = "FRONT_CREATE_MESSAGE"
    FRONT_CREATE_MESSAGE_REPLY = "FRONT_CREATE_MESSAGE_REPLY"
    FRONT_IMPORT_MESSAGE = "FRONT_IMPORT_MESSAGE"
    FRONT_RECEIVE_CUSTOM_MESSAGES = "FRONT_RECEIVE_CUSTOM_MESSAGES"
    FRONT_LIST_CONVERSATIONS = "FRONT_LIST_CONVERSATIONS"
    FRONT_GET_CONVERSATION = "FRONT_GET_CONVERSATION"
    FRONT_LIST_CONVERSATION_MESSAGES = "FRONT_LIST_CONVERSATION_MESSAGES"
    FRONT_LIST_CONVERSATION_EVENTS = "FRONT_LIST_CONVERSATION_EVENTS"
    FRONT_LIST_CONVERSATION_INBOXES = "FRONT_LIST_CONVERSATION_INBOXES"
    FRONT_SEARCH_CONVERSATIONS = "FRONT_SEARCH_CONVERSATIONS"
    FRONT_CREATE_DISCUSSION_CONVERSATION = "FRONT_CREATE_DISCUSSION_CONVERSATION"
    FRONT_UPDATE_CONVERSATION = "FRONT_UPDATE_CONVERSATION"
    FRONT_UPDATE_CONVERSATION_ASSIGNEE = "FRONT_UPDATE_CONVERSATION_ASSIGNEE"
    FRONT_UPDATE_CONVERSATION_REMINDERS = "FRONT_UPDATE_CONVERSATION_REMINDERS"
    FRONT_ADD_CONVERSATION_FOLLOWERS = "FRONT_ADD_CONVERSATION_FOLLOWERS"
    FRONT_DELETE_CONVERSATION_FOLLOWERS = "FRONT_DELETE_CONVERSATION_FOLLOWERS"
    FRONT_LIST_CONVERSATION_FOLLOWERS = "FRONT_LIST_CONVERSATION_FOLLOWERS"
    FRONT_ADD_CONVERSATION_TAG = "FRONT_ADD_CONVERSATION_TAG"
    FRONT_REMOVE_CONVERSATION_TAG = "FRONT_REMOVE_CONVERSATION_TAG"
    FRONT_ADD_CONVERSATION_LINK = "FRONT_ADD_CONVERSATION_LINK"
    FRONT_REMOVE_CONVERSATION_LINKS = "FRONT_REMOVE_CONVERSATION_LINKS"
    FRONT_LIST_CONTACTS = "FRONT_LIST_CONTACTS"
    FRONT_GET_CONTACT = "FRONT_GET_CONTACT"
    FRONT_CREATE_CONTACT = "FRONT_CREATE_CONTACT"
    FRONT_UPDATE_CONTACT = "FRONT_UPDATE_CONTACT"
    FRONT_DELETE_CONTACT = "FRONT_DELETE_CONTACT"
    FRONT_MERGE_CONTACTS = "FRONT_MERGE_CONTACTS"
    FRONT_LIST_ACCOUNT_CONTACTS = "FRONT_LIST_ACCOUNT_CONTACTS"
    FRONT_ADD_CONTACT_TO_ACCOUNT = "FRONT_ADD_CONTACT_TO_ACCOUNT"
    FRONT_REMOVE_CONTACT_FROM_ACCOUNT = "FRONT_REMOVE_CONTACT_FROM_ACCOUNT"

    # Bigquery actions
    BIGQUERY_GET_TABLE = "BIGQUERY_GET_TABLE"
    BIGQUERY_LIST_DATASETS = "BIGQUERY_LIST_DATASETS"
    BIGQUERY_LIST_BIGQUERY_MODELS = "BIGQUERY_LIST_BIGQUERY_MODELS"
    BIGQUERY_GET_QUERY_RESULTS = "BIGQUERY_GET_QUERY_RESULTS"
    BIGQUERY_LIST_TABLES = "BIGQUERY_LIST_TABLES"
    BIGQUERY_GET_ROUTINE_RESOURCE = "BIGQUERY_GET_ROUTINE_RESOURCE"
    BIGQUERY_LIST_ROUTINES = "BIGQUERY_LIST_ROUTINES"
    BIGQUERY_LIST_TABLE_DATA = "BIGQUERY_LIST_TABLE_DATA"
    BIGQUERY_GET_DATASET = "BIGQUERY_GET_DATASET"
    BIGQUERY_LIST_ROW_ACCESS_POLICIES = "BIGQUERY_LIST_ROW_ACCESS_POLICIES"
    BIGQUERY_LIST_JOBS = "BIGQUERY_LIST_JOBS"
    BIGQUERY_GET_JOB_INFORMATION = "BIGQUERY_GET_JOB_INFORMATION"
    BIGQUERY_LIST_PROJECTS = "BIGQUERY_LIST_PROJECTS"
    BIGQUERY_GET_MODEL = "BIGQUERY_GET_MODEL"
    BIGQUERY_GET_PROJECT_SERVICE_ACCOUNT = "BIGQUERY_GET_PROJECT_SERVICE_ACCOUNT"
    BIGQUERY_INSERT_DATA = "BIGQUERY_INSERT_DATA"
    BIGQUERY_GET_ROW_ACCESS_POLICY = "BIGQUERY_GET_ROW_ACCESS_POLICY"
    BIGQUERY_SET_IAM_POLICY = "BIGQUERY_SET_IAM_POLICY"
    BIGQUERY_CANCEL_BIGQUERY_JOB = "BIGQUERY_CANCEL_BIGQUERY_JOB"
    BIGQUERY_CREATE_TABLE = "BIGQUERY_CREATE_TABLE"
    BIGQUERY_GET_IAM_POLICY = "BIGQUERY_GET_IAM_POLICY"
    BIGQUERY_CREATE_ROUTINE = "BIGQUERY_CREATE_ROUTINE"
    BIGQUERY_CREATE_DATASET = "BIGQUERY_CREATE_DATASET"
    BIGQUERY_UNDELETE_DATASET = "BIGQUERY_UNDELETE_DATASET"
    BIGQUERY_TEST_IAM_PERMISSIONS = "BIGQUERY_TEST_IAM_PERMISSIONS"
    BIGQUERY_START_ASYNC_JOB = "BIGQUERY_START_ASYNC_JOB"
    BIGQUERY_EXECUTE_SQL_QUERY = "BIGQUERY_EXECUTE_SQL_QUERY"
    BIGQUERY_UPDATE_DATASET = "BIGQUERY_UPDATE_DATASET"
    BIGQUERY_UPDATE_ROUTINE = "BIGQUERY_UPDATE_ROUTINE"
    BIGQUERY_UPDATE_TABLE = "BIGQUERY_UPDATE_TABLE"
    BIGQUERY_DELETE_JOB_METADATA = "BIGQUERY_DELETE_JOB_METADATA"
    BIGQUERY_DELETE_ROUTINE = "BIGQUERY_DELETE_ROUTINE"
    BIGQUERY_DELETE_DATASET = "BIGQUERY_DELETE_DATASET"
    BIGQUERY_DELETE_TABLE = "BIGQUERY_DELETE_TABLE"
    BIGQUERY_DELETE_BIGQUERY_MODEL = "BIGQUERY_DELETE_BIGQUERY_MODEL"
    BIGQUERY_PATCH_MODEL_FIELDS = "BIGQUERY_PATCH_MODEL_FIELDS"

    # Hackernews actions
    HACKERNEWS_GET_MAX_ITEM_ID = "HACKERNEWS_GET_MAX_ITEM_ID"
    HACKERNEWS_GET_USER = "HACKERNEWS_GET_USER"
    HACKERNEWS_GET_SHOW_STORIES = "HACKERNEWS_GET_SHOW_STORIES"
    HACKERNEWS_GET_UPDATES = "HACKERNEWS_GET_UPDATES"
    HACKERNEWS_GET_BEST_STORIES = "HACKERNEWS_GET_BEST_STORIES"
    HACKERNEWS_GET_TOP_STORIES = "HACKERNEWS_GET_TOP_STORIES"
    HACKERNEWS_GET_NEW_STORIES = "HACKERNEWS_GET_NEW_STORIES"
    HACKERNEWS_GET_JOB_STORIES = "HACKERNEWS_GET_JOB_STORIES"
    HACKERNEWS_GET_ASK_STORIES = "HACKERNEWS_GET_ASK_STORIES"
    HACKERNEWS_GET_ITEM = "HACKERNEWS_GET_ITEM"

    # Hubspot actions
    HUBSPOT_CREATE_BATCH_TICKETS = "HUBSPOT_CREATE_BATCH_TICKETS"
    HUBSPOT_CREATE_PRODUCT_BATCH = "HUBSPOT_CREATE_PRODUCT_BATCH"
    HUBSPOT_CREATE_PRODUCT_OBJECT = "HUBSPOT_CREATE_PRODUCT_OBJECT"
    HUBSPOT_GET_PIPELINE_STAGE_AUDIT = "HUBSPOT_GET_PIPELINE_STAGE_AUDIT"
    HUBSPOT_LIST_PRODUCTS_WITH_PAGING = "HUBSPOT_LIST_PRODUCTS_WITH_PAGING"
    HUBSPOT_UPDATE_PRODUCT = "HUBSPOT_UPDATE_PRODUCT"
    HUBSPOT_ARCHIVE_PRODUCT_BY_ID = "HUBSPOT_ARCHIVE_PRODUCT_BY_ID"
    HUBSPOT_CREATE_COMPANY_BATCH = "HUBSPOT_CREATE_COMPANY_BATCH"
    HUBSPOT_CREATE_CONTACT_BATCH = "HUBSPOT_CREATE_CONTACT_BATCH"
    HUBSPOT_CREATE_DEAL_BATCH = "HUBSPOT_CREATE_DEAL_BATCH"
    HUBSPOT_SEARCH_CONTACTS = "HUBSPOT_SEARCH_CONTACTS"
    HUBSPOT_SEARCH_COMPANIES = "HUBSPOT_SEARCH_COMPANIES"
    HUBSPOT_SEARCH_DEALS = "HUBSPOT_SEARCH_DEALS"
    HUBSPOT_CREATE_CUSTOM_PROPERTY = "HUBSPOT_CREATE_CUSTOM_PROPERTY"
    HUBSPOT_CREATE_PIPELINE = "HUBSPOT_CREATE_PIPELINE"
    HUBSPOT_GET_CONTACT_BY_ID = "HUBSPOT_GET_CONTACT_BY_ID"
    HUBSPOT_GET_COMPANY_BY_ID = "HUBSPOT_GET_COMPANY_BY_ID"
    HUBSPOT_GET_DEAL_BY_ID = "HUBSPOT_GET_DEAL_BY_ID"
    HUBSPOT_CREATE_MARKETING_EMAIL = "HUBSPOT_CREATE_MARKETING_EMAIL"
    HUBSPOT_CREATE_WORKFLOW = "HUBSPOT_CREATE_WORKFLOW"
    HUBSPOT_ARCHIVE_BATCH_CONTACTS = "HUBSPOT_ARCHIVE_BATCH_CONTACTS"
    HUBSPOT_ARCHIVE_BATCH_COMPANIES = "HUBSPOT_ARCHIVE_BATCH_COMPANIES"
    HUBSPOT_ARCHIVE_BATCH_DEALS = "HUBSPOT_ARCHIVE_BATCH_DEALS"
    HUBSPOT_MERGE_CONTACTS = "HUBSPOT_MERGE_CONTACTS"
    HUBSPOT_MERGE_COMPANIES = "HUBSPOT_MERGE_COMPANIES"
    HUBSPOT_MERGE_DEALS = "HUBSPOT_MERGE_DEALS"
    HUBSPOT_LIST_ALL_PROPERTIES = "HUBSPOT_LIST_ALL_PROPERTIES"
    HUBSPOT_LIST_OWNERS = "HUBSPOT_LIST_OWNERS"
    HUBSPOT_GET_ALL_PIPELINES = "HUBSPOT_GET_ALL_PIPELINES"
    HUBSPOT_CREATE_ASSOCIATION_DEFINITION = "HUBSPOT_CREATE_ASSOCIATION_DEFINITION"
    HUBSPOT_GDPR_DELETE_CONTACT = "HUBSPOT_GDPR_DELETE_CONTACT"
    HUBSPOT_RETRIEVE_ALL_OBJECT_SCHEMAS = "HUBSPOT_RETRIEVE_ALL_OBJECT_SCHEMAS"
    HUBSPOT_RETRIEVE_ALL_PIPELINES_FOR_OBJECT_TYPE = "HUBSPOT_RETRIEVE_ALL_PIPELINES_FOR_OBJECT_TYPE"
    HUBSPOT_RETRIEVE_BATCH_DEALS_BY_IDS = "HUBSPOT_RETRIEVE_BATCH_DEALS_BY_IDS"
    HUBSPOT_RETRIEVE_CALLING_SETTINGS_FOR_APP = "HUBSPOT_RETRIEVE_CALLING_SETTINGS_FOR_APP"
    HUBSPOT_RETRIEVE_COMPANY_BY_ID = "HUBSPOT_RETRIEVE_COMPANY_BY_ID"
    HUBSPOT_RETRIEVE_DEAL_BY_ID = "HUBSPOT_RETRIEVE_DEAL_BY_ID"
    HUBSPOT_RETRIEVE_EXISTING_OBJECT_SCHEMA = "HUBSPOT_RETRIEVE_EXISTING_OBJECT_SCHEMA"
    HUBSPOT_RETRIEVE_LINE_ITEMS_LIST = "HUBSPOT_RETRIEVE_LINE_ITEMS_LIST"
    HUBSPOT_RETRIEVE_LINE_ITEM_BY_ID = "HUBSPOT_RETRIEVE_LINE_ITEM_BY_ID"
    HUBSPOT_RETRIEVE_OWNERS = "HUBSPOT_RETRIEVE_OWNERS"

    # Intercom actions
    INTERCOM_ATTACH_CONTACT_TO_COMPANY = "INTERCOM_ATTACH_CONTACT_TO_COMPANY"
    INTERCOM_ADD_SUBSCRIPTION_TO_CONTACT = "INTERCOM_ADD_SUBSCRIPTION_TO_CONTACT"
    INTERCOM_ADD_TAG_TO_CONTACT = "INTERCOM_ADD_TAG_TO_CONTACT"
    INTERCOM_CREATE_ARTICLE = "INTERCOM_CREATE_ARTICLE"
    INTERCOM_CREATE_COLLECTION = "INTERCOM_CREATE_COLLECTION"
    INTERCOM_CREATE_NOTE = "INTERCOM_CREATE_NOTE"
    INTERCOM_CREATE_OR_UPDATE_COMPANY = "INTERCOM_CREATE_OR_UPDATE_COMPANY"
    INTERCOM_DELETE_ARTICLE = "INTERCOM_DELETE_ARTICLE"
    INTERCOM_DELETE_COLLECTION = "INTERCOM_DELETE_COLLECTION"
    INTERCOM_DELETE_COMPANY = "INTERCOM_DELETE_COMPANY"
    INTERCOM_DELETE_CONTACT = "INTERCOM_DELETE_CONTACT"
    INTERCOM_DETACH_CONTACT_FROM_COMPANY = "INTERCOM_DETACH_CONTACT_FROM_COMPANY"
    INTERCOM_GET_CONTACT = "INTERCOM_GET_CONTACT"
    INTERCOM_IDENTIFY_ADMIN = "INTERCOM_IDENTIFY_ADMIN"
    INTERCOM_LIST_ALL_ACTIVITY_LOGS = "INTERCOM_LIST_ALL_ACTIVITY_LOGS"
    INTERCOM_LIST_ALL_ADMINS = "INTERCOM_LIST_ALL_ADMINS"
    INTERCOM_LIST_ALL_ARTICLES = "INTERCOM_LIST_ALL_ARTICLES"
    INTERCOM_LIST_ALL_COLLECTIONS = "INTERCOM_LIST_ALL_COLLECTIONS"
    INTERCOM_LIST_ALL_COMPANIES = "INTERCOM_LIST_ALL_COMPANIES"
    INTERCOM_LIST_ALL_HELP_CENTERS = "INTERCOM_LIST_ALL_HELP_CENTERS"
    INTERCOM_LIST_ALL_NOTES = "INTERCOM_LIST_ALL_NOTES"
    INTERCOM_LIST_ATTACHED_COMPANIES_FOR_CONTACT = "INTERCOM_LIST_ATTACHED_COMPANIES_FOR_CONTACT"
    INTERCOM_LIST_ATTACHED_CONTACTS = "INTERCOM_LIST_ATTACHED_CONTACTS"
    INTERCOM_LIST_ATTACHED_SEGMENTS_FOR_COMPANIES = "INTERCOM_LIST_ATTACHED_SEGMENTS_FOR_COMPANIES"
    INTERCOM_LIST_ATTACHED_SEGMENTS_FOR_CONTACT = "INTERCOM_LIST_ATTACHED_SEGMENTS_FOR_CONTACT"
    INTERCOM_LIST_SUBSCRIPTIONS_FOR_CONTACT = "INTERCOM_LIST_SUBSCRIPTIONS_FOR_CONTACT"
    INTERCOM_LIST_TAGS_ATTACHED_TO_CONTACT = "INTERCOM_LIST_TAGS_ATTACHED_TO_CONTACT"
    INTERCOM_MERGE_LEAD_AND_USER = "INTERCOM_MERGE_LEAD_AND_USER"
    INTERCOM_REMOVE_SUBSCRIPTION_FROM_CONTACT = "INTERCOM_REMOVE_SUBSCRIPTION_FROM_CONTACT"
    INTERCOM_REMOVE_TAG_FROM_CONTACT = "INTERCOM_REMOVE_TAG_FROM_CONTACT"
    INTERCOM_RETRIEVE_ADMIN = "INTERCOM_RETRIEVE_ADMIN"
    INTERCOM_RETRIEVE_ARTICLE = "INTERCOM_RETRIEVE_ARTICLE"
    INTERCOM_RETRIEVE_COLLECTION = "INTERCOM_RETRIEVE_COLLECTION"
    INTERCOM_RETRIEVE_COMPANY_BY_ID = "INTERCOM_RETRIEVE_COMPANY_BY_ID"
    INTERCOM_RETRIEVE_HELP_CENTER = "INTERCOM_RETRIEVE_HELP_CENTER"
    INTERCOM_RETRIEVE_COMPANIES = "INTERCOM_RETRIEVE_COMPANIES"
    INTERCOM_SCROLL_OVER_ALL_COMPANIES = "INTERCOM_SCROLL_OVER_ALL_COMPANIES"
    INTERCOM_SEARCH_FOR_ARTICLES = "INTERCOM_SEARCH_FOR_ARTICLES"
    INTERCOM_SET_ADMIN_TO_AWAY = "INTERCOM_SET_ADMIN_TO_AWAY"
    INTERCOM_UPDATE_ARTICLE = "INTERCOM_UPDATE_ARTICLE"
    INTERCOM_UPDATE_COLLECTION = "INTERCOM_UPDATE_COLLECTION"
    INTERCOM_UPDATE_COMPANY = "INTERCOM_UPDATE_COMPANY"
    INTERCOM_UPDATE_CONTACT = "INTERCOM_UPDATE_CONTACT"

    # Kernel actions
    KERNEL_GET_BROWSER_SESSION_DETAILS = "KERNEL_GET_BROWSER_SESSION_DETAILS"
    KERNEL_GET_DEPLOYMENT_DETAILS = "KERNEL_GET_DEPLOYMENT_DETAILS"
    KERNEL_LIST_ACTIVE_BROWSER_SESSIONS = "KERNEL_LIST_ACTIVE_BROWSER_SESSIONS"
    KERNEL_GET_INVOCATION_STATUS = "KERNEL_GET_INVOCATION_STATUS"
    KERNEL_LIST_APPLICATIONS = "KERNEL_LIST_APPLICATIONS"
    KERNEL_CREATE_BROWSER_SESSION = "KERNEL_CREATE_BROWSER_SESSION"
    KERNEL_INVOKE_ACTION = "KERNEL_INVOKE_ACTION"
    KERNEL_DELETE_PERSISTENT_BROWSER_SESSION = "KERNEL_DELETE_PERSISTENT_BROWSER_SESSION"

    # Loops actions
    LOOPS_LIST_MAILING_LISTS = "LOOPS_LIST_MAILING_LISTS"
    LOOPS_FIND_CONTACT = "LOOPS_FIND_CONTACT"
    LOOPS_TEST_API_KEY_VALIDITY = "LOOPS_TEST_API_KEY_VALIDITY"
    LOOPS_LIST_TRANSACTIONAL_EMAILS = "LOOPS_LIST_TRANSACTIONAL_EMAILS"
    LOOPS_LIST_CONTACT_PROPERTIES = "LOOPS_LIST_CONTACT_PROPERTIES"
    LOOPS_SEND_EVENT = "LOOPS_SEND_EVENT"
    LOOPS_CREATE_CONTACT = "LOOPS_CREATE_CONTACT"
    LOOPS_DELETE_CONTACT = "LOOPS_DELETE_CONTACT"
    LOOPS_CREATE_CONTACT_PROPERTY = "LOOPS_CREATE_CONTACT_PROPERTY"
    LOOPS_SEND_TRANSACTIONAL_EMAIL = "LOOPS_SEND_TRANSACTIONAL_EMAIL"
    LOOPS_UPDATE_OR_CREATE_CONTACT = "LOOPS_UPDATE_OR_CREATE_CONTACT"

    # Mailchimp actions
    MAILCHIMP_GET_CAMPAIGN_INFO = "MAILCHIMP_GET_CAMPAIGN_INFO"
    MAILCHIMP_GET_LISTS_INFO = "MAILCHIMP_GET_LISTS_INFO"
    MAILCHIMP_LIST_CAMPAIGNS = "MAILCHIMP_LIST_CAMPAIGNS"
    MAILCHIMP_LIST_RECENT_ACTIVITY = "MAILCHIMP_LIST_RECENT_ACTIVITY"
    MAILCHIMP_SEARCH_MEMBERS = "MAILCHIMP_SEARCH_MEMBERS"
    MAILCHIMP_SEND_CAMPAIGN = "MAILCHIMP_SEND_CAMPAIGN"
    MAILCHIMP_ADD_AUTOMATION = "MAILCHIMP_ADD_AUTOMATION"
    MAILCHIMP_ADD_BATCH_WEBHOOK = "MAILCHIMP_ADD_BATCH_WEBHOOK"
    MAILCHIMP_ADD_CAMPAIGN = "MAILCHIMP_ADD_CAMPAIGN"
    MAILCHIMP_ADD_CAMPAIGN_FEEDBACK = "MAILCHIMP_ADD_CAMPAIGN_FEEDBACK"
    MAILCHIMP_ADD_CAMPAIGN_FOLDER = "MAILCHIMP_ADD_CAMPAIGN_FOLDER"
    MAILCHIMP_ADD_CART = "MAILCHIMP_ADD_CART"
    MAILCHIMP_ADD_PRODUCT = "MAILCHIMP_ADD_PRODUCT"
    MAILCHIMP_ADD_PRODUCT_IMAGE = "MAILCHIMP_ADD_PRODUCT_IMAGE"
    MAILCHIMP_ADD_PRODUCT_VARIANT = "MAILCHIMP_ADD_PRODUCT_VARIANT"
    MAILCHIMP_ADD_PROMO_CODE = "MAILCHIMP_ADD_PROMO_CODE"
    MAILCHIMP_ADD_PROMO_RULE = "MAILCHIMP_ADD_PROMO_RULE"
    MAILCHIMP_ADD_SEGMENT = "MAILCHIMP_ADD_SEGMENT"

    # Meetgeek actions
    MEETGEEK_GET_TEAMS_OF_USER = "MEETGEEK_GET_TEAMS_OF_USER"
    MEETGEEK_GET_TRANSCRIPT_SENTENCES_BY_MEETING_ID = "MEETGEEK_GET_TRANSCRIPT_SENTENCES_BY_MEETING_ID"
    MEETGEEK_GET_HIGHLIGHTS_BY_MEETING_ID = "MEETGEEK_GET_HIGHLIGHTS_BY_MEETING_ID"
    MEETGEEK_GET_SUMMARY_BY_MEETING_ID = "MEETGEEK_GET_SUMMARY_BY_MEETING_ID"
    MEETGEEK_GET_PAGINATED_TEAM_MEETINGS = "MEETGEEK_GET_PAGINATED_TEAM_MEETINGS"
    MEETGEEK_GET_PAGINATED_PAST_MEETINGS = "MEETGEEK_GET_PAGINATED_PAST_MEETINGS"
    MEETGEEK_GET_MEETING_DETAILS = "MEETGEEK_GET_MEETING_DETAILS"
    MEETGEEK_UPLOAD_FILE_FOR_ANALYSIS = "MEETGEEK_UPLOAD_FILE_FOR_ANALYSIS"

    # Netlify actions
    NETLIFY_GET_SITE_DEV_SERVER_HOOK = "NETLIFY_GET_SITE_DEV_SERVER_HOOK"
    NETLIFY_LIST_PAYMENT_METHODS_FOR_USER = "NETLIFY_LIST_PAYMENT_METHODS_FOR_USER"
    NETLIFY_SHOW_SERVICE_INSTANCE = "NETLIFY_SHOW_SERVICE_INSTANCE"
    NETLIFY_GET_SINGLE_DNS_ZONE = "NETLIFY_GET_SINGLE_DNS_ZONE"
    NETLIFY_SHOW_SITE_TLS_CERTIFICATE = "NETLIFY_SHOW_SITE_TLS_CERTIFICATE"
    NETLIFY_LIST_SITES_FOR_ACCOUNT = "NETLIFY_LIST_SITES_FOR_ACCOUNT"
    NETLIFY_LIST_DEPLOY_KEYS = "NETLIFY_LIST_DEPLOY_KEYS"
    NETLIFY_LIST_SITE_SNIPPETS = "NETLIFY_LIST_SITE_SNIPPETS"
    NETLIFY_GET_SITE_ASSET_INFO = "NETLIFY_GET_SITE_ASSET_INFO"
    NETLIFY_GET_SITE_DEV_SERVER = "NETLIFY_GET_SITE_DEV_SERVER"
    NETLIFY_LIST_ACCOUNT_TYPES_FOR_USER = "NETLIFY_LIST_ACCOUNT_TYPES_FOR_USER"
    NETLIFY_GET_HOOK_DETAILS = "NETLIFY_GET_HOOK_DETAILS"
    NETLIFY_GET_ACCOUNT_BUILD_STATUS = "NETLIFY_GET_ACCOUNT_BUILD_STATUS"
    NETLIFY_GET_DNS_RECORDS_FOR_SITE = "NETLIFY_GET_DNS_RECORDS_FOR_SITE"
    NETLIFY_LIST_BUILD_HOOKS_FOR_SITE = "NETLIFY_LIST_BUILD_HOOKS_FOR_SITE"
    NETLIFY_GET_SITE_BUILD = "NETLIFY_GET_SITE_BUILD"
    NETLIFY_LIST_DEPLOYS_FOR_SITE = "NETLIFY_LIST_DEPLOYS_FOR_SITE"
    NETLIFY_GET_SPLIT_TEST_DETAILS = "NETLIFY_GET_SPLIT_TEST_DETAILS"
    NETLIFY_LIST_FORM_SUBMISSION = "NETLIFY_LIST_FORM_SUBMISSION"
    NETLIFY_SEARCH_SITE_FUNCTIONS = "NETLIFY_SEARCH_SITE_FUNCTIONS"
    NETLIFY_GET_PUBLIC_SIGNATURE_URL_FOR_SITE_ASSET = "NETLIFY_GET_PUBLIC_SIGNATURE_URL_FOR_SITE_ASSET"
    NETLIFY_GET_CURRENT_USER = "NETLIFY_GET_CURRENT_USER"
    NETLIFY_GET_DNS_ZONES = "NETLIFY_GET_DNS_ZONES"
    NETLIFY_GET_SITE_DEPLOY = "NETLIFY_GET_SITE_DEPLOY"
    NETLIFY_LIST_FORMS_FOR_SITE = "NETLIFY_LIST_FORMS_FOR_SITE"
    NETLIFY_GET_ENVIRONMENT_VARIABLE_FOR_ACCOUNT = "NETLIFY_GET_ENVIRONMENT_VARIABLE_FOR_ACCOUNT"
    NETLIFY_LIST_SITE_SUBMISSIONS = "NETLIFY_LIST_SITE_SUBMISSIONS"
    NETLIFY_GET_ENVIRONMENT_VARIABLES_FOR_SITE = "NETLIFY_GET_ENVIRONMENT_VARIABLES_FOR_SITE"
    NETLIFY_SHOW_OAUTH_TICKET = "NETLIFY_SHOW_OAUTH_TICKET"
    NETLIFY_GET_SITE_SNIPPET = "NETLIFY_GET_SITE_SNIPPET"
    NETLIFY_LIST_FORM_SUBMISSIONS = "NETLIFY_LIST_FORM_SUBMISSIONS"
    NETLIFY_LIST_SITE_FILES = "NETLIFY_LIST_SITE_FILES"
    NETLIFY_GET_ACCOUNT_MEMBER_DETAILS = "NETLIFY_GET_ACCOUNT_MEMBER_DETAILS"
    NETLIFY_GET_ALL_CERTIFICATES_FOR_SITE = "NETLIFY_GET_ALL_CERTIFICATES_FOR_SITE"
    NETLIFY_GET_DEPLOY_KEY = "NETLIFY_GET_DEPLOY_KEY"
    NETLIFY_GET_INDIVIDUAL_DNS_RECORD = "NETLIFY_GET_INDIVIDUAL_DNS_RECORD"
    NETLIFY_LIST_SITES = "NETLIFY_LIST_SITES"
    NETLIFY_SHOW_SERVICE_DETAILS = "NETLIFY_SHOW_SERVICE_DETAILS"
    NETLIFY_LIST_DEPLOYED_BRANCHES_FOR_SITE = "NETLIFY_LIST_DEPLOYED_BRANCHES_FOR_SITE"
    NETLIFY_LIST_SERVICE_INSTANCES_FOR_SITE = "NETLIFY_LIST_SERVICE_INSTANCES_FOR_SITE"
    NETLIFY_GET_DEPLOY_DETAILS = "NETLIFY_GET_DEPLOY_DETAILS"
    NETLIFY_LIST_ACCOUNTS_FOR_USER = "NETLIFY_LIST_ACCOUNTS_FOR_USER"
    NETLIFY_LIST_SITE_BUILDS = "NETLIFY_LIST_SITE_BUILDS"
    NETLIFY_GET_SITE_METADATA = "NETLIFY_GET_SITE_METADATA"
    NETLIFY_LIST_ACCOUNT_AUDIT_EVENTS = "NETLIFY_LIST_ACCOUNT_AUDIT_EVENTS"
    NETLIFY_LIST_SITE_DEV_SERVERS = "NETLIFY_LIST_SITE_DEV_SERVERS"
    NETLIFY_GET_ENVIRONMENT_VARIABLES = "NETLIFY_GET_ENVIRONMENT_VARIABLES"
    NETLIFY_LIST_HOOK_TYPES = "NETLIFY_LIST_HOOK_TYPES"
    NETLIFY_GET_SITE_BUILD_HOOK = "NETLIFY_GET_SITE_BUILD_HOOK"
    NETLIFY_GET_ALL_DNS_RECORDS_FOR_SINGLE_DNS_ZONE = "NETLIFY_GET_ALL_DNS_RECORDS_FOR_SINGLE_DNS_ZONE"
    NETLIFY_LIST_MEMBERS_FOR_ACCOUNT = "NETLIFY_LIST_MEMBERS_FOR_ACCOUNT"
    NETLIFY_GET_ACCOUNT_INFORMATION = "NETLIFY_GET_ACCOUNT_INFORMATION"
    NETLIFY_GET_SPLIT_TESTS_FOR_SITE = "NETLIFY_GET_SPLIT_TESTS_FOR_SITE"
    NETLIFY_SHOW_SERVICE_MANIFEST = "NETLIFY_SHOW_SERVICE_MANIFEST"
    NETLIFY_GET_SITE_FILE_BY_PATH_NAME = "NETLIFY_GET_SITE_FILE_BY_PATH_NAME"
    NETLIFY_GET_LIST_OF_SERVICES = "NETLIFY_GET_LIST_OF_SERVICES"
    NETLIFY_LIST_HOOKS_BY_SITE_ID = "NETLIFY_LIST_HOOKS_BY_SITE_ID"
    NETLIFY_LIST_SITE_ASSETS = "NETLIFY_LIST_SITE_ASSETS"
    NETLIFY_LIST_SITE_DEV_SERVER_HOOKS = "NETLIFY_LIST_SITE_DEV_SERVER_HOOKS"

    # Newsdata actions
    NEWSDATA_GET_NEWS_SOURCES = "NEWSDATA_GET_NEWS_SOURCES",
    NEWSDATA_GET_LATEST_NEWS = "NEWSDATA_GET_LATEST_NEWS",
    NEWSDATA_GET_CRYPTO_NEWS = "NEWSDATA_GET_CRYPTO_NEWS",
    NEWSDATA_GET_NEWS_ARCHIVE = "NEWSDATA_GET_NEWS_ARCHIVE",

    # Peopledatalabs actions
    PEOPLEDATALABS_PERSON_SEARCH = "PEOPLEDATALABS_PERSON_SEARCH"

    # Openrouter actions
    OPENROUTER_GET_CREDITS = "OPENROUTER_GET_CREDITS"
    OPENROUTER_LIST_AVAILABLE_PROVIDERS = "OPENROUTER_LIST_AVAILABLE_PROVIDERS"
    OPENROUTER_GET_CURRENT_API_KEY_INFO = "OPENROUTER_GET_CURRENT_API_KEY_INFO"
    OPENROUTER_LIST_AVAILABLE_MODELS = "OPENROUTER_LIST_AVAILABLE_MODELS"
    OPENROUTER_LIST_ENDPOINTS_FOR_MODEL = "OPENROUTER_LIST_ENDPOINTS_FOR_MODEL"
    OPENROUTER_GET_API_KEY_DETAILS = "OPENROUTER_GET_API_KEY_DETAILS"
    OPENROUTER_GET_GENERATION = "OPENROUTER_GET_GENERATION"
    OPENROUTER_LIST_API_KEYS = "OPENROUTER_LIST_API_KEYS"
    OPENROUTER_CREATE_COINBASE_CHARGE = "OPENROUTER_CREATE_COINBASE_CHARGE"
    OPENROUTER_CREATE_API_KEY = "OPENROUTER_CREATE_API_KEY"
    OPENROUTER_EXCHANGE_OAUTH_CODE = "OPENROUTER_EXCHANGE_OAUTH_CODE"
    OPENROUTER_SEND_CHAT_COMPLETION = "OPENROUTER_SEND_CHAT_COMPLETION"
    OPENROUTER_SEND_COMPLETION = "OPENROUTER_SEND_COMPLETION"
    OPENROUTER_DELETE_API_KEY = "OPENROUTER_DELETE_API_KEY"
    OPENROUTER_UPDATE_API_KEY = "OPENROUTER_UPDATE_API_KEY"

    # Pinecone actions
    PINECONE_LIST_INDEXES = "PINECONE_LIST_INDEXES"
    PINECONE_DESCRIBE_IMPORT = "PINECONE_DESCRIBE_IMPORT"
    PINECONE_LIST_IMPORTS = "PINECONE_LIST_IMPORTS"
    PINECONE_LIST_COLLECTIONS = "PINECONE_LIST_COLLECTIONS"
    PINECONE_LIST_VECTOR_IDS = "PINECONE_LIST_VECTOR_IDS"
    PINECONE_DESCRIBE_INDEX = "PINECONE_DESCRIBE_INDEX"
    PINECONE_DESCRIBE_COLLECTION = "PINECONE_DESCRIBE_COLLECTION"
    PINECONE_FETCH_VECTORS = "PINECONE_FETCH_VECTORS"
    PINECONE_CREATE_COLLECTION = "PINECONE_CREATE_COLLECTION"
    PINECONE_QUERY_VECTORS = "PINECONE_QUERY_VECTORS"
    PINECONE_GET_INDEX_STATS = "PINECONE_GET_INDEX_STATS"
    PINECONE_UPSERT_VECTORS = "PINECONE_UPSERT_VECTORS"
    PINECONE_START_IMPORT = "PINECONE_START_IMPORT"
    PINECONE_DELETE_VECTORS = "PINECONE_DELETE_VECTORS"
    PINECONE_UPDATE_VECTOR = "PINECONE_UPDATE_VECTOR"
    PINECONE_CREATE_INDEX = "PINECONE_CREATE_INDEX"
    PINECONE_DELETE_INDEX = "PINECONE_DELETE_INDEX"
    PINECONE_DELETE_COLLECTION = "PINECONE_DELETE_COLLECTION"
    PINECONE_CANCEL_IMPORT_OPERATION = "PINECONE_CANCEL_IMPORT_OPERATION"
    PINECONE_CONFIGURE_INDEX = "PINECONE_CONFIGURE_INDEX"

    # Place actions
    PLACES_GET_PLACE_DETAILS = "PLACES_GET_PLACE_DETAILS"
    PLACES_SEARCH_NEARBY_PLACES = "PLACES_SEARCH_NEARBY_PLACES"
    PLACES_TEXT_SEARCH_PLACES = "PLACES_TEXT_SEARCH_PLACES"
    PLACES_AUTOCOMPLETE_PLACES = "PLACES_AUTOCOMPLETE_PLACES"
    PLACES_GET_PLACE_PHOTOS = "PLACES_GET_PLACE_PHOTOS"
    PLACES_SEARCH_PLACES_BY_CATEGORY = "PLACES_SEARCH_PLACES_BY_CATEGORY"
    PLACES_GET_PLACE_REVIEWS = "PLACES_GET_PLACE_REVIEWS"
    PLACES_GET_OPENING_HOURS = "PLACES_GET_OPENING_HOURS"
    PLACES_REVERSE_GEOCODE = "PLACES_REVERSE_GEOCODE"
    PLACES_GEOCODE_ADDRESS = "PLACES_GEOCODE_ADDRESS"
    PLACES_VALIDATE_ADDRESS = "PLACES_VALIDATE_ADDRESS"

    # Posthog actions
    POSTHOG_LIST_PROJECTS = "POSTHOG_LIST_PROJECTS"
    POSTHOG_LIST_PROJECT_GROUP_TYPES = "POSTHOG_LIST_PROJECT_GROUP_TYPES"
    POSTHOG_LIST_ORGANIZATIONS = "POSTHOG_LIST_ORGANIZATIONS"
    POSTHOG_ADD_DASHBOARD_COLLABORATORS = "POSTHOG_ADD_DASHBOARD_COLLABORATORS"
    POSTHOG_ADD_ORGANIZATION_MEMBER_ROLE = "POSTHOG_ADD_ORGANIZATION_MEMBER_ROLE"
    POSTHOG_ADD_PROJECT_MEMBER_ROLES = "POSTHOG_ADD_PROJECT_MEMBER_ROLES"
    POSTHOG_ASSIGN_FEATURE_FLAG_ROLE_ACCESS = "POSTHOG_ASSIGN_FEATURE_FLAG_ROLE_ACCESS"
    POSTHOG_BOOKMARK_PROJECT_ACTIVITY_NOTIFICATION = "POSTHOG_BOOKMARK_PROJECT_ACTIVITY_NOTIFICATION"
    POSTHOG_BULK_CREATE_ORGANIZATION_INVITES = "POSTHOG_BULK_CREATE_ORGANIZATION_INVITES"
    POSTHOG_CANCEL_PROJECT_INSIGHTS = "POSTHOG_CANCEL_PROJECT_INSIGHTS"
    POSTHOG_CHECK_PIPELINE_DESTINATION_UPDATES = "POSTHOG_CHECK_PIPELINE_DESTINATION_UPDATES"
    POSTHOG_CHECK_PIPELINE_IMPORT_APP_UPDATES = "POSTHOG_CHECK_PIPELINE_IMPORT_APP_UPDATES"
    POSTHOG_CHECK_PIPELINE_PLUGIN_UPDATE_STATUS = "POSTHOG_CHECK_PIPELINE_PLUGIN_UPDATE_STATUS"
    POSTHOG_CHECK_PROJECT_DEMO_DATA_GENERATION_STATUS = "POSTHOG_CHECK_PROJECT_DEMO_DATA_GENERATION_STATUS"
    POSTHOG_DUPLICATE_COHORT_TO_STATIC = "POSTHOG_DUPLICATE_COHORT_TO_STATIC"
    POSTHOG_CREATE_NOTEBOOK = "POSTHOG_CREATE_NOTEBOOK"
    POSTHOG_CREATE_PROJECT_INSIGHTS = "POSTHOG_CREATE_PROJECT_INSIGHTS"
    POSTHOG_CREATE_DASHBOARD_FROM_TEMPLATE = "POSTHOG_CREATE_DASHBOARD_FROM_TEMPLATE"
    POSTHOG_CREATE_ORGANIZATION_DOMAIN = "POSTHOG_CREATE_ORGANIZATION_DOMAIN"
    POSTHOG_CREATE_EXPERIMENT_EXPOSURE_COHORT = "POSTHOG_CREATE_EXPERIMENT_EXPOSURE_COHORT"
    POSTHOG_CREATE_FEATURE_FLAG = "POSTHOG_CREATE_FEATURE_FLAG"
    POSTHOG_CREATE_FEATURE_FLAG_DASHBOARD = "POSTHOG_CREATE_FEATURE_FLAG_DASHBOARD"
    POSTHOG_CREATE_FRONTEND_APP_PIPELINE_CONFIG = "POSTHOG_CREATE_FRONTEND_APP_PIPELINE_CONFIG"
    POSTHOG_CREATE_FUNNEL_ANALYSIS_FOR_PERSONS = "POSTHOG_CREATE_FUNNEL_ANALYSIS_FOR_PERSONS"
    POSTHOG_CREATE_ORGANIZATION = "POSTHOG_CREATE_ORGANIZATION"
    POSTHOG_CREATE_PROJECT_EXPERIMENT = "POSTHOG_CREATE_PROJECT_EXPERIMENT"
    POSTHOG_CREATE_ORGANIZATION_INVITE = "POSTHOG_CREATE_ORGANIZATION_INVITE"
    POSTHOG_CREATE_ORGANIZATION_ROLE = "POSTHOG_CREATE_ORGANIZATION_ROLE"
    POSTHOG_CREATE_ORGANIZATION_PROXY_RECORD = "POSTHOG_CREATE_ORGANIZATION_PROXY_RECORD"
    POSTHOG_CREATE_PERSON_FUNNEL_CORRELATION = "POSTHOG_CREATE_PERSON_FUNNEL_CORRELATION"
    POSTHOG_CREATE_PERSON_PATH = "POSTHOG_CREATE_PERSON_PATH"
    POSTHOG_CREATE_PIPELINE_DESTINATION_CONFIG = "POSTHOG_CREATE_PIPELINE_DESTINATION_CONFIG"
    POSTHOG_CREATE_PIPELINE_DESTINATION_CONFIG_JOB = "POSTHOG_CREATE_PIPELINE_DESTINATION_CONFIG_JOB"
    POSTHOG_CREATE_PIPELINE_IMPORT_APPS_CONFIG_JOB = "POSTHOG_CREATE_PIPELINE_IMPORT_APPS_CONFIG_JOB"
    POSTHOG_CREATE_PLUGIN_JOB_CONFIGURATION = "POSTHOG_CREATE_PLUGIN_JOB_CONFIGURATION"
    POSTHOG_CREATE_PROJECT_ACTION = "POSTHOG_CREATE_PROJECT_ACTION"
    POSTHOG_CREATE_PROJECT_COHORTS = "POSTHOG_CREATE_PROJECT_COHORTS"
    POSTHOG_CREATE_PROJECT_DASHBOARD = "POSTHOG_CREATE_PROJECT_DASHBOARD"
    POSTHOG_CREATE_PROJECT_PIPELINE_APP_CONFIGS = "POSTHOG_CREATE_PROJECT_PIPELINE_APP_CONFIGS"
    POSTHOG_CREATE_PROJECT_PIPELINE_FRONTEND_APP_JOB = "POSTHOG_CREATE_PROJECT_PIPELINE_FRONTEND_APP_JOB"
    POSTHOG_CREATE_PROJECT_PIPELINE_TRANSFORMATION_CONFIG = "POSTHOG_CREATE_PROJECT_PIPELINE_TRANSFORMATION_CONFIG"
    POSTHOG_CREATE_PROJECT_PLUGIN_CONFIGURATION = "POSTHOG_CREATE_PROJECT_PLUGIN_CONFIGURATION"
    POSTHOG_CREATE_PROJECT_SUBSCRIPTION = "POSTHOG_CREATE_PROJECT_SUBSCRIPTION"
    POSTHOG_CREATE_PROJECT_SURVEYS = "POSTHOG_CREATE_PROJECT_SURVEYS"
    POSTHOG_CREATE_PROJECT_TIMING_INSIGHTS = "POSTHOG_CREATE_PROJECT_TIMING_INSIGHTS"
    POSTHOG_CREATE_PROJECT_QUERY = "POSTHOG_CREATE_PROJECT_QUERY"
    POSTHOG_CREATE_RETENTION_INSIGHTS = "POSTHOG_CREATE_RETENTION_INSIGHTS"
    POSTHOG_CREATE_SESSION_RECORDING_IN_PLAYLIST = "POSTHOG_CREATE_SESSION_RECORDING_IN_PLAYLIST"
    POSTHOG_CREATE_SESSION_RECORDING_PLAYLISTS = "POSTHOG_CREATE_SESSION_RECORDING_PLAYLISTS"
    POSTHOG_CREATE_SESSION_RECORDING_SUMMARY = "POSTHOG_CREATE_SESSION_RECORDING_SUMMARY"
    POSTHOG_CREATE_STATIC_COHORT_FOR_FEATURE_FLAG = "POSTHOG_CREATE_STATIC_COHORT_FOR_FEATURE_FLAG"
    POSTHOG_MANAGE_PROJECT_ANNOTATIONS = "POSTHOG_MANAGE_PROJECT_ANNOTATIONS"
    POSTHOG_GENERATE_PROJECT_FUNNEL_INSIGHTS = "POSTHOG_GENERATE_PROJECT_FUNNEL_INSIGHTS"
    POSTHOG_DELETE_ORGANIZATION = "POSTHOG_DELETE_ORGANIZATION"
    POSTHOG_DELETE_ORGANIZATION_PROJECT = "POSTHOG_DELETE_ORGANIZATION_PROJECT"
    POSTHOG_DELETE_PERSON = "POSTHOG_DELETE_PERSON"
    POSTHOG_DELETE_SESSION_RECORDING = "POSTHOG_DELETE_SESSION_RECORDING"
    POSTHOG_DELETE_SURVEY = "POSTHOG_DELETE_SURVEY"
    POSTHOG_ENABLE_PROJECT_EARLY_ACCESS_FEATURE = "POSTHOG_ENABLE_PROJECT_EARLY_ACCESS_FEATURE"
    POSTHOG_FETCH_BATCH_EXPORT_DETAILS = "POSTHOG_FETCH_BATCH_EXPORT_DETAILS"
    POSTHOG_FETCH_EXPORT_UNSUBSCRIBE_SETTINGS = "POSTHOG_FETCH_EXPORT_UNSUBSCRIBE_SETTINGS"
    POSTHOG_FETCH_FRONTEND_APP_CONFIG_STATUS = "POSTHOG_FETCH_FRONTEND_APP_CONFIG_STATUS"
    POSTHOG_FETCH_ORGANIZATION_DETAILS = "POSTHOG_FETCH_ORGANIZATION_DETAILS"
    POSTHOG_FETCH_ORGANIZATION_PIPELINE_APP_REPOSITORIES = "POSTHOG_FETCH_ORGANIZATION_PIPELINE_APP_REPOSITORIES"
    POSTHOG_FETCH_PIPELINE_DESTINATION_DETAILS = "POSTHOG_FETCH_PIPELINE_DESTINATION_DETAILS"

    # Quickchart actions
    QUICKCHART_CREATE_CHART = "QUICKCHART_CREATE_CHART"
    QUICKCHART_CREATE_QR_CODE = "QUICKCHART_CREATE_QR_CODE"
    QUICKCHART_CREATE_SHORT_URL = "QUICKCHART_CREATE_SHORT_URL"
    QUICKCHART_CREATE_CHART_POST = "QUICKCHART_CREATE_CHART_POST"

    # Resend actions
    RESEND_RETRIEVE_BROADCAST = "RESEND_RETRIEVE_BROADCAST"
    RESEND_LIST_AUDIENCES = "RESEND_LIST_AUDIENCES"
    RESEND_LIST_API_KEYS = "RESEND_LIST_API_KEYS"
    RESEND_LIST_CONTACTS = "RESEND_LIST_CONTACTS"
    RESEND_RETRIEVE_CONTACT = "RESEND_RETRIEVE_CONTACT"
    RESEND_RETRIEVE_AUDIENCE = "RESEND_RETRIEVE_AUDIENCE"
    RESEND_LIST_BROADCASTS = "RESEND_LIST_BROADCASTS"
    RESEND_RETRIEVE_DOMAIN = "RESEND_RETRIEVE_DOMAIN"
    RESEND_LIST_DOMAINS = "RESEND_LIST_DOMAINS"
    RESEND_RETRIEVE_EMAIL = "RESEND_RETRIEVE_EMAIL"
    RESEND_CANCEL_EMAIL = "RESEND_CANCEL_EMAIL"
    RESEND_SEND_BROADCAST = "RESEND_SEND_BROADCAST"
    RESEND_CREATE_API_KEY = "RESEND_CREATE_API_KEY"
    RESEND_CREATE_AUDIENCE = "RESEND_CREATE_AUDIENCE"
    RESEND_CREATE_CONTACT = "RESEND_CREATE_CONTACT"
    RESEND_CREATE_BROADCAST = "RESEND_CREATE_BROADCAST"
    RESEND_CREATE_DOMAIN = "RESEND_CREATE_DOMAIN"
    RESEND_VERIFY_DOMAIN = "RESEND_VERIFY_DOMAIN"
    RESEND_SEND_BATCH_EMAILS = "RESEND_SEND_BATCH_EMAILS"
    RESEND_SEND_EMAIL = "RESEND_SEND_EMAIL"
    RESEND_DELETE_API_KEY = "RESEND_DELETE_API_KEY"
    RESEND_DELETE_CONTACT = "RESEND_DELETE_CONTACT"
    RESEND_DELETE_BROADCAST = "RESEND_DELETE_BROADCAST"
    RESEND_DELETE_AUDIENCE = "RESEND_DELETE_AUDIENCE"
    RESEND_DELETE_DOMAIN = "RESEND_DELETE_DOMAIN"
    RESEND_UPDATE_CONTACT = "RESEND_UPDATE_CONTACT"
    RESEND_UPDATE_EMAIL = "RESEND_UPDATE_EMAIL"
    RESEND_UPDATE_DOMAIN = "RESEND_UPDATE_DOMAIN"

    # Scrapingdog actions
    SCRAPINGDOG_SCRAPE_GOOGLE_VIDEOS_SEARCH_RESULTS = "SCRAPINGDOG_SCRAPE_GOOGLE_VIDEOS_SEARCH_RESULTS"
    SCRAPINGDOG_GET_AMAZON_AUTOCOMPLETE_SUGGESTIONS = "SCRAPINGDOG_GET_AMAZON_AUTOCOMPLETE_SUGGESTIONS"
    SCRAPINGDOG_GET_GOOGLE_NEWS_SEARCH_RESULTS = "SCRAPINGDOG_GET_GOOGLE_NEWS_SEARCH_RESULTS"
    SCRAPINGDOG_GET_GOOGLE_MAPS_REVIEWS = "SCRAPINGDOG_GET_GOOGLE_MAPS_REVIEWS"
    SCRAPINGDOG_RETRIEVE_INSTAGRAM_PROFILE_POSTS = "SCRAPINGDOG_RETRIEVE_INSTAGRAM_PROFILE_POSTS"
    SCRAPINGDOG_SCRAPE_GOOGLE_IMAGES_RESULTS = "SCRAPINGDOG_SCRAPE_GOOGLE_IMAGES_RESULTS"
    SCRAPINGDOG_GET_GOOGLE_PATENT_DETAILS = "SCRAPINGDOG_GET_GOOGLE_PATENT_DETAILS"
    SCRAPINGDOG_SCRAPE_LINKEDIN_POST = "SCRAPINGDOG_SCRAPE_LINKEDIN_POST"
    SCRAPINGDOG_GET_INSTAGRAM_PROFILE_INFORMATION = "SCRAPINGDOG_GET_INSTAGRAM_PROFILE_INFORMATION"
    SCRAPINGDOG_GET_GOOGLE_JOBS_SEARCH_RESULTS = "SCRAPINGDOG_GET_GOOGLE_JOBS_SEARCH_RESULTS"
    SCRAPINGDOG_SCRAPE_GOOGLE_SCHOLAR_SEARCH_RESULTS = "SCRAPINGDOG_SCRAPE_GOOGLE_SCHOLAR_SEARCH_RESULTS"
    SCRAPINGDOG_SCRAPE_ZILLOW_SEARCH_RESULTS = "SCRAPINGDOG_SCRAPE_ZILLOW_SEARCH_RESULTS"
    SCRAPINGDOG_SCRAPE_GOOGLE_LOCAL_RESULTS = "SCRAPINGDOG_SCRAPE_GOOGLE_LOCAL_RESULTS"
    SCRAPINGDOG_GET_GOOGLE_PATENTS_SEARCH_RESULTS = "SCRAPINGDOG_GET_GOOGLE_PATENTS_SEARCH_RESULTS"
    SCRAPINGDOG_SCRAPE_X_PROFILE_BY_PROFILE_ID = "SCRAPINGDOG_SCRAPE_X_PROFILE_BY_PROFILE_ID"
    SCRAPINGDOG_SCRAPE_WEBPAGE = "SCRAPINGDOG_SCRAPE_WEBPAGE"
    SCRAPINGDOG_SCRAPE_GOOGLE_FINANCE_DATA = "SCRAPINGDOG_SCRAPE_GOOGLE_FINANCE_DATA"
    SCRAPINGDOG_GET_WALMART_PRODUCT_REVIEWS = "SCRAPINGDOG_GET_WALMART_PRODUCT_REVIEWS"
    SCRAPINGDOG_SCRAPE_WALMART_SEARCH_RESULTS = "SCRAPINGDOG_SCRAPE_WALMART_SEARCH_RESULTS"
    SCRAPINGDOG_SCRAPE_AMAZON_PRODUCT_REVIEWS = "SCRAPINGDOG_SCRAPE_AMAZON_PRODUCT_REVIEWS"
    SCRAPINGDOG_GET_GOOGLE_SHOPPING_RESULTS = "SCRAPINGDOG_GET_GOOGLE_SHOPPING_RESULTS"
    SCRAPINGDOG_GET_GOOGLE_MAPS_POSTS_FOR_LOCATION = "SCRAPINGDOG_GET_GOOGLE_MAPS_POSTS_FOR_LOCATION"
    SCRAPINGDOG_GET_GOOGLE_SCHOLAR_AUTHOR_DATA = "SCRAPINGDOG_GET_GOOGLE_SCHOLAR_AUTHOR_DATA"
    SCRAPINGDOG_SCRAPE_LINKEDIN_COMPANY_PROFILE = "SCRAPINGDOG_SCRAPE_LINKEDIN_COMPANY_PROFILE"
    SCRAPINGDOG_GET_GOOGLE_AUTOCOMPLETE_SUGGESTIONS = "SCRAPINGDOG_GET_GOOGLE_AUTOCOMPLETE_SUGGESTIONS"
    SCRAPINGDOG_GET_GOOGLE_SCHOLAR_PROFILES = "SCRAPINGDOG_GET_GOOGLE_SCHOLAR_PROFILES"
    SCRAPINGDOG_SCRAPE_AMAZON_PRODUCT_DETAILS = "SCRAPINGDOG_SCRAPE_AMAZON_PRODUCT_DETAILS"
    SCRAPINGDOG_SCRAPE_LINKEDIN_JOB_OVERVIEW = "SCRAPINGDOG_SCRAPE_LINKEDIN_JOB_OVERVIEW"
    SCRAPINGDOG_SCRAPE_LINKEDIN_JOBS = "SCRAPINGDOG_SCRAPE_LINKEDIN_JOBS"
    SCRAPINGDOG_GET_GOOGLE_MAPS_PLACE_DETAILS = "SCRAPINGDOG_GET_GOOGLE_MAPS_PLACE_DETAILS"
    SCRAPINGDOG_GET_YOUTUBE_CHANNEL_DATA = "SCRAPINGDOG_GET_YOUTUBE_CHANNEL_DATA"
    SCRAPINGDOG_GET_GOOGLE_LENS_RESULTS = "SCRAPINGDOG_GET_GOOGLE_LENS_RESULTS"
    SCRAPINGDOG_GET_ACCOUNT_USAGE_INFORMATION = "SCRAPINGDOG_GET_ACCOUNT_USAGE_INFORMATION"
    SCRAPINGDOG_GET_GOOGLE_SCHOLAR_AUTHOR_CITATION_DATA = "SCRAPINGDOG_GET_GOOGLE_SCHOLAR_AUTHOR_CITATION_DATA"
    SCRAPINGDOG_TRIGGER_WEBHOOK_SCRAPING_REQUEST = "SCRAPINGDOG_TRIGGER_WEBHOOK_SCRAPING_REQUEST"
    SCRAPINGDOG_SCRAPE_WALMART_PRODUCT_DATA = "SCRAPINGDOG_SCRAPE_WALMART_PRODUCT_DATA"
    SCRAPINGDOG_SCRAPE_AMAZON_SEARCH_RESULTS = "SCRAPINGDOG_SCRAPE_AMAZON_SEARCH_RESULTS"
    SCRAPINGDOG_SCRAPE_GOOGLE_NEWS_RESULTS = "SCRAPINGDOG_SCRAPE_GOOGLE_NEWS_RESULTS"
    SCRAPINGDOG_SCRAPE_BING_SEARCH_RESULTS = "SCRAPINGDOG_SCRAPE_BING_SEARCH_RESULTS"
    SCRAPINGDOG_GET_GOOGLE_MAPS_PHOTOS = "SCRAPINGDOG_GET_GOOGLE_MAPS_PHOTOS"
    SCRAPINGDOG_GET_GOOGLE_PRODUCT_DETAILS = "SCRAPINGDOG_GET_GOOGLE_PRODUCT_DETAILS"
    SCRAPINGDOG_FETCH_GOOGLE_AI_OVERVIEW_RESULTS = "SCRAPINGDOG_FETCH_GOOGLE_AI_OVERVIEW_RESULTS"
    SCRAPINGDOG_SCRAPE_GOOGLE_SEARCH_RESULTS = "SCRAPINGDOG_SCRAPE_GOOGLE_SEARCH_RESULTS"
    SCRAPINGDOG_SCRAPE_PUBLIC_LINKEDIN_PERSON_PROFILE = "SCRAPINGDOG_SCRAPE_PUBLIC_LINKEDIN_PERSON_PROFILE"
    SCRAPINGDOG_GET_YOUTUBE_VIDEO_TRANSCRIPTS = "SCRAPINGDOG_GET_YOUTUBE_VIDEO_TRANSCRIPTS"
    SCRAPINGDOG_SCRAPE_GOOGLE_SHORTS_RESULTS = "SCRAPINGDOG_SCRAPE_GOOGLE_SHORTS_RESULTS"
    SCRAPINGDOG_SCRAPE_GOOGLE_MAPS_SEARCH_RESULTS = "SCRAPINGDOG_SCRAPE_GOOGLE_MAPS_SEARCH_RESULTS"
    SCRAPINGDOG_SEARCH_YOUTUBE_VIDEOS = "SCRAPINGDOG_SEARCH_YOUTUBE_VIDEOS"
    SCRAPINGDOG_GET_PARSED_INDEED_JOB_DATA = "SCRAPINGDOG_GET_PARSED_INDEED_JOB_DATA"
    SCRAPINGDOG_SCRAPE_YOUTUBE_COMMENTS = "SCRAPINGDOG_SCRAPE_YOUTUBE_COMMENTS"
    SCRAPINGDOG_GET_GOOGLE_TRENDS_DATA = "SCRAPINGDOG_GET_GOOGLE_TRENDS_DATA"
    SCRAPINGDOG_GET_GOOGLE_TRENDS_AUTOCOMPLETE_SUGGESTIONS = "SCRAPINGDOG_GET_GOOGLE_TRENDS_AUTOCOMPLETE_SUGGESTIONS"
    SCRAPINGDOG_TAKE_SCREENSHOT_OF_WEBPAGE = "SCRAPINGDOG_TAKE_SCREENSHOT_OF_WEBPAGE"
    SCRAPINGDOG_GET_YELP_SEARCH_RESULTS = "SCRAPINGDOG_GET_YELP_SEARCH_RESULTS"
    SCRAPINGDOG_SCRAPE_TWEET = "SCRAPINGDOG_SCRAPE_TWEET"
    SCRAPINGDOG_GET_GOOGLE_TRENDS_TRENDING_NOW_DATA = "SCRAPINGDOG_GET_GOOGLE_TRENDS_TRENDING_NOW_DATA"
    SCRAPINGDOG_POST_REQUEST_SCRAPE = "SCRAPINGDOG_POST_REQUEST_SCRAPE"

    # Sendgrind actions
    SENDGRID_SEND_EMAIL = "SENDGRID_SEND_EMAIL"
    SENDGRID_ADD_IP_TO_POOL = "SENDGRID_ADD_IP_TO_POOL"
    SENDGRID_RETRIEVE_ALL_LISTS = "SENDGRID_RETRIEVE_ALL_LISTS"
    SENDGRID_ACTIVATE_TEMPLATE_VERSION = "SENDGRID_ACTIVATE_TEMPLATE_VERSION"
    SENDGRID_ADD_IP_TO_AUTHENTICATED_DOMAIN = "SENDGRID_ADD_IP_TO_AUTHENTICATED_DOMAIN"
    SENDGRID_ADD_BATCH_IPS_TO_POOL = "SENDGRID_ADD_BATCH_IPS_TO_POOL"
    SENDGRID_ADD_RECIPIENT_TO_LIST = "SENDGRID_ADD_RECIPIENT_TO_LIST"
    SENDGRID_ADD_SENDGRID_IP = "SENDGRID_ADD_SENDGRID_IP"
    SENDGRID_ADD_IPS_TO_ACCOUNT = "SENDGRID_ADD_IPS_TO_ACCOUNT"
    SENDGRID_ADD_IPS_TO_ALLOWLIST = "SENDGRID_ADD_IPS_TO_ALLOWLIST"
    SENDGRID_ADD_OR_UPDATE_CONTACT = "SENDGRID_ADD_OR_UPDATE_CONTACT"
    SENDGRID_ADD_GLOBAL_SUPPRESSIONS = "SENDGRID_ADD_GLOBAL_SUPPRESSIONS"
    SENDGRID_ADD_SUPPRESSIONS_TO_GROUP = "SENDGRID_ADD_SUPPRESSIONS_TO_GROUP"
    SENDGRID_APPROVE_ACCESS_REQUEST = "SENDGRID_APPROVE_ACCESS_REQUEST"
    SENDGRID_ASSIGN_SUBUSERS_TO_IP = "SENDGRID_ASSIGN_SUBUSERS_TO_IP"
    SENDGRID_ASSOCIATE_DOMAIN_WITH_SUBUSER = "SENDGRID_ASSOCIATE_DOMAIN_WITH_SUBUSER"
    SENDGRID_ASSOCIATE_BRANDED_LINK_WITH_SUBUSER = "SENDGRID_ASSOCIATE_BRANDED_LINK_WITH_SUBUSER"
    SENDGRID_SSO_AUTHENTICATE = "SENDGRID_SSO_AUTHENTICATE"
    SENDGRID_AUTHENTICATE_DOMAIN = "SENDGRID_AUTHENTICATE_DOMAIN"
    SENDGRID_BIND_DOMAINS_TO_SUBUSER = "SENDGRID_BIND_DOMAINS_TO_SUBUSER"
    SENDGRID_BULK_DELETE_SINGLE_SENDS = "SENDGRID_BULK_DELETE_SINGLE_SENDS"
    SENDGRID_CANCEL_SCHEDULED_SEND = "SENDGRID_CANCEL_SCHEDULED_SEND"
    SENDGRID_GET_COMPLETED_STEPS = "SENDGRID_GET_COMPLETED_STEPS"
    SENDGRID_CREATE_ACCOUNT = "SENDGRID_CREATE_ACCOUNT"
    SENDGRID_CREATE_IP_POOL = "SENDGRID_CREATE_IP_POOL"
    SENDGRID_CREATE_IP_POOL_WITH_ASSIGNMENTS = "SENDGRID_CREATE_IP_POOL_WITH_ASSIGNMENTS"
    SENDGRID_CREATE_SSO_CERTIFICATE = "SENDGRID_CREATE_SSO_CERTIFICATE"
    SENDGRID_CREATE_SSO_INTEGRATION = "SENDGRID_CREATE_SSO_INTEGRATION"
    SENDGRID_CREATE_SSO_TEAMMATE = "SENDGRID_CREATE_SSO_TEAMMATE"
    SENDGRID_CREATE_API_KEY = "SENDGRID_CREATE_API_KEY"
    SENDGRID_CREATE_BATCH_ID = "SENDGRID_CREATE_BATCH_ID"
    SENDGRID_CREATE_BRANDED_LINK = "SENDGRID_CREATE_BRANDED_LINK"
    SENDGRID_CREATE_CAMPAIGN = "SENDGRID_CREATE_CAMPAIGN"
    SENDGRID_CREATE_CUSTOM_FIELD = "SENDGRID_CREATE_CUSTOM_FIELD"
    SENDGRID_CREATE_LIST = "SENDGRID_CREATE_LIST"
    SENDGRID_CREATE_ALERT = "SENDGRID_CREATE_ALERT"
    SENDGRID_CREATE_EVENT_WEBHOOK = "SENDGRID_CREATE_EVENT_WEBHOOK"
    SENDGRID_CREATE_SUPPRESSION_GROUP = "SENDGRID_CREATE_SUPPRESSION_GROUP"
    SENDGRID_CREATE_TEMPLATE_VERSION = "SENDGRID_CREATE_TEMPLATE_VERSION"
    SENDGRID_CREATE_PARSE_SETTING = "SENDGRID_CREATE_PARSE_SETTING"
    SENDGRID_CREATE_SEGMENT = "SENDGRID_CREATE_SEGMENT"
    SENDGRID_CREATE_SENDER = "SENDGRID_CREATE_SENDER"
    SENDGRID_CREATE_SENDER_IDENTITY = "SENDGRID_CREATE_SENDER_IDENTITY"
    SENDGRID_CREATE_TRANSACTIONAL_TEMPLATE = "SENDGRID_CREATE_TRANSACTIONAL_TEMPLATE"
    SENDGRID_CREATE_CUSTOM_FIELD_DEFINITION = "SENDGRID_CREATE_CUSTOM_FIELD_DEFINITION"
    SENDGRID_CREATE_DESIGN = "SENDGRID_CREATE_DESIGN"
    SENDGRID_CREATE_INTEGRATION = "SENDGRID_CREATE_INTEGRATION"
    SENDGRID_CREATE_CONTACTS_LIST = "SENDGRID_CREATE_CONTACTS_LIST"
    SENDGRID_CREATE_CONTACTS_SEGMENT = "SENDGRID_CREATE_CONTACTS_SEGMENT"
    SENDGRID_CREATE_SINGLE_SEND = "SENDGRID_CREATE_SINGLE_SEND"
    SENDGRID_CREATE_SUBUSER = "SENDGRID_CREATE_SUBUSER"
    SENDGRID_CREATE_VERIFIED_SENDER_REQUEST = "SENDGRID_CREATE_VERIFIED_SENDER_REQUEST"
    SENDGRID_DELETE_ACCOUNT = "SENDGRID_DELETE_ACCOUNT"
    SENDGRID_DELETE_ALERT = "SENDGRID_DELETE_ALERT"
    SENDGRID_DELETE_AUTHENTICATED_DOMAIN = "SENDGRID_DELETE_AUTHENTICATED_DOMAIN"
    SENDGRID_DELETE_IP_POOL = "SENDGRID_DELETE_IP_POOL"
    SENDGRID_DELETE_SSO_CERTIFICATE = "SENDGRID_DELETE_SSO_CERTIFICATE"
    SENDGRID_DELETE_SSO_INTEGRATION = "SENDGRID_DELETE_SSO_INTEGRATION"
    SENDGRID_DELETE_API_KEY = "SENDGRID_DELETE_API_KEY"
    SENDGRID_DELETE_BATCH_IPS_FROM_POOL = "SENDGRID_DELETE_BATCH_IPS_FROM_POOL"
    SENDGRID_DELETE_BATCH_SUBUSERS_FROM_IP = "SENDGRID_DELETE_BATCH_SUBUSERS_FROM_IP"
    SENDGRID_DELETE_BOUNCE = "SENDGRID_DELETE_BOUNCE"
    SENDGRID_DELETE_BRANDED_LINK = "SENDGRID_DELETE_BRANDED_LINK"
    SENDGRID_DELETE_CAMPAIGN = "SENDGRID_DELETE_CAMPAIGN"
    SENDGRID_DELETE_SCHEDULED_SEND_CANCELLATION = "SENDGRID_DELETE_SCHEDULED_SEND_CANCELLATION"
    SENDGRID_DELETE_CONTACT_IDENTIFIER = "SENDGRID_DELETE_CONTACT_IDENTIFIER"
    SENDGRID_DELETE_CUSTOM_FIELD = "SENDGRID_DELETE_CUSTOM_FIELD"
    SENDGRID_DELETE_DESIGN = "SENDGRID_DELETE_DESIGN"
    SENDGRID_DELETE_INVALID_EMAILS = "SENDGRID_DELETE_INVALID_EMAILS"
    SENDGRID_DELETE_PENDING_TEAMMATE = "SENDGRID_DELETE_PENDING_TEAMMATE"
    SENDGRID_DELETE_SEGMENT = "SENDGRID_DELETE_SEGMENT"
    SENDGRID_DELETE_SINGLE_SEND = "SENDGRID_DELETE_SINGLE_SEND"
    SENDGRID_DELETE_SINGLE_SEND_SCHEDULE = "SENDGRID_DELETE_SINGLE_SEND_SCHEDULE"
    SENDGRID_DELETE_SPAM_REPORTS = "SENDGRID_DELETE_SPAM_REPORTS"
    SENDGRID_DELETE_TEAMMATE = "SENDGRID_DELETE_TEAMMATE"
    SENDGRID_DELETE_VERIFIED_SENDER = "SENDGRID_DELETE_VERIFIED_SENDER"
    SENDGRID_GET_ALL_CATEGORIES = "SENDGRID_GET_ALL_CATEGORIES"
    SENDGRID_GET_ALL_FIELD_DEFINITIONS = "SENDGRID_GET_ALL_FIELD_DEFINITIONS"
    SENDGRID_GET_ALL_LISTS = "SENDGRID_GET_ALL_LISTS"
    SENDGRID_GET_ALL_SINGLE_SENDS = "SENDGRID_GET_ALL_SINGLE_SENDS"
    SENDGRID_GET_ALL_SINGLE_SENDS_STATS = "SENDGRID_GET_ALL_SINGLE_SENDS_STATS"
    SENDGRID_GET_ALL_VERIFIED_SENDERS = "SENDGRID_GET_ALL_VERIFIED_SENDERS"
    SENDGRID_GET_CONTACT_BY_ID = "SENDGRID_GET_CONTACT_BY_ID"
    SENDGRID_GET_LIST_BY_ID = "SENDGRID_GET_LIST_BY_ID"
    SENDGRID_GET_CONTACTS_BY_EMAILS = "SENDGRID_GET_CONTACTS_BY_EMAILS"
    SENDGRID_GET_BATCHED_CONTACTS_BY_IDS = "SENDGRID_GET_BATCHED_CONTACTS_BY_IDS"
    SENDGRID_EXPORT_CONTACTS = "SENDGRID_EXPORT_CONTACTS"
    SENDGRID_EXPORT_CONTACTS_STATUS = "SENDGRID_EXPORT_CONTACTS_STATUS"
    SENDGRID_DUPLICATE_DESIGN = "SENDGRID_DUPLICATE_DESIGN"
    SENDGRID_DUPLICATE_SINGLE_SEND = "SENDGRID_DUPLICATE_SINGLE_SEND"
    SENDGRID_GET_AUTOMATION_STATS_BY_ID = "SENDGRID_GET_AUTOMATION_STATS_BY_ID"
    SENDGRID_GET_ALL_AUTOMATION_STATS = "SENDGRID_GET_ALL_AUTOMATION_STATS"
    SENDGRID_FILTER_MESSAGES_BY_MESSAGE_ID = "SENDGRID_FILTER_MESSAGES_BY_MESSAGE_ID"
    SENDGRID_GET_USER_PROFILE = "SENDGRID_GET_USER_PROFILE"
    SENDGRID_GET_USER_ACCOUNT_INFORMATION = "SENDGRID_GET_USER_ACCOUNT_INFORMATION"

    # Spotify actions
    SPOTIFY_SAVE_AUDIOBOOKS_FOR_CURRENT_USER = "SPOTIFY_SAVE_AUDIOBOOKS_FOR_CURRENT_USER"
    SPOTIFY_SAVE_EPISODES_FOR_CURRENT_USER = "SPOTIFY_SAVE_EPISODES_FOR_CURRENT_USER"
    SPOTIFY_SAVE_SHOWS_FOR_CURRENT_USER = "SPOTIFY_SAVE_SHOWS_FOR_CURRENT_USER"
    SPOTIFY_SEARCH_FOR_ITEM = "SPOTIFY_SEARCH_FOR_ITEM"
    SPOTIFY_SEEK_TO_POSITION = "SPOTIFY_SEEK_TO_POSITION"
    SPOTIFY_SET_PLAYBACK_VOLUME = "SPOTIFY_SET_PLAYBACK_VOLUME"
    SPOTIFY_SET_REPEAT_MODE = "SPOTIFY_SET_REPEAT_MODE"
    SPOTIFY_SKIP_TO_NEXT = "SPOTIFY_SKIP_TO_NEXT"
    SPOTIFY_SKIP_TO_PREVIOUS = "SPOTIFY_SKIP_TO_PREVIOUS"
    SPOTIFY_START_RESUME_PLAYBACK = "SPOTIFY_START_RESUME_PLAYBACK"
    SPOTIFY_TOGGLE_PLAYBACK_SHUFFLE = "SPOTIFY_TOGGLE_PLAYBACK_SHUFFLE"
    SPOTIFY_TRANSFER_PLAYBACK = "SPOTIFY_TRANSFER_PLAYBACK"
    SPOTIFY_UNFOLLOW_ARTISTS_OR_USERS = "SPOTIFY_UNFOLLOW_ARTISTS_OR_USERS"
    SPOTIFY_UNFOLLOW_PLAYLIST = "SPOTIFY_UNFOLLOW_PLAYLIST"
    SPOTIFY_UPDATE_PLAYLIST_ITEMS = "SPOTIFY_UPDATE_PLAYLIST_ITEMS"
    SPOTIFY_GET_PLAYLIST_ITEMS = "SPOTIFY_GET_PLAYLIST_ITEMS"
    SPOTIFY_GET_USER_QUEUE = "SPOTIFY_GET_USER_QUEUE"
    SPOTIFY_GET_RECENTLY_PLAYED_TRACKS = "SPOTIFY_GET_RECENTLY_PLAYED_TRACKS"
    SPOTIFY_GET_RECOMMENDATIONS = "SPOTIFY_GET_RECOMMENDATIONS"
    SPOTIFY_GET_SEVERAL_ALBUMS = "SPOTIFY_GET_SEVERAL_ALBUMS"
    SPOTIFY_GET_SEVERAL_ARTISTS = "SPOTIFY_GET_SEVERAL_ARTISTS"
    SPOTIFY_GET_SEVERAL_AUDIOBOOKS = "SPOTIFY_GET_SEVERAL_AUDIOBOOKS"
    SPOTIFY_GET_SEVERAL_BROWSE_CATEGORIES = "SPOTIFY_GET_SEVERAL_BROWSE_CATEGORIES"
    SPOTIFY_GET_SEVERAL_CHAPTERS = "SPOTIFY_GET_SEVERAL_CHAPTERS"
    SPOTIFY_GET_SEVERAL_EPISODES = "SPOTIFY_GET_SEVERAL_EPISODES"
    SPOTIFY_GET_SEVERAL_SHOWS = "SPOTIFY_GET_SEVERAL_SHOWS"
    SPOTIFY_GET_SEVERAL_TRACKS = "SPOTIFY_GET_SEVERAL_TRACKS"
    SPOTIFY_GET_SEVERAL_TRACKS_AUDIO_FEATURES = "SPOTIFY_GET_SEVERAL_TRACKS_AUDIO_FEATURES"
    SPOTIFY_GET_SINGLE_BROWSE_CATEGORY = "SPOTIFY_GET_SINGLE_BROWSE_CATEGORY"
    SPOTIFY_GET_TRACK = "SPOTIFY_GET_TRACK"
    SPOTIFY_GET_TRACK_AUDIO_ANALYSIS = "SPOTIFY_GET_TRACK_AUDIO_ANALYSIS"
    SPOTIFY_GET_TRACK_AUDIO_FEATURES = "SPOTIFY_GET_TRACK_AUDIO_FEATURES"
    SPOTIFY_GET_USER_PROFILE = "SPOTIFY_GET_USER_PROFILE"
    SPOTIFY_GET_USER_SAVED_ALBUMS = "SPOTIFY_GET_USER_SAVED_ALBUMS"
    SPOTIFY_GET_USER_SAVED_AUDIOBOOKS = "SPOTIFY_GET_USER_SAVED_AUDIOBOOKS"
    SPOTIFY_GET_USER_SAVED_EPISODES = "SPOTIFY_GET_USER_SAVED_EPISODES"
    SPOTIFY_GET_USER_SAVED_SHOWS = "SPOTIFY_GET_USER_SAVED_SHOWS"
    SPOTIFY_GET_USER_SAVED_TRACKS = "SPOTIFY_GET_USER_SAVED_TRACKS"
    SPOTIFY_GET_USER_TOP_ARTISTS = "SPOTIFY_GET_USER_TOP_ARTISTS"
    SPOTIFY_GET_USER_TOP_TRACKS = "SPOTIFY_GET_USER_TOP_TRACKS"
    SPOTIFY_PAUSE_PLAYBACK = "SPOTIFY_PAUSE_PLAYBACK"
    SPOTIFY_REMOVE_PLAYLIST_ITEMS = "SPOTIFY_REMOVE_PLAYLIST_ITEMS"
    SPOTIFY_REMOVE_USER_SAVED_ALBUMS = "SPOTIFY_REMOVE_USER_SAVED_ALBUMS"
    SPOTIFY_REMOVE_USER_SAVED_AUDIOBOOKS = "SPOTIFY_REMOVE_USER_SAVED_AUDIOBOOKS"
    SPOTIFY_REMOVE_USER_SAVED_EPISODES = "SPOTIFY_REMOVE_USER_SAVED_EPISODES"
    SPOTIFY_REMOVE_USER_SAVED_SHOWS = "SPOTIFY_REMOVE_USER_SAVED_SHOWS"
    SPOTIFY_ADD_ITEMS_TO_PLAYLIST = "SPOTIFY_ADD_ITEMS_TO_PLAYLIST"
    SPOTIFY_CREATE_PLAYLIST = "SPOTIFY_CREATE_PLAYLIST"
    SPOTIFY_GET_ARTIST_TOP_TRACKS = "SPOTIFY_GET_ARTIST_TOP_TRACKS"
    SPOTIFY_GET_PLAYLIST = "SPOTIFY_GET_PLAYLIST"
    SPOTIFY_GET_SHOW = "SPOTIFY_GET_SHOW"
    SPOTIFY_GET_SHOW_EPISODES = "SPOTIFY_GET_SHOW_EPISODES"
    SPOTIFY_SAVE_ALBUMS_FOR_CURRENT_USER = "SPOTIFY_SAVE_ALBUMS_FOR_CURRENT_USER"
    SPOTIFY_SAVE_TRACKS_FOR_CURRENT_USER = "SPOTIFY_SAVE_TRACKS_FOR_CURRENT_USER"
    SPOTIFY_ADD_ITEM_TO_PLAYBACK_QUEUE = "SPOTIFY_ADD_ITEM_TO_PLAYBACK_QUEUE"
    SPOTIFY_CHANGE_PLAYLIST_DETAILS = "SPOTIFY_CHANGE_PLAYLIST_DETAILS"
    SPOTIFY_CHECK_IF_USERS_FOLLOW_PLAYLIST = "SPOTIFY_CHECK_IF_USERS_FOLLOW_PLAYLIST"
    SPOTIFY_CHECK_IF_USER_FOLLOWS_ARTISTS_OR_USERS = "SPOTIFY_CHECK_IF_USER_FOLLOWS_ARTISTS_OR_USERS"
    SPOTIFY_CHECK_USER_SAVED_ALBUMS = "SPOTIFY_CHECK_USER_SAVED_ALBUMS"
    SPOTIFY_CHECK_USER_SAVED_AUDIOBOOKS = "SPOTIFY_CHECK_USER_SAVED_AUDIOBOOKS"
    SPOTIFY_CHECK_USER_SAVED_EPISODES = "SPOTIFY_CHECK_USER_SAVED_EPISODES"
    SPOTIFY_CHECK_USER_SAVED_SHOWS = "SPOTIFY_CHECK_USER_SAVED_SHOWS"
    SPOTIFY_CHECK_USER_SAVED_TRACKS = "SPOTIFY_CHECK_USER_SAVED_TRACKS"
    SPOTIFY_FOLLOW_ARTISTS_OR_USERS = "SPOTIFY_FOLLOW_ARTISTS_OR_USERS"
    SPOTIFY_FOLLOW_PLAYLIST = "SPOTIFY_FOLLOW_PLAYLIST"
    SPOTIFY_GET_ALBUM = "SPOTIFY_GET_ALBUM"
    SPOTIFY_GET_ALBUM_TRACKS = "SPOTIFY_GET_ALBUM_TRACKS"
    SPOTIFY_GET_ARTIST = "SPOTIFY_GET_ARTIST"
    SPOTIFY_GET_ARTIST_ALBUMS = "SPOTIFY_GET_ARTIST_ALBUMS"
    SPOTIFY_GET_AUDIOBOOK = "SPOTIFY_GET_AUDIOBOOK"
    SPOTIFY_GET_ARTIST_RELATED_ARTISTS = "SPOTIFY_GET_ARTIST_RELATED_ARTISTS"
    SPOTIFY_GET_AUDIOBOOK_CHAPTERS = "SPOTIFY_GET_AUDIOBOOK_CHAPTERS"
    SPOTIFY_GET_AVAILABLE_DEVICES = "SPOTIFY_GET_AVAILABLE_DEVICES"
    SPOTIFY_GET_AVAILABLE_GENRE_SEEDS = "SPOTIFY_GET_AVAILABLE_GENRE_SEEDS"
    SPOTIFY_GET_AVAILABLE_MARKETS = "SPOTIFY_GET_AVAILABLE_MARKETS"
    SPOTIFY_GET_CHAPTER = "SPOTIFY_GET_CHAPTER"
    SPOTIFY_GET_CURRENT_USER_PLAYLISTS = "SPOTIFY_GET_CURRENT_USER_PLAYLISTS"
    SPOTIFY_GET_CATEGORY_PLAYLISTS = "SPOTIFY_GET_CATEGORY_PLAYLISTS"
    SPOTIFY_GET_CURRENTLY_PLAYING_TRACK = "SPOTIFY_GET_CURRENTLY_PLAYING_TRACK"
    SPOTIFY_GET_CURRENT_USER_PROFILE = "SPOTIFY_GET_CURRENT_USER_PROFILE"
    SPOTIFY_GET_EPISODE = "SPOTIFY_GET_EPISODE"
    SPOTIFY_GET_FEATURED_PLAYLISTS = "SPOTIFY_GET_FEATURED_PLAYLISTS"
    SPOTIFY_GET_FOLLOWED_ARTISTS = "SPOTIFY_GET_FOLLOWED_ARTISTS"
    SPOTIFY_GET_PLAYBACK_STATE = "SPOTIFY_GET_PLAYBACK_STATE"
    SPOTIFY_GET_USER_PLAYLISTS = "SPOTIFY_GET_USER_PLAYLISTS"
    SPOTIFY_GET_NEW_RELEASES = "SPOTIFY_GET_NEW_RELEASES"

    # Stripe actions
    STRIPE_CANCEL_SUBSCRIPTION = "STRIPE_CANCEL_SUBSCRIPTION"
    STRIPE_CREATE_CUSTOMER = "STRIPE_CREATE_CUSTOMER"
    STRIPE_CREATE_INVOICE = "STRIPE_CREATE_INVOICE"
    STRIPE_CREATE_PAYMENT_INTENT = "STRIPE_CREATE_PAYMENT_INTENT"
    STRIPE_CREATE_PRICE = "STRIPE_CREATE_PRICE"
    STRIPE_CREATE_PRODUCT = "STRIPE_CREATE_PRODUCT"
    STRIPE_CREATE_REFUND = "STRIPE_CREATE_REFUND"
    STRIPE_CREATE_SUBSCRIPTION = "STRIPE_CREATE_SUBSCRIPTION"
    STRIPE_DELETE_CUSTOMER = "STRIPE_DELETE_CUSTOMER"
    STRIPE_LIST_CUSTOMER_PAYMENT_METHODS = "STRIPE_LIST_CUSTOMER_PAYMENT_METHODS"
    STRIPE_LIST_PAYMENT_LINKS = "STRIPE_LIST_PAYMENT_LINKS"
    STRIPE_LIST_REFUNDS = "STRIPE_LIST_REFUNDS"
    STRIPE_LIST_SHIPPING_RATES = "STRIPE_LIST_SHIPPING_RATES"
    STRIPE_LIST_TAX_RATES = "STRIPE_LIST_TAX_RATES"
    STRIPE_RETRIEVE_CHARGE_DETAILS = "STRIPE_RETRIEVE_CHARGE_DETAILS"
    STRIPE_RETRIEVE_PAYMENT_INTENT = "STRIPE_RETRIEVE_PAYMENT_INTENT"
    STRIPE_RETRIEVE_REFUND = "STRIPE_RETRIEVE_REFUND"
    STRIPE_SEARCH_CUSTOMERS = "STRIPE_SEARCH_CUSTOMERS"
    STRIPE_UPDATE_PAYMENT_INTENT = "STRIPE_UPDATE_PAYMENT_INTENT"
    STRIPE_UPDATE_SUBSCRIPTION = "STRIPE_UPDATE_SUBSCRIPTION"
    STRIPE_CONFIRM_PAYMENT_INTENT = "STRIPE_CONFIRM_PAYMENT_INTENT"
    STRIPE_LIST_CHARGES = "STRIPE_LIST_CHARGES"
    STRIPE_LIST_COUPONS = "STRIPE_LIST_COUPONS"
    STRIPE_LIST_CUSTOMERS = "STRIPE_LIST_CUSTOMERS"
    STRIPE_LIST_INVOICES = "STRIPE_LIST_INVOICES"
    STRIPE_LIST_PAYMENT_INTENTS = "STRIPE_LIST_PAYMENT_INTENTS"
    STRIPE_LIST_PRODUCTS = "STRIPE_LIST_PRODUCTS"
    STRIPE_LIST_SUBSCRIPTIONS = "STRIPE_LIST_SUBSCRIPTIONS"
    STRIPE_LIST_TAX_CODES = "STRIPE_LIST_TAX_CODES"
    STRIPE_RETRIEVE_BALANCE = "STRIPE_RETRIEVE_BALANCE"
    STRIPE_RETRIEVE_CUSTOMER = "STRIPE_RETRIEVE_CUSTOMER"
    STRIPE_RETRIEVE_SUBSCRIPTION = "STRIPE_RETRIEVE_SUBSCRIPTION"
    STRIPE_UPDATE_CUSTOMER = "STRIPE_UPDATE_CUSTOMER"

    # Supabase actions
    SUPABASE_EXECUTE_PROJECT_DATABASE_QUERY = "SUPABASE_EXECUTE_PROJECT_DATABASE_QUERY"
    SUPABASE_CREATE_ORGANIZATION = "SUPABASE_CREATE_ORGANIZATION"
    SUPABASE_CREATE_NEW_PROJECT = "SUPABASE_CREATE_NEW_PROJECT"
    SUPABASE_LIST_ALL_ORGANIZATIONS = "SUPABASE_LIST_ALL_ORGANIZATIONS"
    SUPABASE_LIST_ALL_PROJECTS = "SUPABASE_LIST_ALL_PROJECTS"
    SUPABASE_CREATE_PROJECT_API_KEY = "SUPABASE_CREATE_PROJECT_API_KEY"
    SUPABASE_DELETE_API_KEY = "SUPABASE_DELETE_API_KEY"
    SUPABASE_GET_THIRD_PARTY_INTEGRATION = "SUPABASE_GET_THIRD_PARTY_INTEGRATION"
    SUPABASE_LIST_THIRD_PARTY_AUTH_INTEGRATIONS = "SUPABASE_LIST_THIRD_PARTY_AUTH_INTEGRATIONS"
    SUPABASE_DELETE_THIRD_PARTY_AUTH_CONFIG = "SUPABASE_DELETE_THIRD_PARTY_AUTH_CONFIG"
    SUPABASE_UPDATE_API_KEY = "SUPABASE_UPDATE_API_KEY"
    SUPABASE_ACTIVATE_CUSTOM_HOSTNAME = "SUPABASE_ACTIVATE_CUSTOM_HOSTNAME"
    SUPABASE_ACTIVATE_VANITY_SUBDOMAIN = "SUPABASE_ACTIVATE_VANITY_SUBDOMAIN"
    SUPABASE_AUTHORIZE_USER_OAUTH = "SUPABASE_AUTHORIZE_USER_OAUTH"
    SUPABASE_CHECK_VANITY_SUBDOMAIN_AVAILABILITY = "SUPABASE_CHECK_VANITY_SUBDOMAIN_AVAILABILITY"
    SUPABASE_ENABLE_DATABASE_WEBHOOKS = "SUPABASE_ENABLE_DATABASE_WEBHOOKS"
    SUPABASE_GET_VANITY_SUBDOMAIN_CONFIG = "SUPABASE_GET_VANITY_SUBDOMAIN_CONFIG"
    SUPABASE_GET_CUSTOM_HOSTNAME_CONFIG = "SUPABASE_GET_CUSTOM_HOSTNAME_CONFIG"
    SUPABASE_RETRIEVE_NETWORK_BANS = "SUPABASE_RETRIEVE_NETWORK_BANS"
    SUPABASE_RETRIEVE_NETWORK_RESTRICTIONS = "SUPABASE_RETRIEVE_NETWORK_RESTRICTIONS"
    SUPABASE_GET_PGSODIUM_CONFIG = "SUPABASE_GET_PGSODIUM_CONFIG"
    SUPABASE_GET_SSL_ENFORCEMENT_CONFIG = "SUPABASE_GET_SSL_ENFORCEMENT_CONFIG"
    SUPABASE_REMOVE_READ_REPLICA = "SUPABASE_REMOVE_READ_REPLICA"
    SUPABASE_REMOVE_NETWORK_BANS = "SUPABASE_REMOVE_NETWORK_BANS"
    SUPABASE_SETUP_READ_REPLICA = "SUPABASE_SETUP_READ_REPLICA"
    SUPABASE_UPDATE_NETWORK_RESTRICTIONS = "SUPABASE_UPDATE_NETWORK_RESTRICTIONS"
    SUPABASE_UPGRADE_POSTGRESQL_VERSION = "SUPABASE_UPGRADE_POSTGRESQL_VERSION"
    SUPABASE_UPDATE_PGSODIUM_ROOT_KEY = "SUPABASE_UPDATE_PGSODIUM_ROOT_KEY"
    SUPABASE_CREATE_SSO_PROVIDER = "SUPABASE_CREATE_SSO_PROVIDER"
    SUPABASE_CREATE_THIRD_PARTY_AUTH = "SUPABASE_CREATE_THIRD_PARTY_AUTH"
    SUPABASE_CREATE_DATABASE_BRANCH = "SUPABASE_CREATE_DATABASE_BRANCH"
    SUPABASE_CREATE_EDGE_FUNCTION = "SUPABASE_CREATE_EDGE_FUNCTION"
    SUPABASE_REVERIFY_CUSTOM_HOSTNAME = "SUPABASE_REVERIFY_CUSTOM_HOSTNAME"
    SUPABASE_DELETE_PROJECT = "SUPABASE_DELETE_PROJECT"
    SUPABASE_DELETE_DATABASE_BRANCH = "SUPABASE_DELETE_DATABASE_BRANCH"
    SUPABASE_DELETE_EDGE_FUNCTION = "SUPABASE_DELETE_EDGE_FUNCTION"
    SUPABASE_DELETE_CUSTOM_HOSTNAME = "SUPABASE_DELETE_CUSTOM_HOSTNAME"
    SUPABASE_DELETE_VANITY_SUBDOMAIN = "SUPABASE_DELETE_VANITY_SUBDOMAIN"
    SUPABASE_DEPLOY_EDGE_FUNCTION = "SUPABASE_DEPLOY_EDGE_FUNCTION"
    SUPABASE_DISABLE_PREVIEW_BRANCHING = "SUPABASE_DISABLE_PREVIEW_BRANCHING"
    SUPABASE_DISABLE_READONLY_MODE = "SUPABASE_DISABLE_READONLY_MODE"
    SUPABASE_EXCHANGE_AUTH_CODE = "SUPABASE_EXCHANGE_AUTH_CODE"
    SUPABASE_GENERATE_TYPESCRIPT_TYPES = "SUPABASE_GENERATE_TYPESCRIPT_TYPES"
    SUPABASE_GET_SQL_SNIPPET = "SUPABASE_GET_SQL_SNIPPET"
    SUPABASE_GET_SSO_PROVIDER_BY_UUID = "SUPABASE_GET_SSO_PROVIDER_BY_UUID"
    SUPABASE_GET_ORGANIZATION_INFO = "SUPABASE_GET_ORGANIZATION_INFO"
    SUPABASE_GET_PROJECT_AUTH_CONFIG = "SUPABASE_GET_PROJECT_AUTH_CONFIG"
    SUPABASE_GET_PROJECT_POSTGREST_CONFIG = "SUPABASE_GET_PROJECT_POSTGREST_CONFIG"
    SUPABASE_GET_PROJECT_POSTGRES_CONFIG = "SUPABASE_GET_PROJECT_POSTGRES_CONFIG"
    SUPABASE_GET_PROJECT_SERVICE_HEALTH_STATUS = "SUPABASE_GET_PROJECT_SERVICE_HEALTH_STATUS"
    SUPABASE_GET_PROJECT_SUPAVISOR_CONFIGURATION = "SUPABASE_GET_PROJECT_SUPAVISOR_CONFIGURATION"
    SUPABASE_GET_DATABASE_BRANCH_CONFIG = "SUPABASE_GET_DATABASE_BRANCH_CONFIG"
    SUPABASE_GET_PROJECT_API_KEYS = "SUPABASE_GET_PROJECT_API_KEYS"
    SUPABASE_GET_PROJECT_PGBOUNCER_CONFIG = "SUPABASE_GET_PROJECT_PGBOUNCER_CONFIG"
    SUPABASE_GET_PROJECT_UPGRADE_ELIGIBILITY = "SUPABASE_GET_PROJECT_UPGRADE_ELIGIBILITY"
    SUPABASE_GET_PROJECT_UPGRADE_STATUS = "SUPABASE_GET_PROJECT_UPGRADE_STATUS"
    SUPABASE_LIST_PROJECT_DATABASE_BACKUPS = "SUPABASE_LIST_PROJECT_DATABASE_BACKUPS"
    SUPABASE_LIST_ALL_BUCKETS = "SUPABASE_LIST_ALL_BUCKETS"
    SUPABASE_LIST_ALL_SSO_PROVIDERS = "SUPABASE_LIST_ALL_SSO_PROVIDERS"
    SUPABASE_LIST_SQL_SNIPPETS_FOR_USER = "SUPABASE_LIST_SQL_SNIPPETS_FOR_USER"
    SUPABASE_LIST_ALL_DATABASE_BRANCHES = "SUPABASE_LIST_ALL_DATABASE_BRANCHES"
    SUPABASE_LIST_ALL_FUNCTIONS = "SUPABASE_LIST_ALL_FUNCTIONS"
    SUPABASE_LIST_ALL_SECRETS = "SUPABASE_LIST_ALL_SECRETS"
    SUPABASE_LIST_MEMBERS_OF_ORGANIZATION = "SUPABASE_LIST_MEMBERS_OF_ORGANIZATION"
    SUPABASE_REMOVE_SSO_PROVIDER = "SUPABASE_REMOVE_SSO_PROVIDER"
    SUPABASE_RESET_DATABASE_BRANCH = "SUPABASE_RESET_DATABASE_BRANCH"
    SUPABASE_RESTORE_DATABASE_PITR_BACKUP = "SUPABASE_RESTORE_DATABASE_PITR_BACKUP"
    SUPABASE_RETRIEVE_FUNCTION = "SUPABASE_RETRIEVE_FUNCTION"
    SUPABASE_RETRIEVE_FUNCTION_BODY = "SUPABASE_RETRIEVE_FUNCTION_BODY"
    SUPABASE_GET_PROJECT_READONLY_MODE_STATUS = "SUPABASE_GET_PROJECT_READONLY_MODE_STATUS"
    SUPABASE_UPDATE_SSO_PROVIDER_BY_UUID = "SUPABASE_UPDATE_SSO_PROVIDER_BY_UUID"
    SUPABASE_UPDATE_PROJECT_POSTGREST_CONFIG = "SUPABASE_UPDATE_PROJECT_POSTGREST_CONFIG"
    SUPABASE_UPDATE_PROJECT_POSTGRES_CONFIG = "SUPABASE_UPDATE_PROJECT_POSTGRES_CONFIG"
    SUPABASE_UPDATE_DATABASE_POOLER_CONFIG = "SUPABASE_UPDATE_DATABASE_POOLER_CONFIG"
    SUPABASE_UPDATE_FUNCTION = "SUPABASE_UPDATE_FUNCTION"
    SUPABASE_UPDATE_DATABASE_BRANCH_CONFIG = "SUPABASE_UPDATE_DATABASE_BRANCH_CONFIG"
    SUPABASE_UPDATE_PROJECT_CUSTOM_HOSTNAME_CONFIGURATION = "SUPABASE_UPDATE_PROJECT_CUSTOM_HOSTNAME_CONFIGURATION"
    SUPABASE_UPDATE_SSL_ENFORCEMENT_CONFIG = "SUPABASE_UPDATE_SSL_ENFORCEMENT_CONFIG"

    # Tavily actions
    TAVILY_SEARCH_DATA = "TAVILY_SEARCH_DATA"
    TAVILY_EXTRACT_CONTENT = "TAVILY_EXTRACT_CONTENT"

    # Typeform actions
    TYPEFORM_RETRIEVE_WORKSPACES = "TYPEFORM_RETRIEVE_WORKSPACES"
    TYPEFORM_RETRIEVE_THEMES = "TYPEFORM_RETRIEVE_THEMES"
    TYPEFORM_RETRIEVE_WORKSPACE = "TYPEFORM_RETRIEVE_WORKSPACE"
    TYPEFORM_RETRIEVE_CUSTOM_FORM_MESSAGES = "TYPEFORM_RETRIEVE_CUSTOM_FORM_MESSAGES"
    TYPEFORM_RETRIEVE_SINGLE_WEBHOOK = "TYPEFORM_RETRIEVE_SINGLE_WEBHOOK"
    TYPEFORM_RETRIEVE_IMAGES_COLLECTION = "TYPEFORM_RETRIEVE_IMAGES_COLLECTION"
    TYPEFORM_RETRIEVE_FORM = "TYPEFORM_RETRIEVE_FORM"
    TYPEFORM_RETRIEVE_RESPONSES_FOR_FORM = "TYPEFORM_RETRIEVE_RESPONSES_FOR_FORM"
    TYPEFORM_RETRIEVE_THEME = "TYPEFORM_RETRIEVE_THEME"
    TYPEFORM_RETRIEVE_ACCOUNT_WORKSPACES = "TYPEFORM_RETRIEVE_ACCOUNT_WORKSPACES"
    TYPEFORM_RETRIEVE_FORMS = "TYPEFORM_RETRIEVE_FORMS"
    TYPEFORM_RETRIEVE_WEBHOOKS = "TYPEFORM_RETRIEVE_WEBHOOKS"
    TYPEFORM_RETRIEVE_IMAGE = "TYPEFORM_RETRIEVE_IMAGE"
    TYPEFORM_CREATE_FORM = "TYPEFORM_CREATE_FORM"
    TYPEFORM_CREATE_THEME = "TYPEFORM_CREATE_THEME"
    TYPEFORM_CREATE_IMAGE = "TYPEFORM_CREATE_IMAGE"
    TYPEFORM_CREATE_WORKSPACE = "TYPEFORM_CREATE_WORKSPACE"
    TYPEFORM_CREATE_ACCOUNT_WORKSPACE = "TYPEFORM_CREATE_ACCOUNT_WORKSPACE"
    TYPEFORM_CREATE_OR_UPDATE_WEBHOOK = "TYPEFORM_CREATE_OR_UPDATE_WEBHOOK"
    TYPEFORM_UPDATE_CUSTOM_MESSAGES_FOR_FORMS = "TYPEFORM_UPDATE_CUSTOM_MESSAGES_FOR_FORMS"
    TYPEFORM_UPDATE_FORM = "TYPEFORM_UPDATE_FORM"
    TYPEFORM_UPDATE_THEME = "TYPEFORM_UPDATE_THEME"
    TYPEFORM_UPDATE_WORKSPACE = "TYPEFORM_UPDATE_WORKSPACE"
    TYPEFORM_PATCH_UPDATE_FORM = "TYPEFORM_PATCH_UPDATE_FORM"
    TYPEFORM_PARTIAL_UPDATE_THEME = "TYPEFORM_PARTIAL_UPDATE_THEME"
    TYPEFORM_DELETE_THEME = "TYPEFORM_DELETE_THEME"
    TYPEFORM_DELETE_FORM = "TYPEFORM_DELETE_FORM"
    TYPEFORM_DELETE_WEBHOOK = "TYPEFORM_DELETE_WEBHOOK"
    TYPEFORM_DELETE_RESPONSES_TO_FORM = "TYPEFORM_DELETE_RESPONSES_TO_FORM"
    TYPEFORM_DELETE_WORKSPACE = "TYPEFORM_DELETE_WORKSPACE"
    TYPEFORM_DELETE_IMAGE = "TYPEFORM_DELETE_IMAGE"

    # Vercel actions
    VERCEL_ADD_ENVIRONMENT_VARIABLE = "VERCEL_ADD_ENVIRONMENT_VARIABLE"
    VERCEL_CHECK_CACHE_ARTIFACT_EXISTS = "VERCEL_CHECK_CACHE_ARTIFACT_EXISTS"
    VERCEL_CHECK_DOMAIN_AVAILABILITY = "VERCEL_CHECK_DOMAIN_AVAILABILITY"
    VERCEL_CHECK_DOMAIN_PRICE = "VERCEL_CHECK_DOMAIN_PRICE"
    VERCEL_CREATE_AUTH_TOKEN = "VERCEL_CREATE_AUTH_TOKEN"
    VERCEL_CREATE_EDGE_CONFIG = "VERCEL_CREATE_EDGE_CONFIG"
    VERCEL_CREATE_DEPLOYMENT = "VERCEL_CREATE_DEPLOYMENT"
    VERCEL_DELETE_AUTH_TOKEN = "VERCEL_DELETE_AUTH_TOKEN"
    VERCEL_DELETE_DEPLOYMENT = "VERCEL_DELETE_DEPLOYMENT"
    VERCEL_DELETE_ENVIRONMENT_VARIABLE = "VERCEL_DELETE_ENVIRONMENT_VARIABLE"
    VERCEL_DELETE_PROJECT = "VERCEL_DELETE_PROJECT"
    VERCEL_DEPLOY_EDGE_FUNCTION = "VERCEL_DEPLOY_EDGE_FUNCTION"
    VERCEL_GET_DEPLOYMENT_DETAILS = "VERCEL_GET_DEPLOYMENT_DETAILS"
    VERCEL_GET_DEPLOYMENT_EVENTS = "VERCEL_GET_DEPLOYMENT_EVENTS"
    VERCEL_GET_DEPLOYMENT_LOGS = "VERCEL_GET_DEPLOYMENT_LOGS"
    VERCEL_GET_DOMAIN_TRANSFER_INFO = "VERCEL_GET_DOMAIN_TRANSFER_INFO"
    VERCEL_GET_EDGE_CONFIG = "VERCEL_GET_EDGE_CONFIG"
    VERCEL_GET_EDGE_CONFIG_ITEM = "VERCEL_GET_EDGE_CONFIG_ITEM"
    VERCEL_GET_PROJECT = "VERCEL_GET_PROJECT"
    VERCEL_LIST_ALIASES = "VERCEL_LIST_ALIASES"
    VERCEL_LIST_DEPLOYMENTS = "VERCEL_LIST_DEPLOYMENTS"
    VERCEL_LIST_AUTH_TOKENS = "VERCEL_LIST_AUTH_TOKENS"
    VERCEL_LIST_DEPLOYMENT_CHECKS = "VERCEL_LIST_DEPLOYMENT_CHECKS"
    VERCEL_LIST_EDGE_CONFIGS = "VERCEL_LIST_EDGE_CONFIGS"
    VERCEL_LIST_ENVIRONMENT_VARIABLES = "VERCEL_LIST_ENVIRONMENT_VARIABLES"
    VERCEL_UPDATE_EDGE_CONFIG_ITEMS = "VERCEL_UPDATE_EDGE_CONFIG_ITEMS"
    VERCEL_UPDATE_PROJECT = "VERCEL_UPDATE_PROJECT"
    VERCEL_CREATE_EDGE_CONFIG_TOKEN = "VERCEL_CREATE_EDGE_CONFIG_TOKEN"

    # Wttr actions
    WTTR_GET_WEATHER_DATA = "WTTR_GET_WEATHER_DATA"

    # Zoom actions
    ZOOM_CREATE_MEETING = "ZOOM_CREATE_MEETING"
    ZOOM_GET_MEETING = "ZOOM_GET_MEETING"
    ZOOM_GET_MEETING_SUMMARY = "ZOOM_GET_MEETING_SUMMARY"
    ZOOM_GET_MEETING_RECORDINGS = "ZOOM_GET_MEETING_RECORDINGS"
    ZOOM_LIST_RECORDINGS = "ZOOM_LIST_RECORDINGS"
    ZOOM_LIST_MEETINGS = "ZOOM_LIST_MEETINGS"
    ZOOM_ADD_MEETING_REGISTRANT = "ZOOM_ADD_MEETING_REGISTRANT"
    ZOOM_GET_WEBINAR = "ZOOM_GET_WEBINAR"
    ZOOM_LIST_WEBINARS = "ZOOM_LIST_WEBINARS"
    ZOOM_GET_PAST_MEETING_PARTICIPANTS = "ZOOM_GET_PAST_MEETING_PARTICIPANTS"
    ZOOM_UPDATE_MEETING = "ZOOM_UPDATE_MEETING"
    ZOOM_DELETE_MEETING_RECORDINGS = "ZOOM_DELETE_MEETING_RECORDINGS"

     

ACTION_METADATA = {
    # Gmail actions
    Action.GMAIL_SEND_EMAIL: {"provider": "google", "service": "gmail", "friendly_name": "send_email_gmail"},
    Action.GMAIL_REPLY_TO_THREAD: {"provider": "google", "service": "gmail", "friendly_name": "reply_to_thread"},
    Action.GMAIL_FETCH_MESSAGES_BY_THREAD: {"provider": "google", "service": "gmail", "friendly_name": "fetch_messages_by_thread"},
    Action.GMAIL_SEND_DRAFT: {"provider": "google", "service": "gmail", "friendly_name": "send_draft"},
    Action.GMAIL_SEARCH_PEOPLE: {"provider": "google", "service": "gmail", "friendly_name": "search_people"},
    Action.GMAIL_DELETE_DRAFT: {"provider": "google", "service": "gmail", "friendly_name": "delete_draft"},
    Action.GMAIL_DELETE_MESSAGE: {"provider": "google", "service": "gmail", "friendly_name": "delete_message_gmail"},
    Action.GMAIL_FETCH_EMAILS: {"provider": "google", "service": "gmail", "friendly_name": "fetch_emails"},
    Action.GMAIL_GET_GMAIL_ATTACHMENT: {"provider": "google", "service": "gmail", "friendly_name": "get_gmail_attachment"},
    Action.GMAIL_GET_CONTACTS: {"provider": "google", "service": "gmail", "friendly_name": "get_contacts"},
    Action.GMAIL_LIST_DRAFTS: {"provider": "google", "service": "gmail", "friendly_name": "list_drafts"},
    Action.GMAIL_MOVE_TO_TRASH: {"provider": "google", "service": "gmail", "friendly_name": "move_to_trash"},
    Action.GMAIL_PATCH_LABEL: {"provider": "google", "service": "gmail", "friendly_name": "patch_label"},
    Action.GMAIL_MODIFY_EMAIL_LABELS: {"provider": "google", "service": "gmail", "friendly_name": "modify_email_labels"},
    Action.GMAIL_CREATE_LABEL: {"provider": "google", "service": "gmail", "friendly_name": "create_label"},
    Action.GMAIL_GET_PEOPLE: {"provider": "google", "service": "gmail", "friendly_name": "get_people"},
    Action.GMAIL_GET_PROFILE: {"provider": "google", "service": "gmail", "friendly_name": "get_profile"},
    Action.GMAIL_LIST_GMAIL_LABELS: {"provider": "google", "service": "gmail", "friendly_name": "list_gmail_labels"},
    Action.GMAIL_LIST_THREADS: {"provider": "google", "service": "gmail", "friendly_name": "list_threads"},
    Action.GMAIL_MODIFY_THREAD_LABELS: {"provider": "google", "service": "gmail", "friendly_name": "modify_thread_labels"},
    Action.GMAIL_REMOVE_LABEL: {"provider": "google", "service": "gmail", "friendly_name": "remove_label"},
    Action.GMAIL_FETCH_MESSAGE_BY_MESSAGE_ID : {"provider": "google", "service": "gmail", "friendly_name": "fetch_message_by_message_id"},
    Action.GMAIL_CREATE_DRAFT : {"provider": "google", "service": "gmail", "friendly_name": "create_draft"},
    
    # Calendar actions
    Action.CALENDAR_CREATE_EVENT: {"provider": "google", "service": "calendar", "friendly_name": "create_event"},
    Action.CALENDAR_DELETE_EVENT: {"provider": "google", "service": "calendar", "friendly_name": "delete_event"},
    Action.CALENDAR_LIST_EVENTS: {"provider": "google", "service": "calendar", "friendly_name": "list_events_calendar"},
    Action.CALENDAR_UPDATE_ACL_RULE: {"provider": "google", "service": "calendar", "friendly_name": "update_acl_rule"},
    Action.CALENDAR_UPDATE_CALENDAR_LIST_ENTRY: {"provider": "google", "service": "calendar", "friendly_name": "update_calendar_list_entry"},
    Action.CALENDAR_GET_EVENT_INSTANCES: {"provider": "google", "service": "calendar", "friendly_name": "get_event_instances"},
    Action.CALENDAR_CREATE_CALENDAR: {"provider": "google", "service": "calendar", "friendly_name": "create_calendar"},
    Action.CALENDAR_DELETE_CALENDAR: {"provider": "google", "service": "calendar", "friendly_name": "delete_calendar"},
    Action.CALENDAR_UPDATE_CALENDAR: {"provider": "google", "service": "calendar", "friendly_name": "update_calendar"},
    Action.CALENDAR_INSERT_CALENDAR_INTO_LIST: {"provider": "google", "service": "calendar", "friendly_name": "insert_calendar_into_list"},
    Action.CALENDAR_GET_CALENDAR: {"provider": "google", "service": "calendar", "friendly_name": "get_calendar"},
    Action.CALENDAR_QUERY_FREE_BUSY: {"provider": "google", "service": "calendar", "friendly_name": "query_free_busy"},
    Action.CALENDAR_PATCH_CALENDAR: {"provider": "google", "service": "calendar", "friendly_name": "patch_calendar"},
    Action.CALENDAR_PATCH_EVENT: {"provider": "google", "service": "calendar", "friendly_name": "patch_event"},
    Action.CALENDAR_QUICK_ADD_EVENT: {"provider": "google", "service": "calendar", "friendly_name": "quick_add_event"},
    Action.CALENDAR_SYNC_EVENTS: {"provider": "google", "service": "calendar", "friendly_name": "sync_events"},
    Action.CALENDAR_CLEAR_CALENDAR: {"provider": "google", "service": "calendar", "friendly_name": "clear_calendar"},
    Action.CALENDAR_MOVE_EVENT: {"provider": "google", "service": "calendar", "friendly_name": "move_event"},
    Action.CALENDAR_FIND_FREE_SLOTS: {"provider": "google", "service": "calendar", "friendly_name": "find_free_slots"},
    Action.CALENDAR_LIST_ACL_RULES: {"provider": "google", "service": "calendar", "friendly_name": "list_acl_rules"},
    Action.CALENDAR_LIST_GOOGLE_CALENDARS: {"provider": "google", "service": "calendar", "friendly_name": "list_google_calendars"},
    Action.CALENDAR_REMOVE_ATTENDEE_FROM_EVENT: {"provider": "google", "service": "calendar", "friendly_name": "remove_attendee_from_event"},
    Action.CALENDAR_LIST_SETTINGS: {"provider": "google", "service": "calendar", "friendly_name": "list_settings"},
    Action.CALENDAR_GET_CURRENT_DATE_AND_TIME: {"provider": "google", "service": "calendar", "friendly_name": "get_current_date_and_time"},
    Action.CALENDAR_UPDATE_EVENT: {"provider": "google", "service": "calendar", "friendly_name": "update_event"},

    # Drive actions
    Action.DRIVE_DELETE_FILE: {"provider": "google", "service": "drive", "friendly_name": "delete_file_drive"},
    Action.DRIVE_CREATE_COMMENT: {"provider": "google", "service": "drive", "friendly_name": "create_comment_drive"},
    Action.DRIVE_CREATE_SHARED_DRIVE: {"provider": "google", "service": "drive", "friendly_name": "create_shared_drive"},
    Action.DRIVE_CREATE_FILE_OR_FOLDER: {"provider": "google", "service": "drive", "friendly_name": "create_file_or_folder"},
    Action.DRIVE_CREATE_REPLY: {"provider": "google", "service": "drive", "friendly_name": "create_reply"},
    Action.DRIVE_CREATE_SHORTCUT: {"provider": "google", "service": "drive", "friendly_name": "create_shortcut"},
    Action.DRIVE_DELETE_COMMENT: {"provider": "google", "service": "drive", "friendly_name": "delete_comment_drive"},
    Action.DRIVE_DELETE_SHARED_DRIVE: {"provider": "google", "service": "drive", "friendly_name": "delete_shared_drive"},
    Action.DRIVE_DELETE_PERMISSION: {"provider": "google", "service": "drive", "friendly_name": "delete_permission"},
    Action.DRIVE_DELETE_REPLY: {"provider": "google", "service": "drive", "friendly_name": "delete_reply"},
    Action.DRIVE_EMPTY_TRASH: {"provider": "google", "service": "drive", "friendly_name": "empty_trash"},
    Action.DRIVE_MODIFY_FILE_LABELS: {"provider": "google", "service": "drive", "friendly_name": "modify_file_labels"},
    Action.DRIVE_GENERATE_FILE_IDS: {"provider": "google", "service": "drive", "friendly_name": "generate_file_ids"},
    Action.DRIVE_GET_ABOUT_INFORMATION: {"provider": "google", "service": "drive", "friendly_name": "get_about_information"},
    Action.DRIVE_GET_CHANGES_START_PAGE_TOKEN: {"provider": "google", "service": "drive", "friendly_name": "get_changes_start_page_token"},
    Action.DRIVE_GET_COMMENT: {"provider": "google", "service": "drive", "friendly_name": "get_comment"},
    Action.DRIVE_GET_SHARED_DRIVE: {"provider": "google", "service": "drive", "friendly_name": "get_shared_drive"},
    Action.DRIVE_GET_FILE_METADATA: {"provider": "google", "service": "drive", "friendly_name": "get_file_metadata"},
    Action.DRIVE_GET_PERMISSION: {"provider": "google", "service": "drive", "friendly_name": "get_permission"},
    Action.DRIVE_GET_REPLY: {"provider": "google", "service": "drive", "friendly_name": "get_reply"},
    Action.DRIVE_GET_REVISION: {"provider": "google", "service": "drive", "friendly_name": "get_revision"},
    Action.DRIVE_HIDE_SHARED_DRIVE: {"provider": "google", "service": "drive", "friendly_name": "hide_shared_drive"},
    Action.DRIVE_LIST_CHANGES: {"provider": "google", "service": "drive", "friendly_name": "list_changes"},
    Action.DRIVE_LIST_COMMENTS: {"provider": "google", "service": "drive", "friendly_name": "list_comments_drive"},
    Action.DRIVE_LIST_FILES_AND_FOLDERS: {"provider": "google", "service": "drive", "friendly_name": "list_files_and_folders"},
    Action.DRIVE_LIST_FILE_LABELS: {"provider": "google", "service": "drive", "friendly_name": "list_file_labels"},
    Action.DRIVE_LIST_PERMISSIONS: {"provider": "google", "service": "drive", "friendly_name": "list_permissions"},
    Action.DRIVE_LIST_REPLIES: {"provider": "google", "service": "drive", "friendly_name": "list_replies"},
    Action.DRIVE_LIST_REVISIONS: {"provider": "google", "service": "drive", "friendly_name": "list_revisions"},
    Action.DRIVE_LIST_SHARED_DRIVES: {"provider": "google", "service": "drive", "friendly_name": "list_shared_drives"},
    Action.DRIVE_MOVE_FILE: {"provider": "google", "service": "drive", "friendly_name": "move_file"},
    Action.DRIVE_UNTRASH_FILE: {"provider": "google", "service": "drive", "friendly_name": "untrash_file"},
    Action.DRIVE_UPDATE_COMMENT: {"provider": "google", "service": "drive", "friendly_name": "update_comment"},
    Action.DRIVE_UPDATE_SHARED_DRIVE: {"provider": "google", "service": "drive", "friendly_name": "update_shared_drive"},
    Action.DRIVE_FIND_FILE: {"provider": "google", "service": "drive", "friendly_name": "find_file"},
    Action.DRIVE_FIND_FOLDER: {"provider": "google", "service": "drive", "friendly_name": "find_folder"},
    Action.DRIVE_COPY_FILE: {"provider": "google", "service": "drive", "friendly_name": "copy_file"},
    Action.DRIVE_CREATE_TEXT_FILE: {"provider": "google", "service": "drive", "friendly_name": "create_text_file"},
    Action.DRIVE_UPDATE_FILE_METADATA: {"provider": "google", "service": "drive", "friendly_name": "update_file_metadata"},
    Action.DRIVE_UPDATE_REPLY: {"provider": "google", "service": "drive", "friendly_name": "update_reply"},
    Action.DRIVE_UPDATE_FILE_REVISION: {"provider": "google", "service": "drive", "friendly_name": "update_file_revision"},
    Action.DRIVE_UNHIDE_SHARED_DRIVE: {"provider": "google", "service": "drive", "friendly_name": "unhide_shared_drive"},
    Action.DRIVE_ADD_FILE_SHARING_PREFERENCE: {"provider": "google", "service": "drive", "friendly_name": "add_file_sharing_preference"},
    Action.DRIVE_DELETE_FOLDER: {"provider": "google", "service": "drive", "friendly_name": "delete_folder_drive"},
    Action.DRIVE_UPLOAD_FILE: {"provider": "google", "service": "drive", "friendly_name": "upload_file_drive"},
    Action.DRIVE_EDIT_FILE: {"provider": "google", "service": "drive", "friendly_name": "edit_file"},

    # Docs actions
    Action.DOCS_CREATE_DOCUMENT: {"provider": "google", "service": "docs", "friendly_name": "create_document"},
    Action.DOCS_GET_DOCUMENT: {"provider": "google", "service": "docs", "friendly_name": "get_document"},
    Action.DOCS_CREATE_PARAGRAPH_BULLETS: {"provider": "google", "service": "docs", "friendly_name": "create_paragraph_bullets"},
    Action.DOCS_DELETE_PARAGRAPH_BULLETS: {"provider": "google", "service": "docs", "friendly_name": "delete_paragraph_bullets"},
    Action.DOCS_INSERT_TABLE: {"provider": "google", "service": "docs", "friendly_name": "insert_table"},
    Action.DOCS_DELETE_TABLE: {"provider": "google", "service": "docs", "friendly_name": "delete_table_docs"},
    Action.DOCS_INSERT_TABLE_ROW: {"provider": "google", "service": "docs", "friendly_name": "insert_table_row"},
    Action.DOCS_DELETE_TABLE_ROW: {"provider": "google", "service": "docs", "friendly_name": "delete_table_row"},
    Action.DOCS_INSERT_TABLE_COLUMN: {"provider": "google", "service": "docs", "friendly_name": "insert_table_column"},
    Action.DOCS_DELETE_TABLE_COLUMN: {"provider": "google", "service": "docs", "friendly_name": "delete_table_column"},
    Action.DOCS_CREATE_HEADER: {"provider": "google", "service": "docs", "friendly_name": "create_header"},
    Action.DOCS_DELETE_HEADER: {"provider": "google", "service": "docs", "friendly_name": "delete_header"},
    Action.DOCS_CREATE_FOOTER: {"provider": "google", "service": "docs", "friendly_name": "create_footer"},
    Action.DOCS_DELETE_FOOTER: {"provider": "google", "service": "docs", "friendly_name": "delete_footer"},
    Action.DOCS_CREATE_FOOTNOTE: {"provider": "google", "service": "docs", "friendly_name": "create_footnote"},
    Action.DOCS_CREATE_NAMED_RANGE: {"provider": "google", "service": "docs", "friendly_name": "create_named_range"},
    Action.DOCS_DELETE_NAMED_RANGE: {"provider": "google", "service": "docs", "friendly_name": "delete_named_range"},
    Action.DOCS_UPDATE_TEXT_STYLE: {"provider": "google", "service": "docs", "friendly_name": "update_text_style"},
    Action.DOCS_UPDATE_PARAGRAPH_STYLE: {"provider": "google", "service": "docs", "friendly_name": "update_paragraph_style"},
    Action.DOCS_INSERT_PAGE_BREAK: {"provider": "google", "service": "docs", "friendly_name": "insert_page_break"},
    Action.DOCS_INSERT_SECTION_BREAK: {"provider": "google", "service": "docs", "friendly_name": "insert_section_break"},
    Action.DOCS_INSERT_INLINE_IMAGE: {"provider": "google", "service": "docs", "friendly_name": "insert_inline_image"},
    Action.DOCS_REPLACE_IMAGE: {"provider": "google", "service": "docs", "friendly_name": "replace_image"},
    Action.DOCS_UNMERGE_TABLE_CELLS: {"provider": "google", "service": "docs", "friendly_name": "unmerge_table_cells"},
    Action.DOCS_UPDATE_DOCUMENT_STYLE: {"provider": "google", "service": "docs", "friendly_name": "update_document_style"},
    Action.DOCS_UPDATE_TABLE_ROW_STYLE: {"provider": "google", "service": "docs", "friendly_name": "update_table_row_style"},
    Action.DOCS_COPY_DOCUMENT: {"provider": "google", "service": "docs", "friendly_name": "copy_document"},
    Action.DOCS_INSERT_TEXT: {"provider": "google", "service": "docs", "friendly_name": "insert_text"},
    Action.DOCS_DELETE_CONTENT_RANGE: {"provider": "google", "service": "docs", "friendly_name": "delete_content_range"},
    Action.DOCS_REPLACE_ALL_TEXT: {"provider": "google", "service": "docs", "friendly_name": "replace_all_text"},
    Action.DOCS_SEARCH_DOCUMENTS: {"provider": "google", "service": "docs", "friendly_name": "search_documents"},
    Action.DOCS_CREATE_DOCUMENT_MARKDOWN: {"provider": "google", "service": "docs", "friendly_name": "create_document_markdown"},

    # Meet actions
    Action.MEET_GET_CONFERENCE_RECORD: {"provider": "google", "service": "meet", "friendly_name": "get_conference_record"},
    Action.MEET_GET_PARTICIPANT_SESSION: {"provider": "google", "service": "meet", "friendly_name": "get_participant_session"},
    Action.MEET_LIST_PARTICIPANT_SESSIONS: {"provider": "google", "service": "meet", "friendly_name": "list_participant_sessions"},
    Action.MEET_LIST_CONFERENCE_RECORDS: {"provider": "google", "service": "meet", "friendly_name": "list_conference_records"},
    Action.MEET_UPDATE_GOOGLE_MEET_SPACE: {"provider": "google", "service": "meet", "friendly_name": "update_google_meet_space"},
    Action.MEET_CREATE_MEET_SPACE: {"provider": "google", "service": "meet", "friendly_name": "create_meet_space"},
    Action.MEET_GET_MEET_SPACE_DETAILS: {"provider": "google", "service": "meet", "friendly_name": "get_meet_space_details"},
    Action.MEET_GET_RECORDINGS_BY_CONFERENCE_RECORD: {"provider": "google", "service": "meet", "friendly_name": "get_recordings_by_conference_record"},
    Action.MEET_GET_TRANSCRIPTS_BY_CONFERENCE_RECORD: {"provider": "google", "service": "meet", "friendly_name": "get_transcripts_by_conference_record"},

    # Firecrawl actions
    Action.FIRECRAWL_SCRAPE_URL: {"provider": "firecrawl", "service": "firecrawl", "friendly_name": "scrape_url"},
    Action.FIRECRAWL_START_CRAWL: {"provider": "firecrawl", "service": "firecrawl", "friendly_name": "start_crawl"},
    Action.FIRECRAWL_GET_CRAWL_STATUS: {"provider": "firecrawl", "service": "firecrawl", "friendly_name": "get_crawl_status"},
    Action.FIRECRAWL_CANCEL_CRAWL: {"provider": "firecrawl", "service": "firecrawl", "friendly_name": "cancel_crawl"},
    Action.FIRECRAWL_MAP_URLS: {"provider": "firecrawl", "service": "firecrawl", "friendly_name": "map_urls"},
    Action.FIRECRAWL_EXTRACT_DATA: {"provider": "firecrawl", "service": "firecrawl", "friendly_name": "extract_data"},
    Action.FIRECRAWL_SEARCH_WEB: {"provider": "firecrawl", "service": "firecrawl", "friendly_name": "search_web"},
    
    # Serpapi actions
    Action.SERPAPI_BAIDU_SEARCH: {"provider": "serpapi", "service": "serpapi", "friendly_name": "baidu_search"},
    Action.SERPAPI_BING_SEARCH: {"provider": "serpapi", "service": "serpapi", "friendly_name": "bing_search"},
    Action.SERPAPI_EBAY_SEARCH: {"provider": "serpapi", "service": "serpapi", "friendly_name": "ebay_search"},
    Action.SERPAPI_GOOGLE_DOMAINS_LIST: {"provider": "serpapi", "service": "serpapi", "friendly_name": "google_domains_list"},
    Action.SERPAPI_GOOGLE_JOBS_SEARCH: {"provider": "serpapi", "service": "serpapi", "friendly_name": "google_jobs_search"},
    Action.SERPAPI_GOOGLE_LIGHT_SEARCH: {"provider": "serpapi", "service": "serpapi", "friendly_name": "google_light_search"},
    Action.SERPAPI_HOTEL_SEARCH: {"provider": "serpapi", "service": "serpapi", "friendly_name": "hotel_search"},
    Action.SERPAPI_LIST_LOCATIONS: {"provider": "serpapi", "service": "serpapi", "friendly_name": "list_locations"},
    Action.SERPAPI_GOOGLE_PLAY_SEARCH: {"provider": "serpapi", "service": "serpapi", "friendly_name": "google_play_search"},
    Action.SERPAPI_WALMART_SEARCH: {"provider": "serpapi", "service": "serpapi", "friendly_name": "walmart_search"},
    Action.SERPAPI_YAHOO_SEARCH: {"provider": "serpapi", "service": "serpapi", "friendly_name": "yahoo_search"},
    Action.SERPAPI_YANDEX_SEARCH: {"provider": "serpapi", "service": "serpapi", "friendly_name": "yandex_search"},
    Action.SERPAPI_YOUTUBE_SEARCH: {"provider": "serpapi", "service": "serpapi", "friendly_name": "youtube_search"},
    Action.SERPAPI_DUCKDUCKGO_SEARCH: {"provider": "serpapi", "service": "serpapi", "friendly_name": "duckduckgo_search"},
    Action.SERPAPI_GOOGLE_EVENTS_SEARCH: {"provider": "serpapi", "service": "serpapi", "friendly_name": "google_events_search"},
    Action.SERPAPI_GOOGLE_FINANCE_SEARCH: {"provider": "serpapi", "service": "serpapi", "friendly_name": "google_finance_search"},
    Action.SERPAPI_GOOGLE_MAPS_SEARCH: {"provider": "serpapi", "service": "serpapi", "friendly_name": "google_maps_search"},
    Action.SERPAPI_GOOGLE_IMAGES_SEARCH: {"provider": "serpapi", "service": "serpapi", "friendly_name": "google_images_search"},
    Action.SERPAPI_GOOGLE_NEWS_SEARCH: {"provider": "serpapi", "service": "serpapi", "friendly_name": "google_news_search"},
    Action.SERPAPI_GOOGLE_SCHOLAR_SEARCH: {"provider": "serpapi", "service": "serpapi", "friendly_name": "google_scholar_search"},
    Action.SERPAPI_GOOGLE_SEARCH: {"provider": "serpapi", "service": "serpapi", "friendly_name": "google_search"},
    Action.SERPAPI_GOOGLE_SHOPPING_SEARCH: {"provider": "serpapi", "service": "serpapi", "friendly_name": "google_shopping_search"},
    Action.SERPAPI_GOOGLE_TRENDS_SEARCH: {"provider": "serpapi", "service": "serpapi", "friendly_name": "google_trends_search"},

    # Notion actions
    Action.NOTION_CREATE_COMMENT: {"provider": "notion", "service": "notion", "friendly_name": "create_comment_notion"},
    Action.NOTION_ADD_MULTIPLE_CONTENT_BLOCKS: {"provider": "notion", "service": "notion", "friendly_name": "add_multiple_content_blocks"},
    Action.NOTION_DELETE_BLOCK: {"provider": "notion", "service": "notion", "friendly_name": "delete_block"},
    Action.NOTION_FETCH_BLOCK_CHILDREN: {"provider": "notion", "service": "notion", "friendly_name": "fetch_block_children"},
    Action.NOTION_FETCH_COMMENTS: {"provider": "notion", "service": "notion", "friendly_name": "fetch_comments"},
    Action.NOTION_CREATE_DATABASE: {"provider": "notion", "service": "notion", "friendly_name": "create_database"},
    Action.NOTION_CREATE_PAGE: {"provider": "notion", "service": "notion", "friendly_name": "create_page"},
    Action.NOTION_FETCH_DATABASE: {"provider": "notion", "service": "notion", "friendly_name": "fetch_database"},
    Action.NOTION_FETCH_DATABASE_ROW: {"provider": "notion", "service": "notion", "friendly_name": "fetch_database_row"},
    Action.NOTION_INSERT_DATABASE_ROW: {"provider": "notion", "service": "notion", "friendly_name": "insert_database_row"},
    Action.NOTION_QUERY_DATABASE: {"provider": "notion", "service": "notion", "friendly_name": "query_database"},
    Action.NOTION_RETRIEVE_DATABASE_PROPERTY: {"provider": "notion", "service": "notion", "friendly_name": "retrieve_database_property"},
    Action.NOTION_GET_ABOUT_ME: {"provider": "notion", "service": "notion", "friendly_name": "get_about_me"},
    Action.NOTION_GET_ABOUT_USER: {"provider": "notion", "service": "notion", "friendly_name": "get_about_user"},
    Action.NOTION_LIST_USERS: {"provider": "notion", "service": "notion", "friendly_name": "list_users_notion"},
    Action.NOTION_RETRIEVE_COMMENT: {"provider": "notion", "service": "notion", "friendly_name": "retrieve_comment"},
    Action.NOTION_UPDATE_DATABASE_SCHEMA: {"provider": "notion", "service": "notion", "friendly_name": "update_database_schema"},
    Action.NOTION_UPDATE_ROW_DATABASE: {"provider": "notion", "service": "notion", "friendly_name": "update_row_database"},
    Action.NOTION_SEARCH_NOTION_PAGE: {"provider": "notion", "service": "notion", "friendly_name": "search_notion_page"},
    Action.NOTION_UPDATE_PAGE: {"provider": "notion", "service": "notion", "friendly_name": "update_page"},
    Action.NOTION_ADD_CONTENT_TO_NOTION_PAGE: {"provider": "notion", "service": "notion", "friendly_name": "add_content_to_notion_page"},
    Action.NOTION_APPEND_COMPLEX_BLOCKS: {"provider": "notion", "service": "notion", "friendly_name": "append_complex_blocks"},
    Action.NOTION_DUPLICATE_PAGE: {"provider": "notion", "service": "notion", "friendly_name": "duplicate_page"},
    Action.NOTION_FETCH_NOTION_BLOCK_METADATA: {"provider": "notion", "service": "notion", "friendly_name": "fetch_notion_block_metadata"},
    Action.NOTION_UPDATE_BLOCK: {"provider": "notion", "service": "notion", "friendly_name": "update_block"},
    Action.NOTION_FETCH_NOTION_DATA: {"provider": "notion", "service": "notion", "friendly_name": "fetch_notion_data"},
    Action.NOTION_GET_PAGE_PROPERTY: {"provider": "notion", "service": "notion", "friendly_name": "get_page_property"},

    # Airtable actions
    Action.AIRTABLE_LIST_BASES: {"provider": "airtable", "service": "airtable", "friendly_name": "list_bases"},
    Action.AIRTABLE_CREATE_BASE: {"provider": "airtable", "service": "airtable", "friendly_name": "create_base"},
    Action.AIRTABLE_GET_BASE_SCHEMA: {"provider": "airtable", "service": "airtable", "friendly_name": "get_base_schema"},
    Action.AIRTABLE_CREATE_TABLE: {"provider": "airtable", "service": "airtable", "friendly_name": "create_table_airtable"},
    Action.AIRTABLE_CREATE_FIELD: {"provider": "airtable", "service": "airtable", "friendly_name": "create_field"},
    Action.AIRTABLE_CREATE_RECORD: {"provider": "airtable", "service": "airtable", "friendly_name": "create_record"},
    Action.AIRTABLE_CREATE_MULTIPLE_RECORDS: {"provider": "airtable", "service": "airtable", "friendly_name": "create_multiple_records"},
    Action.AIRTABLE_GET_RECORD: {"provider": "airtable", "service": "airtable", "friendly_name": "get_record"},
    Action.AIRTABLE_LIST_RECORDS: {"provider": "airtable", "service": "airtable", "friendly_name": "list_records"},
    Action.AIRTABLE_UPDATE_RECORD: {"provider": "airtable", "service": "airtable", "friendly_name": "update_record"},
    Action.AIRTABLE_UPDATE_MULTIPLE_RECORDS: {"provider": "airtable", "service": "airtable", "friendly_name": "update_multiple_records"},
    Action.AIRTABLE_DELETE_RECORD: {"provider": "airtable", "service": "airtable", "friendly_name": "delete_record"},
    Action.AIRTABLE_DELETE_MULTIPLE_RECORDS: {"provider": "airtable", "service": "airtable", "friendly_name": "delete_multiple_records"},
    Action.AIRTABLE_CREATE_COMMENT: {"provider": "airtable", "service": "airtable", "friendly_name": "create_comment_airtable"},
    Action.AIRTABLE_DELETE_COMMENT: {"provider": "airtable", "service": "airtable", "friendly_name": "delete_comment_airtable"},
    Action.AIRTABLE_LIST_COMMENTS: {"provider": "airtable", "service": "airtable", "friendly_name": "list_comments_airtable"},
    Action.AIRTABLE_GET_USER_INFORMATION: {"provider": "airtable", "service": "airtable", "friendly_name": "get_user_information"},

    # Github actions
    Action.GITHUB_ADD_ASSIGNEES_TO_ISSUE : {"provider": "github", "service": "github", "friendly_name": "add_assignees_to_issue"},
    Action.GITHUB_ADD_REPOSITORY_COLLABORATOR : {"provider": "github", "service": "github", "friendly_name": "add_repository_collaborator"},
    Action.GITHUB_ADD_LABELS_TO_ISSUE : {"provider": "github", "service": "github", "friendly_name": "add_labels_to_issue"},
    Action.GITHUB_CREATE_ISSUE : {"provider": "github", "service": "github", "friendly_name": "create_issue"},
    Action.GITHUB_CREATE_ISSUE_COMMENT : {"provider": "github", "service": "github", "friendly_name": "create_issue_comment"},
    Action.GITHUB_CREATE_PULL_REQUEST : {"provider": "github", "service": "github", "friendly_name": "create_pull_request"},
    Action.GITHUB_CREATE_REPOSITORY : {"provider": "github", "service": "github", "friendly_name": "create_repository"},
    Action.GITHUB_CREATE_OR_UPDATE_FILE : {"provider": "github", "service": "github", "friendly_name": "create_or_update_file"},
    Action.GITHUB_GET_PULL_REQUEST : {"provider": "github", "service": "github", "friendly_name": "get_pull_request"},
    Action.GITHUB_LIST_REPOSITORY_ISSUES : {"provider": "github", "service": "github", "friendly_name": "list_repository_issues"},
    Action.GITHUB_STAR_REPOSITORY : {"provider": "github", "service": "github", "friendly_name": "star_repository"},
    Action.GITHUB_DELETE_REPOSITORY : {"provider": "github", "service": "github", "friendly_name": "delete_repository"},
    Action.GITHUB_LIST_REPOSITORIES_STARRED_BY_AUTHENTICATED_USER : {"provider": "github", "service": "github", "friendly_name": "list_repositories_starred_by_authenticated_user"},
    Action.GITHUB_LIST_STARGAZERS : {"provider": "github", "service": "github", "friendly_name": "list_stargazers"},
    Action.GITHUB_STAR_REPOSITORY_FOR_AUTHENTICATED_USER : {"provider": "github", "service": "github", "friendly_name": "star_repository_for_authenticated_user"},
    Action.GITHUB_CHECK_IF_REPOSITORY_IS_STARRED_BY_AUTHENTICATED_USER : {"provider": "github", "service": "github", "friendly_name": "check_if_repository_is_starred_by_authenticated_user"},
    Action.GITHUB_CHECK_IF_GIST_IS_STARRED : {"provider": "github", "service": "github", "friendly_name": "check_if_gist_is_starred"},
    Action.GITHUB_BLOCK_USER : {"provider": "github", "service": "github", "friendly_name": "block_user"},
    Action.GITHUB_CHECK_IF_USER_BLOCKED_BY_AUTHENTICATED_USER : {"provider": "github", "service": "github", "friendly_name": "check_if_user_blocked_by_authenticated_user"},
    Action.GITHUB_CHECK_PRIVATE_VULNERABILITY_REPORTING_STATUS : {"provider": "github", "service": "github", "friendly_name": "check_private_vulnerability_reporting_status"},
    Action.GITHUB_CHECK_TEAM_PERMISSIONS_FOR_PROJECT : {"provider": "github", "service": "github", "friendly_name": "check_team_permissions_for_project"},
    Action.GITHUB_CHECK_TEAM_PERMISSIONS_FOR_REPOSITORY : {"provider": "github", "service": "github", "friendly_name": "check_team_permissions_for_repository"},
    Action.GITHUB_CLEAR_REPOSITORY_CACHE_BY_KEY : {"provider": "github", "service": "github", "friendly_name": "clear_repository_cache_by_key"},
    Action.GITHUB_CLEAR_SELF_HOSTED_RUNNER_ORG_LABELS : {"provider": "github", "service": "github", "friendly_name": "clear_self_hosted_runner_org_labels"},
    Action.GITHUB_CONFIGURE_JIT_RUNNER_FOR_ORG : {"provider": "github", "service": "github", "friendly_name": "configure_jit_runner_for_org"},
    Action.GITHUB_CONFIGURE_OIDC_SUBJECT_CLAIM_TEMPLATE : {"provider": "github", "service": "github", "friendly_name": "configure_oidc_subject_claim_template"},
    Action.GITHUB_CONVERT_ORG_MEMBER_TO_OUTSIDE_COLLABORATOR : {"provider": "github", "service": "github", "friendly_name": "convert_org_member_to_outside_collaborator"},
    Action.GITHUB_CREATE_AUTOLINK_REFERENCE_FOR_REPOSITORY : {"provider": "github", "service": "github", "friendly_name": "create_autolink_reference_for_repository"},
    Action.GITHUB_CREATE_ENVIRONMENT_VARIABLE : {"provider": "github", "service": "github", "friendly_name": "create_environment_variable"},
    Action.GITHUB_CREATE_ORGANIZATION_PROJECT : {"provider": "github", "service": "github", "friendly_name": "create_organization_project"},
    Action.GITHUB_CREATE_ORGANIZATION_VARIABLE : {"provider": "github", "service": "github", "friendly_name": "create_organization_variable"},
    Action.GITHUB_DELETE_DEPLOYMENT_BRANCH_POLICY : {"provider": "github", "service": "github", "friendly_name": "delete_deployment_branch_policy"},
    Action.GITHUB_DELETE_DEPLOY_KEY : {"provider": "github", "service": "github", "friendly_name": "delete_deploy_key"},
    Action.GITHUB_DELETE_DISCUSSION : {"provider": "github", "service": "github", "friendly_name": "delete_discussion"},
    Action.GITHUB_DELETE_DISCUSSION_COMMENT : {"provider": "github", "service": "github", "friendly_name": "delete_discussion_comment"},
    Action.GITHUB_DELETE_FILE : {"provider": "github", "service": "github", "friendly_name": "delete_file_github"},
    Action.GITHUB_DELETE_GIST : {"provider": "github", "service": "github", "friendly_name": "delete_gist"},
    Action.GITHUB_DELETE_GIST_COMMENT : {"provider": "github", "service": "github", "friendly_name": "delete_gist_comment"},
    Action.GITHUB_DELETE_GITHUB_PAGES_SITE : {"provider": "github", "service": "github", "friendly_name": "delete_github_pages_site"},
    Action.GITHUB_DELETE_LABEL : {"provider": "github", "service": "github", "friendly_name": "delete_label"},
    Action.GITHUB_DELETE_MILESTONE : {"provider": "github", "service": "github", "friendly_name": "delete_milestone"},
    Action.GITHUB_DELETE_PACKAGE_FOR_ORGANIZATION : {"provider": "github", "service": "github", "friendly_name": "delete_package_for_organization"},
    Action.GITHUB_DELETE_PACKAGE_FOR_USER : {"provider": "github", "service": "github", "friendly_name": "delete_package_for_user"},
    Action.GITHUB_DELETE_PACKAGE_FOR_AUTHENTICATED_USER : {"provider": "github", "service": "github", "friendly_name": "delete_package_for_authenticated_user"},
    Action.GITHUB_DELETE_PACKAGE_VERSION_FOR_AUTHENTICATED_USER : {"provider": "github", "service": "github", "friendly_name": "delete_package_version_for_authenticated_user"},
    Action.GITHUB_DELETE_PENDING_REVIEW_FOR_PULL_REQUEST : {"provider": "github", "service": "github", "friendly_name": "delete_pending_review_for_pull_request"},
    Action.GITHUB_DELETE_PROJECT : {"provider": "github", "service": "github", "friendly_name": "delete_project_github"},
    Action.GITHUB_DELETE_PROJECT_CARD : {"provider": "github", "service": "github", "friendly_name": "delete_project_card"},
    Action.GITHUB_DELETE_PROJECT_COLUMN : {"provider": "github", "service": "github", "friendly_name": "delete_project_column"},
    Action.GITHUB_DELETE_PULL_REQUEST_COMMENT_REACTION : {"provider": "github", "service": "github", "friendly_name": "delete_pull_request_comment_reaction"},
    Action.GITHUB_DELETE_REFERENCE : {"provider": "github", "service": "github", "friendly_name": "delete_reference"},
    Action.GITHUB_DELETE_RELEASE : {"provider": "github", "service": "github", "friendly_name": "delete_release"},
    Action.GITHUB_DELETE_RELEASE_ASSET : {"provider": "github", "service": "github", "friendly_name": "delete_release_asset"},
    Action.GITHUB_DELETE_RELEASE_REACTION : {"provider": "github", "service": "github", "friendly_name": "delete_release_reaction"},
    Action.GITHUB_DELETE_REPOSITORY_INVITATION : {"provider": "github", "service": "github", "friendly_name": "delete_repository_invitation"},
    Action.GITHUB_DELETE_REPOSITORY_RULESET : {"provider": "github", "service": "github", "friendly_name": "delete_repository_ruleset"},
    Action.GITHUB_DELETE_REPOSITORY_SECRET : {"provider": "github", "service": "github", "friendly_name": "delete_repository_secret"},
    Action.GITHUB_DELETE_REPOSITORY_SUBSCRIPTION : {"provider": "github", "service": "github", "friendly_name": "delete_repository_subscription"},
    Action.GITHUB_DELETE_REPOSITORY_VARIABLE : {"provider": "github", "service": "github", "friendly_name": "delete_repository_variable"},
    Action.GITHUB_DELETE_REVIEW_COMMENT_FOR_PULL_REQUEST : {"provider": "github", "service": "github", "friendly_name": "delete_review_comment_for_pull_request"},
    Action.GITHUB_DELETE_SECRET_FOR_AUTHENTICATED_USER : {"provider": "github", "service": "github", "friendly_name": "delete_secret_for_authenticated_user"},
    Action.GITHUB_DELETE_SELF_HOSTED_RUNNER_FROM_ORGANIZATION : {"provider": "github", "service": "github", "friendly_name": "delete_self_hosted_runner_from_organization"},
    Action.GITHUB_DELETE_SELF_HOSTED_RUNNER_FROM_REPOSITORY : {"provider": "github", "service": "github", "friendly_name": "delete_self_hosted_runner_from_repository"},
    Action.GITHUB_DELETE_TAG_PROTECTION_FOR_REPOSITORY : {"provider": "github", "service": "github", "friendly_name": "delete_tag_protection_for_repository"},
    Action.GITHUB_DELETE_TEAM : {"provider": "github", "service": "github", "friendly_name": "delete_team"},
    Action.GITHUB_DELETE_THREAD_SUBSCRIPTION : {"provider": "github", "service": "github", "friendly_name": "delete_thread_subscription"},
    Action.GITHUB_DELETE_WORKFLOW_RUN : {"provider": "github", "service": "github", "friendly_name": "delete_workflow_run"},
    Action.GITHUB_ENABLE_WORKFLOW : {"provider": "github", "service": "github", "friendly_name": "enable_workflow"},
    Action.GITHUB_ENABLE_GITHUB_ACTIONS_SELECTED_REPOSITORIES : {"provider": "github", "service": "github", "friendly_name": "enable_github_actions_selected_repositories"},
    Action.GITHUB_ENABLE_PRIVATE_VULNERABILITY_REPORTING : {"provider": "github", "service": "github", "friendly_name": "enable_private_vulnerability_reporting"},
    Action.GITHUB_ENABLE_REPOSITORY_ACTIONS : {"provider": "github", "service": "github", "friendly_name": "enable_repository_actions"},
    Action.GITHUB_EXPORT_CODESPACE_FOR_AUTHENTICATED_USER : {"provider": "github", "service": "github", "friendly_name": "export_codespace_for_authenticated_user"},
    Action.GITHUB_EXPORT_REPOSITORY_SBOM : {"provider": "github", "service": "github", "friendly_name": "export_repository_sbom"},
    Action.GITHUB_FOLLOW_USER : {"provider": "github", "service": "github", "friendly_name": "follow_user"},
    Action.GITHUB_FORCE_CANCEL_WORKFLOW_RUN : {"provider": "github", "service": "github", "friendly_name": "force_cancel_workflow_run"},
    Action.GITHUB_FORK_GIST : {"provider": "github", "service": "github", "friendly_name": "fork_gist"},
    Action.GITHUB_GENERATE_RELEASE_NOTES : {"provider": "github", "service": "github", "friendly_name": "generate_release_notes"},
    Action.GITHUB_GET_ACCESS_RESTRICTIONS : {"provider": "github", "service": "github", "friendly_name": "get_access_restrictions"},
    Action.GITHUB_GET_ADMIN_BRANCH_PROTECTION : {"provider": "github", "service": "github", "friendly_name": "get_admin_branch_protection"},
    Action.GITHUB_GET_ALL_API_VERSIONS : {"provider": "github", "service": "github", "friendly_name": "get_all_api_versions"},
    Action.GITHUB_GET_ALL_AUTOLINKS_OF_REPOSITORY : {"provider": "github", "service": "github", "friendly_name": "get_all_autolinks_of_repository"},
    Action.GITHUB_GET_ALL_CODES_OF_CONDUCT : {"provider": "github", "service": "github", "friendly_name": "get_all_codes_of_conduct"},
    Action.GITHUB_GET_ALL_LICENSES : {"provider": "github", "service": "github", "friendly_name": "get_all_licenses"},
    Action.GITHUB_GET_ALL_CONTRIBUTOR_COMMIT_ACTIVITY : {"provider": "github", "service": "github", "friendly_name": "get_all_contributor_commit_activity"},
    Action.GITHUB_GET_ALL_CUSTOM_PROPERTIES_FOR_ORGANIZATION : {"provider": "github", "service": "github", "friendly_name": "get_all_custom_properties_for_organization"},
    Action.GITHUB_GET_ALL_CUSTOM_PROPERTY_VALUES_FOR_REPOSITORY : {"provider": "github", "service": "github", "friendly_name": "get_all_custom_property_values_for_repository"},
    Action.GITHUB_GET_ALL_DEPLOYMENT_PROTECTION_RULES : {"provider": "github", "service": "github", "friendly_name": "get_all_deployment_protection_rules"},
    Action.GITHUB_GET_ALL_GITIGNORE_TEMPLATES : {"provider": "github", "service": "github", "friendly_name": "get_all_gitignore_templates"},
    Action.GITHUB_GET_ALL_ORGANIZATION_ROLES : {"provider": "github", "service": "github", "friendly_name": "get_all_organization_roles"},
    Action.GITHUB_GET_ALL_REPOSITORY_RULESETS : {"provider": "github", "service": "github", "friendly_name": "get_all_repository_rulesets"},
    Action.GITHUB_GET_ALL_REPOSITORY_TOPICS : {"provider": "github", "service": "github", "friendly_name": "get_all_repository_topics"},
    Action.GITHUB_GET_ALL_REQUESTED_REVIEWERS_FOR_PULL_REQUEST : {"provider": "github", "service": "github", "friendly_name": "get_all_requested_reviewers_for_pull_request"},
    Action.GITHUB_GET_ALL_STATUS_CHECK_CONTEXTS : {"provider": "github", "service": "github", "friendly_name": "get_all_status_check_contexts"},
    Action.GITHUB_GET_APP : {"provider": "github", "service": "github", "friendly_name": "get_app"},
    Action.GITHUB_GET_ARTIFACT : {"provider": "github", "service": "github", "friendly_name": "get_artifact"},
    Action.GITHUB_GET_ASSIGNMENT : {"provider": "github", "service": "github", "friendly_name": "get_assignment"},
    Action.GITHUB_GET_AUTOLINK_REFERENCE_OF_REPOSITORY : {"provider": "github", "service": "github", "friendly_name": "get_autolink_reference_of_repository"},
    Action.GITHUB_GET_ENVIRONMENT : {"provider": "github", "service": "github", "friendly_name": "get_environment"},
    Action.GITHUB_GET_ENVIRONMENT_PUBLIC_KEY : {"provider": "github", "service": "github", "friendly_name": "get_environment_public_key"},
    Action.GITHUB_GET_ENVIRONMENT_SECRET : {"provider": "github", "service": "github", "friendly_name": "get_environment_secret"},
    Action.GITHUB_GET_ENVIRONMENT_VARIABLE : {"provider": "github", "service": "github", "friendly_name": "get_environment_variable"},
    Action.GITHUB_GET_ISSUE : {"provider": "github", "service": "github", "friendly_name": "get_issue"},
    Action.GITHUB_GET_ISSUE_COMMENT : {"provider": "github", "service": "github", "friendly_name": "get_issue_comment"},
    Action.GITHUB_GET_ISSUE_EVENT : {"provider": "github", "service": "github", "friendly_name": "get_issue_event"},
    Action.GITHUB_GET_ORGANIZATION : {"provider": "github", "service": "github", "friendly_name": "get_organization"},
    Action.GITHUB_GET_ORGANIZATION_PUBLIC_KEY : {"provider": "github", "service": "github", "friendly_name": "get_organization_public_key"},
    Action.GITHUB_GET_ORGANIZATION_ROLE : {"provider": "github", "service": "github", "friendly_name": "get_organization_role"},
    Action.GITHUB_GET_ORGANIZATION_SECRET : {"provider": "github", "service": "github", "friendly_name": "get_organization_secret"},
    Action.GITHUB_GET_ORGANIZATION_VARIABLE : {"provider": "github", "service": "github", "friendly_name": "get_organization_variable"},
    Action.GITHUB_GET_APPS_WITH_ACCESS_TO_PROTECTED_BRANCH : {"provider": "github", "service": "github", "friendly_name": "get_apps_with_access_to_protected_branch"},
    Action.GITHUB_GET_ASSIGNMENT_GRADES : {"provider": "github", "service": "github", "friendly_name": "get_assignment_grades"},
    Action.GITHUB_GET_BLOB : {"provider": "github", "service": "github", "friendly_name": "get_blob"},
    Action.GITHUB_GET_BRANCH : {"provider": "github", "service": "github", "friendly_name": "get_branch"},
    Action.GITHUB_GET_CHECK_RUN : {"provider": "github", "service": "github", "friendly_name": "get_check_run"},
    Action.GITHUB_DELETE_BRANCH_PROTECTION : {"provider": "github", "service": "github", "friendly_name": "delete_branch_protection"},
    Action.GITHUB_DELETE_COMMIT_SIGNATURE_PROTECTION : {"provider": "github", "service": "github", "friendly_name": "delete_commit_signature_protection"},
    Action.GITHUB_DELETE_DEPENDABOT_SECRET : {"provider": "github", "service": "github", "friendly_name": "delete_dependabot_secret"},
    Action.GITHUB_DELETE_ACTIONS_CACHE : {"provider": "github", "service": "github", "friendly_name": "delete_actions_cache"},
    Action.GITHUB_DELETE_PACKAGE_VERSION_FOR_ORGANIZATION : {"provider": "github", "service": "github", "friendly_name": "delete_package_version_for_organization"},
    Action.GITHUB_DELETE_PACKAGE_VERSION_FOR_USER : {"provider": "github", "service": "github", "friendly_name": "delete_package_version_for_user"},
    Action.GITHUB_DELETE_PULL_REQUEST_REVIEW_PROTECTION : {"provider": "github", "service": "github", "friendly_name": "delete_pull_request_review_protection"},
    Action.GITHUB_DELETE_CODESPACE_SECRET : {"provider": "github", "service": "github", "friendly_name": "delete_codespace_secret"},
    Action.GITHUB_DELETE_SOCIAL_ACCOUNTS_FOR_AUTHENTICATED_USER : {"provider": "github", "service": "github", "friendly_name": "delete_social_accounts_for_authenticated_user"},
    Action.GITHUB_DELETE_TEAM_DISCUSSION_COMMENT_REACTION : {"provider": "github", "service": "github", "friendly_name": "delete_team_discussion_comment_reaction"},
    Action.GITHUB_DELETE_TEAM_DISCUSSION_REACTION : {"provider": "github", "service": "github", "friendly_name": "delete_team_discussion_reaction"},
    Action.GITHUB_DELETE_WORKFLOW_RUN_LOGS : {"provider": "github", "service": "github", "friendly_name": "delete_workflow_run_logs"},
    Action.GITHUB_DISABLE_CUSTOM_PROTECTION_RULE_FOR_ENVIRONMENT : {"provider": "github", "service": "github", "friendly_name": "disable_custom_protection_rule_for_environment"},
    Action.GITHUB_DISABLE_WORKFLOW : {"provider": "github", "service": "github", "friendly_name": "disable_workflow"},
    Action.GITHUB_DISABLE_PRIVATE_VULNERABILITY_REPORTING : {"provider": "github", "service": "github", "friendly_name": "disable_private_vulnerability_reporting"},
    Action.GITHUB_DISABLE_REPOSITORY_ACTIONS_IN_ORGANIZATION : {"provider": "github", "service": "github", "friendly_name": "disable_repository_actions_in_organization"},
    Action.GITHUB_DISMISS_PULL_REQUEST_REVIEW : {"provider": "github", "service": "github", "friendly_name": "dismiss_pull_request_review"},
    Action.GITHUB_DOWNLOAD_ARTIFACT : {"provider": "github", "service": "github", "friendly_name": "download_artifact"},
    Action.GITHUB_DOWNLOAD_REPOSITORY_TARBALL : {"provider": "github", "service": "github", "friendly_name": "download_repository_tarball"},
    Action.GITHUB_DOWNLOAD_REPOSITORY_ZIPBALL : {"provider": "github", "service": "github", "friendly_name": "download_repository_zipball"},
    Action.GITHUB_DOWNLOAD_JOB_LOGS_FOR_WORKFLOW_RUN : {"provider": "github", "service": "github", "friendly_name": "download_job_logs_for_workflow_run"},
    Action.GITHUB_DOWNLOAD_WORKFLOW_RUN_ATTEMPT_LOGS : {"provider": "github", "service": "github", "friendly_name": "download_workflow_run_attempt_logs"},
    Action.GITHUB_DOWNLOAD_WORKFLOW_RUN_LOGS : {"provider": "github", "service": "github", "friendly_name": "download_workflow_run_logs"},
    Action.GITHUB_GET_ME : {"provider": "github", "service": "github", "friendly_name": "get_me"},
    Action.GITHUB_SEARCH_ISSUES : {"provider": "github", "service": "github", "friendly_name": "search_issues"},
    Action.GITHUB_LIST_ISSUES : {"provider": "github", "service": "github", "friendly_name": "list_issues"},
    Action.GITHUB_ADD_ISSUE_COMMENT : {"provider": "github", "service": "github", "friendly_name": "add_issue_comment"},
    Action.GITHUB_UPDATE_ISSUE : {"provider": "github", "service": "github", "friendly_name": "update_issue"},
    Action.GITHUB_LIST_PULL_REQUESTS : {"provider": "github", "service": "github", "friendly_name": "list_pull_requests"},
    Action.GITHUB_GET_PULL_REQUEST_FILES : {"provider": "github", "service": "github", "friendly_name": "get_pull_request_files"},
    Action.GITHUB_GET_PULL_REQUEST_COMMENTS : {"provider": "github", "service": "github", "friendly_name": "get_pull_request_comments"},
    Action.GITHUB_GET_PULL_REQUEST_REVIEWS : {"provider": "github", "service": "github", "friendly_name": "get_pull_request_reviews"},
    Action.GITHUB_MERGE_PULL_REQUEST : {"provider": "github", "service": "github", "friendly_name": "merge_pull_request"},
    Action.GITHUB_UPDATE_PULL_REQUEST_BRANCH : {"provider": "github", "service": "github", "friendly_name": "update_pull_request_branch"},
    Action.GITHUB_CREATE_PULL_REQUEST_REVIEW : {"provider": "github", "service": "github", "friendly_name": "create_pull_request_review"},
    Action.GITHUB_UPDATE_PULL_REQUEST : {"provider": "github", "service": "github", "friendly_name": "update_pull_request"},
    Action.GITHUB_SEARCH_REPOSITORIES : {"provider": "github", "service": "github", "friendly_name": "search_repositories"},
    Action.GITHUB_GET_FILE_CONTENTS : {"provider": "github", "service": "github", "friendly_name": "get_file_contents"},
    Action.GITHUB_LIST_COMMITS : {"provider": "github", "service": "github", "friendly_name": "list_commits"},
    Action.GITHUB_FORK_REPOSITORY : {"provider": "github", "service": "github", "friendly_name": "fork_repository"},
    Action.GITHUB_CREATE_BRANCH : {"provider": "github", "service": "github", "friendly_name": "create_branch"},
    Action.GITHUB_SEARCH_CODE : {"provider": "github", "service": "github", "friendly_name": "search_code"},
    Action.GITHUB_SEARCH_USERS : {"provider": "github", "service": "github", "friendly_name": "search_users"},
    Action.GITHUB_GET_COMMIT : {"provider": "github", "service": "github", "friendly_name": "get_commit"},

    # Slack actions
    Action.SLACK_SEND_MESSAGE: {"provider": "slack", "service": "slack", "friendly_name": "send_message"},
    Action.SLACK_UPDATE_MESSAGE: {"provider": "slack", "service": "slack", "friendly_name": "update_message"},
    Action.SLACK_SCHEDULE_MESSAGE: {"provider": "slack", "service": "slack", "friendly_name": "schedule_message"},
    Action.SLACK_FETCH_CONVERSATION_HISTORY: {"provider": "slack", "service": "slack", "friendly_name": "fetch_conversation_history"},
    Action.SLACK_SEARCH_MESSAGES: {"provider": "slack", "service": "slack", "friendly_name": "search_messages"},
    Action.SLACK_CREATE_CHANNEL: {"provider": "slack", "service": "slack", "friendly_name": "create_channel"},
    Action.SLACK_ARCHIVE_CHANNEL: {"provider": "slack", "service": "slack", "friendly_name": "archive_channel"},
    Action.SLACK_FIND_CHANNELS: {"provider": "slack", "service": "slack", "friendly_name": "find_channels"},
    Action.SLACK_FIND_USERS: {"provider": "slack", "service": "slack", "friendly_name": "find_users"},
    Action.SLACK_ADD_STAR: {"provider": "slack", "service": "slack", "friendly_name": "add_star"},
    Action.SLACK_ADD_EMOJI: {"provider": "slack", "service": "slack", "friendly_name": "add_emoji"},
    Action.SLACK_CREATE_USER_GROUP: {"provider": "slack", "service": "slack", "friendly_name": "create_user_group"},
    Action.SLACK_ADD_REMOTE_FILE: {"provider": "slack", "service": "slack", "friendly_name": "add_remote_file"},
    Action.SLACK_DELETE_MESSAGE: {"provider": "slack", "service": "slack", "friendly_name": "delete_message_slack"},
    Action.SLACK_UNARCHIVE_CHANNEL: {"provider": "slack", "service": "slack", "friendly_name": "unarchive_channel"},
    Action.SLACK_RENAME_CHANNEL: {"provider": "slack", "service": "slack", "friendly_name": "rename_channel"},
    Action.SLACK_SET_CHANNEL_PURPOSE: {"provider": "slack", "service": "slack", "friendly_name": "set_channel_purpose"},
    Action.SLACK_SET_CHANNEL_TOPIC: {"provider": "slack", "service": "slack", "friendly_name": "set_channel_topic"},
    Action.SLACK_GET_CHANNEL_INFO: {"provider": "slack", "service": "slack", "friendly_name": "get_channel_info"},
    Action.SLACK_LIST_CHANNELS: {"provider": "slack", "service": "slack", "friendly_name": "list_channels"},
    Action.SLACK_GET_CHANNEL_HISTORY: {"provider": "slack", "service": "slack", "friendly_name": "get_channel_history"},
    Action.SLACK_KICK_USER_FROM_CHANNEL: {"provider": "slack", "service": "slack", "friendly_name": "kick_user_from_channel"},
    Action.SLACK_JOIN_CHANNEL: {"provider": "slack", "service": "slack", "friendly_name": "join_channel"},
    Action.SLACK_LEAVE_CHANNEL: {"provider": "slack", "service": "slack", "friendly_name": "leave_channel"},
    Action.SLACK_LIST_USERS: {"provider": "slack", "service": "slack", "friendly_name": "list_users_slack"},
    Action.SLACK_LOOKUP_USER_BY_EMAIL: {"provider": "slack", "service": "slack", "friendly_name": "lookup_user_by_email"},
    Action.SLACK_SET_USER_PRESENCE: {"provider": "slack", "service": "slack", "friendly_name": "set_user_presence"},
    Action.SLACK_ADD_REACTION: {"provider": "slack", "service": "slack", "friendly_name": "add_reaction"},
    Action.SLACK_REMOVE_REACTION: {"provider": "slack", "service": "slack", "friendly_name": "remove_reaction"},
    Action.SLACK_GET_REACTIONS: {"provider": "slack", "service": "slack", "friendly_name": "get_reactions_slack"},
    Action.SLACK_GET_CONVERSATION_REPLIES: {"provider": "slack", "service": "slack", "friendly_name": "get_conversation_replies"},
    Action.SLACK_PIN_MESSAGE: {"provider": "slack", "service": "slack", "friendly_name": "pin_message"},
    Action.SLACK_UNPIN_MESSAGE: {"provider": "slack", "service": "slack", "friendly_name": "unpin_message"},
    Action.SLACK_LIST_PINS: {"provider": "slack", "service": "slack", "friendly_name": "list_pins"},
    Action.SLACK_CREATE_REMINDER: {"provider": "slack", "service": "slack", "friendly_name": "create_reminder_slack"},
    Action.SLACK_DELETE_REMINDER: {"provider": "slack", "service": "slack", "friendly_name": "delete_reminder_slack"},
    Action.SLACK_COMPLETE_REMINDER: {"provider": "slack", "service": "slack", "friendly_name": "complete_reminder"},
    Action.SLACK_LIST_REMINDERS: {"provider": "slack", "service": "slack", "friendly_name": "list_reminders"},
    Action.SLACK_GET_REMINDER_INFO: {"provider": "slack", "service": "slack", "friendly_name": "get_reminder_info"},
    Action.SLACK_GET_USER_IDENTITY: {"provider": "slack", "service": "slack", "friendly_name": "get_user_identity"},
    Action.SLACK_GET_CONVERSATION_INFO: {"provider": "slack", "service": "slack", "friendly_name": "get_conversation_info"},
    Action.SLACK_GET_CONVERSATION_MEMBERS: {"provider": "slack", "service": "slack", "friendly_name": "get_conversation_members"},
    Action.SLACK_GET_USER_DND_STATUS: {"provider": "slack", "service": "slack", "friendly_name": "get_user_dnd_status"},
    Action.SLACK_GET_FILE_INFO: {"provider": "slack", "service": "slack", "friendly_name": "get_file_info"},
    Action.SLACK_GET_USER_INFO: {"provider": "slack", "service": "slack", "friendly_name": "get_user_info"},
    Action.SLACK_GET_MESSAGE_PERMALINK: {"provider": "slack", "service": "slack", "friendly_name": "get_message_permalink"},
    Action.SLACK_GET_TEAM_PROFILE: {"provider": "slack", "service": "slack", "friendly_name": "get_team_profile"},
    Action.SLACK_GET_USER_PROFILE: {"provider": "slack", "service": "slack", "friendly_name": "get_user_profile_slack"},
    Action.SLACK_REVOKE_FILE_PUBLIC_URL: {"provider": "slack", "service": "slack", "friendly_name": "revoke_file_public_url"},
    Action.SLACK_SEND_EPHEMERAL_MESSAGE: {"provider": "slack", "service": "slack", "friendly_name": "send_ephemeral_message"},
    Action.SLACK_SET_CONVERSATION_PURPOSE: {"provider": "slack", "service": "slack", "friendly_name": "set_conversation_purpose"},
    Action.SLACK_SET_DND_DURATION: {"provider": "slack", "service": "slack", "friendly_name": "set_dnd_duration"},
    Action.SLACK_MARK_CONVERSATION_READ: {"provider": "slack", "service": "slack", "friendly_name": "mark_conversation_read"},
    Action.SLACK_SET_USER_PROFILE: {"provider": "slack", "service": "slack", "friendly_name": "set_user_profile"},
    Action.SLACK_SET_CONVERSATION_TOPIC: {"provider": "slack", "service": "slack", "friendly_name": "set_conversation_topic"},
    Action.SLACK_SEND_ME_MESSAGE: {"provider": "slack", "service": "slack", "friendly_name": "send_me_message"},
    Action.SLACK_UPLOAD_FILE: {"provider": "slack", "service": "slack", "friendly_name": "upload_file_slack"},
    Action.SLACK_GET_REMOTE_FILE: {"provider": "slack", "service": "slack", "friendly_name": "get_remote_file"},
    Action.SLACK_GET_TEAM_DND_STATUS: {"provider": "slack", "service": "slack", "friendly_name": "get_team_dnd_status"},
    Action.SLACK_GET_USER_PRESENCE: {"provider": "slack", "service": "slack", "friendly_name": "get_user_presence"},
    Action.SLACK_INVITE_USERS_TO_CHANNEL: {"provider": "slack", "service": "slack", "friendly_name": "invite_users_to_channel"},
    Action.SLACK_JOIN_CONVERSATION: {"provider": "slack", "service": "slack", "friendly_name": "join_conversation"},
    Action.SLACK_LEAVE_CONVERSATION: {"provider": "slack", "service": "slack", "friendly_name": "leave_conversation"},
    Action.SLACK_LIST_PINNED_ITEMS: {"provider": "slack", "service": "slack", "friendly_name": "list_pinned_items"},
    Action.SLACK_LIST_STARRED_ITEMS: {"provider": "slack", "service": "slack", "friendly_name": "list_starred_items"},
    Action.SLACK_LIST_CONVERSATIONS: {"provider": "slack", "service": "slack", "friendly_name": "list_conversations_slack"},
    Action.SLACK_LIST_USERGROUP_USERS: {"provider": "slack", "service": "slack", "friendly_name": "list_usergroup_users"},
    Action.SLACK_LIST_FILES: {"provider": "slack", "service": "slack", "friendly_name": "list_files"},
    Action.SLACK_LIST_REMOTE_FILES: {"provider": "slack", "service": "slack", "friendly_name": "list_remote_files"},
    Action.SLACK_LIST_SCHEDULED_MESSAGES: {"provider": "slack", "service": "slack", "friendly_name": "list_scheduled_messages"},
    Action.SLACK_LIST_TEAM_EMOJIS: {"provider": "slack", "service": "slack", "friendly_name": "list_team_emojis"},
    Action.SLACK_LIST_USERGROUPS: {"provider": "slack", "service": "slack", "friendly_name": "list_usergroups"},
    Action.SLACK_LIST_USER_REACTIONS: {"provider": "slack", "service": "slack", "friendly_name": "list_user_reactions"},
    Action.SLACK_OPEN_DM: {"provider": "slack", "service": "slack", "friendly_name": "open_dm"},
    Action.SLACK_PIN_ITEM: {"provider": "slack", "service": "slack", "friendly_name": "pin_item"},
    Action.SLACK_REMOVE_REMOTE_FILE: {"provider": "slack", "service": "slack", "friendly_name": "remove_remote_file"},
    Action.SLACK_REMOVE_STAR: {"provider": "slack", "service": "slack", "friendly_name": "remove_star"},
    Action.SLACK_REMOVE_USER_FROM_CONVERSATION: {"provider": "slack", "service": "slack", "friendly_name": "remove_user_from_conversation"},
    Action.SLACK_RENAME_EMOJI: {"provider": "slack", "service": "slack", "friendly_name": "rename_emoji"},
    Action.SLACK_RENAME_CONVERSATION: {"provider": "slack", "service": "slack", "friendly_name": "rename_conversation"},

    # Brevo actions
    Action.BREVO_CREATE_COMPANY: {"provider": "brevo", "service": "brevo", "friendly_name": "create_company_brevo"},
    Action.BREVO_CREATE_OR_UPDATE_EMAIL_TEMPLATE: {"provider": "brevo", "service": "brevo", "friendly_name": "create_or_update_email_template"},
    Action.BREVO_CREATE_SMS_CAMPAIGN: {"provider": "brevo", "service": "brevo", "friendly_name": "create_sms_campaign"},
    Action.BREVO_DELETE_COMPANY: {"provider": "brevo", "service": "brevo", "friendly_name": "delete_company_brevo"},
    Action.BREVO_DELETE_CONTACT: {"provider": "brevo", "service": "brevo", "friendly_name": "delete_contact_brevo"},
    Action.BREVO_DELETE_EMAIL_TEMPLATE: {"provider": "brevo", "service": "brevo", "friendly_name": "delete_email_template"},
    Action.BREVO_DELETE_SMS_CAMPAIGN: {"provider": "brevo", "service": "brevo", "friendly_name": "delete_sms_campaign"},
    Action.BREVO_FIND_CONTACT: {"provider": "brevo", "service": "brevo", "friendly_name": "find_contact_brevo"},
    Action.BREVO_GET_ACCOUNT_INFORMATION: {"provider": "brevo", "service": "brevo", "friendly_name": "get_account_information_brevo"},
    Action.BREVO_GET_ALL_CONTACTS: {"provider": "brevo", "service": "brevo", "friendly_name": "get_all_contacts"},
    Action.BREVO_GET_ALL_EMAIL_TEMPLATES: {"provider": "brevo", "service": "brevo", "friendly_name": "get_all_email_templates"},
    Action.BREVO_GET_ALL_SENDERS: {"provider": "brevo", "service": "brevo", "friendly_name": "get_all_senders"},
    Action.BREVO_GET_COMPANY_DETAILS: {"provider": "brevo", "service": "brevo", "friendly_name": "get_company_details"},
    Action.BREVO_GET_CONTACT_DETAILS: {"provider": "brevo", "service": "brevo", "friendly_name": "get_contact_details"},
    Action.BREVO_GET_SMS_CAMPAIGNS: {"provider": "brevo", "service": "brevo", "friendly_name": "get_sms_campaigns"},
    Action.BREVO_GET_SMS_CAMPAIGN_DETAILS: {"provider": "brevo", "service": "brevo", "friendly_name": "get_sms_campaign_details"},
    Action.BREVO_LIST_ALL_COMPANIES: {"provider": "brevo", "service": "brevo", "friendly_name": "list_all_companies_brevo"},
    Action.BREVO_LIST_EMAIL_CAMPAIGNS: {"provider": "brevo", "service": "brevo", "friendly_name": "list_email_campaigns"},
    Action.BREVO_UPDATE_EMAIL_CAMPAIGN: {"provider": "brevo", "service": "brevo", "friendly_name": "update_email_campaign"},

    # Youtube actions
    Action.YOUTUBE_LIST_CAPTIONS: {"provider": "google", "service": "youtube", "friendly_name": "list_captions"},
    Action.YOUTUBE_UPDATE_THUMBNAIL: {"provider": "google", "service": "youtube", "friendly_name": "update_thumbnail"},
    Action.YOUTUBE_GET_CHANNEL_ID_BY_HANDLE: {"provider": "google", "service": "youtube", "friendly_name": "get_channel_id_by_handle"},
    Action.YOUTUBE_GET_CHANNEL_STATISTICS: {"provider": "google", "service": "youtube", "friendly_name": "get_channel_statistics"},
    Action.YOUTUBE_LIST_CHANNEL_VIDEOS: {"provider": "google", "service": "youtube", "friendly_name": "list_channel_videos"},
    Action.YOUTUBE_LIST_USER_PLAYLISTS: {"provider": "google", "service": "youtube", "friendly_name": "list_user_playlists"},
    Action.YOUTUBE_LIST_USER_SUBSCRIPTIONS: {"provider": "google", "service": "youtube", "friendly_name": "list_user_subscriptions"},
    Action.YOUTUBE_DOWNLOAD_CAPTION_TRACK: {"provider": "google", "service": "youtube", "friendly_name": "download_caption_track"},
    Action.YOUTUBE_SEARCH_YOUTUBE: {"provider": "google", "service": "youtube", "friendly_name": "search_youtube"},
    Action.YOUTUBE_SUBSCRIBE_TO_CHANNEL: {"provider": "google", "service": "youtube", "friendly_name": "subscribe_to_channel"},
    Action.YOUTUBE_UPDATE_VIDEO: {"provider": "google", "service": "youtube", "friendly_name": "update_video"},
    Action.YOUTUBE_UPLOAD_VIDEO: {"provider": "google", "service": "youtube", "friendly_name": "upload_video"},
    Action.YOUTUBE_GET_VIDEO_DETAILS: {"provider": "google", "service": "youtube", "friendly_name": "get_video_details"},

    # Calendly actions
    Action.CALENDLY_GET_USER: {"provider": "calendly", "service": "calendly", "friendly_name": "get_user_calendly"},
    Action.CALENDLY_GET_CURRENT_USER: {"provider": "calendly", "service": "calendly", "friendly_name": "get_current_user_calendly"},
    Action.CALENDLY_CANCEL_EVENT: {"provider": "calendly", "service": "calendly", "friendly_name": "cancel_event"},
    Action.CALENDLY_GET_EVENT: {"provider": "calendly", "service": "calendly", "friendly_name": "get_event"},
    Action.CALENDLY_LIST_EVENTS: {"provider": "calendly", "service": "calendly", "friendly_name": "list_events_calendly"},
    Action.CALENDLY_GET_EVENT_TYPE: {"provider": "calendly", "service": "calendly", "friendly_name": "get_event_type_calendly"},
    Action.CALENDLY_LIST_EVENT_TYPE_AVAILABLE_TIMES: {"provider": "calendly", "service": "calendly", "friendly_name": "list_event_type_available_times"},
    Action.CALENDLY_CREATE_ONE_OFF_EVENT_TYPE: {"provider": "calendly", "service": "calendly", "friendly_name": "create_one_off_event_type"},
    Action.CALENDLY_GET_EVENT_INVITEE: {"provider": "calendly", "service": "calendly", "friendly_name": "get_event_invitee"},
    Action.CALENDLY_LIST_EVENT_INVITEES: {"provider": "calendly", "service": "calendly", "friendly_name": "list_event_invitees"},
    Action.CALENDLY_CREATE_INVITEE_NO_SHOW: {"provider": "calendly", "service": "calendly", "friendly_name": "create_invitee_no_show"},
    Action.CALENDLY_GET_INVITEE_NO_SHOW: {"provider": "calendly", "service": "calendly", "friendly_name": "get_invitee_no_show"},
    Action.CALENDLY_DELETE_INVITEE_NO_SHOW: {"provider": "calendly", "service": "calendly", "friendly_name": "delete_invitee_no_show"},
    Action.CALENDLY_CREATE_SCHEDULING_LINK: {"provider": "calendly", "service": "calendly", "friendly_name": "create_scheduling_link"},
    Action.CALENDLY_CREATE_SINGLE_USE_SCHEDULING_LINK: {"provider": "calendly", "service": "calendly", "friendly_name": "create_single_use_scheduling_link"},
    Action.CALENDLY_CREATE_SHARE: {"provider": "calendly", "service": "calendly", "friendly_name": "create_share"},
    Action.CALENDLY_GET_USER_AVAILABILITY_SCHEDULE: {"provider": "calendly", "service": "calendly", "friendly_name": "get_user_availability_schedule"},
    Action.CALENDLY_CREATE_WEBHOOK_SUBSCRIPTION: {"provider": "calendly", "service": "calendly", "friendly_name": "create_webhook_subscription"},
    Action.CALENDLY_GET_WEBHOOK_SUBSCRIPTION: {"provider": "calendly", "service": "calendly", "friendly_name": "get_webhook_subscription"},
    Action.CALENDLY_DELETE_WEBHOOK_SUBSCRIPTION: {"provider": "calendly", "service": "calendly", "friendly_name": "delete_webhook_subscription"},
    Action.CALENDLY_GET_ORGANIZATION_INVITATION: {"provider": "calendly", "service": "calendly", "friendly_name": "get_organization_invitation"},
    Action.CALENDLY_INVITE_USER_TO_ORGANIZATION: {"provider": "calendly", "service": "calendly", "friendly_name": "invite_user_to_organization"},
    Action.CALENDLY_GET_ORGANIZATION_MEMBERSHIP: {"provider": "calendly", "service": "calendly", "friendly_name": "get_organization_membership"},
    Action.CALENDLY_GET_GROUP: {"provider": "calendly", "service": "calendly", "friendly_name": "get_group"},
    Action.CALENDLY_GET_GROUP_RELATIONSHIP: {"provider": "calendly", "service": "calendly", "friendly_name": "get_group_relationship"},
    Action.CALENDLY_GET_ROUTING_FORM: {"provider": "calendly", "service": "calendly", "friendly_name": "get_routing_form"},
    Action.CALENDLY_LIST_ACTIVITY_LOG_ENTRIES: {"provider": "calendly", "service": "calendly", "friendly_name": "list_activity_log_entries"},
    Action.CALENDLY_DELETE_INVITEE_DATA: {"provider": "calendly", "service": "calendly", "friendly_name": "delete_invitee_data"},
    Action.CALENDLY_DELETE_SCHEDULED_EVENT_DATA: {"provider": "calendly", "service": "calendly", "friendly_name": "delete_scheduled_event_data"},
    Action.CALENDLY_LIST_EVENT_TYPE_HOSTS: {"provider": "calendly", "service": "calendly", "friendly_name": "list_event_type_hosts"},
    Action.CALENDLY_LIST_GROUPS: {"provider": "calendly", "service": "calendly", "friendly_name": "list_groups"},
    Action.CALENDLY_LIST_GROUP_RELATIONSHIPS: {"provider": "calendly", "service": "calendly", "friendly_name": "list_group_relationships"},
    Action.CALENDLY_LIST_ORGANIZATION_INVITATIONS: {"provider": "calendly", "service": "calendly", "friendly_name": "list_organization_invitations"},
    Action.CALENDLY_LIST_ORGANIZATION_MEMBERSHIPS: {"provider": "calendly", "service": "calendly", "friendly_name": "list_organization_memberships"},
    Action.CALENDLY_LIST_OUTGOING_COMMUNICATIONS: {"provider": "calendly", "service": "calendly", "friendly_name": "list_outgoing_communications"},
    Action.CALENDLY_LIST_ROUTING_FORMS: {"provider": "calendly", "service": "calendly", "friendly_name": "list_routing_forms"},
    Action.CALENDLY_LIST_USER_AVAILABILITY_SCHEDULES: {"provider": "calendly", "service": "calendly", "friendly_name": "list_user_availability_schedules"},
    Action.CALENDLY_LIST_USER_BUSY_TIMES: {"provider": "calendly", "service": "calendly", "friendly_name": "list_user_busy_times"},
    Action.CALENDLY_LIST_USER_EVENT_TYPES: {"provider": "calendly", "service": "calendly", "friendly_name": "list_user_event_types"},
    Action.CALENDLY_LIST_WEBHOOK_SUBSCRIPTIONS: {"provider": "calendly", "service": "calendly", "friendly_name": "list_webhook_subscriptions"},
    Action.CALENDLY_REMOVE_USER_FROM_ORGANIZATION: {"provider": "calendly", "service": "calendly", "friendly_name": "remove_user_from_organization"},
    Action.CALENDLY_REVOKE_ORGANIZATION_INVITATION: {"provider": "calendly", "service": "calendly", "friendly_name": "revoke_organization_invitation"},

    # Agentql actions
    Action.AGENTQL_QUERY_STRUCTURED_DATA: {"provider": "agentql", "service": "agentql", "friendly_name": "query_structured_data"},

    # Apollo actions
    Action.APOLLO_ADD_CONTACTS_TO_SEQUENCE: {"provider": "apollo", "service": "apollo", "friendly_name": "add_contacts_to_sequence"},
    Action.APOLLO_BULK_ORGANIZATION_ENRICHMENT: {"provider": "apollo", "service": "apollo", "friendly_name": "bulk_organization_enrichment"},
    Action.APOLLO_BULK_PEOPLE_ENRICHMENT: {"provider": "apollo", "service": "apollo", "friendly_name": "bulk_people_enrichment"},
    Action.APOLLO_BULK_UPDATE_ACCOUNT_STAGE: {"provider": "apollo", "service": "apollo", "friendly_name": "bulk_update_account_stage"},
    Action.APOLLO_GET_LABELS: {"provider": "apollo", "service": "apollo", "friendly_name": "get_labels"},
    Action.APOLLO_GET_OPPORTUNITY_STAGES: {"provider": "apollo", "service": "apollo", "friendly_name": "get_opportunity_stages"},
    Action.APOLLO_GET_ORGANIZATION_JOB_POSTINGS: {"provider": "apollo", "service": "apollo", "friendly_name": "get_organization_job_postings"},
    Action.APOLLO_GET_TYPED_CUSTOM_FIELDS: {"provider": "apollo", "service": "apollo", "friendly_name": "get_typed_custom_fields"},
    Action.APOLLO_LIST_EMAIL_ACCOUNTS: {"provider": "apollo", "service": "apollo", "friendly_name": "list_email_accounts"},
    Action.APOLLO_PEOPLE_SEARCH: {"provider": "apollo", "service": "apollo", "friendly_name": "apollo_people_search"},
    Action.APOLLO_SEARCH_TASKS: {"provider": "apollo", "service": "apollo", "friendly_name": "search_tasks"},
    Action.APOLLO_UPDATE_CONTACT_OWNERSHIP: {"provider": "apollo", "service": "apollo", "friendly_name": "update_contact_ownership"},
    Action.APOLLO_UPDATE_CONTACT_STAGE: {"provider": "apollo", "service": "apollo", "friendly_name": "update_contact_stage"},
    Action.APOLLO_UPDATE_CONTACT_STATUS_IN_SEQUENCE: {"provider": "apollo", "service": "apollo", "friendly_name": "update_contact_status_in_sequence"},
    Action.APOLLO_CREATE_ACCOUNT: {"provider": "apollo", "service": "apollo", "friendly_name": "create_apollo_account"},
    Action.APOLLO_CREATE_CONTACT: {"provider": "apollo", "service": "apollo", "friendly_name": "create_apollo_contact"},
    Action.APOLLO_CREATE_DEAL: {"provider": "apollo", "service": "apollo", "friendly_name": "create_apollo_deal"},
    Action.APOLLO_CREATE_TASK: {"provider": "apollo", "service": "apollo", "friendly_name": "create_apollo_task"},
    Action.APOLLO_LIST_ACCOUNT_STAGES: {"provider": "apollo", "service": "apollo", "friendly_name": "list_apollo_account_stages"},
    Action.APOLLO_LIST_CONTACT_STAGES: {"provider": "apollo", "service": "apollo", "friendly_name": "list_apollo_contact_stages"},
    Action.APOLLO_LIST_DEALS: {"provider": "apollo", "service": "apollo", "friendly_name": "list_apollo_deals"},
    Action.APOLLO_LIST_USERS: {"provider": "apollo", "service": "apollo", "friendly_name": "list_apollo_users"},
    Action.APOLLO_ENRICH_ORGANIZATION_DATA: {"provider": "apollo", "service": "apollo", "friendly_name": "enrich_organization_data"},
    Action.APOLLO_SEARCH_ORGANIZATIONS: {"provider": "apollo", "service": "apollo", "friendly_name": "search_organizations_in_apollo"},
    Action.APOLLO_ENRICH_PERSON: {"provider": "apollo", "service": "apollo", "friendly_name": "enrich_person_with_apollo"},
    Action.APOLLO_SEARCH_ACCOUNTS: {"provider": "apollo", "service": "apollo", "friendly_name": "search_apollo_accounts"},
    Action.APOLLO_SEARCH_CONTACTS: {"provider": "apollo", "service": "apollo", "friendly_name": "search_apollo_contacts"},
    Action.APOLLO_UPDATE_ACCOUNT: {"provider": "apollo", "service": "apollo", "friendly_name": "update_apollo_account"},
    Action.APOLLO_UPDATE_CONTACT: {"provider": "apollo", "service": "apollo", "friendly_name": "update_apollo_contact"},
    Action.APOLLO_UPDATE_DEAL: {"provider": "apollo", "service": "apollo", "friendly_name": "update_apollo_deal"},

    # Bannerbear actions
    Action.BANNERBEAR_GET_ACCOUNT_INFO: {"provider": "bannerbear", "service": "bannerbear", "friendly_name": "get_account_info"},
    Action.BANNERBEAR_GET_AVAILABLE_FONTS: {"provider": "bannerbear", "service": "bannerbear", "friendly_name": "get_available_fonts"},
    Action.BANNERBEAR_GET_SIGNED_BASES: {"provider": "bannerbear", "service": "bannerbear", "friendly_name": "get_signed_bases"},
    Action.BANNERBEAR_GET_TEMPLATE_SET_DETAILS: {"provider": "bannerbear", "service": "bannerbear", "friendly_name": "get_template_set_details"},
    Action.BANNERBEAR_JOIN_PDFS: {"provider": "bannerbear", "service": "bannerbear", "friendly_name": "join_pdfs"},
    Action.BANNERBEAR_LIST_IMAGES: {"provider": "bannerbear", "service": "bannerbear", "friendly_name": "list_images"},
    Action.BANNERBEAR_LIST_TEMPLATES: {"provider": "bannerbear", "service": "bannerbear", "friendly_name": "list_templates"},
    Action.BANNERBEAR_LIST_VIDEOS: {"provider": "bannerbear", "service": "bannerbear", "friendly_name": "list_videos"},

    # Bitquery actions
    Action.BITQUERY_COMBINED_DATABASE_QUERY: {"provider": "bitquery", "service": "bitquery", "friendly_name": "combined_database_query"},
    Action.BITQUERY_ALIASES_METRIC: {"provider": "bitquery", "service": "bitquery", "friendly_name": "aliases_metric"},
    Action.BITQUERY_ARCHIVE_DATABASE_QUERY: {"provider": "bitquery", "service": "bitquery", "friendly_name": "archive_database_query"},
    Action.BITQUERY_CONDITIONAL_METRICS_SNIPPET: {"provider": "bitquery", "service": "bitquery", "friendly_name": "conditional_metrics_snippet"},
    Action.BITQUERY_COUNT_DISTINCT_METRIC: {"provider": "bitquery", "service": "bitquery", "friendly_name": "count_distinct_metric"},
    Action.BITQUERY_COUNT_METRIC: {"provider": "bitquery", "service": "bitquery", "friendly_name": "count_metric"},
    Action.BITQUERY_DATABASE_SELECTION: {"provider": "bitquery", "service": "bitquery", "friendly_name": "database_selection"},
    Action.BITQUERY_EARLY_ACCESS_PROGRAM_QUERY: {"provider": "bitquery", "service": "bitquery", "friendly_name": "early_access_program_query"},
    Action.BITQUERY_MEMPOOL_SUBSCRIPTION: {"provider": "bitquery", "service": "bitquery", "friendly_name": "mempool_subscription"},
    Action.BITQUERY_NETWORK_SELECTION: {"provider": "bitquery", "service": "bitquery", "friendly_name": "network_selection"},
    Action.BITQUERY_OPTIONS_QUERY: {"provider": "bitquery", "service": "bitquery", "friendly_name": "options_query"},
    Action.BITQUERY_PRICE_ASYMMETRY_METRIC: {"provider": "bitquery", "service": "bitquery", "friendly_name": "price_asymmetry_metric"},
    Action.BITQUERY_QUANTILE_METRIC: {"provider": "bitquery", "service": "bitquery", "friendly_name": "quantile_metric"},
    Action.BITQUERY_REALTIME_DATABASE_QUERY: {"provider": "bitquery", "service": "bitquery", "friendly_name": "realtime_database_query"},
    Action.BITQUERY_SELECT_BY_METRIC: {"provider": "bitquery", "service": "bitquery", "friendly_name": "select_by_metric"},
    Action.BITQUERY_STATISTICS_METRIC: {"provider": "bitquery", "service": "bitquery", "friendly_name": "statistics_metric"},
    Action.BITQUERY_SUM_METRIC: {"provider": "bitquery", "service": "bitquery", "friendly_name": "sum_metric"},
    Action.BITQUERY_UNIQ_METRIC: {"provider": "bitquery", "service": "bitquery", "friendly_name": "uniq_metric"},

    # Botsonic actions
    Action.BOTSONIC_GET_ALL_BOTS: {"provider": "botsonic", "service": "botsonic", "friendly_name": "get_all_bots"},
    Action.BOTSONIC_GET_SPECIFIC_BOT: {"provider": "botsonic", "service": "botsonic", "friendly_name": "get_specific_bot"},
    Action.BOTSONIC_CREATE_BOT: {"provider": "botsonic", "service": "botsonic", "friendly_name": "create_bot"},
    Action.BOTSONIC_UPDATE_BOT: {"provider": "botsonic", "service": "botsonic", "friendly_name": "update_bot"},
    Action.BOTSONIC_DELETE_BOT: {"provider": "botsonic", "service": "botsonic", "friendly_name": "delete_bot"},
    Action.BOTSONIC_GET_BOT_API_KEY: {"provider": "botsonic", "service": "botsonic", "friendly_name": "get_bot_api_key"},

    # Cal actions
    Action.CAL_GET_BOOKING: {"provider": "cal", "service": "cal", "friendly_name": "get_booking"},
    Action.CAL_GET_ALL_BOOKINGS: {"provider": "cal", "service": "cal", "friendly_name": "get_all_bookings"},
    Action.CAL_GET_ORGANIZATION_BOOKINGS: {"provider": "cal", "service": "cal", "friendly_name": "get_organization_bookings"},
    Action.CAL_GET_ORGANIZATION_TEAM_BOOKINGS: {"provider": "cal", "service": "cal", "friendly_name": "get_organization_team_bookings"},
    Action.CAL_GET_ORGANIZATION_USER_BOOKINGS: {"provider": "cal", "service": "cal", "friendly_name": "get_organization_user_bookings"},
    Action.CAL_CREATE_BOOKING: {"provider": "cal", "service": "cal", "friendly_name": "create_booking"},
    Action.CAL_CONFIRM_BOOKING: {"provider": "cal", "service": "cal", "friendly_name": "confirm_booking"},
    Action.CAL_CANCEL_BOOKING: {"provider": "cal", "service": "cal", "friendly_name": "cancel_booking"},
    Action.CAL_RESCHEDULE_BOOKING: {"provider": "cal", "service": "cal", "friendly_name": "reschedule_booking"},
    Action.CAL_REASSIGN_BOOKING_TO_HOST: {"provider": "cal", "service": "cal", "friendly_name": "reassign_booking_to_host"},
    Action.CAL_REASSIGN_BOOKING_AUTO: {"provider": "cal", "service": "cal", "friendly_name": "reassign_booking_auto"},
    Action.CAL_MARK_BOOKING_ABSENT: {"provider": "cal", "service": "cal", "friendly_name": "mark_booking_absent"},
    Action.CAL_DECLINE_BOOKING: {"provider": "cal", "service": "cal", "friendly_name": "decline_booking"},
    Action.CAL_GET_ADD_TO_CALENDAR_LINKS: {"provider": "cal", "service": "cal", "friendly_name": "get_add_to_calendar_links"},
    Action.CAL_GET_EVENT_TYPE: {"provider": "cal", "service": "cal", "friendly_name": "get_event_type_cal"},
    Action.CAL_GET_ALL_EVENT_TYPES: {"provider": "cal", "service": "cal", "friendly_name": "get_all_event_types"},
    Action.CAL_GET_TEAM_EVENT_TYPES: {"provider": "cal", "service": "cal", "friendly_name": "get_team_event_types"},
    Action.CAL_GET_TEAM_EVENT_TYPE: {"provider": "cal", "service": "cal", "friendly_name": "get_team_event_type"},
    Action.CAL_CREATE_EVENT_TYPE: {"provider": "cal", "service": "cal", "friendly_name": "create_event_type"},
    Action.CAL_FIND_AVAILABLE_SLOTS: {"provider": "cal", "service": "cal", "friendly_name": "find_available_slots"},
    Action.CAL_GET_MY_PROFILE: {"provider": "cal", "service": "cal", "friendly_name": "get_my_profile"},
    Action.CAL_GET_ALL_USERS: {"provider": "cal", "service": "cal", "friendly_name": "get_all_users"},
    Action.CAL_GET_MANAGED_USER: {"provider": "cal", "service": "cal", "friendly_name": "get_managed_user"},
    Action.CAL_GET_ALL_MANAGED_USERS: {"provider": "cal", "service": "cal", "friendly_name": "get_all_managed_users"},
    Action.CAL_GET_MEMBERSHIP: {"provider": "cal", "service": "cal", "friendly_name": "get_membership"},
    Action.CAL_GET_ALL_MEMBERSHIPS: {"provider": "cal", "service": "cal", "friendly_name": "get_all_memberships"},
    Action.CAL_GET_USER_TEAM_MEMBERSHIPS: {"provider": "cal", "service": "cal", "friendly_name": "get_user_team_memberships"},
    Action.CAL_CREATE_MEMBERSHIP: {"provider": "cal", "service": "cal", "friendly_name": "create_membership"},
    Action.CAL_UPDATE_MEMBERSHIP: {"provider": "cal", "service": "cal", "friendly_name": "update_membership"},
    Action.CAL_DELETE_MEMBERSHIP: {"provider": "cal", "service": "cal", "friendly_name": "delete_membership"},
    Action.CAL_GET_MANAGED_ORGANIZATION: {"provider": "cal", "service": "cal", "friendly_name": "get_managed_organization"},
    Action.CAL_GET_ALL_ORGANIZATIONS: {"provider": "cal", "service": "cal", "friendly_name": "get_all_organizations"},
    Action.CAL_CREATE_SUB_ORGANIZATION: {"provider": "cal", "service": "cal", "friendly_name": "create_sub_organization"},
    Action.CAL_GET_TEAMS: {"provider": "cal", "service": "cal", "friendly_name": "get_teams"},
    Action.CAL_GET_TEAM: {"provider": "cal", "service": "cal", "friendly_name": "get_team"},
    Action.CAL_GET_ALL_TEAMS: {"provider": "cal", "service": "cal", "friendly_name": "get_all_teams"},
    Action.CAL_GET_ALL_TEAM_EVENT_TYPES: {"provider": "cal", "service": "cal", "friendly_name": "get_all_team_event_types"},
    Action.CAL_GET_ORGANIZATION_ROUTING_FORMS: {"provider": "cal", "service": "cal", "friendly_name": "get_organization_routing_forms"},
    Action.CAL_GET_TEAM_ROUTING_FORMS: {"provider": "cal", "service": "cal", "friendly_name": "get_team_routing_forms"},
    Action.CAL_GET_ORGANIZATION_TEAM_BOOKINGS_LEGACY: {"provider": "cal", "service": "cal", "friendly_name": "get_organization_team_bookings_legacy"},
    Action.CAL_GET_CALENDAR_BUSY_TIMES: {"provider": "cal", "service": "cal", "friendly_name": "get_calendar_busy_times"},
    Action.CAL_CHECK_CALENDAR_CONNECTION: {"provider": "cal", "service": "cal", "friendly_name": "check_calendar_connection"},
    Action.CAL_DISCONNECT_CALENDAR: {"provider": "cal", "service": "cal", "friendly_name": "disconnect_calendar"},
    Action.CAL_SYNC_CALENDAR_CREDENTIALS: {"provider": "cal", "service": "cal", "friendly_name": "sync_calendar_credentials"},
    Action.CAL_GET_ALL_CALENDARS: {"provider": "cal", "service": "cal", "friendly_name": "get_all_calendars"},
    Action.CAL_GET_ALL_SCHEDULES: {"provider": "cal", "service": "cal", "friendly_name": "get_all_schedules"},
    Action.CAL_GET_SCHEDULE: {"provider": "cal", "service": "cal", "friendly_name": "get_schedule"},
    Action.CAL_GET_DEFAULT_SCHEDULE: {"provider": "cal", "service": "cal", "friendly_name": "get_default_schedule"},
    Action.CAL_GET_TEAM_MEMBER_SCHEDULES: {"provider": "cal", "service": "cal", "friendly_name": "get_team_member_schedules"},
    Action.CAL_GET_USER_OOO_ENTRIES: {"provider": "cal", "service": "cal", "friendly_name": "get_user_ooo_entries"},
    Action.CAL_GET_ORG_USERS_OOO_ENTRIES: {"provider": "cal", "service": "cal", "friendly_name": "get_org_users_ooo_entries"},
    Action.CAL_CREATE_OOO_ENTRY: {"provider": "cal", "service": "cal", "friendly_name": "create_ooo_entry"},
    Action.CAL_CHECK_TEAM_STRIPE_CONNECTION: {"provider": "cal", "service": "cal", "friendly_name": "check_team_stripe_connection"},
    Action.CAL_CHECK_STRIPE_CONNECTION: {"provider": "cal", "service": "cal", "friendly_name": "check_stripe_connection"},
    Action.CAL_SAVE_TEAM_STRIPE_CREDENTIALS: {"provider": "cal", "service": "cal", "friendly_name": "save_team_stripe_credentials"},
    Action.CAL_SAVE_STRIPE_CREDENTIALS: {"provider": "cal", "service": "cal", "friendly_name": "save_stripe_credentials"},
    Action.CAL_GET_TEAM_STRIPE_CONNECT_URL: {"provider": "cal", "service": "cal", "friendly_name": "get_team_stripe_connect_url"},
    Action.CAL_GET_STRIPE_CONNECT_URL: {"provider": "cal", "service": "cal", "friendly_name": "get_stripe_connect_url"},
    Action.CAL_LIST_CONFERENCING_APPLICATIONS: {"provider": "cal", "service": "cal", "friendly_name": "list_conferencing_applications"},
    Action.CAL_LIST_TEAM_CONFERENCING_APPLICATIONS: {"provider": "cal", "service": "cal", "friendly_name": "list_team_conferencing_applications"},
    Action.CAL_GET_DEFAULT_CONFERENCING_APPLICATION: {"provider": "cal", "service": "cal", "friendly_name": "get_default_conferencing_application"},
    Action.CAL_GET_TEAM_DEFAULT_CONFERENCING_APPLICATION: {"provider": "cal", "service": "cal", "friendly_name": "get_team_default_conferencing_application"},
    Action.CAL_SET_DEFAULT_CONFERENCING_APPLICATION: {"provider": "cal", "service": "cal", "friendly_name": "set_default_conferencing_application"},
    Action.CAL_SET_TEAM_DEFAULT_CONFERENCING_APPLICATION: {"provider": "cal", "service": "cal", "friendly_name": "set_team_default_conferencing_application"},
    Action.CAL_CREATE_PHONE_CALL: {"provider": "cal", "service": "cal", "friendly_name": "create_phone_call"},
    Action.CAL_GET_ALL_ATTRIBUTES: {"provider": "cal", "service": "cal", "friendly_name": "get_all_attributes"},
    Action.CAL_GET_ATTRIBUTE: {"provider": "cal", "service": "cal", "friendly_name": "get_attribute"},
    Action.CAL_CREATE_ATTRIBUTE: {"provider": "cal", "service": "cal", "friendly_name": "create_attribute"},
    Action.CAL_ASSIGN_ATTRIBUTE_TO_USER: {"provider": "cal", "service": "cal", "friendly_name": "assign_attribute_to_user"},
    Action.CAL_GET_ALL_ATTRIBUTE_OPTIONS: {"provider": "cal", "service": "cal", "friendly_name": "get_all_attribute_options"},
    Action.CAL_GET_ATTRIBUTE_OPTIONS_BY_ID: {"provider": "cal", "service": "cal", "friendly_name": "get_attribute_options_by_id"},
    Action.CAL_GET_ATTRIBUTE_OPTIONS_BY_SLUG: {"provider": "cal", "service": "cal", "friendly_name": "get_attribute_options_by_slug"},
    Action.CAL_GET_USER_ATTRIBUTE_OPTIONS: {"provider": "cal", "service": "cal", "friendly_name": "get_user_attribute_options"},
    Action.CAL_GET_ROUTING_FORM_RESPONSES: {"provider": "cal", "service": "cal", "friendly_name": "get_routing_form_responses"},
    Action.CAL_UPDATE_ROUTING_FORM_RESPONSE: {"provider": "cal", "service": "cal", "friendly_name": "update_routing_form_response"},
    Action.CAL_GET_ALL_WEBHOOKS: {"provider": "cal", "service": "cal", "friendly_name": "get_all_webhooks"},
    Action.CAL_GET_WEBHOOK: {"provider": "cal", "service": "cal", "friendly_name": "get_webhook_cal"},
    Action.CAL_DELETE_ALL_WEBHOOKS: {"provider": "cal", "service": "cal", "friendly_name": "delete_all_webhooks"},
    Action.CAL_REFRESH_API_KEY: {"provider": "cal", "service": "cal", "friendly_name": "refresh_api_key"},
    Action.CAL_REFRESH_MANAGED_USER_TOKENS: {"provider": "cal", "service": "cal", "friendly_name": "refresh_managed_user_tokens"},
    Action.CAL_UPDATE_ORGANIZATION_DELEGATION_CREDENTIALS: {"provider": "cal", "service": "cal", "friendly_name": "update_organization_delegation_credentials"},
    Action.CAL_RESERVE_SLOT: {"provider": "cal", "service": "cal", "friendly_name": "reserve_slot"},
    Action.CAL_GET_RESERVED_SLOT: {"provider": "cal", "service": "cal", "friendly_name": "get_reserved_slot"},
    Action.CAL_GET_EVENT_TYPE_WEBHOOK: {"provider": "cal", "service": "cal", "friendly_name": "get_event_type_webhook"},
    Action.CAL_GET_ALL_EVENT_TYPE_WEBHOOKS: {"provider": "cal", "service": "cal", "friendly_name": "get_all_event_type_webhooks"},
    Action.CAL_CREATE_OR_UPDATE_WEBHOOK: {"provider": "cal", "service": "cal", "friendly_name": "create_or_update_webhook_cal"},

    # Canva actions
    Action.CANVA_REVOKE_OAUTH_TOKEN: {"provider": "canva", "service": "canva", "friendly_name": "revoke_oauth_token"},
    Action.CANVA_LIST_BRAND_TEMPLATES: {"provider": "canva", "service": "canva", "friendly_name": "list_brand_templates"},
    Action.CANVA_CREATE_DESIGN: {"provider": "canva", "service": "canva", "friendly_name": "create_design_canva"},
    Action.CANVA_CREATE_COMMENT_REPLY: {"provider": "canva", "service": "canva", "friendly_name": "create_comment_reply"},
    Action.CANVA_CREATE_DESIGN_COMMENT: {"provider": "canva", "service": "canva", "friendly_name": "create_design_comment"},
    Action.CANVA_CREATE_FOLDER: {"provider": "canva", "service": "canva", "friendly_name": "create_folder"},
    Action.CANVA_DELETE_ASSET: {"provider": "canva", "service": "canva", "friendly_name": "delete_asset"},
    Action.CANVA_EXCHANGE_OAUTH_TOKEN: {"provider": "canva", "service": "canva", "friendly_name": "exchange_oauth_token"},
    Action.CANVA_GET_ASSET_UPLOAD_JOB: {"provider": "canva", "service": "canva", "friendly_name": "get_asset_upload_job"},
    Action.CANVA_GET_CURRENT_USER: {"provider": "canva", "service": "canva", "friendly_name": "get_current_user_canva"},
    Action.CANVA_GET_DESIGN: {"provider": "canva", "service": "canva", "friendly_name": "get_design"},
    Action.CANVA_GET_DESIGN_EXPORT_JOB: {"provider": "canva", "service": "canva", "friendly_name": "get_design_export_job"},
    Action.CANVA_CREATE_DESIGN_EXPORT_JOB: {"provider": "canva", "service": "canva", "friendly_name": "create_design_export_job"},
    Action.CANVA_CREATE_AUTOFILL_JOB: {"provider": "canva", "service": "canva", "friendly_name": "create_autofill_job"},
    Action.CANVA_LIST_DESIGN_PAGES: {"provider": "canva", "service": "canva", "friendly_name": "list_design_pages"},
    Action.CANVA_LIST_FOLDER_ITEMS: {"provider": "canva", "service": "canva", "friendly_name": "list_folder_items"},
    Action.CANVA_LIST_DESIGNS: {"provider": "canva", "service": "canva", "friendly_name": "list_designs"},
    Action.CANVA_MOVE_ITEM_TO_FOLDER: {"provider": "canva", "service": "canva", "friendly_name": "move_item_to_folder"},
    Action.CANVA_DELETE_FOLDER: {"provider": "canva", "service": "canva", "friendly_name": "delete_folder_canva"},
    Action.CANVA_GET_APP_PUBLIC_KEYS: {"provider": "canva", "service": "canva", "friendly_name": "get_app_public_keys"},
    Action.CANVA_GET_ASSET: {"provider": "canva", "service": "canva", "friendly_name": "get_asset"},
    Action.CANVA_GET_DESIGN_COMMENT: {"provider": "canva", "service": "canva", "friendly_name": "get_design_comment"},
    Action.CANVA_GET_BRAND_TEMPLATE_DATASET: {"provider": "canva", "service": "canva", "friendly_name": "get_brand_template_dataset"},
    Action.CANVA_GET_BRAND_TEMPLATE: {"provider": "canva", "service": "canva", "friendly_name": "get_brand_template"},
    Action.CANVA_GET_AUTOFILL_JOB: {"provider": "canva", "service": "canva", "friendly_name": "get_autofill_job"},
    Action.CANVA_GET_DESIGN_IMPORT_JOB: {"provider": "canva", "service": "canva", "friendly_name": "get_design_import_job"},
    Action.CANVA_GET_FOLDER: {"provider": "canva", "service": "canva", "friendly_name": "get_folder"},
    Action.CANVA_UPDATE_ASSET: {"provider": "canva", "service": "canva", "friendly_name": "update_asset"},
    Action.CANVA_UPDATE_FOLDER: {"provider": "canva", "service": "canva", "friendly_name": "update_folder"},
    Action.CANVA_VALIDATE_OAUTH_TOKEN: {"provider": "canva", "service": "canva", "friendly_name": "validate_oauth_token"},

    # Clerk actions
    Action.CLERK_LIST_ALL_USERS: {"provider": "clerk", "service": "clerk", "friendly_name": "list_all_users"},
    Action.CLERK_COUNT_USERS: {"provider": "clerk", "service": "clerk", "friendly_name": "count_users"},
    Action.CLERK_RETRIEVE_USER: {"provider": "clerk", "service": "clerk", "friendly_name": "retrieve_user"},
    Action.CLERK_CREATE_USER: {"provider": "clerk", "service": "clerk", "friendly_name": "create_user"},
    Action.CLERK_UPDATE_USER: {"provider": "clerk", "service": "clerk", "friendly_name": "update_user"},
    Action.CLERK_DELETE_USER: {"provider": "clerk", "service": "clerk", "friendly_name": "delete_user"},
    Action.CLERK_LOCK_USER: {"provider": "clerk", "service": "clerk", "friendly_name": "lock_user"},
    Action.CLERK_UNLOCK_USER: {"provider": "clerk", "service": "clerk", "friendly_name": "unlock_user"},
    Action.CLERK_BAN_USER: {"provider": "clerk", "service": "clerk", "friendly_name": "ban_user"},
    Action.CLERK_UNBAN_USER: {"provider": "clerk", "service": "clerk", "friendly_name": "unban_user"},
    Action.CLERK_VERIFY_USER_PASSWORD: {"provider": "clerk", "service": "clerk", "friendly_name": "verify_user_password"},
    Action.CLERK_VERIFY_TOTP_OR_BACKUP_CODE: {"provider": "clerk", "service": "clerk", "friendly_name": "verify_totp_or_backup_code"},
    Action.CLERK_DISABLE_USER_MFA: {"provider": "clerk", "service": "clerk", "friendly_name": "disable_user_mfa"},
    Action.CLERK_DISABLE_USER_BACKUP_CODES: {"provider": "clerk", "service": "clerk", "friendly_name": "disable_user_backup_codes"},
    Action.CLERK_DELETE_USER_TOTPS: {"provider": "clerk", "service": "clerk", "friendly_name": "delete_user_totps"},
    Action.CLERK_DELETE_USER_PASSKEY: {"provider": "clerk", "service": "clerk", "friendly_name": "delete_user_passkey"},
    Action.CLERK_DELETE_USER_WEB3_WALLET: {"provider": "clerk", "service": "clerk", "friendly_name": "delete_user_web3_wallet"},
    Action.CLERK_SET_USER_PROFILE_IMAGE: {"provider": "clerk", "service": "clerk", "friendly_name": "set_user_profile_image"},
    Action.CLERK_DELETE_USER_PROFILE_IMAGE: {"provider": "clerk", "service": "clerk", "friendly_name": "delete_user_profile_image"},
    Action.CLERK_RETRIEVE_USER_ORGANIZATION_MEMBERSHIPS: {"provider": "clerk", "service": "clerk", "friendly_name": "retrieve_user_organization_memberships"},
    Action.CLERK_RETRIEVE_USER_INVITATIONS: {"provider": "clerk", "service": "clerk", "friendly_name": "retrieve_user_invitations"},
    Action.CLERK_MERGE_AND_UPDATE_USER_METADATA: {"provider": "clerk", "service": "clerk", "friendly_name": "merge_and_update_user_metadata"},
    Action.CLERK_RETRIEVE_ORGANIZATION: {"provider": "clerk", "service": "clerk", "friendly_name": "retrieve_organization"},
    Action.CLERK_GET_LIST_OF_ORGANIZATIONS: {"provider": "clerk", "service": "clerk", "friendly_name": "get_list_of_organizations"},
    Action.CLERK_CREATE_ORGANIZATION: {"provider": "clerk", "service": "clerk", "friendly_name": "create_organization_clerk"},
    Action.CLERK_UPDATE_ORGANIZATION: {"provider": "clerk", "service": "clerk", "friendly_name": "update_organization_clerk"},
    Action.CLERK_DELETE_ORGANIZATION: {"provider": "clerk", "service": "clerk", "friendly_name": "delete_organization_clerk"},
    Action.CLERK_UPLOAD_ORGANIZATION_LOGO: {"provider": "clerk", "service": "clerk", "friendly_name": "upload_organization_logo"},
    Action.CLERK_DELETE_ORGANIZATION_LOGO: {"provider": "clerk", "service": "clerk", "friendly_name": "delete_organization_logo"},
    Action.CLERK_MERGE_AND_UPDATE_ORGANIZATION_METADATA: {"provider": "clerk", "service": "clerk", "friendly_name": "merge_and_update_organization_metadata"},
    Action.CLERK_LIST_INVITATIONS: {"provider": "clerk", "service": "clerk", "friendly_name": "list_invitations"},
    Action.CLERK_RETRIEVE_ORGANIZATION_INVITATIONS: {"provider": "clerk", "service": "clerk", "friendly_name": "retrieve_organization_invitations"},
    Action.CLERK_GET_ORGANIZATION_INVITATIONS_FOR_CURRENT_INSTANCE: {"provider": "clerk", "service": "clerk", "friendly_name": "get_organization_invitations_for_current_instance"},
    Action.CLERK_RETRIEVE_ORGANIZATION_INVITATION_BY_ID: {"provider": "clerk", "service": "clerk", "friendly_name": "retrieve_organization_invitation_by_id"},
    Action.CLERK_CREATE_INVITATION: {"provider": "clerk", "service": "clerk", "friendly_name": "create_invitation"},
    Action.CLERK_CREATE_MULTIPLE_INVITATIONS: {"provider": "clerk", "service": "clerk", "friendly_name": "create_multiple_invitations"},
    Action.CLERK_BULK_CREATE_AND_SEND_ORGANIZATION_INVITATIONS: {"provider": "clerk", "service": "clerk", "friendly_name": "bulk_create_and_send_organization_invitations"},
    Action.CLERK_CREATE_AND_SEND_ORGANIZATION_INVITATION: {"provider": "clerk", "service": "clerk", "friendly_name": "create_and_send_organization_invitation"},
    Action.CLERK_REVOKE_INVITATION: {"provider": "clerk", "service": "clerk", "friendly_name": "revoke_invitation"},
    Action.CLERK_REVOKE_PENDING_ORGANIZATION_INVITATION: {"provider": "clerk", "service": "clerk", "friendly_name": "revoke_pending_organization_invitation"},
    Action.CLERK_LIST_WAITLIST_ENTRIES: {"provider": "clerk", "service": "clerk", "friendly_name": "list_waitlist_entries"},
    Action.CLERK_CREATE_WAITLIST_ENTRY: {"provider": "clerk", "service": "clerk", "friendly_name": "create_waitlist_entry"},
    Action.CLERK_LIST_ALLOWLIST_IDENTIFIERS: {"provider": "clerk", "service": "clerk", "friendly_name": "list_allowlist_identifiers"},
    Action.CLERK_ADD_IDENTIFIER_TO_ALLOWLIST: {"provider": "clerk", "service": "clerk", "friendly_name": "add_identifier_to_allowlist"},
    Action.CLERK_DELETE_IDENTIFIER_FROM_ALLOWLIST: {"provider": "clerk", "service": "clerk", "friendly_name": "delete_identifier_from_allowlist"},
    Action.CLERK_LIST_BLOCKLIST_IDENTIFIERS: {"provider": "clerk", "service": "clerk", "friendly_name": "list_blocklist_identifiers"},
    Action.CLERK_ADD_IDENTIFIER_TO_BLOCKLIST: {"provider": "clerk", "service": "clerk", "friendly_name": "add_identifier_to_blocklist"},
    Action.CLERK_DELETE_IDENTIFIER_FROM_BLOCKLIST: {"provider": "clerk", "service": "clerk", "friendly_name": "delete_identifier_from_blocklist"},
    Action.CLERK_RETRIEVE_EMAIL_ADDRESS: {"provider": "clerk", "service": "clerk", "friendly_name": "retrieve_email_address"},
    Action.CLERK_CREATE_EMAIL_ADDRESS: {"provider": "clerk", "service": "clerk", "friendly_name": "create_email_address"},
    Action.CLERK_DELETE_EMAIL_ADDRESS: {"provider": "clerk", "service": "clerk", "friendly_name": "delete_email_address"},
    Action.CLERK_UPDATE_EMAIL_ADDRESS: {"provider": "clerk", "service": "clerk", "friendly_name": "update_email_address"},
    Action.CLERK_RETRIEVE_OAUTH_ACCESS_TOKEN: {"provider": "clerk", "service": "clerk", "friendly_name": "retrieve_oauth_access_token"},

    # Close actions
    Action.CLOSE_GET_ORGANIZATION_DETAILS: {"provider": "close", "service": "close", "friendly_name": "get_organization_details"},
    Action.CLOSE_FILTER_LEADS: {"provider": "close", "service": "close", "friendly_name": "filter_leads"},
    Action.CLOSE_LIST_OPPORTUNITIES: {"provider": "close", "service": "close", "friendly_name": "list_opportunities"},
    Action.CLOSE_LIST_CONTACTS: {"provider": "close", "service": "close", "friendly_name": "list_contacts_close"},
    Action.CLOSE_FETCH_SINGLE_CONTACT: {"provider": "close", "service": "close", "friendly_name": "fetch_single_contact"},
    Action.CLOSE_RETRIEVE_SINGLE_LEAD: {"provider": "close", "service": "close", "friendly_name": "retrieve_single_lead"},
    Action.CLOSE_LIST_LEADS: {"provider": "close", "service": "close", "friendly_name": "list_leads"},
    Action.CLOSE_RETRIEVE_OPPORTUNITY: {"provider": "close", "service": "close", "friendly_name": "retrieve_opportunity"},
    Action.CLOSE_MERGE_LEADS: {"provider": "close", "service": "close", "friendly_name": "merge_leads"},
    Action.CLOSE_CREATE_NEW_CONTACT: {"provider": "close", "service": "close", "friendly_name": "create_new_contact"},
    Action.CLOSE_CREATE_LEAD: {"provider": "close", "service": "close", "friendly_name": "create_lead"},
    Action.CLOSE_CREATE_OPPORTUNITY: {"provider": "close", "service": "close", "friendly_name": "create_opportunity"},
    Action.CLOSE_UPDATE_CONTACT: {"provider": "close", "service": "close", "friendly_name": "update_contact_close"},
    Action.CLOSE_UPDATE_LEAD: {"provider": "close", "service": "close", "friendly_name": "update_lead"},
    Action.CLOSE_UPDATE_OPPORTUNITY: {"provider": "close", "service": "close", "friendly_name": "update_opportunity"},
    Action.CLOSE_UPDATE_ORGANIZATION: {"provider": "close", "service": "close", "friendly_name": "update_organization_close"},
    Action.CLOSE_DELETE_OPPORTUNITY: {"provider": "close", "service": "close", "friendly_name": "delete_opportunity"},
    Action.CLOSE_DELETE_LEAD: {"provider": "close", "service": "close", "friendly_name": "delete_lead"},
    Action.CLOSE_DELETE_CONTACT: {"provider": "close", "service": "close", "friendly_name": "delete_contact_close"},

    # Exa actions
    Action.EXA_GET_LLM_ANSWER: {"provider": "exa", "service": "exa", "friendly_name": "get_llm_answer"},
    Action.EXA_SEARCH: {"provider": "exa", "service": "exa", "friendly_name": "search"},
    Action.EXA_GET_CONTENTS: {"provider": "exa", "service": "exa", "friendly_name": "get_contents"},
    Action.EXA_FIND_SIMILAR_LINKS: {"provider": "exa", "service": "exa", "friendly_name": "find_similar_links"},

    # Figma actions
    Action.FIGMA_GET_FILE_JSON: {"provider": "figma", "service": "figma", "friendly_name": "get_file_json"},
    Action.FIGMA_GET_COMPONENT: {"provider": "figma", "service": "figma", "friendly_name": "get_component"},
    Action.FIGMA_EXTRACT_DESIGN_TOKENS: {"provider": "figma", "service": "figma", "friendly_name": "extract_design_tokens"},
    Action.FIGMA_DESIGN_TOKENS_TO_TAILWIND: {"provider": "figma", "service": "figma", "friendly_name": "design_tokens_to_tailwind"},
    Action.FIGMA_RENDER_IMAGES_OF_FILE_NODES: {"provider": "figma", "service": "figma", "friendly_name": "render_images_of_file_nodes"},
    Action.FIGMA_DOWNLOAD_FIGMA_IMAGES: {"provider": "figma", "service": "figma", "friendly_name": "download_figma_images"},
    Action.FIGMA_GET_FILE_COMPONENTS: {"provider": "figma", "service": "figma", "friendly_name": "get_file_component_sets"},
    Action.FIGMA_GET_FILE_COMPONENT_SETS: {"provider": "figma", "service": "figma", "friendly_name": "get_file_component_sets"},
    Action.FIGMA_GET_LOCAL_VARIABLES: {"provider": "figma", "service": "figma", "friendly_name": "get_local_variables"},
    Action.FIGMA_GET_PUBLISHED_VARIABLES: {"provider": "figma", "service": "figma", "friendly_name": "get_published_variables"},
    Action.FIGMA_CREATE_MODIFY_DELETE_VARIABLES: {"provider": "figma", "service": "figma", "friendly_name": "create_modify_delete_variables"},
    Action.FIGMA_EXTRACT_PROTOTYPE_INTERACTIONS: {"provider": "figma", "service": "figma", "friendly_name": "extract_prototype_interactions"},
    Action.FIGMA_DISCOVER_FIGMA_RESOURCES: {"provider": "figma", "service": "figma", "friendly_name": "discover_figma_resources"},
    Action.FIGMA_GET_CURRENT_USER: {"provider": "figma", "service": "figma", "friendly_name": "get_current_user_figma"},
    Action.FIGMA_GET_PROJECTS_IN_TEAM: {"provider": "figma", "service": "figma", "friendly_name": "get_projects_in_team"},
    Action.FIGMA_GET_FILES_IN_PROJECT: {"provider": "figma", "service": "figma", "friendly_name": "get_files_in_project"},
    Action.FIGMA_GET_VERSIONS_OF_FILE: {"provider": "figma", "service": "figma", "friendly_name": "get_versions_of_file"},
    Action.FIGMA_GET_COMMENTS_IN_FILE: {"provider": "figma", "service": "figma", "friendly_name": "get_comments_in_file"},
    Action.FIGMA_ADD_COMMENT_TO_FILE: {"provider": "figma", "service": "figma", "friendly_name": "add_comment_to_file"},
    Action.FIGMA_DELETE_COMMENT: {"provider": "figma", "service": "figma", "friendly_name": "delete_comment_figma"},
    Action.FIGMA_CREATE_WEBHOOK: {"provider": "figma", "service": "figma", "friendly_name": "create_webhook"},
    Action.FIGMA_GET_TEAM_WEBHOOKS: {"provider": "figma", "service": "figma", "friendly_name": "get_team_webhooks"},
    Action.FIGMA_GET_WEBHOOK: {"provider": "figma", "service": "figma", "friendly_name": "get_webhook_figma"},
    Action.FIGMA_DELETE_WEBHOOK: {"provider": "figma", "service": "figma", "friendly_name": "delete_webhook_figma"},
    Action.FIGMA_DELETE_DEV_RESOURCE: {"provider": "figma", "service": "figma", "friendly_name": "delete_dev_resource"},
    Action.FIGMA_DETECT_BACKGROUND: {"provider": "figma", "service": "figma", "friendly_name": "detect_background"},
    Action.FIGMA_GET_ACTIVITY_LOGS: {"provider": "figma", "service": "figma", "friendly_name": "get_activity_logs"},
    Action.FIGMA_GET_COMMENTS: {"provider": "figma", "service": "figma", "friendly_name": "get_comments"},
    Action.FIGMA_GET_COMPONENT_SET: {"provider": "figma", "service": "figma", "friendly_name": "get_component_set"},
    Action.FIGMA_GET_DEV_RESOURCES: {"provider": "figma", "service": "figma", "friendly_name": "get_dev_resources"},
    Action.FIGMA_GET_FILE_STYLES: {"provider": "figma", "service": "figma", "friendly_name": "get_file_styles"},
    Action.FIGMA_GET_IMAGE_FILLS: {"provider": "figma", "service": "figma", "friendly_name": "get_image_fills"},
    Action.FIGMA_GET_LIBRARY_ANALYTICS_COMPONENT_ACTION_DATA: {"provider": "figma", "service": "figma", "friendly_name": "get_library_analytics_component_action_data"},
    Action.FIGMA_GET_LIBRARY_ANALYTICS_COMPONENT_USAGE_DATA: {"provider": "figma", "service": "figma", "friendly_name": "get_library_analytics_component_usage_data"},
    Action.FIGMA_GET_LIBRARY_ANALYTICS_STYLE_ACTION_DATA: {"provider": "figma", "service": "figma", "friendly_name": "get_library_analytics_style_action_data"},
    Action.FIGMA_GET_LIBRARY_ANALYTICS_STYLE_USAGE_DATA: {"provider": "figma", "service": "figma", "friendly_name": "get_library_analytics_style_usage_data"},
    Action.FIGMA_GET_LIBRARY_ANALYTICS_VARIABLE_ACTION_DATA: {"provider": "figma", "service": "figma", "friendly_name": "get_library_analytics_variable_action_data"},
    Action.FIGMA_GET_LIBRARY_ANALYTICS_VARIABLE_USAGE_DATA: {"provider": "figma", "service": "figma", "friendly_name": "get_library_analytics_variable_usage_data"},
    Action.FIGMA_GET_PAYMENTS: {"provider": "figma", "service": "figma", "friendly_name": "get_payments"},
    Action.FIGMA_GET_REACTIONS: {"provider": "figma", "service": "figma", "friendly_name": "get_reactions_figma"},
    Action.FIGMA_GET_STYLE: {"provider": "figma", "service": "figma", "friendly_name": "get_style"},
    Action.FIGMA_GET_TEAM_COMPONENTS: {"provider": "figma", "service": "figma", "friendly_name": "get_team_components"},
    Action.FIGMA_GET_TEAM_COMPONENT_SETS: {"provider": "figma", "service": "figma", "friendly_name": "get_team_component_sets"},
    Action.FIGMA_GET_TEAM_STYLES: {"provider": "figma", "service": "figma", "friendly_name": "get_team_styles"},
    Action.FIGMA_GET_VERSIONS: {"provider": "figma", "service": "figma", "friendly_name": "get_versions"},
    Action.FIGMA_GET_WEBHOOK_REQUESTS: {"provider": "figma", "service": "figma", "friendly_name": "get_webhook_requests"},
    Action.FIGMA_RENDER_IMAGES: {"provider": "figma", "service": "figma", "friendly_name": "render_images"},
    Action.FIGMA_UPDATE_WEBHOOK: {"provider": "figma", "service": "figma", "friendly_name": "update_webhook"},
    Action.FIGMA_UPDATE_DEV_RESOURCES: {"provider": "figma", "service": "figma", "friendly_name": "update_dev_resources"},

    # Firefiles actions
    Action.FIREFILES_DELETE_TRANSCRIPT: {"provider": "firefiles", "service": "firefiles", "friendly_name": "delete_transcript"},
    Action.FIREFILES_UPLOAD_AUDIO: {"provider": "firefiles", "service": "firefiles", "friendly_name": "upload_audio"},
    Action.FIREFILES_ADD_TO_LIVE: {"provider": "firefiles", "service": "firefiles", "friendly_name": "add_to_live"},
    Action.FIREFILES_SET_USER_ROLE: {"provider": "firefiles", "service": "firefiles", "friendly_name": "set_user_role"},
    Action.FIREFILES_QUERY_USERS: {"provider": "firefiles", "service": "firefiles", "friendly_name": "query_users"},
    Action.FIREFILES_QUERY_BITE_DETAILS: {"provider": "firefiles", "service": "firefiles", "friendly_name": "query_bite_details"},
    Action.FIREFILES_CREATE_BITE: {"provider": "firefiles", "service": "firefiles", "friendly_name": "create_bite"},
    Action.FIREFILES_QUERY_AI_APPS_OUTPUTS: {"provider": "firefiles", "service": "firefiles", "friendly_name": "query_ai_apps_outputs"},
    Action.FIREFILES_QUERY_TRANSCRIPTS: {"provider": "firefiles", "service": "firefiles", "friendly_name": "query_transcripts"},
    Action.FIREFILES_QUERY_TRANSCRIPT_DETAILS: {"provider": "firefiles", "service": "firefiles", "friendly_name": "query_transcript_details"},
    Action.FIREFILES_QUERY_USER_DETAILS: {"provider": "firefiles", "service": "firefiles", "friendly_name": "query_user_details"},
    Action.FIREFILES_QUERY_BITES: {"provider": "firefiles", "service": "firefiles", "friendly_name": "query_bites"},

    # Folk actions
    Action.FOLK_GET_CURRENT_USER: {"provider": "folk", "service": "folk", "friendly_name": "get_current_user_folk"},
    Action.FOLK_GET_USER: {"provider": "folk", "service": "folk", "friendly_name": "get_user_folk"},
    Action.FOLK_LIST_PEOPLE_IN_WORKSPACE: {"provider": "folk", "service": "folk", "friendly_name": "list_people_in_workspace"},
    Action.FOLK_GET_NOTE: {"provider": "folk", "service": "folk", "friendly_name": "get_note"},
    Action.FOLK_LIST_NOTES_IN_WORKSPACE: {"provider": "folk", "service": "folk", "friendly_name": "list_notes_in_workspace"},
    Action.FOLK_GET_COMPANY: {"provider": "folk", "service": "folk", "friendly_name": "get_company"},
    Action.FOLK_LIST_GROUP_CUSTOM_FIELDS_FOR_ENTITY_TYPE: {"provider": "folk", "service": "folk", "friendly_name": "list_group_custom_fields_for_entity_type"},
    Action.FOLK_GET_DEAL: {"provider": "folk", "service": "folk", "friendly_name": "get_deal"},
    Action.FOLK_RETRIEVE_REMINDER: {"provider": "folk", "service": "folk", "friendly_name": "retrieve_reminder"},
    Action.FOLK_LIST_REMINDERS_IN_WORKSPACE: {"provider": "folk", "service": "folk", "friendly_name": "list_reminders_in_workspace"},
    Action.FOLK_GET_PERSON: {"provider": "folk", "service": "folk", "friendly_name": "get_person"},
    Action.FOLK_LIST_USERS: {"provider": "folk", "service": "folk", "friendly_name": "list_users_folk"},
    Action.FOLK_LIST_WORKSPACE_GROUPS: {"provider": "folk", "service": "folk", "friendly_name": "list_workspace_groups"},
    Action.FOLK_LIST_DEALS_IN_WORKSPACE_GROUP: {"provider": "folk", "service": "folk", "friendly_name": "list_deals_in_workspace_group"},
    Action.FOLK_LIST_COMPANIES: {"provider": "folk", "service": "folk", "friendly_name": "list_companies"},
    Action.FOLK_CREATE_PERSON: {"provider": "folk", "service": "folk", "friendly_name": "create_person"},
    Action.FOLK_CREATE_NOTE_IN_WORKSPACE: {"provider": "folk", "service": "folk", "friendly_name": "create_note_in_workspace"},
    Action.FOLK_CREATE_COMPANY: {"provider": "folk", "service": "folk", "friendly_name": "create_company_folk"},
    Action.FOLK_CREATE_INTERACTION: {"provider": "folk", "service": "folk", "friendly_name": "create_interaction"},
    Action.FOLK_CREATE_DEAL_IN_WORKSPACE: {"provider": "folk", "service": "folk", "friendly_name": "create_deal_in_workspace"},
    Action.FOLK_CREATE_REMINDER: {"provider": "folk", "service": "folk", "friendly_name": "create_reminder_folk"},
    Action.FOLK_DELETE_NOTE: {"provider": "folk", "service": "folk", "friendly_name": "delete_note"},
    Action.FOLK_DELETE_COMPANY: {"provider": "folk", "service": "folk", "friendly_name": "delete_company_folk"},
    Action.FOLK_DELETE_DEAL: {"provider": "folk", "service": "folk", "friendly_name": "delete_deal"},
    Action.FOLK_DELETE_REMINDER: {"provider": "folk", "service": "folk", "friendly_name": "delete_reminder_folk"},
    Action.FOLK_DELETE_PERSON: {"provider": "folk", "service": "folk", "friendly_name": "delete_person_folk"},
    Action.FOLK_UPDATE_NOTE: {"provider": "folk", "service": "folk", "friendly_name": "update_note"},
    Action.FOLK_UPDATE_COMPANY: {"provider": "folk", "service": "folk", "friendly_name": "update_company_folk"},
    Action.FOLK_UPDATE_DEAL: {"provider": "folk", "service": "folk", "friendly_name": "update_deal"},
    Action.FOLK_UPDATE_PERSON: {"provider": "folk", "service": "folk", "friendly_name": "update_person"},
    Action.FOLK_UPDATE_REMINDER: {"provider": "folk", "service": "folk", "friendly_name": "update_reminder"},

    # Front actions
    Action.FRONT_GET_MESSAGE: {"provider": "front", "service": "front", "friendly_name": "get_message"},
    Action.FRONT_GET_MESSAGE_SEEN_STATUS: {"provider": "front", "service": "front", "friendly_name": "get_message_seen_status"},
    Action.FRONT_MARK_MESSAGE_SEEN: {"provider": "front", "service": "front", "friendly_name": "mark_message_seen"},
    Action.FRONT_CREATE_MESSAGE: {"provider": "front", "service": "front", "friendly_name": "create_message"},
    Action.FRONT_CREATE_MESSAGE_REPLY: {"provider": "front", "service": "front", "friendly_name": "create_message_reply"},
    Action.FRONT_IMPORT_MESSAGE: {"provider": "front", "service": "front", "friendly_name": "import_message"},
    Action.FRONT_RECEIVE_CUSTOM_MESSAGES: {"provider": "front", "service": "front", "friendly_name": "receive_custom_messages"},
    Action.FRONT_LIST_CONVERSATIONS: {"provider": "front", "service": "front", "friendly_name": "list_conversations_front"},
    Action.FRONT_GET_CONVERSATION: {"provider": "front", "service": "front", "friendly_name": "get_conversation"},
    Action.FRONT_LIST_CONVERSATION_MESSAGES: {"provider": "front", "service": "front", "friendly_name": "list_conversation_messages"},
    Action.FRONT_LIST_CONVERSATION_EVENTS: {"provider": "front", "service": "front", "friendly_name": "list_conversation_events"},
    Action.FRONT_LIST_CONVERSATION_INBOXES: {"provider": "front", "service": "front", "friendly_name": "list_conversation_inboxes"},
    Action.FRONT_SEARCH_CONVERSATIONS: {"provider": "front", "service": "front", "friendly_name": "search_conversations"},
    Action.FRONT_CREATE_DISCUSSION_CONVERSATION: {"provider": "front", "service": "front", "friendly_name": "create_discussion_conversation"},
    Action.FRONT_UPDATE_CONVERSATION: {"provider": "front", "service": "front", "friendly_name": "update_conversation"},
    Action.FRONT_UPDATE_CONVERSATION_ASSIGNEE: {"provider": "front", "service": "front", "friendly_name": "update_conversation_assignee"},
    Action.FRONT_UPDATE_CONVERSATION_REMINDERS: {"provider": "front", "service": "front", "friendly_name": "update_conversation_reminders"},
    Action.FRONT_ADD_CONVERSATION_FOLLOWERS: {"provider": "front", "service": "front", "friendly_name": "add_conversation_followers"},
    Action.FRONT_DELETE_CONVERSATION_FOLLOWERS: {"provider": "front", "service": "front", "friendly_name": "delete_conversation_followers"},
    Action.FRONT_LIST_CONVERSATION_FOLLOWERS: {"provider": "front", "service": "front", "friendly_name": "list_conversation_followers"},
    Action.FRONT_ADD_CONVERSATION_TAG: {"provider": "front", "service": "front", "friendly_name": "add_conversation_tag"},
    Action.FRONT_REMOVE_CONVERSATION_TAG: {"provider": "front", "service": "front", "friendly_name": "remove_conversation_tag"},
    Action.FRONT_ADD_CONVERSATION_LINK: {"provider": "front", "service": "front", "friendly_name": "add_conversation_link"},
    Action.FRONT_REMOVE_CONVERSATION_LINKS: {"provider": "front", "service": "front", "friendly_name": "remove_conversation_links"},
    Action.FRONT_LIST_CONTACTS: {"provider": "front", "service": "front", "friendly_name": "list_contacts_front"},
    Action.FRONT_GET_CONTACT: {"provider": "front", "service": "front", "friendly_name": "get_contact_front"},
    Action.FRONT_CREATE_CONTACT: {"provider": "front", "service": "front", "friendly_name": "create_contact_front"},
    Action.FRONT_UPDATE_CONTACT: {"provider": "front", "service": "front", "friendly_name": "update_contact_front"},
    Action.FRONT_DELETE_CONTACT: {"provider": "front", "service": "front", "friendly_name": "delete_contact_front"},
    Action.FRONT_LIST_ACCOUNT_CONTACTS: {"provider": "front", "service": "front", "friendly_name": "list_account_contacts"},
    Action.FRONT_ADD_CONTACT_TO_ACCOUNT: {"provider": "front", "service": "front", "friendly_name": "add_contact_to_account"},
    Action.FRONT_REMOVE_CONTACT_FROM_ACCOUNT: {"provider": "front", "service": "front", "friendly_name": "remove_contact_from_account"},

    # Bigquery actions
    Action.BIGQUERY_GET_TABLE: {"provider": "google_cloud", "service": "bigquery", "friendly_name": "get_table"},
    Action.BIGQUERY_LIST_DATASETS: {"provider": "google_cloud", "service": "bigquery", "friendly_name": "list_datasets"},
    Action.BIGQUERY_LIST_BIGQUERY_MODELS: {"provider": "google_cloud", "service": "bigquery", "friendly_name": "list_bigquery_models"},
    Action.BIGQUERY_GET_QUERY_RESULTS: {"provider": "google_cloud", "service": "bigquery", "friendly_name": "get_query_results"},
    Action.BIGQUERY_LIST_TABLES: {"provider": "google_cloud", "service": "bigquery", "friendly_name": "list_tables"},
    Action.BIGQUERY_GET_ROUTINE_RESOURCE: {"provider": "google_cloud", "service": "bigquery", "friendly_name": "get_routine_resource"},
    Action.BIGQUERY_LIST_ROUTINES: {"provider": "google_cloud", "service": "bigquery", "friendly_name": "list_routines"},
    Action.BIGQUERY_LIST_TABLE_DATA: {"provider": "google_cloud", "service": "bigquery", "friendly_name": "list_table_data"},
    Action.BIGQUERY_GET_DATASET: {"provider": "google_cloud", "service": "bigquery", "friendly_name": "get_dataset"},
    Action.BIGQUERY_LIST_ROW_ACCESS_POLICIES: {"provider": "google_cloud", "service": "bigquery", "friendly_name": "list_row_access_policies"},
    Action.BIGQUERY_LIST_JOBS: {"provider": "google_cloud", "service": "bigquery", "friendly_name": "list_jobs"},
    Action.BIGQUERY_GET_JOB_INFORMATION: {"provider": "google_cloud", "service": "bigquery", "friendly_name": "get_job_information"},
    Action.BIGQUERY_LIST_PROJECTS: {"provider": "google_cloud", "service": "bigquery", "friendly_name": "list_projects_bigquery"},
    Action.BIGQUERY_GET_MODEL: {"provider": "google_cloud", "service": "bigquery", "friendly_name": "get_model"},
    Action.BIGQUERY_GET_PROJECT_SERVICE_ACCOUNT: {"provider": "google_cloud", "service": "bigquery", "friendly_name": "get_project_service_account"},
    Action.BIGQUERY_INSERT_DATA: {"provider": "google_cloud", "service": "bigquery", "friendly_name": "insert_data"},
    Action.BIGQUERY_GET_ROW_ACCESS_POLICY: {"provider": "google_cloud", "service": "bigquery", "friendly_name": "get_row_access_policy"},
    Action.BIGQUERY_SET_IAM_POLICY: {"provider": "google_cloud", "service": "bigquery", "friendly_name": "set_iam_policy"},
    Action.BIGQUERY_CANCEL_BIGQUERY_JOB: {"provider": "google_cloud", "service": "bigquery", "friendly_name": "cancel_bigquery_job"},
    Action.BIGQUERY_CREATE_TABLE: {"provider": "google_cloud", "service": "bigquery", "friendly_name": "create_table_biquery"},
    Action.BIGQUERY_GET_IAM_POLICY: {"provider": "google_cloud", "service": "bigquery", "friendly_name": "get_iam_policy"},
    Action.BIGQUERY_CREATE_ROUTINE: {"provider": "google_cloud", "service": "bigquery", "friendly_name": "create_routine"},
    Action.BIGQUERY_CREATE_DATASET: {"provider": "google_cloud", "service": "bigquery", "friendly_name": "create_dataset"},
    Action.BIGQUERY_UNDELETE_DATASET: {"provider": "google_cloud", "service": "bigquery", "friendly_name": "undelete_dataset"},
    Action.BIGQUERY_TEST_IAM_PERMISSIONS: {"provider": "google_cloud", "service": "bigquery", "friendly_name": "test_iam_permissions"},
    Action.BIGQUERY_START_ASYNC_JOB: {"provider": "google_cloud", "service": "bigquery", "friendly_name": "start_async_job"},
    Action.BIGQUERY_EXECUTE_SQL_QUERY: {"provider": "google_cloud", "service": "bigquery", "friendly_name": "execute_sql_query"},
    Action.BIGQUERY_UPDATE_DATASET: {"provider": "google_cloud", "service": "bigquery", "friendly_name": "update_dataset"},
    Action.BIGQUERY_UPDATE_ROUTINE: {"provider": "google_cloud", "service": "bigquery", "friendly_name": "update_routine"},
    Action.BIGQUERY_UPDATE_TABLE: {"provider": "google_cloud", "service": "bigquery", "friendly_name": "update_table"},
    Action.BIGQUERY_DELETE_JOB_METADATA: {"provider": "google_cloud", "service": "bigquery", "friendly_name": "delete_job_metadata"},
    Action.BIGQUERY_DELETE_ROUTINE: {"provider": "google_cloud", "service": "bigquery", "friendly_name": "delete_routine"},
    Action.BIGQUERY_DELETE_DATASET: {"provider": "google_cloud", "service": "bigquery", "friendly_name": "delete_dataset"},
    Action.BIGQUERY_DELETE_TABLE: {"provider": "google_cloud", "service": "bigquery", "friendly_name": "delete_table_bigquery"},
    Action.BIGQUERY_DELETE_BIGQUERY_MODEL: {"provider": "google_cloud", "service": "bigquery", "friendly_name": "delete_bigquery_model"},
    Action.BIGQUERY_PATCH_MODEL_FIELDS: {"provider": "google_cloud", "service": "bigquery", "friendly_name": "patch_model_fields"},

    # Hackernews actions
    Action.HACKERNEWS_GET_MAX_ITEM_ID: {"provider": "hackernews", "service": "hackernews", "friendly_name": "get_max_item_id"},
    Action.HACKERNEWS_GET_USER: {"provider": "hackernews", "service": "hackernews", "friendly_name": "get_user_hackernews"},
    Action.HACKERNEWS_GET_SHOW_STORIES: {"provider": "hackernews", "service": "hackernews", "friendly_name": "get_show_stories"},
    Action.HACKERNEWS_GET_UPDATES: {"provider": "hackernews", "service": "hackernews", "friendly_name": "get_updates"},
    Action.HACKERNEWS_GET_BEST_STORIES: {"provider": "hackernews", "service": "hackernews", "friendly_name": "get_best_stories"},
    Action.HACKERNEWS_GET_TOP_STORIES: {"provider": "hackernews", "service": "hackernews", "friendly_name": "get_top_stories"},
    Action.HACKERNEWS_GET_NEW_STORIES: {"provider": "hackernews", "service": "hackernews", "friendly_name": "get_new_stories"},
    Action.HACKERNEWS_GET_JOB_STORIES: {"provider": "hackernews", "service": "hackernews", "friendly_name": "get_job_stories"},
    Action.HACKERNEWS_GET_ASK_STORIES: {"provider": "hackernews", "service": "hackernews", "friendly_name": "get_ask_stories"},
    Action.HACKERNEWS_GET_ITEM: {"provider": "hackernews", "service": "hackernews", "friendly_name": "get_item"},

    # Hubspot actions
    Action.HUBSPOT_CREATE_BATCH_TICKETS: {"provider": "hubspot", "service": "hubspot", "friendly_name": "create_batch_tickets"},
    Action.HUBSPOT_CREATE_PRODUCT_BATCH: {"provider": "hubspot", "service": "hubspot", "friendly_name": "create_product_batch"},
    Action.HUBSPOT_CREATE_PRODUCT_OBJECT: {"provider": "hubspot", "service": "hubspot", "friendly_name": "create_product_object"},
    Action.HUBSPOT_GET_PIPELINE_STAGE_AUDIT: {"provider": "hubspot", "service": "hubspot", "friendly_name": "get_pipeline_stage_audit"},
    Action.HUBSPOT_LIST_PRODUCTS_WITH_PAGING: {"provider": "hubspot", "service": "hubspot", "friendly_name": "list_products_with_paging"},
    Action.HUBSPOT_UPDATE_PRODUCT: {"provider": "hubspot", "service": "hubspot", "friendly_name": "update_product"},
    Action.HUBSPOT_ARCHIVE_PRODUCT_BY_ID: {"provider": "hubspot", "service": "hubspot", "friendly_name": "archive_product_by_id"},
    Action.HUBSPOT_CREATE_COMPANY_BATCH: {"provider": "hubspot", "service": "hubspot", "friendly_name": "create_company_batch"},
    Action.HUBSPOT_CREATE_CONTACT_BATCH: {"provider": "hubspot", "service": "hubspot", "friendly_name": "create_contact_batch"},
    Action.HUBSPOT_CREATE_DEAL_BATCH: {"provider": "hubspot", "service": "hubspot", "friendly_name": "create_deal_batch"},
    Action.HUBSPOT_SEARCH_CONTACTS: {"provider": "hubspot", "service": "hubspot", "friendly_name": "search_contacts"},
    Action.HUBSPOT_SEARCH_COMPANIES: {"provider": "hubspot", "service": "hubspot", "friendly_name": "search_companies"},
    Action.HUBSPOT_SEARCH_DEALS: {"provider": "hubspot", "service": "hubspot", "friendly_name": "search_deals"},
    Action.HUBSPOT_CREATE_CUSTOM_PROPERTY: {"provider": "hubspot", "service": "hubspot", "friendly_name": "create_custom_property"},
    Action.HUBSPOT_CREATE_PIPELINE: {"provider": "hubspot", "service": "hubspot", "friendly_name": "create_pipeline"},
    Action.HUBSPOT_GET_CONTACT_BY_ID: {"provider": "hubspot", "service": "hubspot", "friendly_name": "get_contact_by_id_hubspot"},
    Action.HUBSPOT_GET_COMPANY_BY_ID: {"provider": "hubspot", "service": "hubspot", "friendly_name": "get_company_by_id"},
    Action.HUBSPOT_GET_DEAL_BY_ID: {"provider": "hubspot", "service": "hubspot", "friendly_name": "get_deal_by_id"},
    Action.HUBSPOT_CREATE_MARKETING_EMAIL: {"provider": "hubspot", "service": "hubspot", "friendly_name": "create_marketing_email"},
    Action.HUBSPOT_CREATE_WORKFLOW: {"provider": "hubspot", "service": "hubspot", "friendly_name": "create_workflow"},
    Action.HUBSPOT_ARCHIVE_BATCH_CONTACTS: {"provider": "hubspot", "service": "hubspot", "friendly_name": "archive_batch_contacts"},
    Action.HUBSPOT_ARCHIVE_BATCH_COMPANIES: {"provider": "hubspot", "service": "hubspot", "friendly_name": "archive_batch_companies"},
    Action.HUBSPOT_ARCHIVE_BATCH_DEALS: {"provider": "hubspot", "service": "hubspot", "friendly_name": "archive_batch_deals"},
    Action.HUBSPOT_MERGE_CONTACTS: {"provider": "hubspot", "service": "hubspot", "friendly_name": "merge_contacts"},
    Action.HUBSPOT_MERGE_COMPANIES: {"provider": "hubspot", "service": "hubspot", "friendly_name": "merge_companies"},
    Action.HUBSPOT_MERGE_DEALS: {"provider": "hubspot", "service": "hubspot", "friendly_name": "merge_deals"},
    Action.HUBSPOT_LIST_ALL_PROPERTIES: {"provider": "hubspot", "service": "hubspot", "friendly_name": "list_all_properties"},
    Action.HUBSPOT_LIST_OWNERS: {"provider": "hubspot", "service": "hubspot", "friendly_name": "list_owners"},
    Action.HUBSPOT_GET_ALL_PIPELINES: {"provider": "hubspot", "service": "hubspot", "friendly_name": "get_all_pipelines"},
    Action.HUBSPOT_CREATE_ASSOCIATION_DEFINITION: {"provider": "hubspot", "service": "hubspot", "friendly_name": "create_association_definition"},
    Action.HUBSPOT_GDPR_DELETE_CONTACT: {"provider": "hubspot", "service": "hubspot", "friendly_name": "gdpr_delete_contact"},
    Action.HUBSPOT_RETRIEVE_ALL_OBJECT_SCHEMAS: {"provider": "hubspot", "service": "hubspot", "friendly_name": "retrieve_all_object_schemas"},
    Action.HUBSPOT_RETRIEVE_ALL_PIPELINES_FOR_OBJECT_TYPE: {"provider": "hubspot", "service": "hubspot", "friendly_name": "retrieve_all_pipelines_for_object_type"},
    Action.HUBSPOT_RETRIEVE_BATCH_DEALS_BY_IDS: {"provider": "hubspot", "service": "hubspot", "friendly_name": "retrieve_batch_deals_by_ids"},
    Action.HUBSPOT_RETRIEVE_CALLING_SETTINGS_FOR_APP: {"provider": "hubspot", "service": "hubspot", "friendly_name": "retrieve_calling_settings_for_app"},
    Action.HUBSPOT_RETRIEVE_COMPANY_BY_ID: {"provider": "hubspot", "service": "hubspot", "friendly_name": "retrieve_company_by_id_hubspot"},
    Action.HUBSPOT_RETRIEVE_DEAL_BY_ID: {"provider": "hubspot", "service": "hubspot", "friendly_name": "retrieve_deal_by_id"},
    Action.HUBSPOT_RETRIEVE_EXISTING_OBJECT_SCHEMA: {"provider": "hubspot", "service": "hubspot", "friendly_name": "retrieve_existing_object_schema"},
    Action.HUBSPOT_RETRIEVE_LINE_ITEMS_LIST: {"provider": "hubspot", "service": "hubspot", "friendly_name": "retrieve_line_items_list"},
    Action.HUBSPOT_RETRIEVE_LINE_ITEM_BY_ID: {"provider": "hubspot", "service": "hubspot", "friendly_name": "retrieve_line_item_by_id"},
    Action.HUBSPOT_RETRIEVE_OWNERS: {"provider": "hubspot", "service": "hubspot", "friendly_name": "retrieve_owners"},

    # Intercom actions
    Action.INTERCOM_ATTACH_CONTACT_TO_COMPANY: {"provider": "intercom", "service": "intercom", "friendly_name": "attach_contact_to_company"},
    Action.INTERCOM_ADD_SUBSCRIPTION_TO_CONTACT: {"provider": "intercom", "service": "intercom", "friendly_name": "add_subscription_to_contact"},
    Action.INTERCOM_ADD_TAG_TO_CONTACT: {"provider": "intercom", "service": "intercom", "friendly_name": "add_tag_to_contact"},
    Action.INTERCOM_CREATE_ARTICLE: {"provider": "intercom", "service": "intercom", "friendly_name": "create_article"},
    Action.INTERCOM_CREATE_COLLECTION: {"provider": "intercom", "service": "intercom", "friendly_name": "create_collection_intercom"},
    Action.INTERCOM_CREATE_NOTE: {"provider": "intercom", "service": "intercom", "friendly_name": "create_note"},
    Action.INTERCOM_CREATE_OR_UPDATE_COMPANY: {"provider": "intercom", "service": "intercom", "friendly_name": "create_or_update_company"},
    Action.INTERCOM_DELETE_ARTICLE: {"provider": "intercom", "service": "intercom", "friendly_name": "delete_article"},
    Action.INTERCOM_DELETE_COLLECTION: {"provider": "intercom", "service": "intercom", "friendly_name": "delete_collection_intercom"},
    Action.INTERCOM_DELETE_COMPANY: {"provider": "intercom", "service": "intercom", "friendly_name": "delete_company_intercom"},
    Action.INTERCOM_DELETE_CONTACT: {"provider": "intercom", "service": "intercom", "friendly_name": "delete_contact_intercom"},
    Action.INTERCOM_DETACH_CONTACT_FROM_COMPANY: {"provider": "intercom", "service": "intercom", "friendly_name": "detach_contact_from_company"},
    Action.INTERCOM_GET_CONTACT: {"provider": "intercom", "service": "intercom", "friendly_name": "get_contact_intercom"},
    Action.INTERCOM_IDENTIFY_ADMIN: {"provider": "intercom", "service": "intercom", "friendly_name": "identify_admin"},
    Action.INTERCOM_LIST_ALL_ACTIVITY_LOGS: {"provider": "intercom", "service": "intercom", "friendly_name": "list_all_activity_logs"},
    Action.INTERCOM_LIST_ALL_ADMINS: {"provider": "intercom", "service": "intercom", "friendly_name": "list_all_admins"},
    Action.INTERCOM_LIST_ALL_ARTICLES: {"provider": "intercom", "service": "intercom", "friendly_name": "list_all_articles"},
    Action.INTERCOM_LIST_ALL_COLLECTIONS: {"provider": "intercom", "service": "intercom", "friendly_name": "list_all_collections"},
    Action.INTERCOM_LIST_ALL_COMPANIES: {"provider": "intercom", "service": "intercom", "friendly_name": "list_all_companies_intercom"},
    Action.INTERCOM_LIST_ALL_HELP_CENTERS: {"provider": "intercom", "service": "intercom", "friendly_name": "list_all_help_centers"},
    Action.INTERCOM_LIST_ALL_NOTES: {"provider": "intercom", "service": "intercom", "friendly_name": "list_all_notes"},
    Action.INTERCOM_LIST_ATTACHED_COMPANIES_FOR_CONTACT: {"provider": "intercom", "service": "intercom", "friendly_name": "list_attached_companies_for_contact"},
    Action.INTERCOM_LIST_ATTACHED_CONTACTS: {"provider": "intercom", "service": "intercom", "friendly_name": "list_attached_contacts"},
    Action.INTERCOM_LIST_ATTACHED_SEGMENTS_FOR_COMPANIES: {"provider": "intercom", "service": "intercom", "friendly_name": "list_attached_segments_for_companies"},
    Action.INTERCOM_LIST_ATTACHED_SEGMENTS_FOR_CONTACT: {"provider": "intercom", "service": "intercom", "friendly_name": "list_attached_segments_for_contact"},
    Action.INTERCOM_LIST_SUBSCRIPTIONS_FOR_CONTACT: {"provider": "intercom", "service": "intercom", "friendly_name": "list_subscriptions_for_contact"},
    Action.INTERCOM_LIST_TAGS_ATTACHED_TO_CONTACT: {"provider": "intercom", "service": "intercom", "friendly_name": "list_tags_attached_to_contact"},
    Action.INTERCOM_MERGE_LEAD_AND_USER: {"provider": "intercom", "service": "intercom", "friendly_name": "merge_lead_and_user"},
    Action.INTERCOM_REMOVE_SUBSCRIPTION_FROM_CONTACT: {"provider": "intercom", "service": "intercom", "friendly_name": "remove_subscription_from_contact"},
    Action.INTERCOM_REMOVE_TAG_FROM_CONTACT: {"provider": "intercom", "service": "intercom", "friendly_name": "remove_tag_from_contact"},
    Action.INTERCOM_RETRIEVE_ADMIN: {"provider": "intercom", "service": "intercom", "friendly_name": "retrieve_admin"},
    Action.INTERCOM_RETRIEVE_ARTICLE: {"provider": "intercom", "service": "intercom", "friendly_name": "retrieve_article"},
    Action.INTERCOM_RETRIEVE_COLLECTION: {"provider": "intercom", "service": "intercom", "friendly_name": "retrieve_collection"},
    Action.INTERCOM_RETRIEVE_COMPANY_BY_ID: {"provider": "intercom", "service": "intercom", "friendly_name": "retrieve_company_by_id_intercom"},
    Action.INTERCOM_RETRIEVE_HELP_CENTER: {"provider": "intercom", "service": "intercom", "friendly_name": "retrieve_help_center"},
    Action.INTERCOM_RETRIEVE_COMPANIES: {"provider": "intercom", "service": "intercom", "friendly_name": "retrieve_companies"},
    Action.INTERCOM_SCROLL_OVER_ALL_COMPANIES: {"provider": "intercom", "service": "intercom", "friendly_name": "scroll_over_all_companies"},
    Action.INTERCOM_SEARCH_FOR_ARTICLES: {"provider": "intercom", "service": "intercom", "friendly_name": "search_for_articles"},
    Action.INTERCOM_SET_ADMIN_TO_AWAY: {"provider": "intercom", "service": "intercom", "friendly_name": "set_admin_to_away"},
    Action.INTERCOM_UPDATE_ARTICLE: {"provider": "intercom", "service": "intercom", "friendly_name": "update_article"},
    Action.INTERCOM_UPDATE_COLLECTION: {"provider": "intercom", "service": "intercom", "friendly_name": "update_collection"},
    Action.INTERCOM_UPDATE_COMPANY: {"provider": "intercom", "service": "intercom", "friendly_name": "update_company_intercom"},
    Action.INTERCOM_UPDATE_CONTACT: {"provider": "intercom", "service": "intercom", "friendly_name": "update_contact_intercom"},

    # Kernel actions
    Action.KERNEL_GET_BROWSER_SESSION_DETAILS: {"provider": "kernel", "service": "kernel", "friendly_name": "get_browser_session_details"},
    Action.KERNEL_GET_DEPLOYMENT_DETAILS: {"provider": "kernel", "service": "kernel", "friendly_name": "get_deployment_details_kernel"},
    Action.KERNEL_LIST_ACTIVE_BROWSER_SESSIONS: {"provider": "kernel", "service": "kernel", "friendly_name": "list_active_browser_sessions"},
    Action.KERNEL_GET_INVOCATION_STATUS: {"provider": "kernel", "service": "kernel", "friendly_name": "get_invocation_status"},
    Action.KERNEL_LIST_APPLICATIONS: {"provider": "kernel", "service": "kernel", "friendly_name": "list_applications"},
    Action.KERNEL_CREATE_BROWSER_SESSION: {"provider": "kernel", "service": "kernel", "friendly_name": "create_browser_session"},
    Action.KERNEL_INVOKE_ACTION: {"provider": "kernel", "service": "kernel", "friendly_name": "invoke_action"},
    Action.KERNEL_DELETE_PERSISTENT_BROWSER_SESSION: {"provider": "kernel", "service": "kernel", "friendly_name": "delete_persistent_browser_session"},

    # Loops actions
    Action.LOOPS_LIST_MAILING_LISTS: {"provider": "loops", "service": "loops", "friendly_name": "list_mailing_lists"},
    Action.LOOPS_FIND_CONTACT: {"provider": "loops", "service": "loops", "friendly_name": "find_contact_loops"},
    Action.LOOPS_TEST_API_KEY_VALIDITY: {"provider": "loops", "service": "loops", "friendly_name": "test_api_key_validity"},
    Action.LOOPS_LIST_TRANSACTIONAL_EMAILS: {"provider": "loops", "service": "loops", "friendly_name": "list_transactional_emails"},
    Action.LOOPS_LIST_CONTACT_PROPERTIES: {"provider": "loops", "service": "loops", "friendly_name": "list_contact_properties"},
    Action.LOOPS_SEND_EVENT: {"provider": "loops", "service": "loops", "friendly_name": "send_event"},
    Action.LOOPS_CREATE_CONTACT: {"provider": "loops", "service": "loops", "friendly_name": "create_contact_loops"},
    Action.LOOPS_DELETE_CONTACT: {"provider": "loops", "service": "loops", "friendly_name": "delete_contact_loops"},
    Action.LOOPS_CREATE_CONTACT_PROPERTY: {"provider": "loops", "service": "loops", "friendly_name": "create_contact_property"},
    Action.LOOPS_SEND_TRANSACTIONAL_EMAIL: {"provider": "loops", "service": "loops", "friendly_name": "send_transactional_email"},
    Action.LOOPS_UPDATE_OR_CREATE_CONTACT: {"provider": "loops", "service": "loops", "friendly_name": "update_or_create_contact"},

    # Mailchimp actions
    Action.MAILCHIMP_GET_CAMPAIGN_INFO: {"provider": "mailchimp", "service": "mailchimp", "friendly_name": "get_campaign_info"},
    Action.MAILCHIMP_GET_LISTS_INFO: {"provider": "mailchimp", "service": "mailchimp", "friendly_name": "get_lists_info"},
    Action.MAILCHIMP_LIST_CAMPAIGNS: {"provider": "mailchimp", "service": "mailchimp", "friendly_name": "list_campaigns"},
    Action.MAILCHIMP_LIST_RECENT_ACTIVITY: {"provider": "mailchimp", "service": "mailchimp", "friendly_name": "list_recent_activity"},
    Action.MAILCHIMP_SEARCH_MEMBERS: {"provider": "mailchimp", "service": "mailchimp", "friendly_name": "search_members"},
    Action.MAILCHIMP_SEND_CAMPAIGN: {"provider": "mailchimp", "service": "mailchimp", "friendly_name": "send_campaign"},
    Action.MAILCHIMP_ADD_AUTOMATION: {"provider": "mailchimp", "service": "mailchimp", "friendly_name": "add_automation"},
    Action.MAILCHIMP_ADD_BATCH_WEBHOOK: {"provider": "mailchimp", "service": "mailchimp", "friendly_name": "add_batch_webhook"},
    Action.MAILCHIMP_ADD_CAMPAIGN: {"provider": "mailchimp", "service": "mailchimp", "friendly_name": "add_campaign"},
    Action.MAILCHIMP_ADD_CAMPAIGN_FEEDBACK: {"provider": "mailchimp", "service": "mailchimp", "friendly_name": "add_campaign_feedback"},
    Action.MAILCHIMP_ADD_CAMPAIGN_FOLDER: {"provider": "mailchimp", "service": "mailchimp", "friendly_name": "add_campaign_folder"},
    Action.MAILCHIMP_ADD_CART: {"provider": "mailchimp", "service": "mailchimp", "friendly_name": "add_cart"},
    Action.MAILCHIMP_ADD_PRODUCT: {"provider": "mailchimp", "service": "mailchimp", "friendly_name": "add_product"},
    Action.MAILCHIMP_ADD_PRODUCT_IMAGE: {"provider": "mailchimp", "service": "mailchimp", "friendly_name": "add_product_image"},
    Action.MAILCHIMP_ADD_PRODUCT_VARIANT: {"provider": "mailchimp", "service": "mailchimp", "friendly_name": "add_product_variant"},
    Action.MAILCHIMP_ADD_PROMO_CODE: {"provider": "mailchimp", "service": "mailchimp", "friendly_name": "add_promo_code"},
    Action.MAILCHIMP_ADD_PROMO_RULE: {"provider": "mailchimp", "service": "mailchimp", "friendly_name": "add_promo_rule"},
    Action.MAILCHIMP_ADD_SEGMENT: {"provider": "mailchimp", "service": "mailchimp", "friendly_name": "add_segment"},

    # Meetgeek actions
    Action.MEETGEEK_GET_TEAMS_OF_USER: {"provider": "meetgeek", "service": "meetgeek", "friendly_name": "get_teams_of_user"},
    Action.MEETGEEK_GET_TRANSCRIPT_SENTENCES_BY_MEETING_ID: {"provider": "meetgeek", "service": "meetgeek", "friendly_name": "get_transcript_sentences_by_meeting_id"},
    Action.MEETGEEK_GET_HIGHLIGHTS_BY_MEETING_ID: {"provider": "meetgeek", "service": "meetgeek", "friendly_name": "get_highlights_by_meeting_id"},
    Action.MEETGEEK_GET_SUMMARY_BY_MEETING_ID: {"provider": "meetgeek", "service": "meetgeek", "friendly_name": "get_summary_by_meeting_id"},
    Action.MEETGEEK_GET_PAGINATED_TEAM_MEETINGS: {"provider": "meetgeek", "service": "meetgeek", "friendly_name": "get_paginated_team_meetings"},
    Action.MEETGEEK_GET_PAGINATED_PAST_MEETINGS: {"provider": "meetgeek", "service": "meetgeek", "friendly_name": "get_paginated_past_meetings"},
    Action.MEETGEEK_GET_MEETING_DETAILS: {"provider": "meetgeek", "service": "meetgeek", "friendly_name": "get_meeting_details"},
    Action.MEETGEEK_UPLOAD_FILE_FOR_ANALYSIS: {"provider": "meetgeek", "service": "meetgeek", "friendly_name": "upload_file_for_analysis"},

    # Netlify actions
    Action.NETLIFY_GET_SITE_DEV_SERVER_HOOK: {"provider": "netlify", "service": "netlify", "friendly_name": "get_site_dev_server_hook"},
    Action.NETLIFY_LIST_PAYMENT_METHODS_FOR_USER: {"provider": "netlify", "service": "netlify", "friendly_name": "list_payment_methods_for_user"},
    Action.NETLIFY_SHOW_SERVICE_INSTANCE: {"provider": "netlify", "service": "netlify", "friendly_name": "show_service_instance"},
    Action.NETLIFY_GET_SINGLE_DNS_ZONE: {"provider": "netlify", "service": "netlify", "friendly_name": "get_single_dns_zone"},
    Action.NETLIFY_SHOW_SITE_TLS_CERTIFICATE: {"provider": "netlify", "service": "netlify", "friendly_name": "show_site_tls_certificate"},
    Action.NETLIFY_LIST_SITES_FOR_ACCOUNT: {"provider": "netlify", "service": "netlify", "friendly_name": "list_sites_for_account"},
    Action.NETLIFY_LIST_DEPLOY_KEYS: {"provider": "netlify", "service": "netlify", "friendly_name": "list_deploy_keys"},
    Action.NETLIFY_LIST_SITE_SNIPPETS: {"provider": "netlify", "service": "netlify", "friendly_name": "list_site_snippets"},
    Action.NETLIFY_GET_SITE_ASSET_INFO: {"provider": "netlify", "service": "netlify", "friendly_name": "get_site_asset_info"},
    Action.NETLIFY_GET_SITE_DEV_SERVER: {"provider": "netlify", "service": "netlify", "friendly_name": "get_site_dev_server"},
    Action.NETLIFY_LIST_ACCOUNT_TYPES_FOR_USER: {"provider": "netlify", "service": "netlify", "friendly_name": "list_account_types_for_user"},
    Action.NETLIFY_GET_HOOK_DETAILS: {"provider": "netlify", "service": "netlify", "friendly_name": "get_hook_details"},
    Action.NETLIFY_GET_ACCOUNT_BUILD_STATUS: {"provider": "netlify", "service": "netlify", "friendly_name": "get_account_build_status"},
    Action.NETLIFY_GET_DNS_RECORDS_FOR_SITE: {"provider": "netlify", "service": "netlify", "friendly_name": "get_dns_records_for_site"},
    Action.NETLIFY_LIST_BUILD_HOOKS_FOR_SITE: {"provider": "netlify", "service": "netlify", "friendly_name": "list_build_hooks_for_site"},
    Action.NETLIFY_GET_SITE_BUILD: {"provider": "netlify", "service": "netlify", "friendly_name": "get_site_build"},
    Action.NETLIFY_LIST_DEPLOYS_FOR_SITE: {"provider": "netlify", "service": "netlify", "friendly_name": "list_deploys_for_site"},
    Action.NETLIFY_GET_SPLIT_TEST_DETAILS: {"provider": "netlify", "service": "netlify", "friendly_name": "get_split_test_details"},
    Action.NETLIFY_LIST_FORM_SUBMISSION: {"provider": "netlify", "service": "netlify", "friendly_name": "list_form_submission"},
    Action.NETLIFY_SEARCH_SITE_FUNCTIONS: {"provider": "netlify", "service": "netlify", "friendly_name": "search_site_functions"},
    Action.NETLIFY_GET_PUBLIC_SIGNATURE_URL_FOR_SITE_ASSET: {"provider": "netlify", "service": "netlify", "friendly_name": "get_public_signature_url_for_site_asset"},
    Action.NETLIFY_GET_CURRENT_USER: {"provider": "netlify", "service": "netlify", "friendly_name": "get_current_user_netlify"},
    Action.NETLIFY_GET_DNS_ZONES: {"provider": "netlify", "service": "netlify", "friendly_name": "get_dns_zones"},
    Action.NETLIFY_GET_SITE_DEPLOY: {"provider": "netlify", "service": "netlify", "friendly_name": "get_site_deploy"},
    Action.NETLIFY_LIST_FORMS_FOR_SITE: {"provider": "netlify", "service": "netlify", "friendly_name": "list_forms_for_site"},
    Action.NETLIFY_GET_ENVIRONMENT_VARIABLE_FOR_ACCOUNT: {"provider": "netlify", "service": "netlify", "friendly_name": "get_environment_variable_for_account"},
    Action.NETLIFY_LIST_SITE_SUBMISSIONS: {"provider": "netlify", "service": "netlify", "friendly_name": "list_site_submissions"},
    Action.NETLIFY_GET_ENVIRONMENT_VARIABLES_FOR_SITE: {"provider": "netlify", "service": "netlify", "friendly_name": "get_environment_variables_for_site"},
    Action.NETLIFY_SHOW_OAUTH_TICKET: {"provider": "netlify", "service": "netlify", "friendly_name": "show_oauth_ticket"},
    Action.NETLIFY_GET_SITE_SNIPPET: {"provider": "netlify", "service": "netlify", "friendly_name": "get_site_snippet"},
    Action.NETLIFY_LIST_FORM_SUBMISSIONS: {"provider": "netlify", "service": "netlify", "friendly_name": "list_form_submissions"},
    Action.NETLIFY_LIST_SITE_FILES: {"provider": "netlify", "service": "netlify", "friendly_name": "list_site_files"},
    Action.NETLIFY_GET_ACCOUNT_MEMBER_DETAILS: {"provider": "netlify", "service": "netlify", "friendly_name": "get_account_member_details"},
    Action.NETLIFY_GET_ALL_CERTIFICATES_FOR_SITE: {"provider": "netlify", "service": "netlify", "friendly_name": "get_all_certificates_for_site"},
    Action.NETLIFY_GET_DEPLOY_KEY: {"provider": "netlify", "service": "netlify", "friendly_name": "get_deploy_key"},
    Action.NETLIFY_GET_INDIVIDUAL_DNS_RECORD: {"provider": "netlify", "service": "netlify", "friendly_name": "get_individual_dns_record"},
    Action.NETLIFY_LIST_SITES: {"provider": "netlify", "service": "netlify", "friendly_name": "list_sites"},
    Action.NETLIFY_SHOW_SERVICE_DETAILS: {"provider": "netlify", "service": "netlify", "friendly_name": "show_service_details"},
    Action.NETLIFY_LIST_DEPLOYED_BRANCHES_FOR_SITE: {"provider": "netlify", "service": "netlify", "friendly_name": "list_deployed_branches_for_site"},
    Action.NETLIFY_LIST_SERVICE_INSTANCES_FOR_SITE: {"provider": "netlify", "service": "netlify", "friendly_name": "list_service_instances_for_site"},
    Action.NETLIFY_GET_DEPLOY_DETAILS: {"provider": "netlify", "service": "netlify", "friendly_name": "get_deploy_details"},
    Action.NETLIFY_LIST_ACCOUNTS_FOR_USER: {"provider": "netlify", "service": "netlify", "friendly_name": "list_accounts_for_user"},
    Action.NETLIFY_LIST_SITE_BUILDS: {"provider": "netlify", "service": "netlify", "friendly_name": "list_site_builds"},
    Action.NETLIFY_GET_SITE_METADATA: {"provider": "netlify", "service": "netlify", "friendly_name": "get_site_metadata"},
    Action.NETLIFY_LIST_ACCOUNT_AUDIT_EVENTS: {"provider": "netlify", "service": "netlify", "friendly_name": "list_account_audit_events"},
    Action.NETLIFY_LIST_SITE_DEV_SERVERS: {"provider": "netlify", "service": "netlify", "friendly_name": "list_site_dev_servers"},
    Action.NETLIFY_GET_ENVIRONMENT_VARIABLES: {"provider": "netlify", "service": "netlify", "friendly_name": "get_environment_variables"},
    Action.NETLIFY_LIST_HOOK_TYPES: {"provider": "netlify", "service": "netlify", "friendly_name": "list_hook_types"},
    Action.NETLIFY_GET_SITE_BUILD_HOOK: {"provider": "netlify", "service": "netlify", "friendly_name": "get_site_build_hook"},
    Action.NETLIFY_GET_ALL_DNS_RECORDS_FOR_SINGLE_DNS_ZONE: {"provider": "netlify", "service": "netlify", "friendly_name": "get_all_dns_records_for_single_dns_zone"},
    Action.NETLIFY_LIST_MEMBERS_FOR_ACCOUNT: {"provider": "netlify", "service": "netlify", "friendly_name": "list_members_for_account"},
    Action.NETLIFY_GET_ACCOUNT_INFORMATION: {"provider": "netlify", "service": "netlify", "friendly_name": "get_account_information_netlify"},
    Action.NETLIFY_GET_SPLIT_TESTS_FOR_SITE: {"provider": "netlify", "service": "netlify", "friendly_name": "get_split_tests_for_site"},
    Action.NETLIFY_SHOW_SERVICE_MANIFEST: {"provider": "netlify", "service": "netlify", "friendly_name": "show_service_manifest"},
    Action.NETLIFY_GET_SITE_FILE_BY_PATH_NAME: {"provider": "netlify", "service": "netlify", "friendly_name": "get_site_file_by_path_name"},
    Action.NETLIFY_GET_LIST_OF_SERVICES: {"provider": "netlify", "service": "netlify", "friendly_name": "get_list_of_services"},
    Action.NETLIFY_LIST_HOOKS_BY_SITE_ID: {"provider": "netlify", "service": "netlify", "friendly_name": "list_hooks_by_site_id"},
    Action.NETLIFY_LIST_SITE_ASSETS: {"provider": "netlify", "service": "netlify", "friendly_name": "list_site_assets"},
    Action.NETLIFY_LIST_SITE_DEV_SERVER_HOOKS: {"provider": "netlify", "service": "netlify", "friendly_name": "list_site_dev_server_hooks"},

    # Newsdata actions
    Action.NEWSDATA_GET_NEWS_SOURCES: {"provider": "newsdata", "service": "newsdata", "friendly_name": "get_news_sources"},
    Action.NEWSDATA_GET_LATEST_NEWS: {"provider": "newsdata", "service": "newsdata", "friendly_name": "get_latest_news"},
    Action.NEWSDATA_GET_CRYPTO_NEWS: {"provider": "newsdata", "service": "newsdata", "friendly_name": "get_crypto_news"},
    Action.NEWSDATA_GET_NEWS_ARCHIVE: {"provider": "newsdata", "service": "newsdata", "friendly_name": "get_news_archive"},

    # Peopledatalabs actions
    Action.PEOPLEDATALABS_PERSON_SEARCH: {"provider": "peopledatalabs", "service": "peopledatalabs", "friendly_name": "person_search"},

    # Openrouter actions
    Action.OPENROUTER_GET_CREDITS: { "provider": "openrouter", "service": "openrouter", "friendly_name": "get_credits" },
    Action.OPENROUTER_LIST_AVAILABLE_PROVIDERS: { "provider": "openrouter", "service": "openrouter", "friendly_name": "list_available_providers" },
    Action.OPENROUTER_GET_CURRENT_API_KEY_INFO: { "provider": "openrouter", "service": "openrouter", "friendly_name": "get_current_api_key_info" },
    Action.OPENROUTER_LIST_AVAILABLE_MODELS: { "provider": "openrouter", "service": "openrouter", "friendly_name": "list_available_models" },
    Action.OPENROUTER_LIST_ENDPOINTS_FOR_MODEL: { "provider": "openrouter", "service": "openrouter", "friendly_name": "list_endpoints_for_model" },
    Action.OPENROUTER_GET_API_KEY_DETAILS: { "provider": "openrouter", "service": "openrouter", "friendly_name": "get_api_key_details" },
    Action.OPENROUTER_GET_GENERATION: { "provider": "openrouter", "service": "openrouter", "friendly_name": "get_generation" },
    Action.OPENROUTER_LIST_API_KEYS: { "provider": "openrouter", "service": "openrouter", "friendly_name": "list_api_keys_openrouter" },
    Action.OPENROUTER_CREATE_COINBASE_CHARGE: { "provider": "openrouter", "service": "openrouter", "friendly_name": "create_coinbase_charge" },
    Action.OPENROUTER_CREATE_API_KEY: { "provider": "openrouter", "service": "openrouter", "friendly_name": "create_api_key_openrouter" },
    Action.OPENROUTER_EXCHANGE_OAUTH_CODE: { "provider": "openrouter", "service": "openrouter", "friendly_name": "exchange_oauth_code" },
    Action.OPENROUTER_SEND_CHAT_COMPLETION: { "provider": "openrouter", "service": "openrouter", "friendly_name": "send_chat_completion" },
    Action.OPENROUTER_SEND_COMPLETION: { "provider": "openrouter", "service": "openrouter", "friendly_name": "send_completion" },
    Action.OPENROUTER_DELETE_API_KEY: { "provider": "openrouter", "service": "openrouter", "friendly_name": "delete_api_key_openrouter" },
    Action.OPENROUTER_UPDATE_API_KEY: { "provider": "openrouter", "service": "openrouter", "friendly_name": "update_api_key_openrouter" },

    # Pinecone actions
    Action.PINECONE_LIST_INDEXES: {"provider": "pinecone", "service": "pinecone", "friendly_name": "list_indexes"},
    Action.PINECONE_DESCRIBE_IMPORT: {"provider": "pinecone", "service": "pinecone", "friendly_name": "describe_import"},
    Action.PINECONE_LIST_IMPORTS: {"provider": "pinecone", "service": "pinecone", "friendly_name": "list_imports"},
    Action.PINECONE_LIST_COLLECTIONS: {"provider": "pinecone", "service": "pinecone", "friendly_name": "list_collections"},
    Action.PINECONE_LIST_VECTOR_IDS: {"provider": "pinecone", "service": "pinecone", "friendly_name": "list_vector_ids"},
    Action.PINECONE_DESCRIBE_INDEX: {"provider": "pinecone", "service": "pinecone", "friendly_name": "describe_index"},
    Action.PINECONE_DESCRIBE_COLLECTION: {"provider": "pinecone", "service": "pinecone", "friendly_name": "describe_collection"},
    Action.PINECONE_FETCH_VECTORS: {"provider": "pinecone", "service": "pinecone", "friendly_name": "fetch_vectors"},
    Action.PINECONE_CREATE_COLLECTION: {"provider": "pinecone", "service": "pinecone", "friendly_name": "create_collection_pinecone"},
    Action.PINECONE_QUERY_VECTORS: {"provider": "pinecone", "service": "pinecone", "friendly_name": "query_vectors"},
    Action.PINECONE_GET_INDEX_STATS: {"provider": "pinecone", "service": "pinecone", "friendly_name": "get_index_stats"},
    Action.PINECONE_UPSERT_VECTORS: {"provider": "pinecone", "service": "pinecone", "friendly_name": "upsert_vectors"},
    Action.PINECONE_START_IMPORT: {"provider": "pinecone", "service": "pinecone", "friendly_name": "start_import"},
    Action.PINECONE_DELETE_VECTORS: {"provider": "pinecone", "service": "pinecone", "friendly_name": "delete_vectors"},
    Action.PINECONE_UPDATE_VECTOR: {"provider": "pinecone", "service": "pinecone", "friendly_name": "update_vector"},
    Action.PINECONE_CREATE_INDEX: {"provider": "pinecone", "service": "pinecone", "friendly_name": "create_index"},
    Action.PINECONE_DELETE_INDEX: {"provider": "pinecone", "service": "pinecone", "friendly_name": "delete_index"},
    Action.PINECONE_DELETE_COLLECTION: {"provider": "pinecone", "service": "pinecone", "friendly_name": "delete_collection_pinecone"},
    Action.PINECONE_CANCEL_IMPORT_OPERATION: {"provider": "pinecone", "service": "pinecone", "friendly_name": "cancel_import_operation"},
    Action.PINECONE_CONFIGURE_INDEX: {"provider": "pinecone", "service": "pinecone", "friendly_name": "configure_index"},

    # Places actions
    Action.PLACES_GET_PLACE_DETAILS: {"provider": "places", "service": "places", "friendly_name": "get_place_details"},
    Action.PLACES_SEARCH_NEARBY_PLACES: {"provider": "places", "service": "places", "friendly_name": "search_nearby_places"},
    Action.PLACES_TEXT_SEARCH_PLACES: {"provider": "places", "service": "places", "friendly_name": "text_search_places"},
    Action.PLACES_AUTOCOMPLETE_PLACES: {"provider": "places", "service": "places", "friendly_name": "autocomplete_places"},
    Action.PLACES_GET_PLACE_PHOTOS: {"provider": "places", "service": "places", "friendly_name": "get_place_photos"},
    Action.PLACES_SEARCH_PLACES_BY_CATEGORY: {"provider": "places", "service": "places", "friendly_name": "search_places_by_category"},
    Action.PLACES_GET_PLACE_REVIEWS: {"provider": "places", "service": "places", "friendly_name": "get_place_reviews"},
    Action.PLACES_GET_OPENING_HOURS: {"provider": "places", "service": "places", "friendly_name": "get_opening_hours"},
    Action.PLACES_REVERSE_GEOCODE: {"provider": "places", "service": "places", "friendly_name": "reverse_geocode"},
    Action.PLACES_GEOCODE_ADDRESS: {"provider": "places", "service": "places", "friendly_name": "geocode_address"},
    Action.PLACES_VALIDATE_ADDRESS: {"provider": "places", "service": "places", "friendly_name": "validate_address"},

    # Posthog actions
    Action.POSTHOG_LIST_PROJECTS: {"provider": "posthog", "service": "posthog", "friendly_name": "list_projects_posthog"},
    Action.POSTHOG_LIST_PROJECT_GROUP_TYPES: {"provider": "posthog", "service": "posthog", "friendly_name": "list_project_group_types"},
    Action.POSTHOG_LIST_ORGANIZATIONS: {"provider": "posthog", "service": "posthog", "friendly_name": "list_organizations"},
    Action.POSTHOG_ADD_DASHBOARD_COLLABORATORS: {"provider": "posthog", "service": "posthog", "friendly_name": "add_dashboard_collaborators"},
    Action.POSTHOG_ADD_ORGANIZATION_MEMBER_ROLE: {"provider": "posthog", "service": "posthog", "friendly_name": "add_organization_member_role"},
    Action.POSTHOG_ADD_PROJECT_MEMBER_ROLES: {"provider": "posthog", "service": "posthog", "friendly_name": "add_project_member_roles"},
    Action.POSTHOG_ASSIGN_FEATURE_FLAG_ROLE_ACCESS: {"provider": "posthog", "service": "posthog", "friendly_name": "assign_feature_flag_role_access"},
    Action.POSTHOG_BOOKMARK_PROJECT_ACTIVITY_NOTIFICATION: {"provider": "posthog", "service": "posthog", "friendly_name": "bookmark_project_activity_notification"},
    Action.POSTHOG_BULK_CREATE_ORGANIZATION_INVITES: {"provider": "posthog", "service": "posthog", "friendly_name": "bulk_create_organization_invites"},
    Action.POSTHOG_CANCEL_PROJECT_INSIGHTS: {"provider": "posthog", "service": "posthog", "friendly_name": "cancel_project_insights"},
    Action.POSTHOG_CHECK_PIPELINE_DESTINATION_UPDATES: {"provider": "posthog", "service": "posthog", "friendly_name": "check_pipeline_destination_updates"},
    Action.POSTHOG_CHECK_PIPELINE_IMPORT_APP_UPDATES: {"provider": "posthog", "service": "posthog", "friendly_name": "check_pipeline_import_app_updates"},
    Action.POSTHOG_CHECK_PIPELINE_PLUGIN_UPDATE_STATUS: {"provider": "posthog", "service": "posthog", "friendly_name": "check_pipeline_plugin_update_status"},
    Action.POSTHOG_CHECK_PROJECT_DEMO_DATA_GENERATION_STATUS: {"provider": "posthog", "service": "posthog", "friendly_name": "check_project_demo_data_generation_status"},
    Action.POSTHOG_DUPLICATE_COHORT_TO_STATIC: {"provider": "posthog", "service": "posthog", "friendly_name": "duplicate_cohort_to_static"},
    Action.POSTHOG_CREATE_NOTEBOOK: {"provider": "posthog", "service": "posthog", "friendly_name": "create_notebook"},
    Action.POSTHOG_CREATE_PROJECT_INSIGHTS: {"provider": "posthog", "service": "posthog", "friendly_name": "create_project_insights"},
    Action.POSTHOG_CREATE_DASHBOARD_FROM_TEMPLATE: {"provider": "posthog", "service": "posthog", "friendly_name": "create_dashboard_from_template"},
    Action.POSTHOG_CREATE_ORGANIZATION_DOMAIN: {"provider": "posthog", "service": "posthog", "friendly_name": "create_organization_domain"},
    Action.POSTHOG_CREATE_EXPERIMENT_EXPOSURE_COHORT: {"provider": "posthog", "service": "posthog", "friendly_name": "create_experiment_exposure_cohort"},
    Action.POSTHOG_CREATE_FEATURE_FLAG: {"provider": "posthog", "service": "posthog", "friendly_name": "create_feature_flag"},
    Action.POSTHOG_CREATE_FEATURE_FLAG_DASHBOARD: {"provider": "posthog", "service": "posthog", "friendly_name": "create_feature_flag_dashboard"},
    Action.POSTHOG_CREATE_FRONTEND_APP_PIPELINE_CONFIG: {"provider": "posthog", "service": "posthog", "friendly_name": "create_frontend_app_pipeline_config"},
    Action.POSTHOG_CREATE_FUNNEL_ANALYSIS_FOR_PERSONS: {"provider": "posthog", "service": "posthog", "friendly_name": "create_funnel_analysis_for_persons"},
    Action.POSTHOG_CREATE_ORGANIZATION: {"provider": "posthog", "service": "posthog", "friendly_name": "create_organization_posthog"},
    Action.POSTHOG_CREATE_PROJECT_EXPERIMENT: {"provider": "posthog", "service": "posthog", "friendly_name": "create_project_experiment"},
    Action.POSTHOG_CREATE_ORGANIZATION_INVITE: {"provider": "posthog", "service": "posthog", "friendly_name": "create_organization_invite"},
    Action.POSTHOG_CREATE_ORGANIZATION_ROLE: {"provider": "posthog", "service": "posthog", "friendly_name": "create_organization_role"},
    Action.POSTHOG_CREATE_ORGANIZATION_PROXY_RECORD: {"provider": "posthog", "service": "posthog", "friendly_name": "create_organization_proxy_record"},
    Action.POSTHOG_CREATE_PERSON_FUNNEL_CORRELATION: {"provider": "posthog", "service": "posthog", "friendly_name": "create_person_funnel_correlation"},
    Action.POSTHOG_CREATE_PERSON_PATH: {"provider": "posthog", "service": "posthog", "friendly_name": "create_person_path"},
    Action.POSTHOG_CREATE_PIPELINE_DESTINATION_CONFIG: {"provider": "posthog", "service": "posthog", "friendly_name": "create_pipeline_destination_config"},
    Action.POSTHOG_CREATE_PIPELINE_DESTINATION_CONFIG_JOB: {"provider": "posthog", "service": "posthog", "friendly_name": "create_pipeline_destination_config_job"},
    Action.POSTHOG_CREATE_PIPELINE_IMPORT_APPS_CONFIG_JOB: {"provider": "posthog", "service": "posthog", "friendly_name": "create_pipeline_import_apps_config_job"},
    Action.POSTHOG_CREATE_PLUGIN_JOB_CONFIGURATION: {"provider": "posthog", "service": "posthog", "friendly_name": "create_plugin_job_configuration"},
    Action.POSTHOG_CREATE_PROJECT_ACTION: {"provider": "posthog", "service": "posthog", "friendly_name": "create_project_action"},
    Action.POSTHOG_CREATE_PROJECT_COHORTS: {"provider": "posthog", "service": "posthog", "friendly_name": "create_project_cohorts"},
    Action.POSTHOG_CREATE_PROJECT_DASHBOARD: {"provider": "posthog", "service": "posthog", "friendly_name": "create_project_dashboard"},
    Action.POSTHOG_CREATE_PROJECT_PIPELINE_APP_CONFIGS: {"provider": "posthog", "service": "posthog", "friendly_name": "create_project_pipeline_app_configs"},
    Action.POSTHOG_CREATE_PROJECT_PIPELINE_FRONTEND_APP_JOB: {"provider": "posthog", "service": "posthog", "friendly_name": "create_project_pipeline_frontend_app_job"},
    Action.POSTHOG_CREATE_PROJECT_PIPELINE_TRANSFORMATION_CONFIG: {"provider": "posthog", "service": "posthog", "friendly_name": "create_project_pipeline_transformation_config"},
    Action.POSTHOG_CREATE_PROJECT_PLUGIN_CONFIGURATION: {"provider": "posthog", "service": "posthog", "friendly_name": "create_project_plugin_configuration"},
    Action.POSTHOG_CREATE_PROJECT_SUBSCRIPTION: {"provider": "posthog", "service": "posthog", "friendly_name": "create_project_subscription"},
    Action.POSTHOG_CREATE_PROJECT_SURVEYS: {"provider": "posthog", "service": "posthog", "friendly_name": "create_project_surveys"},
    Action.POSTHOG_CREATE_PROJECT_TIMING_INSIGHTS: {"provider": "posthog", "service": "posthog", "friendly_name": "create_project_timing_insights"},
    Action.POSTHOG_CREATE_PROJECT_QUERY: {"provider": "posthog", "service": "posthog", "friendly_name": "create_project_query"},
    Action.POSTHOG_CREATE_RETENTION_INSIGHTS: {"provider": "posthog", "service": "posthog", "friendly_name": "create_retention_insights"},
    Action.POSTHOG_CREATE_SESSION_RECORDING_IN_PLAYLIST: {"provider": "posthog", "service": "posthog", "friendly_name": "create_session_recording_in_playlist"},
    Action.POSTHOG_CREATE_SESSION_RECORDING_PLAYLISTS: {"provider": "posthog", "service": "posthog", "friendly_name": "create_session_recording_playlists"},
    Action.POSTHOG_CREATE_SESSION_RECORDING_SUMMARY: {"provider": "posthog", "service": "posthog", "friendly_name": "create_session_recording_summary"},
    Action.POSTHOG_CREATE_STATIC_COHORT_FOR_FEATURE_FLAG: {"provider": "posthog", "service": "posthog", "friendly_name": "create_static_cohort_for_feature_flag"},
    Action.POSTHOG_MANAGE_PROJECT_ANNOTATIONS: {"provider": "posthog", "service": "posthog", "friendly_name": "manage_project_annotations"},
    Action.POSTHOG_GENERATE_PROJECT_FUNNEL_INSIGHTS: {"provider": "posthog", "service": "posthog", "friendly_name": "generate_project_funnel_insights"},
    Action.POSTHOG_DELETE_ORGANIZATION: {"provider": "posthog", "service": "posthog", "friendly_name": "delete_organization_posthog"},
    Action.POSTHOG_DELETE_ORGANIZATION_PROJECT: {"provider": "posthog", "service": "posthog", "friendly_name": "delete_organization_project"},
    Action.POSTHOG_DELETE_PERSON: {"provider": "posthog", "service": "posthog", "friendly_name": "delete_person_posthog"},
    Action.POSTHOG_DELETE_SESSION_RECORDING: {"provider": "posthog", "service": "posthog", "friendly_name": "delete_session_recording"},
    Action.POSTHOG_DELETE_SURVEY: {"provider": "posthog", "service": "posthog", "friendly_name": "delete_survey"},
    Action.POSTHOG_ENABLE_PROJECT_EARLY_ACCESS_FEATURE: {"provider": "posthog", "service": "posthog", "friendly_name": "enable_project_early_access_feature"},
    Action.POSTHOG_FETCH_BATCH_EXPORT_DETAILS: {"provider": "posthog", "service": "posthog", "friendly_name": "fetch_batch_export_details"},
    Action.POSTHOG_FETCH_EXPORT_UNSUBSCRIBE_SETTINGS: {"provider": "posthog", "service": "posthog", "friendly_name": "fetch_export_unsubscribe_settings"},
    Action.POSTHOG_FETCH_FRONTEND_APP_CONFIG_STATUS: {"provider": "posthog", "service": "posthog", "friendly_name": "fetch_frontend_app_config_status"},
    Action.POSTHOG_FETCH_ORGANIZATION_DETAILS: {"provider": "posthog", "service": "posthog", "friendly_name": "fetch_organization_details"},
    Action.POSTHOG_FETCH_ORGANIZATION_PIPELINE_APP_REPOSITORIES: {"provider": "posthog", "service": "posthog", "friendly_name": "fetch_organization_pipeline_app_repositories"},
    Action.POSTHOG_FETCH_PIPELINE_DESTINATION_DETAILS: {"provider": "posthog", "service": "posthog", "friendly_name": "fetch_pipeline_destination_details"},

    # Quickchart actions
    Action.QUICKCHART_CREATE_CHART: {"provider": "quickchart", "service": "quickchart", "friendly_name": "create_chart"},
    Action.QUICKCHART_CREATE_QR_CODE: {"provider": "quickchart", "service": "quickchart", "friendly_name": "create_qr_code"},
    Action.QUICKCHART_CREATE_SHORT_URL: {"provider": "quickchart", "service": "quickchart", "friendly_name": "create_short_url"},
    Action.QUICKCHART_CREATE_CHART_POST: {"provider": "quickchart", "service": "quickchart", "friendly_name": "create_chart_post"},

    # Resend actions
    Action.RESEND_RETRIEVE_BROADCAST: {"provider": "resend", "service": "resend", "friendly_name": "retrieve_broadcast"},
    Action.RESEND_LIST_AUDIENCES: {"provider": "resend", "service": "resend", "friendly_name": "list_audiences"},
    Action.RESEND_LIST_API_KEYS: {"provider": "resend", "service": "resend", "friendly_name": "list_api_keys_resend"},
    Action.RESEND_LIST_CONTACTS: {"provider": "resend", "service": "resend", "friendly_name": "list_contacts_resend"},
    Action.RESEND_RETRIEVE_CONTACT: {"provider": "resend", "service": "resend", "friendly_name": "retrieve_contact"},
    Action.RESEND_RETRIEVE_AUDIENCE: {"provider": "resend", "service": "resend", "friendly_name": "retrieve_audience"},
    Action.RESEND_LIST_BROADCASTS: {"provider": "resend", "service": "resend", "friendly_name": "list_broadcasts"},
    Action.RESEND_RETRIEVE_DOMAIN: {"provider": "resend", "service": "resend", "friendly_name": "retrieve_domain"},
    Action.RESEND_LIST_DOMAINS: {"provider": "resend", "service": "resend", "friendly_name": "list_domains"},
    Action.RESEND_RETRIEVE_EMAIL: {"provider": "resend", "service": "resend", "friendly_name": "retrieve_email"},
    Action.RESEND_CANCEL_EMAIL: {"provider": "resend", "service": "resend", "friendly_name": "cancel_email"},
    Action.RESEND_SEND_BROADCAST: {"provider": "resend", "service": "resend", "friendly_name": "send_broadcast"},
    Action.RESEND_CREATE_API_KEY: {"provider": "resend", "service": "resend", "friendly_name": "create_api_key_resend"},
    Action.RESEND_CREATE_AUDIENCE: {"provider": "resend", "service": "resend", "friendly_name": "create_audience"},
    Action.RESEND_CREATE_CONTACT: {"provider": "resend", "service": "resend", "friendly_name": "create_contact_resend"},
    Action.RESEND_CREATE_BROADCAST: {"provider": "resend", "service": "resend", "friendly_name": "create_broadcast"},
    Action.RESEND_CREATE_DOMAIN: {"provider": "resend", "service": "resend", "friendly_name": "create_domain"},
    Action.RESEND_VERIFY_DOMAIN: {"provider": "resend", "service": "resend", "friendly_name": "verify_domain"},
    Action.RESEND_SEND_BATCH_EMAILS: {"provider": "resend", "service": "resend", "friendly_name": "send_batch_emails"},
    Action.RESEND_SEND_EMAIL: {"provider": "resend", "service": "resend", "friendly_name": "send_email_resend"},
    Action.RESEND_DELETE_API_KEY: {"provider": "resend", "service": "resend", "friendly_name": "delete_api_key_resend"},
    Action.RESEND_DELETE_CONTACT: {"provider": "resend", "service": "resend", "friendly_name": "delete_contact_resend"},
    Action.RESEND_DELETE_BROADCAST: {"provider": "resend", "service": "resend", "friendly_name": "delete_broadcast"},
    Action.RESEND_DELETE_AUDIENCE: {"provider": "resend", "service": "resend", "friendly_name": "delete_audience"},
    Action.RESEND_DELETE_DOMAIN: {"provider": "resend", "service": "resend", "friendly_name": "delete_domain"},
    Action.RESEND_UPDATE_CONTACT: {"provider": "resend", "service": "resend", "friendly_name": "update_contact_resend"},
    Action.RESEND_UPDATE_EMAIL: {"provider": "resend", "service": "resend", "friendly_name": "update_email"},
    Action.RESEND_UPDATE_DOMAIN: {"provider": "resend", "service": "resend", "friendly_name": "update_domain"},

    # Scrapingdog actions
    Action.SCRAPINGDOG_SCRAPE_GOOGLE_VIDEOS_SEARCH_RESULTS: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "scrape_google_videos_search_results"},
    Action.SCRAPINGDOG_GET_AMAZON_AUTOCOMPLETE_SUGGESTIONS: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "get_amazon_autocomplete_suggestions"},
    Action.SCRAPINGDOG_GET_GOOGLE_NEWS_SEARCH_RESULTS: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "get_google_news_search_results"},
    Action.SCRAPINGDOG_GET_GOOGLE_MAPS_REVIEWS: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "get_google_maps_reviews"},
    Action.SCRAPINGDOG_RETRIEVE_INSTAGRAM_PROFILE_POSTS: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "retrieve_instagram_profile_posts"},
    Action.SCRAPINGDOG_SCRAPE_GOOGLE_IMAGES_RESULTS: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "scrape_google_images_results"},
    Action.SCRAPINGDOG_GET_GOOGLE_PATENT_DETAILS: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "get_google_patent_details"},
    Action.SCRAPINGDOG_SCRAPE_LINKEDIN_POST: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "scrape_linkedin_post"},
    Action.SCRAPINGDOG_GET_INSTAGRAM_PROFILE_INFORMATION: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "get_instagram_profile_information"},
    Action.SCRAPINGDOG_GET_GOOGLE_JOBS_SEARCH_RESULTS: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "get_google_jobs_search_results"},
    Action.SCRAPINGDOG_SCRAPE_GOOGLE_SCHOLAR_SEARCH_RESULTS: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "scrape_google_scholar_search_results"},
    Action.SCRAPINGDOG_SCRAPE_ZILLOW_SEARCH_RESULTS: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "scrape_zillow_search_results"},
    Action.SCRAPINGDOG_SCRAPE_GOOGLE_LOCAL_RESULTS: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "scrape_google_local_results"},
    Action.SCRAPINGDOG_GET_GOOGLE_PATENTS_SEARCH_RESULTS: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "get_google_patents_search_results"},
    Action.SCRAPINGDOG_SCRAPE_X_PROFILE_BY_PROFILE_ID: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "scrape_x_profile_by_profile_id"},
    Action.SCRAPINGDOG_SCRAPE_WEBPAGE: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "scrape_webpage"},
    Action.SCRAPINGDOG_SCRAPE_GOOGLE_FINANCE_DATA: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "scrape_google_finance_data"},
    Action.SCRAPINGDOG_GET_WALMART_PRODUCT_REVIEWS: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "get_walmart_product_reviews"},
    Action.SCRAPINGDOG_SCRAPE_WALMART_SEARCH_RESULTS: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "scrape_walmart_search_results"},
    Action.SCRAPINGDOG_SCRAPE_AMAZON_PRODUCT_REVIEWS: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "scrape_amazon_product_reviews"},
    Action.SCRAPINGDOG_GET_GOOGLE_SHOPPING_RESULTS: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "get_google_shopping_results"},
    Action.SCRAPINGDOG_GET_GOOGLE_MAPS_POSTS_FOR_LOCATION: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "get_google_maps_posts_for_location"},
    Action.SCRAPINGDOG_GET_GOOGLE_SCHOLAR_AUTHOR_DATA: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "get_google_scholar_author_data"},
    Action.SCRAPINGDOG_SCRAPE_LINKEDIN_COMPANY_PROFILE: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "scrape_linkedin_company_profile"},
    Action.SCRAPINGDOG_GET_GOOGLE_AUTOCOMPLETE_SUGGESTIONS: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "get_google_autocomplete_suggestions"},
    Action.SCRAPINGDOG_GET_GOOGLE_SCHOLAR_PROFILES: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "get_google_scholar_profiles"},
    Action.SCRAPINGDOG_SCRAPE_AMAZON_PRODUCT_DETAILS: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "scrape_amazon_product_details"},
    Action.SCRAPINGDOG_SCRAPE_LINKEDIN_JOB_OVERVIEW: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "scrape_linkedin_job_overview"},
    Action.SCRAPINGDOG_SCRAPE_LINKEDIN_JOBS: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "scrape_linkedin_jobs"},
    Action.SCRAPINGDOG_GET_GOOGLE_MAPS_PLACE_DETAILS: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "get_google_maps_place_details"},
    Action.SCRAPINGDOG_GET_YOUTUBE_CHANNEL_DATA: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "get_youtube_channel_data"},
    Action.SCRAPINGDOG_GET_GOOGLE_LENS_RESULTS: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "get_google_lens_results"},
    Action.SCRAPINGDOG_GET_ACCOUNT_USAGE_INFORMATION: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "get_account_usage_information"},
    Action.SCRAPINGDOG_GET_GOOGLE_SCHOLAR_AUTHOR_CITATION_DATA: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "get_google_scholar_author_citation_data"},
    Action.SCRAPINGDOG_TRIGGER_WEBHOOK_SCRAPING_REQUEST: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "trigger_webhook_scraping_request"},
    Action.SCRAPINGDOG_SCRAPE_WALMART_PRODUCT_DATA: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "scrape_walmart_product_data"},
    Action.SCRAPINGDOG_SCRAPE_AMAZON_SEARCH_RESULTS: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "scrape_amazon_search_results"},
    Action.SCRAPINGDOG_SCRAPE_GOOGLE_NEWS_RESULTS: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "scrape_google_news_results"},
    Action.SCRAPINGDOG_SCRAPE_BING_SEARCH_RESULTS: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "scrape_bing_search_results"},
    Action.SCRAPINGDOG_GET_GOOGLE_MAPS_PHOTOS: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "get_google_maps_photos"},
    Action.SCRAPINGDOG_GET_GOOGLE_PRODUCT_DETAILS: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "get_google_product_details"},
    Action.SCRAPINGDOG_FETCH_GOOGLE_AI_OVERVIEW_RESULTS: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "fetch_google_ai_overview_results"},
    Action.SCRAPINGDOG_SCRAPE_GOOGLE_SEARCH_RESULTS: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "scrape_google_search_results"},
    Action.SCRAPINGDOG_SCRAPE_PUBLIC_LINKEDIN_PERSON_PROFILE: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "scrape_public_linkedin_person_profile"},
    Action.SCRAPINGDOG_GET_YOUTUBE_VIDEO_TRANSCRIPTS: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "get_youtube_video_transcripts"},
    Action.SCRAPINGDOG_SCRAPE_GOOGLE_SHORTS_RESULTS: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "scrape_google_shorts_results"},
    Action.SCRAPINGDOG_SCRAPE_GOOGLE_MAPS_SEARCH_RESULTS: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "scrape_google_maps_search_results"},
    Action.SCRAPINGDOG_SEARCH_YOUTUBE_VIDEOS: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "search_youtube_videos"},
    Action.SCRAPINGDOG_GET_PARSED_INDEED_JOB_DATA: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "get_parsed_indeed_job_data"},
    Action.SCRAPINGDOG_SCRAPE_YOUTUBE_COMMENTS: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "scrape_youtube_comments"},
    Action.SCRAPINGDOG_GET_GOOGLE_TRENDS_DATA: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "get_google_trends_data"},
    Action.SCRAPINGDOG_GET_GOOGLE_TRENDS_AUTOCOMPLETE_SUGGESTIONS: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "get_google_trends_autocomplete_suggestions"},
    Action.SCRAPINGDOG_TAKE_SCREENSHOT_OF_WEBPAGE: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "take_screenshot_of_webpage"},
    Action.SCRAPINGDOG_GET_YELP_SEARCH_RESULTS: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "get_yelp_search_results"},
    Action.SCRAPINGDOG_SCRAPE_TWEET: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "scrape_tweet"},
    Action.SCRAPINGDOG_GET_GOOGLE_TRENDS_TRENDING_NOW_DATA: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "get_google_trends_trending_now_data"},
    Action.SCRAPINGDOG_POST_REQUEST_SCRAPE: {"provider": "scrapingdog", "service": "scrapingdog", "friendly_name": "post_request_scrape"},

    # Sendgrid actions
    Action.SENDGRID_SEND_EMAIL: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "send_email_sendgrid"},
    Action.SENDGRID_ADD_IP_TO_POOL: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "add_ip_to_pool"},
    Action.SENDGRID_RETRIEVE_ALL_LISTS: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "retrieve_all_lists"},
    Action.SENDGRID_ACTIVATE_TEMPLATE_VERSION: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "activate_template_version"},
    Action.SENDGRID_ADD_IP_TO_AUTHENTICATED_DOMAIN: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "add_ip_to_authenticated_domain"},
    Action.SENDGRID_ADD_BATCH_IPS_TO_POOL: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "add_batch_ips_to_pool"},
    Action.SENDGRID_ADD_RECIPIENT_TO_LIST: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "add_recipient_to_list"},
    Action.SENDGRID_ADD_SENDGRID_IP: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "add_sendgrid_ip"},
    Action.SENDGRID_ADD_IPS_TO_ACCOUNT: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "add_ips_to_account"},
    Action.SENDGRID_ADD_IPS_TO_ALLOWLIST: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "add_ips_to_allowlist"},
    Action.SENDGRID_ADD_OR_UPDATE_CONTACT: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "add_or_update_contact"},
    Action.SENDGRID_ADD_GLOBAL_SUPPRESSIONS: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "add_global_suppressions"},
    Action.SENDGRID_ADD_SUPPRESSIONS_TO_GROUP: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "add_suppressions_to_group"},
    Action.SENDGRID_APPROVE_ACCESS_REQUEST: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "approve_access_request"},
    Action.SENDGRID_ASSIGN_SUBUSERS_TO_IP: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "assign_subusers_to_ip"},
    Action.SENDGRID_ASSOCIATE_DOMAIN_WITH_SUBUSER: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "associate_domain_with_subuser"},
    Action.SENDGRID_ASSOCIATE_BRANDED_LINK_WITH_SUBUSER: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "associate_branded_link_with_subuser"},
    Action.SENDGRID_SSO_AUTHENTICATE: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "sso_authenticate"},
    Action.SENDGRID_AUTHENTICATE_DOMAIN: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "authenticate_domain"},
    Action.SENDGRID_BIND_DOMAINS_TO_SUBUSER: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "bind_domains_to_subuser"},
    Action.SENDGRID_BULK_DELETE_SINGLE_SENDS: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "bulk_delete_single_sends"},
    Action.SENDGRID_CANCEL_SCHEDULED_SEND: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "cancel_scheduled_send"},
    Action.SENDGRID_GET_COMPLETED_STEPS: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "get_completed_steps"},
    Action.SENDGRID_CREATE_ACCOUNT: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "create_account"},
    Action.SENDGRID_CREATE_IP_POOL: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "create_ip_pool"},
    Action.SENDGRID_CREATE_IP_POOL_WITH_ASSIGNMENTS: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "create_ip_pool_with_assignments"},
    Action.SENDGRID_CREATE_SSO_CERTIFICATE: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "create_sso_certificate"},
    Action.SENDGRID_CREATE_SSO_INTEGRATION: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "create_sso_integration"},
    Action.SENDGRID_CREATE_SSO_TEAMMATE: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "create_sso_teammate"},
    Action.SENDGRID_CREATE_API_KEY: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "create_api_key_sendgrid"},
    Action.SENDGRID_CREATE_BATCH_ID: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "create_batch_id"},
    Action.SENDGRID_CREATE_BRANDED_LINK: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "create_branded_link"},
    Action.SENDGRID_CREATE_CAMPAIGN: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "create_campaign"},
    Action.SENDGRID_CREATE_CUSTOM_FIELD: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "create_custom_field"},
    Action.SENDGRID_CREATE_LIST: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "create_list"},
    Action.SENDGRID_CREATE_ALERT: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "create_alert"},
    Action.SENDGRID_CREATE_EVENT_WEBHOOK: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "create_event_webhook"},
    Action.SENDGRID_CREATE_SUPPRESSION_GROUP: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "create_suppression_group"},
    Action.SENDGRID_CREATE_TEMPLATE_VERSION: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "create_template_version"},
    Action.SENDGRID_CREATE_PARSE_SETTING: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "create_parse_setting"},
    Action.SENDGRID_CREATE_SEGMENT: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "create_segment"},
    Action.SENDGRID_CREATE_SENDER: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "create_sender"},
    Action.SENDGRID_CREATE_SENDER_IDENTITY: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "create_sender_identity"},
    Action.SENDGRID_CREATE_TRANSACTIONAL_TEMPLATE: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "create_transactional_template"},
    Action.SENDGRID_CREATE_CUSTOM_FIELD_DEFINITION: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "create_custom_field_definition"},
    Action.SENDGRID_CREATE_DESIGN: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "create_design_sendgrid"},
    Action.SENDGRID_CREATE_INTEGRATION: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "create_integration"},
    Action.SENDGRID_CREATE_CONTACTS_LIST: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "create_contacts_list"},
    Action.SENDGRID_CREATE_CONTACTS_SEGMENT: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "create_contacts_segment"},
    Action.SENDGRID_CREATE_SINGLE_SEND: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "create_single_send"},
    Action.SENDGRID_CREATE_SUBUSER: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "create_subuser"},
    Action.SENDGRID_CREATE_VERIFIED_SENDER_REQUEST: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "create_verified_sender_request"},
    Action.SENDGRID_DELETE_ACCOUNT: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "delete_account"},
    Action.SENDGRID_DELETE_ALERT: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "delete_alert"},
    Action.SENDGRID_DELETE_AUTHENTICATED_DOMAIN: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "delete_authenticated_domain"},
    Action.SENDGRID_DELETE_IP_POOL: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "delete_ip_pool"},
    Action.SENDGRID_DELETE_SSO_CERTIFICATE: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "delete_sso_certificate"},
    Action.SENDGRID_DELETE_SSO_INTEGRATION: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "delete_sso_integration"},
    Action.SENDGRID_DELETE_API_KEY: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "delete_api_key_sendgrid"},
    Action.SENDGRID_DELETE_BATCH_IPS_FROM_POOL: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "delete_batch_ips_from_pool"},
    Action.SENDGRID_DELETE_BATCH_SUBUSERS_FROM_IP: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "delete_batch_subusers_from_ip"},
    Action.SENDGRID_DELETE_BOUNCE: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "delete_bounce"},
    Action.SENDGRID_DELETE_BRANDED_LINK: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "delete_branded_link"},
    Action.SENDGRID_DELETE_CAMPAIGN: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "delete_campaign"},
    Action.SENDGRID_DELETE_SCHEDULED_SEND_CANCELLATION: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "delete_scheduled_send_cancellation"},
    Action.SENDGRID_DELETE_CONTACT_IDENTIFIER: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "delete_contact_identifier"},
    Action.SENDGRID_DELETE_CUSTOM_FIELD: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "delete_custom_field"},
    Action.SENDGRID_DELETE_DESIGN: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "delete_design"},
    Action.SENDGRID_DELETE_INVALID_EMAILS: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "delete_invalid_emails"},
    Action.SENDGRID_DELETE_PENDING_TEAMMATE: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "delete_pending_teammate"},
    Action.SENDGRID_DELETE_SEGMENT: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "delete_segment"},
    Action.SENDGRID_DELETE_SINGLE_SEND: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "delete_single_send"},
    Action.SENDGRID_DELETE_SINGLE_SEND_SCHEDULE: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "delete_single_send_schedule"},
    Action.SENDGRID_DELETE_SPAM_REPORTS: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "delete_spam_reports"},
    Action.SENDGRID_DELETE_TEAMMATE: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "delete_teammate"},
    Action.SENDGRID_DELETE_VERIFIED_SENDER: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "delete_verified_sender"},
    Action.SENDGRID_GET_ALL_CATEGORIES: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "get_all_categories"},
    Action.SENDGRID_GET_ALL_FIELD_DEFINITIONS: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "get_all_field_definitions"},
    Action.SENDGRID_GET_ALL_LISTS: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "get_all_lists"},
    Action.SENDGRID_GET_ALL_SINGLE_SENDS: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "get_all_single_sends"},
    Action.SENDGRID_GET_ALL_SINGLE_SENDS_STATS: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "get_all_single_sends_stats"},
    Action.SENDGRID_GET_ALL_VERIFIED_SENDERS: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "get_all_verified_senders"},
    Action.SENDGRID_GET_CONTACT_BY_ID: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "get_contact_by_id_sendgrid"},
    Action.SENDGRID_GET_LIST_BY_ID: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "get_list_by_id"},
    Action.SENDGRID_GET_CONTACTS_BY_EMAILS: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "get_contacts_by_emails"},
    Action.SENDGRID_GET_BATCHED_CONTACTS_BY_IDS: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "get_batched_contacts_by_ids"},
    Action.SENDGRID_EXPORT_CONTACTS: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "export_contacts"},
    Action.SENDGRID_EXPORT_CONTACTS_STATUS: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "export_contacts_status"},
    Action.SENDGRID_DUPLICATE_DESIGN: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "duplicate_design"},
    Action.SENDGRID_DUPLICATE_SINGLE_SEND: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "duplicate_single_send"},
    Action.SENDGRID_GET_AUTOMATION_STATS_BY_ID: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "get_automation_stats_by_id"},
    Action.SENDGRID_GET_ALL_AUTOMATION_STATS: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "get_all_automation_stats"},
    Action.SENDGRID_FILTER_MESSAGES_BY_MESSAGE_ID: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "filter_messages_by_message_id"},
    Action.SENDGRID_GET_USER_PROFILE: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "get_user_profile_sendgrid"},
    Action.SENDGRID_GET_USER_ACCOUNT_INFORMATION: {"provider": "sendgrid", "service": "sendgrid", "friendly_name": "get_user_account_information"},

    # Spotify actions
    Action.SPOTIFY_SAVE_AUDIOBOOKS_FOR_CURRENT_USER: {"provider": "spotify", "service": "spotify", "friendly_name": "save_audiobooks_for_current_user"},
    Action.SPOTIFY_SAVE_EPISODES_FOR_CURRENT_USER: {"provider": "spotify", "service": "spotify", "friendly_name": "save_episodes_for_current_user"},
    Action.SPOTIFY_SAVE_SHOWS_FOR_CURRENT_USER: {"provider": "spotify", "service": "spotify", "friendly_name": "save_shows_for_current_user"},
    Action.SPOTIFY_SEARCH_FOR_ITEM: {"provider": "spotify", "service": "spotify", "friendly_name": "search_for_item"},
    Action.SPOTIFY_SEEK_TO_POSITION: {"provider": "spotify", "service": "spotify", "friendly_name": "seek_to_position"},
    Action.SPOTIFY_SET_PLAYBACK_VOLUME: {"provider": "spotify", "service": "spotify", "friendly_name": "set_playback_volume"},
    Action.SPOTIFY_SET_REPEAT_MODE: {"provider": "spotify", "service": "spotify", "friendly_name": "set_repeat_mode"},
    Action.SPOTIFY_SKIP_TO_NEXT: {"provider": "spotify", "service": "spotify", "friendly_name": "skip_to_next"},
    Action.SPOTIFY_SKIP_TO_PREVIOUS: {"provider": "spotify", "service": "spotify", "friendly_name": "skip_to_previous"},
    Action.SPOTIFY_START_RESUME_PLAYBACK: {"provider": "spotify", "service": "spotify", "friendly_name": "start_resume_playback"},
    Action.SPOTIFY_TOGGLE_PLAYBACK_SHUFFLE: {"provider": "spotify", "service": "spotify", "friendly_name": "toggle_playback_shuffle"},
    Action.SPOTIFY_TRANSFER_PLAYBACK: {"provider": "spotify", "service": "spotify", "friendly_name": "transfer_playback"},
    Action.SPOTIFY_UNFOLLOW_ARTISTS_OR_USERS: {"provider": "spotify", "service": "spotify", "friendly_name": "unfollow_artists_or_users"},
    Action.SPOTIFY_UNFOLLOW_PLAYLIST: {"provider": "spotify", "service": "spotify", "friendly_name": "unfollow_playlist"},
    Action.SPOTIFY_UPDATE_PLAYLIST_ITEMS: {"provider": "spotify", "service": "spotify", "friendly_name": "update_playlist_items"},
    Action.SPOTIFY_GET_PLAYLIST_ITEMS: {"provider": "spotify", "service": "spotify", "friendly_name": "get_playlist_items"},
    Action.SPOTIFY_GET_USER_QUEUE: {"provider": "spotify", "service": "spotify", "friendly_name": "get_user_queue"},
    Action.SPOTIFY_GET_RECENTLY_PLAYED_TRACKS: {"provider": "spotify", "service": "spotify", "friendly_name": "get_recently_played_tracks"},
    Action.SPOTIFY_GET_RECOMMENDATIONS: {"provider": "spotify", "service": "spotify", "friendly_name": "get_recommendations"},
    Action.SPOTIFY_GET_SEVERAL_ALBUMS: {"provider": "spotify", "service": "spotify", "friendly_name": "get_several_albums"},
    Action.SPOTIFY_GET_SEVERAL_ARTISTS: {"provider": "spotify", "service": "spotify", "friendly_name": "get_several_artists"},
    Action.SPOTIFY_GET_SEVERAL_AUDIOBOOKS: {"provider": "spotify", "service": "spotify", "friendly_name": "get_several_audiobooks"},
    Action.SPOTIFY_GET_SEVERAL_BROWSE_CATEGORIES: {"provider": "spotify", "service": "spotify", "friendly_name": "get_several_browse_categories"},
    Action.SPOTIFY_GET_SEVERAL_CHAPTERS: {"provider": "spotify", "service": "spotify", "friendly_name": "get_several_chapters"},
    Action.SPOTIFY_GET_SEVERAL_EPISODES: {"provider": "spotify", "service": "spotify", "friendly_name": "get_several_episodes"},
    Action.SPOTIFY_GET_SEVERAL_SHOWS: {"provider": "spotify", "service": "spotify", "friendly_name": "get_several_shows"},
    Action.SPOTIFY_GET_SEVERAL_TRACKS: {"provider": "spotify", "service": "spotify", "friendly_name": "get_several_tracks"},
    Action.SPOTIFY_GET_SEVERAL_TRACKS_AUDIO_FEATURES: {"provider": "spotify", "service": "spotify", "friendly_name": "get_several_tracks_audio_features"},
    Action.SPOTIFY_GET_SINGLE_BROWSE_CATEGORY: {"provider": "spotify", "service": "spotify", "friendly_name": "get_single_browse_category"},
    Action.SPOTIFY_GET_TRACK: {"provider": "spotify", "service": "spotify", "friendly_name": "get_track"},
    Action.SPOTIFY_GET_TRACK_AUDIO_ANALYSIS: {"provider": "spotify", "service": "spotify", "friendly_name": "get_track_audio_analysis"},
    Action.SPOTIFY_GET_TRACK_AUDIO_FEATURES: {"provider": "spotify", "service": "spotify", "friendly_name": "get_track_audio_features"},
    Action.SPOTIFY_GET_USER_PROFILE: {"provider": "spotify", "service": "spotify", "friendly_name": "get_user_profile_spotify"},
    Action.SPOTIFY_GET_USER_SAVED_ALBUMS: {"provider": "spotify", "service": "spotify", "friendly_name": "get_user_saved_albums"},
    Action.SPOTIFY_GET_USER_SAVED_AUDIOBOOKS: {"provider": "spotify", "service": "spotify", "friendly_name": "get_user_saved_audiobooks"},
    Action.SPOTIFY_GET_USER_SAVED_EPISODES: {"provider": "spotify", "service": "spotify", "friendly_name": "get_user_saved_episodes"},
    Action.SPOTIFY_GET_USER_SAVED_SHOWS: {"provider": "spotify", "service": "spotify", "friendly_name": "get_user_saved_shows"},
    Action.SPOTIFY_GET_USER_SAVED_TRACKS: {"provider": "spotify", "service": "spotify", "friendly_name": "get_user_saved_tracks"},
    Action.SPOTIFY_GET_USER_TOP_ARTISTS: {"provider": "spotify", "service": "spotify", "friendly_name": "get_user_top_artists"},
    Action.SPOTIFY_GET_USER_TOP_TRACKS: {"provider": "spotify", "service": "spotify", "friendly_name": "get_user_top_tracks"},
    Action.SPOTIFY_PAUSE_PLAYBACK: {"provider": "spotify", "service": "spotify", "friendly_name": "pause_playback"},
    Action.SPOTIFY_REMOVE_PLAYLIST_ITEMS: {"provider": "spotify", "service": "spotify", "friendly_name": "remove_playlist_items"},
    Action.SPOTIFY_REMOVE_USER_SAVED_ALBUMS: {"provider": "spotify", "service": "spotify", "friendly_name": "remove_user_saved_albums"},
    Action.SPOTIFY_REMOVE_USER_SAVED_AUDIOBOOKS: {"provider": "spotify", "service": "spotify", "friendly_name": "remove_user_saved_audiobooks"},
    Action.SPOTIFY_REMOVE_USER_SAVED_EPISODES: {"provider": "spotify", "service": "spotify", "friendly_name": "remove_user_saved_episodes"},
    Action.SPOTIFY_REMOVE_USER_SAVED_SHOWS: {"provider": "spotify", "service": "spotify", "friendly_name": "remove_user_saved_shows"},
    Action.SPOTIFY_ADD_ITEMS_TO_PLAYLIST: {"provider": "spotify", "service": "spotify", "friendly_name": "add_items_to_playlist"},
    Action.SPOTIFY_CREATE_PLAYLIST: {"provider": "spotify", "service": "spotify", "friendly_name": "create_playlist"},
    Action.SPOTIFY_GET_ARTIST_TOP_TRACKS: {"provider": "spotify", "service": "spotify", "friendly_name": "get_artist_top_tracks"},
    Action.SPOTIFY_GET_PLAYLIST: {"provider": "spotify", "service": "spotify", "friendly_name": "get_playlist"},
    Action.SPOTIFY_GET_SHOW: {"provider": "spotify", "service": "spotify", "friendly_name": "get_show"},
    Action.SPOTIFY_GET_SHOW_EPISODES: {"provider": "spotify", "service": "spotify", "friendly_name": "get_show_episodes"},
    Action.SPOTIFY_SAVE_ALBUMS_FOR_CURRENT_USER: {"provider": "spotify", "service": "spotify", "friendly_name": "save_albums_for_current_user"},
    Action.SPOTIFY_SAVE_TRACKS_FOR_CURRENT_USER: {"provider": "spotify", "service": "spotify", "friendly_name": "save_tracks_for_current_user"},
    Action.SPOTIFY_ADD_ITEM_TO_PLAYBACK_QUEUE: {"provider": "spotify", "service": "spotify", "friendly_name": "add_item_to_playback_queue"},
    Action.SPOTIFY_CHANGE_PLAYLIST_DETAILS: {"provider": "spotify", "service": "spotify", "friendly_name": "change_playlist_details"},
    Action.SPOTIFY_CHECK_IF_USERS_FOLLOW_PLAYLIST: {"provider": "spotify", "service": "spotify", "friendly_name": "check_if_users_follow_playlist"},
    Action.SPOTIFY_CHECK_IF_USER_FOLLOWS_ARTISTS_OR_USERS: {"provider": "spotify", "service": "spotify", "friendly_name": "check_if_user_follows_artists_or_users"},
    Action.SPOTIFY_CHECK_USER_SAVED_ALBUMS: {"provider": "spotify", "service": "spotify", "friendly_name": "check_user_saved_albums"},
    Action.SPOTIFY_CHECK_USER_SAVED_AUDIOBOOKS: {"provider": "spotify", "service": "spotify", "friendly_name": "check_user_saved_audiobooks"},
    Action.SPOTIFY_CHECK_USER_SAVED_EPISODES: {"provider": "spotify", "service": "spotify", "friendly_name": "check_user_saved_episodes"},
    Action.SPOTIFY_CHECK_USER_SAVED_SHOWS: {"provider": "spotify", "service": "spotify", "friendly_name": "check_user_saved_shows"},
    Action.SPOTIFY_CHECK_USER_SAVED_TRACKS: {"provider": "spotify", "service": "spotify", "friendly_name": "check_user_saved_tracks"},
    Action.SPOTIFY_FOLLOW_ARTISTS_OR_USERS: {"provider": "spotify", "service": "spotify", "friendly_name": "follow_artists_or_users"},
    Action.SPOTIFY_FOLLOW_PLAYLIST: {"provider": "spotify", "service": "spotify", "friendly_name": "follow_playlist"},
    Action.SPOTIFY_GET_ALBUM: {"provider": "spotify", "service": "spotify", "friendly_name": "get_album"},
    Action.SPOTIFY_GET_ALBUM_TRACKS: {"provider": "spotify", "service": "spotify", "friendly_name": "get_album_tracks"},
    Action.SPOTIFY_GET_ARTIST: {"provider": "spotify", "service": "spotify", "friendly_name": "get_artist"},
    Action.SPOTIFY_GET_ARTIST_ALBUMS: {"provider": "spotify", "service": "spotify", "friendly_name": "get_artist_albums"},
    Action.SPOTIFY_GET_AUDIOBOOK: {"provider": "spotify", "service": "spotify", "friendly_name": "get_audiobook"},
    Action.SPOTIFY_GET_ARTIST_RELATED_ARTISTS: {"provider": "spotify", "service": "spotify", "friendly_name": "get_artist_related_artists"},
    Action.SPOTIFY_GET_AUDIOBOOK_CHAPTERS: {"provider": "spotify", "service": "spotify", "friendly_name": "get_audiobook_chapters"},
    Action.SPOTIFY_GET_AVAILABLE_DEVICES: {"provider": "spotify", "service": "spotify", "friendly_name": "get_available_devices"},
    Action.SPOTIFY_GET_AVAILABLE_GENRE_SEEDS: {"provider": "spotify", "service": "spotify", "friendly_name": "get_available_genre_seeds"},
    Action.SPOTIFY_GET_AVAILABLE_MARKETS: {"provider": "spotify", "service": "spotify", "friendly_name": "get_available_markets"},
    Action.SPOTIFY_GET_CHAPTER: {"provider": "spotify", "service": "spotify", "friendly_name": "get_chapter"},
    Action.SPOTIFY_GET_CURRENT_USER_PLAYLISTS: {"provider": "spotify", "service": "spotify", "friendly_name": "get_current_user_playlists"},
    Action.SPOTIFY_GET_CATEGORY_PLAYLISTS: {"provider": "spotify", "service": "spotify", "friendly_name": "get_category_playlists"},
    Action.SPOTIFY_GET_CURRENTLY_PLAYING_TRACK: {"provider": "spotify", "service": "spotify", "friendly_name": "get_currently_playing_track"},
    Action.SPOTIFY_GET_CURRENT_USER_PROFILE: {"provider": "spotify", "service": "spotify", "friendly_name": "get_current_user_profile"},
    Action.SPOTIFY_GET_EPISODE: {"provider": "spotify", "service": "spotify", "friendly_name": "get_episode"},
    Action.SPOTIFY_GET_FEATURED_PLAYLISTS: {"provider": "spotify", "service": "spotify", "friendly_name": "get_featured_playlists"},
    Action.SPOTIFY_GET_FOLLOWED_ARTISTS: {"provider": "spotify", "service": "spotify", "friendly_name": "get_followed_artists"},
    Action.SPOTIFY_GET_PLAYBACK_STATE: {"provider": "spotify", "service": "spotify", "friendly_name": "get_playback_state"},
    Action.SPOTIFY_GET_USER_PLAYLISTS: {"provider": "spotify", "service": "spotify", "friendly_name": "get_user_playlists"},
    Action.SPOTIFY_GET_NEW_RELEASES: {"provider": "spotify", "service": "spotify", "friendly_name": "get_new_releases"},

    # Stripe actions
    Action.STRIPE_CANCEL_SUBSCRIPTION: {"provider": "stripe", "service": "stripe", "friendly_name": "cancel_subscription"},
    Action.STRIPE_CREATE_CUSTOMER: {"provider": "stripe", "service": "stripe", "friendly_name": "create_customer"},
    Action.STRIPE_CREATE_INVOICE: {"provider": "stripe", "service": "stripe", "friendly_name": "create_invoice"},
    Action.STRIPE_CREATE_PAYMENT_INTENT: {"provider": "stripe", "service": "stripe", "friendly_name": "create_payment_intent"},
    Action.STRIPE_CREATE_PRICE: {"provider": "stripe", "service": "stripe", "friendly_name": "create_price"},
    Action.STRIPE_CREATE_PRODUCT: {"provider": "stripe", "service": "stripe", "friendly_name": "create_product"},
    Action.STRIPE_CREATE_REFUND: {"provider": "stripe", "service": "stripe", "friendly_name": "create_refund"},
    Action.STRIPE_CREATE_SUBSCRIPTION: {"provider": "stripe", "service": "stripe", "friendly_name": "create_subscription"},
    Action.STRIPE_DELETE_CUSTOMER: {"provider": "stripe", "service": "stripe", "friendly_name": "delete_customer"},
    Action.STRIPE_LIST_CUSTOMER_PAYMENT_METHODS: {"provider": "stripe", "service": "stripe", "friendly_name": "list_customer_payment_methods"},
    Action.STRIPE_LIST_PAYMENT_LINKS: {"provider": "stripe", "service": "stripe", "friendly_name": "list_payment_links"},
    Action.STRIPE_LIST_REFUNDS: {"provider": "stripe", "service": "stripe", "friendly_name": "list_refunds"},
    Action.STRIPE_LIST_SHIPPING_RATES: {"provider": "stripe", "service": "stripe", "friendly_name": "list_shipping_rates"},
    Action.STRIPE_LIST_TAX_RATES: {"provider": "stripe", "service": "stripe", "friendly_name": "list_tax_rates"},
    Action.STRIPE_RETRIEVE_CHARGE_DETAILS: {"provider": "stripe", "service": "stripe", "friendly_name": "retrieve_charge_details"},
    Action.STRIPE_RETRIEVE_PAYMENT_INTENT: {"provider": "stripe", "service": "stripe", "friendly_name": "retrieve_payment_intent"},
    Action.STRIPE_RETRIEVE_REFUND: {"provider": "stripe", "service": "stripe", "friendly_name": "retrieve_refund"},
    Action.STRIPE_SEARCH_CUSTOMERS: {"provider": "stripe", "service": "stripe", "friendly_name": "search_customers"},
    Action.STRIPE_UPDATE_PAYMENT_INTENT: {"provider": "stripe", "service": "stripe", "friendly_name": "update_payment_intent"},
    Action.STRIPE_UPDATE_SUBSCRIPTION: {"provider": "stripe", "service": "stripe", "friendly_name": "update_subscription"},
    Action.STRIPE_CONFIRM_PAYMENT_INTENT: {"provider": "stripe", "service": "stripe", "friendly_name": "confirm_payment_intent"},
    Action.STRIPE_LIST_CHARGES: {"provider": "stripe", "service": "stripe", "friendly_name": "list_charges"},
    Action.STRIPE_LIST_COUPONS: {"provider": "stripe", "service": "stripe", "friendly_name": "list_coupons"},
    Action.STRIPE_LIST_CUSTOMERS: {"provider": "stripe", "service": "stripe", "friendly_name": "list_customers"},
    Action.STRIPE_LIST_INVOICES: {"provider": "stripe", "service": "stripe", "friendly_name": "list_invoices"},
    Action.STRIPE_LIST_PAYMENT_INTENTS: {"provider": "stripe", "service": "stripe", "friendly_name": "list_payment_intents"},
    Action.STRIPE_LIST_PRODUCTS: {"provider": "stripe", "service": "stripe", "friendly_name": "list_products"},
    Action.STRIPE_LIST_SUBSCRIPTIONS: {"provider": "stripe", "service": "stripe", "friendly_name": "list_subscriptions"},
    Action.STRIPE_LIST_TAX_CODES: {"provider": "stripe", "service": "stripe", "friendly_name": "list_tax_codes"},
    Action.STRIPE_RETRIEVE_BALANCE: {"provider": "stripe", "service": "stripe", "friendly_name": "retrieve_balance"},
    Action.STRIPE_RETRIEVE_CUSTOMER: {"provider": "stripe", "service": "stripe", "friendly_name": "retrieve_customer"},
    Action.STRIPE_RETRIEVE_SUBSCRIPTION: {"provider": "stripe", "service": "stripe", "friendly_name": "retrieve_subscription"},
    Action.STRIPE_UPDATE_CUSTOMER: {"provider": "stripe", "service": "stripe", "friendly_name": "update_customer"},

    # Supabase actions
    Action.SUPABASE_EXECUTE_PROJECT_DATABASE_QUERY: {"provider": "supabase", "service": "supabase", "friendly_name": "execute_project_database_query"},
    Action.SUPABASE_CREATE_ORGANIZATION: {"provider": "supabase", "service": "supabase", "friendly_name": "create_organization_supabase"},
    Action.SUPABASE_CREATE_NEW_PROJECT: {"provider": "supabase", "service": "supabase", "friendly_name": "create_new_project"},
    Action.SUPABASE_LIST_ALL_ORGANIZATIONS: {"provider": "supabase", "service": "supabase", "friendly_name": "list_all_organizations"},
    Action.SUPABASE_LIST_ALL_PROJECTS: {"provider": "supabase", "service": "supabase", "friendly_name": "list_all_projects"},
    Action.SUPABASE_CREATE_PROJECT_API_KEY: {"provider": "supabase", "service": "supabase", "friendly_name": "create_project_api_key"},
    Action.SUPABASE_DELETE_API_KEY: {"provider": "supabase", "service": "supabase", "friendly_name": "delete_api_key_supabase"},
    Action.SUPABASE_GET_THIRD_PARTY_INTEGRATION: {"provider": "supabase", "service": "supabase", "friendly_name": "get_third_party_integration"},
    Action.SUPABASE_LIST_THIRD_PARTY_AUTH_INTEGRATIONS: {"provider": "supabase", "service": "supabase", "friendly_name": "list_third_party_auth_integrations"},
    Action.SUPABASE_DELETE_THIRD_PARTY_AUTH_CONFIG: {"provider": "supabase", "service": "supabase", "friendly_name": "delete_third_party_auth_config"},
    Action.SUPABASE_UPDATE_API_KEY: {"provider": "supabase", "service": "supabase", "friendly_name": "update_api_key_supabase"},
    Action.SUPABASE_ACTIVATE_CUSTOM_HOSTNAME: {"provider": "supabase", "service": "supabase", "friendly_name": "activate_custom_hostname"},
    Action.SUPABASE_ACTIVATE_VANITY_SUBDOMAIN: {"provider": "supabase", "service": "supabase", "friendly_name": "activate_vanity_subdomain"},
    Action.SUPABASE_AUTHORIZE_USER_OAUTH: {"provider": "supabase", "service": "supabase", "friendly_name": "authorize_user_oauth"},
    Action.SUPABASE_CHECK_VANITY_SUBDOMAIN_AVAILABILITY: {"provider": "supabase", "service": "supabase", "friendly_name": "check_vanity_subdomain_availability"},
    Action.SUPABASE_ENABLE_DATABASE_WEBHOOKS: {"provider": "supabase", "service": "supabase", "friendly_name": "enable_database_webhooks"},
    Action.SUPABASE_GET_VANITY_SUBDOMAIN_CONFIG: {"provider": "supabase", "service": "supabase", "friendly_name": "get_vanity_subdomain_config"},
    Action.SUPABASE_GET_CUSTOM_HOSTNAME_CONFIG: {"provider": "supabase", "service": "supabase", "friendly_name": "get_custom_hostname_config"},
    Action.SUPABASE_RETRIEVE_NETWORK_BANS: {"provider": "supabase", "service": "supabase", "friendly_name": "retrieve_network_bans"},
    Action.SUPABASE_RETRIEVE_NETWORK_RESTRICTIONS: {"provider": "supabase", "service": "supabase", "friendly_name": "retrieve_network_restrictions"},
    Action.SUPABASE_GET_PGSODIUM_CONFIG: {"provider": "supabase", "service": "supabase", "friendly_name": "get_pgsodium_config"},
    Action.SUPABASE_GET_SSL_ENFORCEMENT_CONFIG: {"provider": "supabase", "service": "supabase", "friendly_name": "get_ssl_enforcement_config"},
    Action.SUPABASE_REMOVE_READ_REPLICA: {"provider": "supabase", "service": "supabase", "friendly_name": "remove_read_replica"},
    Action.SUPABASE_REMOVE_NETWORK_BANS: {"provider": "supabase", "service": "supabase", "friendly_name": "remove_network_bans"},
    Action.SUPABASE_SETUP_READ_REPLICA: {"provider": "supabase", "service": "supabase", "friendly_name": "setup_read_replica"},
    Action.SUPABASE_UPDATE_NETWORK_RESTRICTIONS: {"provider": "supabase", "service": "supabase", "friendly_name": "update_network_restrictions"},
    Action.SUPABASE_UPGRADE_POSTGRESQL_VERSION: {"provider": "supabase", "service": "supabase", "friendly_name": "upgrade_postgresql_version"},
    Action.SUPABASE_UPDATE_PGSODIUM_ROOT_KEY: {"provider": "supabase", "service": "supabase", "friendly_name": "update_pgsodium_root_key"},
    Action.SUPABASE_CREATE_SSO_PROVIDER: {"provider": "supabase", "service": "supabase", "friendly_name": "create_sso_provider"},
    Action.SUPABASE_CREATE_THIRD_PARTY_AUTH: {"provider": "supabase", "service": "supabase", "friendly_name": "create_third_party_auth"},
    Action.SUPABASE_CREATE_DATABASE_BRANCH: {"provider": "supabase", "service": "supabase", "friendly_name": "create_database_branch"},
    Action.SUPABASE_CREATE_EDGE_FUNCTION: {"provider": "supabase", "service": "supabase", "friendly_name": "create_edge_function"},
    Action.SUPABASE_REVERIFY_CUSTOM_HOSTNAME: {"provider": "supabase", "service": "supabase", "friendly_name": "reverify_custom_hostname"},
    Action.SUPABASE_DELETE_PROJECT: {"provider": "supabase", "service": "supabase", "friendly_name": "delete_project_supabase"},
    Action.SUPABASE_DELETE_DATABASE_BRANCH: {"provider": "supabase", "service": "supabase", "friendly_name": "delete_database_branch"},
    Action.SUPABASE_DELETE_EDGE_FUNCTION: {"provider": "supabase", "service": "supabase", "friendly_name": "delete_edge_function"},
    Action.SUPABASE_DELETE_CUSTOM_HOSTNAME: {"provider": "supabase", "service": "supabase", "friendly_name": "delete_custom_hostname"},
    Action.SUPABASE_DELETE_VANITY_SUBDOMAIN: {"provider": "supabase", "service": "supabase", "friendly_name": "delete_vanity_subdomain"},
    Action.SUPABASE_DEPLOY_EDGE_FUNCTION: {"provider": "supabase", "service": "supabase", "friendly_name": "deploy_edge_function_supabase"},
    Action.SUPABASE_DISABLE_PREVIEW_BRANCHING: {"provider": "supabase", "service": "supabase", "friendly_name": "disable_preview_branching"},
    Action.SUPABASE_DISABLE_READONLY_MODE: {"provider": "supabase", "service": "supabase", "friendly_name": "disable_readonly_mode"},
    Action.SUPABASE_EXCHANGE_AUTH_CODE: {"provider": "supabase", "service": "supabase", "friendly_name": "exchange_auth_code"},
    Action.SUPABASE_GENERATE_TYPESCRIPT_TYPES: {"provider": "supabase", "service": "supabase", "friendly_name": "generate_typescript_types"},
    Action.SUPABASE_GET_SQL_SNIPPET: {"provider": "supabase", "service": "supabase", "friendly_name": "get_sql_snippet"},
    Action.SUPABASE_GET_SSO_PROVIDER_BY_UUID: {"provider": "supabase", "service": "supabase", "friendly_name": "get_sso_provider_by_uuid"},
    Action.SUPABASE_GET_ORGANIZATION_INFO: {"provider": "supabase", "service": "supabase", "friendly_name": "get_organization_info"},
    Action.SUPABASE_GET_PROJECT_AUTH_CONFIG: {"provider": "supabase", "service": "supabase", "friendly_name": "get_project_auth_config"},
    Action.SUPABASE_GET_PROJECT_POSTGREST_CONFIG: {"provider": "supabase", "service": "supabase", "friendly_name": "get_project_postgrest_config"},
    Action.SUPABASE_GET_PROJECT_POSTGRES_CONFIG: {"provider": "supabase", "service": "supabase", "friendly_name": "get_project_postgres_config"},
    Action.SUPABASE_GET_PROJECT_SERVICE_HEALTH_STATUS: {"provider": "supabase", "service": "supabase", "friendly_name": "get_project_service_health_status"},
    Action.SUPABASE_GET_PROJECT_SUPAVISOR_CONFIGURATION: {"provider": "supabase", "service": "supabase", "friendly_name": "get_project_supavisor_configuration"},
    Action.SUPABASE_GET_DATABASE_BRANCH_CONFIG: {"provider": "supabase", "service": "supabase", "friendly_name": "get_database_branch_config"},
    Action.SUPABASE_GET_PROJECT_API_KEYS: {"provider": "supabase", "service": "supabase", "friendly_name": "get_project_api_keys"},
    Action.SUPABASE_GET_PROJECT_PGBOUNCER_CONFIG: {"provider": "supabase", "service": "supabase", "friendly_name": "get_project_pgbouncer_config"},
    Action.SUPABASE_GET_PROJECT_UPGRADE_ELIGIBILITY: {"provider": "supabase", "service": "supabase", "friendly_name": "get_project_upgrade_eligibility"},
    Action.SUPABASE_GET_PROJECT_UPGRADE_STATUS: {"provider": "supabase", "service": "supabase", "friendly_name": "get_project_upgrade_status"},
    Action.SUPABASE_LIST_PROJECT_DATABASE_BACKUPS: {"provider": "supabase", "service": "supabase", "friendly_name": "list_project_database_backups"},
    Action.SUPABASE_LIST_ALL_BUCKETS: {"provider": "supabase", "service": "supabase", "friendly_name": "list_all_buckets"},
    Action.SUPABASE_LIST_ALL_SSO_PROVIDERS: {"provider": "supabase", "service": "supabase", "friendly_name": "list_all_sso_providers"},
    Action.SUPABASE_LIST_SQL_SNIPPETS_FOR_USER: {"provider": "supabase", "service": "supabase", "friendly_name": "list_sql_snippets_for_user"},
    Action.SUPABASE_LIST_ALL_DATABASE_BRANCHES: {"provider": "supabase", "service": "supabase", "friendly_name": "list_all_database_branches"},
    Action.SUPABASE_LIST_ALL_FUNCTIONS: {"provider": "supabase", "service": "supabase", "friendly_name": "list_all_functions"},
    Action.SUPABASE_LIST_ALL_SECRETS: {"provider": "supabase", "service": "supabase", "friendly_name": "list_all_secrets"},
    Action.SUPABASE_LIST_MEMBERS_OF_ORGANIZATION: {"provider": "supabase", "service": "supabase", "friendly_name": "list_members_of_organization"},
    Action.SUPABASE_REMOVE_SSO_PROVIDER: {"provider": "supabase", "service": "supabase", "friendly_name": "remove_sso_provider"},
    Action.SUPABASE_RESET_DATABASE_BRANCH: {"provider": "supabase", "service": "supabase", "friendly_name": "reset_database_branch"},
    Action.SUPABASE_RESTORE_DATABASE_PITR_BACKUP: {"provider": "supabase", "service": "supabase", "friendly_name": "restore_database_pitr_backup"},
    Action.SUPABASE_RETRIEVE_FUNCTION: {"provider": "supabase", "service": "supabase", "friendly_name": "retrieve_function"},
    Action.SUPABASE_RETRIEVE_FUNCTION_BODY: {"provider": "supabase", "service": "supabase", "friendly_name": "retrieve_function_body"},
    Action.SUPABASE_GET_PROJECT_READONLY_MODE_STATUS: {"provider": "supabase", "service": "supabase", "friendly_name": "get_project_readonly_mode_status"},
    Action.SUPABASE_UPDATE_SSO_PROVIDER_BY_UUID: {"provider": "supabase", "service": "supabase", "friendly_name": "update_sso_provider_by_uuid"},
    Action.SUPABASE_UPDATE_PROJECT_POSTGREST_CONFIG: {"provider": "supabase", "service": "supabase", "friendly_name": "update_project_postgrest_config"},
    Action.SUPABASE_UPDATE_PROJECT_POSTGRES_CONFIG: {"provider": "supabase", "service": "supabase", "friendly_name": "update_project_postgres_config"},
    Action.SUPABASE_UPDATE_DATABASE_POOLER_CONFIG: {"provider": "supabase", "service": "supabase", "friendly_name": "update_database_pooler_config"},
    Action.SUPABASE_UPDATE_FUNCTION: {"provider": "supabase", "service": "supabase", "friendly_name": "update_function"},
    Action.SUPABASE_UPDATE_DATABASE_BRANCH_CONFIG: {"provider": "supabase", "service": "supabase", "friendly_name": "update_database_branch_config"},
    Action.SUPABASE_UPDATE_PROJECT_CUSTOM_HOSTNAME_CONFIGURATION: {"provider": "supabase", "service": "supabase", "friendly_name": "update_project_custom_hostname_configuration"},
    Action.SUPABASE_UPDATE_SSL_ENFORCEMENT_CONFIG: {"provider": "supabase", "service": "supabase", "friendly_name": "update_ssl_enforcement_config"},

    # Tavily actions
    Action.TAVILY_SEARCH_DATA: {"provider": "tavily", "service": "tavily", "friendly_name": "search_data"},
    Action.TAVILY_EXTRACT_CONTENT: {"provider": "tavily", "service": "tavily", "friendly_name": "extract_content"},

    # Typeform actions
    Action.TYPEFORM_RETRIEVE_WORKSPACES: {"provider": "typeform", "service": "typeform", "friendly_name": "retrieve_workspaces"},
    Action.TYPEFORM_RETRIEVE_THEMES: {"provider": "typeform", "service": "typeform", "friendly_name": "retrieve_themes"},
    Action.TYPEFORM_RETRIEVE_WORKSPACE: {"provider": "typeform", "service": "typeform", "friendly_name": "retrieve_workspace"},
    Action.TYPEFORM_RETRIEVE_CUSTOM_FORM_MESSAGES: {"provider": "typeform", "service": "typeform", "friendly_name": "retrieve_custom_form_messages"},
    Action.TYPEFORM_RETRIEVE_SINGLE_WEBHOOK: {"provider": "typeform", "service": "typeform", "friendly_name": "retrieve_single_webhook"},
    Action.TYPEFORM_RETRIEVE_IMAGES_COLLECTION: {"provider": "typeform", "service": "typeform", "friendly_name": "retrieve_images_collection"},
    Action.TYPEFORM_RETRIEVE_FORM: {"provider": "typeform", "service": "typeform", "friendly_name": "retrieve_form"},
    Action.TYPEFORM_RETRIEVE_RESPONSES_FOR_FORM: {"provider": "typeform", "service": "typeform", "friendly_name": "retrieve_responses_for_form"},
    Action.TYPEFORM_RETRIEVE_THEME: {"provider": "typeform", "service": "typeform", "friendly_name": "retrieve_theme"},
    Action.TYPEFORM_RETRIEVE_ACCOUNT_WORKSPACES: {"provider": "typeform", "service": "typeform", "friendly_name": "retrieve_account_workspaces"},
    Action.TYPEFORM_RETRIEVE_FORMS: {"provider": "typeform", "service": "typeform", "friendly_name": "retrieve_forms"},
    Action.TYPEFORM_RETRIEVE_WEBHOOKS: {"provider": "typeform", "service": "typeform", "friendly_name": "retrieve_webhooks"},
    Action.TYPEFORM_RETRIEVE_IMAGE: {"provider": "typeform", "service": "typeform", "friendly_name": "retrieve_image"},
    Action.TYPEFORM_CREATE_FORM: {"provider": "typeform", "service": "typeform", "friendly_name": "create_form"},
    Action.TYPEFORM_CREATE_THEME: {"provider": "typeform", "service": "typeform", "friendly_name": "create_theme"},
    Action.TYPEFORM_CREATE_IMAGE: {"provider": "typeform", "service": "typeform", "friendly_name": "create_image"},
    Action.TYPEFORM_CREATE_WORKSPACE: {"provider": "typeform", "service": "typeform", "friendly_name": "create_workspace"},
    Action.TYPEFORM_CREATE_ACCOUNT_WORKSPACE: {"provider": "typeform", "service": "typeform", "friendly_name": "create_account_workspace"},
    Action.TYPEFORM_CREATE_OR_UPDATE_WEBHOOK: {"provider": "typeform", "service": "typeform", "friendly_name": "create_or_update_webhook_typeform"},
    Action.TYPEFORM_UPDATE_CUSTOM_MESSAGES_FOR_FORMS: {"provider": "typeform", "service": "typeform", "friendly_name": "update_custom_messages_for_forms"},
    Action.TYPEFORM_UPDATE_FORM: {"provider": "typeform", "service": "typeform", "friendly_name": "update_form"},
    Action.TYPEFORM_UPDATE_THEME: {"provider": "typeform", "service": "typeform", "friendly_name": "update_theme"},
    Action.TYPEFORM_UPDATE_WORKSPACE: {"provider": "typeform", "service": "typeform", "friendly_name": "update_workspace"},
    Action.TYPEFORM_PATCH_UPDATE_FORM: {"provider": "typeform", "service": "typeform", "friendly_name": "patch_update_form"},
    Action.TYPEFORM_PARTIAL_UPDATE_THEME: {"provider": "typeform", "service": "typeform", "friendly_name": "partial_update_theme"},
    Action.TYPEFORM_DELETE_THEME: {"provider": "typeform", "service": "typeform", "friendly_name": "delete_theme"},
    Action.TYPEFORM_DELETE_FORM: {"provider": "typeform", "service": "typeform", "friendly_name": "delete_form"},
    Action.TYPEFORM_DELETE_WEBHOOK: {"provider": "typeform", "service": "typeform", "friendly_name": "delete_webhook_typeform"},
    Action.TYPEFORM_DELETE_RESPONSES_TO_FORM: {"provider": "typeform", "service": "typeform", "friendly_name": "delete_responses_to_form"},
    Action.TYPEFORM_DELETE_WORKSPACE: {"provider": "typeform", "service": "typeform", "friendly_name": "delete_workspace"},
    Action.TYPEFORM_DELETE_IMAGE: {"provider": "typeform", "service": "typeform", "friendly_name": "delete_image"},

    # Vercel actions
    Action.VERCEL_ADD_ENVIRONMENT_VARIABLE: {"provider": "vercel", "service": "vercel", "friendly_name": "add_environment_variable"},
    Action.VERCEL_CHECK_CACHE_ARTIFACT_EXISTS: {"provider": "vercel", "service": "vercel", "friendly_name": "check_cache_artifact_exists"},
    Action.VERCEL_CHECK_DOMAIN_AVAILABILITY: {"provider": "vercel", "service": "vercel", "friendly_name": "check_domain_availability"},
    Action.VERCEL_CHECK_DOMAIN_PRICE: {"provider": "vercel", "service": "vercel", "friendly_name": "check_domain_price"},
    Action.VERCEL_CREATE_AUTH_TOKEN: {"provider": "vercel", "service": "vercel", "friendly_name": "create_auth_token"},
    Action.VERCEL_CREATE_EDGE_CONFIG: {"provider": "vercel", "service": "vercel", "friendly_name": "create_edge_config"},
    Action.VERCEL_CREATE_DEPLOYMENT: {"provider": "vercel", "service": "vercel", "friendly_name": "create_deployment"},
    Action.VERCEL_DELETE_AUTH_TOKEN: {"provider": "vercel", "service": "vercel", "friendly_name": "delete_auth_token"},
    Action.VERCEL_DELETE_DEPLOYMENT: {"provider": "vercel", "service": "vercel", "friendly_name": "delete_deployment"},
    Action.VERCEL_DELETE_ENVIRONMENT_VARIABLE: {"provider": "vercel", "service": "vercel", "friendly_name": "delete_environment_variable"},
    Action.VERCEL_DELETE_PROJECT: {"provider": "vercel", "service": "vercel", "friendly_name": "delete_project_vercel"},
    Action.VERCEL_DEPLOY_EDGE_FUNCTION: {"provider": "vercel", "service": "vercel", "friendly_name": "deploy_edge_function_vercel"},
    Action.VERCEL_GET_DEPLOYMENT_DETAILS: {"provider": "vercel", "service": "vercel", "friendly_name": "get_deployment_details_vercel"},
    Action.VERCEL_GET_DEPLOYMENT_EVENTS: {"provider": "vercel", "service": "vercel", "friendly_name": "get_deployment_events"},
    Action.VERCEL_GET_DEPLOYMENT_LOGS: {"provider": "vercel", "service": "vercel", "friendly_name": "get_deployment_logs"},
    Action.VERCEL_GET_DOMAIN_TRANSFER_INFO: {"provider": "vercel", "service": "vercel", "friendly_name": "get_domain_transfer_info"},
    Action.VERCEL_GET_EDGE_CONFIG: {"provider": "vercel", "service": "vercel", "friendly_name": "get_edge_config"},
    Action.VERCEL_GET_EDGE_CONFIG_ITEM: {"provider": "vercel", "service": "vercel", "friendly_name": "get_edge_config_item"},
    Action.VERCEL_GET_PROJECT: {"provider": "vercel", "service": "vercel", "friendly_name": "get_project"},
    Action.VERCEL_LIST_ALIASES: {"provider": "vercel", "service": "vercel", "friendly_name": "list_aliases"},
    Action.VERCEL_LIST_DEPLOYMENTS: {"provider": "vercel", "service": "vercel", "friendly_name": "list_deployments"},
    Action.VERCEL_LIST_AUTH_TOKENS: {"provider": "vercel", "service": "vercel", "friendly_name": "list_auth_tokens"},
    Action.VERCEL_LIST_DEPLOYMENT_CHECKS: {"provider": "vercel", "service": "vercel", "friendly_name": "list_deployment_checks"},
    Action.VERCEL_LIST_EDGE_CONFIGS: {"provider": "vercel", "service": "vercel", "friendly_name": "list_edge_configs"},
    Action.VERCEL_LIST_ENVIRONMENT_VARIABLES: {"provider": "vercel", "service": "vercel", "friendly_name": "list_environment_variables"},
    Action.VERCEL_UPDATE_EDGE_CONFIG_ITEMS: {"provider": "vercel", "service": "vercel", "friendly_name": "update_edge_config_items"},
    Action.VERCEL_UPDATE_PROJECT: {"provider": "vercel", "service": "vercel", "friendly_name": "update_project"},
    Action.VERCEL_CREATE_EDGE_CONFIG_TOKEN: {"provider": "vercel", "service": "vercel", "friendly_name": "create_edge_config_token"},

    # Wttr actions
    Action.WTTR_GET_WEATHER_DATA: {"provider": "wttr", "service": "wttr", "friendly_name": "get_weather_data"},

    # Zoom actions
    Action.ZOOM_CREATE_MEETING: {"provider": "zoom", "service": "zoom", "friendly_name": "create_meeting"},
    Action.ZOOM_GET_MEETING: {"provider": "zoom", "service": "zoom", "friendly_name": "get_meeting"},
    Action.ZOOM_GET_MEETING_SUMMARY: {"provider": "zoom", "service": "zoom", "friendly_name": "get_meeting_summary"},
    Action.ZOOM_GET_MEETING_RECORDINGS: {"provider": "zoom", "service": "zoom", "friendly_name": "get_meeting_recordings"},
    Action.ZOOM_LIST_RECORDINGS: {"provider": "zoom", "service": "zoom", "friendly_name": "list_recordings"},
    Action.ZOOM_LIST_MEETINGS: {"provider": "zoom", "service": "zoom", "friendly_name": "list_meetings"},
    Action.ZOOM_ADD_MEETING_REGISTRANT: {"provider": "zoom", "service": "zoom", "friendly_name": "add_meeting_registrant"},
    Action.ZOOM_GET_WEBINAR: {"provider": "zoom", "service": "zoom", "friendly_name": "get_webinar"},
    Action.ZOOM_LIST_WEBINARS: {"provider": "zoom", "service": "zoom", "friendly_name": "list_webinars"},
    Action.ZOOM_GET_PAST_MEETING_PARTICIPANTS: {"provider": "zoom", "service": "zoom", "friendly_name": "get_past_meeting_participants"},
    Action.ZOOM_UPDATE_MEETING: {"provider": "zoom", "service": "zoom", "friendly_name": "update_meeting"},
    Action.ZOOM_DELETE_MEETING_RECORDINGS: {"provider": "zoom", "service": "zoom", "friendly_name": "delete_meeting_recordings"},

}

class App:
    """
    Constants for entire app/service collections.
    """
    GMAIL = "GMAIL"
    CALENDAR = "CALENDAR"
    DRIVE = "DRIVE"
    DOCS = "DOCS"
    MEET = "MEET"
    YOUTUBE = "YOUTUBE"
    FIRECRAWL = "FIRECRAWL"
    SERPAPI = "SERPAPI"
    NOTION = "NOTION"
    AIRTABLE = "AIRTABLE"
    GITHUB = "GITHUB"
    SLACK = "SLACK"
    BREVO = "BREVO"
    CALENDLY = "CALENDLY"
    AGENTQL = "AGENTQL"
    APOLLO = "APOLLO"
    BANNERBEAR = "BANNERBEAR"
    BITQUERY = "BITQUERY"
    BOTSONIC = "BOTSONIC"
    CAL = "CAL"
    CANVA = "CANVA"
    CLERK = "CLERK"
    CLOSE = "CLOSE"
    EXA = "EXA"
    FIGMA = "FIGMA"
    FIREFILES = "FIREFILES"
    FOLK = "FOLK"
    FRONT = "FRONT"
    BIGQUERY = "BIGQUERY"
    HACKERNEWS = "HACKERNEWS"
    HUBSPOT = "HUBSPOT"
    INTERCOM = "INTERCOM"
    KERNEL = "KERNEL"
    LOOPS = "LOOPS"
    MAILCHIMP = "MAILCHIMP"
    MEETGEEK = "MEETGEEK"
    NETLIFY = "NETLIFY"
    NEWSDATA = "NEWSDATA"
    PEOPLEDATALABS = "PEOPLEDATALABS"
    OPENROUTER = "OPENROUTER"
    PINECONE = "PINECONE"
    PLACES = "PLACES"
    POSTHOG = "POSTHOG"
    QUICKCHART = "QUICKCHART"
    RESEND = "RESEND"
    SCRAPINGDOG = "SCRAPINGDOG"
    SENDGRID = "SENDGRID"
    SPOTIFY = "SPOTIFY"
    STRIPE = "STRIPE"
    SUPABASE = "SUPABASE"
    TAVILY = "TAVILY"
    TYPEFORM = "TYPEFORM"
    VERCEL = "VERCEL"
    WTTR = "WTTR"
    ZOOM = "ZOOM"

APP_TO_ACTIONS = {
    App.GMAIL: [
        Action.GMAIL_SEND_EMAIL,
        Action.GMAIL_REPLY_TO_THREAD,
        Action.GMAIL_FETCH_MESSAGES_BY_THREAD,
        Action.GMAIL_SEND_DRAFT,
        Action.GMAIL_SEARCH_PEOPLE,
        Action.GMAIL_DELETE_DRAFT,
        Action.GMAIL_DELETE_MESSAGE,
        Action.GMAIL_FETCH_EMAILS,
        Action.GMAIL_GET_GMAIL_ATTACHMENT,
        Action.GMAIL_GET_CONTACTS,
        Action.GMAIL_LIST_DRAFTS,
        Action.GMAIL_MOVE_TO_TRASH,
        Action.GMAIL_PATCH_LABEL,
        Action.GMAIL_MODIFY_EMAIL_LABELS,
        Action.GMAIL_CREATE_LABEL,
        Action.GMAIL_GET_PEOPLE,
        Action.GMAIL_GET_PROFILE,
        Action.GMAIL_LIST_GMAIL_LABELS,
        Action.GMAIL_LIST_THREADS,
        Action.GMAIL_MODIFY_THREAD_LABELS,
        Action.GMAIL_REMOVE_LABEL,
        Action.GMAIL_FETCH_MESSAGE_BY_MESSAGE_ID,
        Action.GMAIL_CREATE_DRAFT
    ],
    
    App.CALENDAR: [
        Action.CALENDAR_CREATE_EVENT,
        Action.CALENDAR_DELETE_EVENT,
        Action.CALENDAR_LIST_EVENTS,
        Action.CALENDAR_UPDATE_ACL_RULE,
        Action.CALENDAR_UPDATE_CALENDAR_LIST_ENTRY,
        Action.CALENDAR_GET_EVENT_INSTANCES,
        Action.CALENDAR_CREATE_CALENDAR,
        Action.CALENDAR_DELETE_CALENDAR,
        Action.CALENDAR_UPDATE_CALENDAR,
        Action.CALENDAR_INSERT_CALENDAR_INTO_LIST,
        Action.CALENDAR_GET_CALENDAR,
        Action.CALENDAR_QUERY_FREE_BUSY,
        Action.CALENDAR_PATCH_CALENDAR,
        Action.CALENDAR_PATCH_EVENT,
        Action.CALENDAR_QUICK_ADD_EVENT,
        Action.CALENDAR_SYNC_EVENTS,
        Action.CALENDAR_CLEAR_CALENDAR,
        Action.CALENDAR_MOVE_EVENT,
        Action.CALENDAR_FIND_FREE_SLOTS,
        Action.CALENDAR_LIST_ACL_RULES,
        Action.CALENDAR_LIST_GOOGLE_CALENDARS,
        Action.CALENDAR_REMOVE_ATTENDEE_FROM_EVENT,
        Action.CALENDAR_LIST_SETTINGS,
        Action.CALENDAR_GET_CURRENT_DATE_AND_TIME,
        Action.CALENDAR_UPDATE_EVENT
    ],
    
    App.DRIVE: [
        Action.DRIVE_DELETE_FILE,
        Action.DRIVE_CREATE_COMMENT,
        Action.DRIVE_CREATE_SHARED_DRIVE,
        Action.DRIVE_CREATE_FILE_OR_FOLDER,
        Action.DRIVE_CREATE_REPLY,
        Action.DRIVE_CREATE_SHORTCUT,
        Action.DRIVE_DELETE_COMMENT,
        Action.DRIVE_DELETE_SHARED_DRIVE,
        Action.DRIVE_DELETE_PERMISSION,
        Action.DRIVE_DELETE_REPLY,
        Action.DRIVE_EMPTY_TRASH,
        Action.DRIVE_MODIFY_FILE_LABELS,
        Action.DRIVE_GENERATE_FILE_IDS,
        Action.DRIVE_GET_ABOUT_INFORMATION,
        Action.DRIVE_GET_CHANGES_START_PAGE_TOKEN,
        Action.DRIVE_GET_COMMENT,
        Action.DRIVE_GET_SHARED_DRIVE,
        Action.DRIVE_GET_FILE_METADATA,
        Action.DRIVE_GET_PERMISSION,
        Action.DRIVE_GET_REPLY,
        Action.DRIVE_GET_REVISION,
        Action.DRIVE_HIDE_SHARED_DRIVE,
        Action.DRIVE_LIST_CHANGES,
        Action.DRIVE_LIST_COMMENTS,
        Action.DRIVE_LIST_FILES_AND_FOLDERS,
        Action.DRIVE_LIST_FILE_LABELS,
        Action.DRIVE_LIST_PERMISSIONS,
        Action.DRIVE_LIST_REPLIES,
        Action.DRIVE_LIST_REVISIONS,
        Action.DRIVE_LIST_SHARED_DRIVES,
        Action.DRIVE_MOVE_FILE,
        Action.DRIVE_UNTRASH_FILE,
        Action.DRIVE_UPDATE_COMMENT,
        Action.DRIVE_UPDATE_SHARED_DRIVE,
        Action.DRIVE_FIND_FILE,
        Action.DRIVE_FIND_FOLDER,
        Action.DRIVE_COPY_FILE,
        Action.DRIVE_CREATE_TEXT_FILE,
        Action.DRIVE_UPDATE_FILE_METADATA,
        Action.DRIVE_UPDATE_REPLY,
        Action.DRIVE_UPDATE_FILE_REVISION,
        Action.DRIVE_UNHIDE_SHARED_DRIVE,
        Action.DRIVE_ADD_FILE_SHARING_PREFERENCE,
        Action.DRIVE_DELETE_FOLDER,
        Action.DRIVE_UPLOAD_FILE,
        Action.DRIVE_EDIT_FILE,
    ],
    
    App.DOCS: [
        Action.DOCS_CREATE_DOCUMENT,
        Action.DOCS_GET_DOCUMENT,
        Action.DOCS_CREATE_PARAGRAPH_BULLETS,
        Action.DOCS_DELETE_PARAGRAPH_BULLETS,
        Action.DOCS_INSERT_TABLE,
        Action.DOCS_DELETE_TABLE,
        Action.DOCS_INSERT_TABLE_ROW,
        Action.DOCS_DELETE_TABLE_ROW,
        Action.DOCS_INSERT_TABLE_COLUMN,
        Action.DOCS_DELETE_TABLE_COLUMN,
        Action.DOCS_CREATE_HEADER,
        Action.DOCS_DELETE_HEADER,
        Action.DOCS_CREATE_FOOTER,
        Action.DOCS_DELETE_FOOTER,
        Action.DOCS_CREATE_FOOTNOTE,
        Action.DOCS_CREATE_NAMED_RANGE,
        Action.DOCS_DELETE_NAMED_RANGE,
        Action.DOCS_UPDATE_TEXT_STYLE,
        Action.DOCS_UPDATE_PARAGRAPH_STYLE,
        Action.DOCS_INSERT_PAGE_BREAK,
        Action.DOCS_INSERT_SECTION_BREAK,
        Action.DOCS_INSERT_INLINE_IMAGE,
        Action.DOCS_REPLACE_IMAGE,
        Action.DOCS_UNMERGE_TABLE_CELLS,
        Action.DOCS_UPDATE_DOCUMENT_STYLE,
        Action.DOCS_UPDATE_TABLE_ROW_STYLE,
        Action.DOCS_COPY_DOCUMENT,
        Action.DOCS_INSERT_TEXT,
        Action.DOCS_DELETE_CONTENT_RANGE,
        Action.DOCS_REPLACE_ALL_TEXT,
        Action.DOCS_SEARCH_DOCUMENTS,
        Action.DOCS_CREATE_DOCUMENT_MARKDOWN,
    ],

    App.MEET: [
        Action.MEET_GET_CONFERENCE_RECORD,
        Action.MEET_GET_PARTICIPANT_SESSION,
        Action.MEET_LIST_PARTICIPANT_SESSIONS,
        Action.MEET_LIST_CONFERENCE_RECORDS,
        Action.MEET_UPDATE_GOOGLE_MEET_SPACE,
        Action.MEET_CREATE_MEET_SPACE,
        Action.MEET_GET_MEET_SPACE_DETAILS,
        Action.MEET_GET_RECORDINGS_BY_CONFERENCE_RECORD,
        Action.MEET_GET_TRANSCRIPTS_BY_CONFERENCE_RECORD
    ],

    App.FIRECRAWL: [
        Action.FIRECRAWL_SCRAPE_URL,
        Action.FIRECRAWL_START_CRAWL,
        Action.FIRECRAWL_GET_CRAWL_STATUS,
        Action.FIRECRAWL_CANCEL_CRAWL,
        Action.FIRECRAWL_MAP_URLS,
        Action.FIRECRAWL_EXTRACT_DATA,
        Action.FIRECRAWL_SEARCH_WEB,
    ],

    App.SERPAPI: [
        Action.SERPAPI_BAIDU_SEARCH,
        Action.SERPAPI_BING_SEARCH,
        Action.SERPAPI_EBAY_SEARCH,
        Action.SERPAPI_GOOGLE_DOMAINS_LIST,
        Action.SERPAPI_GOOGLE_JOBS_SEARCH,
        Action.SERPAPI_GOOGLE_LIGHT_SEARCH,
        Action.SERPAPI_HOTEL_SEARCH,
        Action.SERPAPI_LIST_LOCATIONS,
        Action.SERPAPI_GOOGLE_PLAY_SEARCH,
        Action.SERPAPI_WALMART_SEARCH,
        Action.SERPAPI_YAHOO_SEARCH,
        Action.SERPAPI_YANDEX_SEARCH,
        Action.SERPAPI_YOUTUBE_SEARCH,
        Action.SERPAPI_DUCKDUCKGO_SEARCH,
        Action.SERPAPI_GOOGLE_EVENTS_SEARCH,
        Action.SERPAPI_GOOGLE_FINANCE_SEARCH,
        Action.SERPAPI_GOOGLE_MAPS_SEARCH,
        Action.SERPAPI_GOOGLE_IMAGES_SEARCH,
        Action.SERPAPI_GOOGLE_NEWS_SEARCH,
        Action.SERPAPI_GOOGLE_SCHOLAR_SEARCH,
        Action.SERPAPI_GOOGLE_SEARCH,
        Action.SERPAPI_GOOGLE_SHOPPING_SEARCH,
        Action.SERPAPI_GOOGLE_TRENDS_SEARCH,
    ],

    App.NOTION: [
        Action.NOTION_CREATE_COMMENT,
        Action.NOTION_ADD_MULTIPLE_CONTENT_BLOCKS,
        Action.NOTION_DELETE_BLOCK,
        Action.NOTION_FETCH_BLOCK_CHILDREN,
        Action.NOTION_FETCH_COMMENTS,
        Action.NOTION_CREATE_DATABASE,
        Action.NOTION_CREATE_PAGE,
        Action.NOTION_FETCH_DATABASE,
        Action.NOTION_FETCH_DATABASE_ROW,
        Action.NOTION_INSERT_DATABASE_ROW,
        Action.NOTION_QUERY_DATABASE,
        Action.NOTION_RETRIEVE_DATABASE_PROPERTY,
        Action.NOTION_GET_ABOUT_ME,
        Action.NOTION_GET_ABOUT_USER,
        Action.NOTION_LIST_USERS,
        Action.NOTION_RETRIEVE_COMMENT,
        Action.NOTION_UPDATE_DATABASE_SCHEMA,
        Action.NOTION_UPDATE_ROW_DATABASE,
        Action.NOTION_SEARCH_NOTION_PAGE,
        Action.NOTION_UPDATE_PAGE,
        Action.NOTION_ADD_CONTENT_TO_NOTION_PAGE,
        Action.NOTION_APPEND_COMPLEX_BLOCKS,
        Action.NOTION_DUPLICATE_PAGE,
        Action.NOTION_FETCH_NOTION_BLOCK_METADATA,
        Action.NOTION_UPDATE_BLOCK,
        Action.NOTION_FETCH_NOTION_DATA,
        Action.NOTION_GET_PAGE_PROPERTY
    ],

    App.AIRTABLE: [
        Action.AIRTABLE_LIST_BASES,
        Action.AIRTABLE_CREATE_BASE,
        Action.AIRTABLE_GET_BASE_SCHEMA,
        Action.AIRTABLE_CREATE_TABLE,
        Action.AIRTABLE_CREATE_FIELD,
        Action.AIRTABLE_CREATE_RECORD,
        Action.AIRTABLE_CREATE_MULTIPLE_RECORDS,
        Action.AIRTABLE_GET_RECORD,
        Action.AIRTABLE_LIST_RECORDS,
        Action.AIRTABLE_UPDATE_RECORD,
        Action.AIRTABLE_UPDATE_MULTIPLE_RECORDS,
        Action.AIRTABLE_DELETE_RECORD,
        Action.AIRTABLE_DELETE_MULTIPLE_RECORDS,
        Action.AIRTABLE_CREATE_COMMENT,
        Action.AIRTABLE_DELETE_COMMENT,
        Action.AIRTABLE_LIST_COMMENTS,
        Action.AIRTABLE_GET_USER_INFORMATION
    ],

    App.GITHUB: [
        Action.GITHUB_ADD_ASSIGNEES_TO_ISSUE,
        Action.GITHUB_ADD_REPOSITORY_COLLABORATOR,
        Action.GITHUB_ADD_LABELS_TO_ISSUE,
        Action.GITHUB_CREATE_ISSUE,
        Action.GITHUB_CREATE_ISSUE_COMMENT,
        Action.GITHUB_CREATE_PULL_REQUEST,
        Action.GITHUB_CREATE_REPOSITORY,
        Action.GITHUB_CREATE_OR_UPDATE_FILE,
        Action.GITHUB_GET_PULL_REQUEST,
        Action.GITHUB_LIST_REPOSITORY_ISSUES,
        Action.GITHUB_STAR_REPOSITORY,
        Action.GITHUB_DELETE_REPOSITORY,
        Action.GITHUB_LIST_REPOSITORIES_STARRED_BY_AUTHENTICATED_USER,
        Action.GITHUB_LIST_STARGAZERS,
        Action.GITHUB_STAR_REPOSITORY_FOR_AUTHENTICATED_USER,
        Action.GITHUB_CHECK_IF_REPOSITORY_IS_STARRED_BY_AUTHENTICATED_USER,
        Action.GITHUB_CHECK_IF_GIST_IS_STARRED,
        Action.GITHUB_BLOCK_USER,
        Action.GITHUB_CHECK_IF_USER_BLOCKED_BY_AUTHENTICATED_USER,
        Action.GITHUB_CHECK_PRIVATE_VULNERABILITY_REPORTING_STATUS,
        Action.GITHUB_CHECK_TEAM_PERMISSIONS_FOR_PROJECT,
        Action.GITHUB_CHECK_TEAM_PERMISSIONS_FOR_REPOSITORY,
        Action.GITHUB_CLEAR_REPOSITORY_CACHE_BY_KEY,
        Action.GITHUB_CLEAR_SELF_HOSTED_RUNNER_ORG_LABELS,
        Action.GITHUB_CONFIGURE_JIT_RUNNER_FOR_ORG,
        Action.GITHUB_CONFIGURE_OIDC_SUBJECT_CLAIM_TEMPLATE,
        Action.GITHUB_CONVERT_ORG_MEMBER_TO_OUTSIDE_COLLABORATOR,
        Action.GITHUB_CREATE_AUTOLINK_REFERENCE_FOR_REPOSITORY,
        Action.GITHUB_CREATE_ENVIRONMENT_VARIABLE,
        Action.GITHUB_CREATE_ORGANIZATION_PROJECT,
        Action.GITHUB_CREATE_ORGANIZATION_VARIABLE,
        Action.GITHUB_DELETE_DEPLOYMENT_BRANCH_POLICY,
        Action.GITHUB_DELETE_DEPLOY_KEY,
        Action.GITHUB_DELETE_DISCUSSION,
        Action.GITHUB_DELETE_DISCUSSION_COMMENT,
        Action.GITHUB_DELETE_FILE,
        Action.GITHUB_DELETE_GIST,
        Action.GITHUB_DELETE_GIST_COMMENT,
        Action.GITHUB_DELETE_GITHUB_PAGES_SITE,
        Action.GITHUB_DELETE_LABEL,
        Action.GITHUB_DELETE_MILESTONE,
        Action.GITHUB_DELETE_PACKAGE_FOR_ORGANIZATION,
        Action.GITHUB_DELETE_PACKAGE_FOR_USER,
        Action.GITHUB_DELETE_PACKAGE_FOR_AUTHENTICATED_USER,
        Action.GITHUB_DELETE_PACKAGE_VERSION_FOR_AUTHENTICATED_USER,
        Action.GITHUB_DELETE_PENDING_REVIEW_FOR_PULL_REQUEST,
        Action.GITHUB_DELETE_PROJECT,
        Action.GITHUB_DELETE_PROJECT_CARD,
        Action.GITHUB_DELETE_PROJECT_COLUMN,
        Action.GITHUB_DELETE_PULL_REQUEST_COMMENT_REACTION,
        Action.GITHUB_DELETE_REFERENCE,
        Action.GITHUB_DELETE_RELEASE,
        Action.GITHUB_DELETE_RELEASE_ASSET,
        Action.GITHUB_DELETE_RELEASE_REACTION,
        Action.GITHUB_DELETE_REPOSITORY_INVITATION,
        Action.GITHUB_DELETE_REPOSITORY_RULESET,
        Action.GITHUB_DELETE_REPOSITORY_SECRET,
        Action.GITHUB_DELETE_REPOSITORY_SUBSCRIPTION,
        Action.GITHUB_DELETE_REPOSITORY_VARIABLE,
        Action.GITHUB_DELETE_REVIEW_COMMENT_FOR_PULL_REQUEST,
        Action.GITHUB_DELETE_SECRET_FOR_AUTHENTICATED_USER,
        Action.GITHUB_DELETE_SELF_HOSTED_RUNNER_FROM_ORGANIZATION,
        Action.GITHUB_DELETE_SELF_HOSTED_RUNNER_FROM_REPOSITORY,
        Action.GITHUB_DELETE_TAG_PROTECTION_FOR_REPOSITORY,
        Action.GITHUB_DELETE_TEAM,
        Action.GITHUB_DELETE_THREAD_SUBSCRIPTION,
        Action.GITHUB_DELETE_WORKFLOW_RUN,
        Action.GITHUB_ENABLE_WORKFLOW,
        Action.GITHUB_ENABLE_GITHUB_ACTIONS_SELECTED_REPOSITORIES,
        Action.GITHUB_ENABLE_PRIVATE_VULNERABILITY_REPORTING,
        Action.GITHUB_ENABLE_REPOSITORY_ACTIONS,
        Action.GITHUB_EXPORT_CODESPACE_FOR_AUTHENTICATED_USER,
        Action.GITHUB_EXPORT_REPOSITORY_SBOM,
        Action.GITHUB_FOLLOW_USER,
        Action.GITHUB_FORCE_CANCEL_WORKFLOW_RUN,
        Action.GITHUB_FORK_GIST,
        Action.GITHUB_GENERATE_RELEASE_NOTES,
        Action.GITHUB_GET_ACCESS_RESTRICTIONS,
        Action.GITHUB_GET_ADMIN_BRANCH_PROTECTION,
        Action.GITHUB_GET_ALL_API_VERSIONS,
        Action.GITHUB_GET_ALL_AUTOLINKS_OF_REPOSITORY,
        Action.GITHUB_GET_ALL_CODES_OF_CONDUCT,
        Action.GITHUB_GET_ALL_LICENSES,
        Action.GITHUB_GET_ALL_CONTRIBUTOR_COMMIT_ACTIVITY,
        Action.GITHUB_GET_ALL_CUSTOM_PROPERTIES_FOR_ORGANIZATION,
        Action.GITHUB_GET_ALL_CUSTOM_PROPERTY_VALUES_FOR_REPOSITORY,
        Action.GITHUB_GET_ALL_DEPLOYMENT_PROTECTION_RULES,
        Action.GITHUB_GET_ALL_GITIGNORE_TEMPLATES,
        Action.GITHUB_GET_ALL_ORGANIZATION_ROLES,
        Action.GITHUB_GET_ALL_REPOSITORY_RULESETS,
        Action.GITHUB_GET_ALL_REPOSITORY_TOPICS,
        Action.GITHUB_GET_ALL_REQUESTED_REVIEWERS_FOR_PULL_REQUEST,
        Action.GITHUB_GET_ALL_STATUS_CHECK_CONTEXTS,
        Action.GITHUB_GET_APP,
        Action.GITHUB_GET_ARTIFACT,
        Action.GITHUB_GET_ASSIGNMENT,
        Action.GITHUB_GET_AUTOLINK_REFERENCE_OF_REPOSITORY,
        Action.GITHUB_GET_ENVIRONMENT,
        Action.GITHUB_GET_ENVIRONMENT_PUBLIC_KEY,
        Action.GITHUB_GET_ENVIRONMENT_SECRET,
        Action.GITHUB_GET_ENVIRONMENT_VARIABLE,
        Action.GITHUB_GET_ISSUE,
        Action.GITHUB_GET_ISSUE_COMMENT,
        Action.GITHUB_GET_ISSUE_EVENT,
        Action.GITHUB_GET_ORGANIZATION,
        Action.GITHUB_GET_ORGANIZATION_PUBLIC_KEY,
        Action.GITHUB_GET_ORGANIZATION_ROLE,
        Action.GITHUB_GET_ORGANIZATION_SECRET,
        Action.GITHUB_GET_ORGANIZATION_VARIABLE,
        Action.GITHUB_GET_APPS_WITH_ACCESS_TO_PROTECTED_BRANCH,
        Action.GITHUB_GET_ASSIGNMENT_GRADES,
        Action.GITHUB_GET_BLOB,
        Action.GITHUB_GET_BRANCH,
        Action.GITHUB_GET_CHECK_RUN,
        Action.GITHUB_DELETE_BRANCH_PROTECTION,
        Action.GITHUB_DELETE_COMMIT_SIGNATURE_PROTECTION,
        Action.GITHUB_DELETE_DEPENDABOT_SECRET,
        Action.GITHUB_DELETE_ACTIONS_CACHE,
        Action.GITHUB_DELETE_PACKAGE_VERSION_FOR_ORGANIZATION,
        Action.GITHUB_DELETE_PACKAGE_VERSION_FOR_USER,
        Action.GITHUB_DELETE_PULL_REQUEST_REVIEW_PROTECTION,
        Action.GITHUB_DELETE_CODESPACE_SECRET,
        Action.GITHUB_DELETE_SOCIAL_ACCOUNTS_FOR_AUTHENTICATED_USER,
        Action.GITHUB_DELETE_TEAM_DISCUSSION_COMMENT_REACTION,
        Action.GITHUB_DELETE_TEAM_DISCUSSION_REACTION,
        Action.GITHUB_DELETE_WORKFLOW_RUN_LOGS,
        Action.GITHUB_DISABLE_CUSTOM_PROTECTION_RULE_FOR_ENVIRONMENT,
        Action.GITHUB_DISABLE_WORKFLOW,
        Action.GITHUB_DISABLE_PRIVATE_VULNERABILITY_REPORTING,
        Action.GITHUB_DISABLE_REPOSITORY_ACTIONS_IN_ORGANIZATION,
        Action.GITHUB_DISMISS_PULL_REQUEST_REVIEW,
        Action.GITHUB_DOWNLOAD_ARTIFACT,
        Action.GITHUB_DOWNLOAD_REPOSITORY_TARBALL,
        Action.GITHUB_DOWNLOAD_REPOSITORY_ZIPBALL,
        Action.GITHUB_DOWNLOAD_JOB_LOGS_FOR_WORKFLOW_RUN,
        Action.GITHUB_DOWNLOAD_WORKFLOW_RUN_ATTEMPT_LOGS,
        Action.GITHUB_DOWNLOAD_WORKFLOW_RUN_LOGS,
        Action.GITHUB_GET_ME,
        Action.GITHUB_SEARCH_ISSUES,
        Action.GITHUB_LIST_ISSUES,
        Action.GITHUB_ADD_ISSUE_COMMENT,
        Action.GITHUB_UPDATE_ISSUE,
        Action.GITHUB_LIST_PULL_REQUESTS,
        Action.GITHUB_GET_PULL_REQUEST_FILES,
        Action.GITHUB_GET_PULL_REQUEST_COMMENTS,
        Action.GITHUB_GET_PULL_REQUEST_REVIEWS,
        Action.GITHUB_MERGE_PULL_REQUEST,
        Action.GITHUB_UPDATE_PULL_REQUEST_BRANCH,
        Action.GITHUB_CREATE_PULL_REQUEST_REVIEW,
        Action.GITHUB_UPDATE_PULL_REQUEST,
        Action.GITHUB_SEARCH_REPOSITORIES,
        Action.GITHUB_GET_FILE_CONTENTS,
        Action.GITHUB_LIST_COMMITS,
        Action.GITHUB_FORK_REPOSITORY,
        Action.GITHUB_CREATE_BRANCH,
        Action.GITHUB_SEARCH_CODE,
        Action.GITHUB_SEARCH_USERS,
        Action.GITHUB_GET_COMMIT
    ],

    App.SLACK: [
        Action.SLACK_SEND_MESSAGE,
        Action.SLACK_UPDATE_MESSAGE,
        Action.SLACK_SCHEDULE_MESSAGE,
        Action.SLACK_FETCH_CONVERSATION_HISTORY,
        Action.SLACK_SEARCH_MESSAGES,
        Action.SLACK_CREATE_CHANNEL,
        Action.SLACK_ARCHIVE_CHANNEL,
        Action.SLACK_FIND_CHANNELS,
        Action.SLACK_FIND_USERS,
        Action.SLACK_ADD_STAR,
        Action.SLACK_ADD_EMOJI,
        Action.SLACK_CREATE_USER_GROUP,
        Action.SLACK_ADD_REMOTE_FILE,
        Action.SLACK_DELETE_MESSAGE,
        Action.SLACK_UNARCHIVE_CHANNEL,
        Action.SLACK_RENAME_CHANNEL,
        Action.SLACK_SET_CHANNEL_PURPOSE,
        Action.SLACK_SET_CHANNEL_TOPIC,
        Action.SLACK_GET_CHANNEL_INFO,
        Action.SLACK_LIST_CHANNELS,
        Action.SLACK_GET_CHANNEL_HISTORY,
        Action.SLACK_KICK_USER_FROM_CHANNEL,
        Action.SLACK_JOIN_CHANNEL,
        Action.SLACK_LEAVE_CHANNEL,
        Action.SLACK_LIST_USERS,
        Action.SLACK_LOOKUP_USER_BY_EMAIL,
        Action.SLACK_SET_USER_PRESENCE,
        Action.SLACK_ADD_REACTION,
        Action.SLACK_REMOVE_REACTION,
        Action.SLACK_GET_REACTIONS,
        Action.SLACK_GET_CONVERSATION_REPLIES,
        Action.SLACK_PIN_MESSAGE,
        Action.SLACK_UNPIN_MESSAGE,
        Action.SLACK_LIST_PINS,
        Action.SLACK_CREATE_REMINDER,
        Action.SLACK_DELETE_REMINDER,
        Action.SLACK_COMPLETE_REMINDER,
        Action.SLACK_LIST_REMINDERS,
        Action.SLACK_GET_REMINDER_INFO,
        Action.SLACK_GET_USER_IDENTITY,
        Action.SLACK_GET_CONVERSATION_INFO,
        Action.SLACK_GET_CONVERSATION_MEMBERS,
        Action.SLACK_GET_USER_DND_STATUS,
        Action.SLACK_GET_FILE_INFO,
        Action.SLACK_GET_USER_INFO,
        Action.SLACK_GET_MESSAGE_PERMALINK,
        Action.SLACK_GET_TEAM_PROFILE,
        Action.SLACK_GET_USER_PROFILE,
        Action.SLACK_REVOKE_FILE_PUBLIC_URL,
        Action.SLACK_SEND_EPHEMERAL_MESSAGE,
        Action.SLACK_SET_CONVERSATION_PURPOSE,
        Action.SLACK_SET_DND_DURATION,
        Action.SLACK_MARK_CONVERSATION_READ,
        Action.SLACK_SET_USER_PROFILE,
        Action.SLACK_SET_CONVERSATION_TOPIC,
        Action.SLACK_SEND_ME_MESSAGE,
        Action.SLACK_UPLOAD_FILE,
        Action.SLACK_GET_REMOTE_FILE,
        Action.SLACK_GET_TEAM_DND_STATUS,
        Action.SLACK_GET_USER_PRESENCE,
        Action.SLACK_INVITE_USERS_TO_CHANNEL,
        Action.SLACK_JOIN_CONVERSATION,
        Action.SLACK_LEAVE_CONVERSATION,
        Action.SLACK_LIST_PINNED_ITEMS,
        Action.SLACK_LIST_STARRED_ITEMS,
        Action.SLACK_LIST_CONVERSATIONS,
        Action.SLACK_LIST_USERGROUP_USERS,
        Action.SLACK_LIST_FILES,
        Action.SLACK_LIST_REMOTE_FILES,
        Action.SLACK_LIST_SCHEDULED_MESSAGES,
        Action.SLACK_LIST_TEAM_EMOJIS,
        Action.SLACK_LIST_USERGROUPS,
        Action.SLACK_LIST_USER_REACTIONS,
        Action.SLACK_OPEN_DM,
        Action.SLACK_PIN_ITEM,
        Action.SLACK_REMOVE_REMOTE_FILE,
        Action.SLACK_REMOVE_STAR,
        Action.SLACK_REMOVE_USER_FROM_CONVERSATION,
        Action.SLACK_RENAME_EMOJI,
        Action.SLACK_RENAME_CONVERSATION
    ],

    App.BREVO: [
        Action.BREVO_CREATE_COMPANY,
        Action.BREVO_CREATE_OR_UPDATE_EMAIL_TEMPLATE,
        Action.BREVO_CREATE_SMS_CAMPAIGN,
        Action.BREVO_DELETE_COMPANY,
        Action.BREVO_DELETE_CONTACT,
        Action.BREVO_DELETE_EMAIL_TEMPLATE,
        Action.BREVO_DELETE_SMS_CAMPAIGN,
        Action.BREVO_FIND_CONTACT,
        Action.BREVO_GET_ACCOUNT_INFORMATION,
        Action.BREVO_GET_ALL_CONTACTS,
        Action.BREVO_GET_ALL_EMAIL_TEMPLATES,
        Action.BREVO_GET_ALL_SENDERS,
        Action.BREVO_GET_COMPANY_DETAILS,
        Action.BREVO_GET_CONTACT_DETAILS,
        Action.BREVO_GET_SMS_CAMPAIGNS,
        Action.BREVO_GET_SMS_CAMPAIGN_DETAILS,
        Action.BREVO_LIST_ALL_COMPANIES,
        Action.BREVO_LIST_EMAIL_CAMPAIGNS,
        Action.BREVO_UPDATE_EMAIL_CAMPAIGN
    ],

    App.YOUTUBE: [
        Action.YOUTUBE_LIST_CAPTIONS,
        Action.YOUTUBE_UPDATE_THUMBNAIL,
        Action.YOUTUBE_GET_CHANNEL_ID_BY_HANDLE,
        Action.YOUTUBE_GET_CHANNEL_STATISTICS,
        Action.YOUTUBE_LIST_CHANNEL_VIDEOS,
        Action.YOUTUBE_LIST_USER_PLAYLISTS,
        Action.YOUTUBE_LIST_USER_SUBSCRIPTIONS,
        Action.YOUTUBE_DOWNLOAD_CAPTION_TRACK,
        Action.YOUTUBE_SEARCH_YOUTUBE,
        Action.YOUTUBE_SUBSCRIBE_TO_CHANNEL,
        Action.YOUTUBE_UPDATE_VIDEO,
        Action.YOUTUBE_UPLOAD_VIDEO,
        Action.YOUTUBE_GET_VIDEO_DETAILS
    ],

    App.CALENDLY: [
        Action.CALENDLY_GET_USER,
        Action.CALENDLY_GET_CURRENT_USER,
        Action.CALENDLY_CANCEL_EVENT,
        Action.CALENDLY_GET_EVENT,
        Action.CALENDLY_LIST_EVENTS,
        Action.CALENDLY_GET_EVENT_TYPE,
        Action.CALENDLY_LIST_EVENT_TYPE_AVAILABLE_TIMES,
        Action.CALENDLY_CREATE_ONE_OFF_EVENT_TYPE,
        Action.CALENDLY_GET_EVENT_INVITEE,
        Action.CALENDLY_LIST_EVENT_INVITEES,
        Action.CALENDLY_CREATE_INVITEE_NO_SHOW,
        Action.CALENDLY_GET_INVITEE_NO_SHOW,
        Action.CALENDLY_DELETE_INVITEE_NO_SHOW,
        Action.CALENDLY_CREATE_SCHEDULING_LINK,
        Action.CALENDLY_CREATE_SINGLE_USE_SCHEDULING_LINK,
        Action.CALENDLY_CREATE_SHARE,
        Action.CALENDLY_GET_USER_AVAILABILITY_SCHEDULE,
        Action.CALENDLY_CREATE_WEBHOOK_SUBSCRIPTION,
        Action.CALENDLY_GET_WEBHOOK_SUBSCRIPTION,
        Action.CALENDLY_DELETE_WEBHOOK_SUBSCRIPTION,
        Action.CALENDLY_GET_ORGANIZATION_INVITATION,
        Action.CALENDLY_INVITE_USER_TO_ORGANIZATION,
        Action.CALENDLY_GET_ORGANIZATION_MEMBERSHIP,
        Action.CALENDLY_GET_GROUP,
        Action.CALENDLY_GET_GROUP_RELATIONSHIP,
        Action.CALENDLY_GET_ROUTING_FORM,
        Action.CALENDLY_LIST_ACTIVITY_LOG_ENTRIES,
        Action.CALENDLY_DELETE_INVITEE_DATA,
        Action.CALENDLY_DELETE_SCHEDULED_EVENT_DATA,
        Action.CALENDLY_LIST_EVENT_TYPE_HOSTS,
        Action.CALENDLY_LIST_GROUPS,
        Action.CALENDLY_LIST_GROUP_RELATIONSHIPS,
        Action.CALENDLY_LIST_ORGANIZATION_INVITATIONS,
        Action.CALENDLY_LIST_ORGANIZATION_MEMBERSHIPS,
        Action.CALENDLY_LIST_OUTGOING_COMMUNICATIONS,
        Action.CALENDLY_LIST_ROUTING_FORMS,
        Action.CALENDLY_LIST_USER_AVAILABILITY_SCHEDULES,
        Action.CALENDLY_LIST_USER_BUSY_TIMES,
        Action.CALENDLY_LIST_USER_EVENT_TYPES,
        Action.CALENDLY_LIST_WEBHOOK_SUBSCRIPTIONS,
        Action.CALENDLY_REMOVE_USER_FROM_ORGANIZATION,
        Action.CALENDLY_REVOKE_ORGANIZATION_INVITATION
    ],

    App.AGENTQL: [
        Action.AGENTQL_QUERY_STRUCTURED_DATA
    ],

    App.APOLLO: [
        Action.APOLLO_ADD_CONTACTS_TO_SEQUENCE,
        Action.APOLLO_BULK_ORGANIZATION_ENRICHMENT,
        Action.APOLLO_BULK_PEOPLE_ENRICHMENT,
        Action.APOLLO_BULK_UPDATE_ACCOUNT_STAGE,
        Action.APOLLO_GET_LABELS,
        Action.APOLLO_GET_OPPORTUNITY_STAGES,
        Action.APOLLO_GET_ORGANIZATION_JOB_POSTINGS,
        Action.APOLLO_GET_TYPED_CUSTOM_FIELDS,
        Action.APOLLO_LIST_EMAIL_ACCOUNTS,
        Action.APOLLO_PEOPLE_SEARCH,
        Action.APOLLO_SEARCH_TASKS,
        Action.APOLLO_UPDATE_CONTACT_OWNERSHIP,
        Action.APOLLO_UPDATE_CONTACT_STAGE,
        Action.APOLLO_UPDATE_CONTACT_STATUS_IN_SEQUENCE,
        Action.APOLLO_CREATE_ACCOUNT,
        Action.APOLLO_CREATE_CONTACT,
        Action.APOLLO_CREATE_DEAL,
        Action.APOLLO_CREATE_TASK,
        Action.APOLLO_LIST_ACCOUNT_STAGES,
        Action.APOLLO_LIST_CONTACT_STAGES,
        Action.APOLLO_LIST_DEALS,
        Action.APOLLO_LIST_USERS,
        Action.APOLLO_ENRICH_ORGANIZATION_DATA,
        Action.APOLLO_SEARCH_ORGANIZATIONS,
        Action.APOLLO_ENRICH_PERSON,
        Action.APOLLO_SEARCH_ACCOUNTS,
        Action.APOLLO_SEARCH_CONTACTS,
        Action.APOLLO_UPDATE_ACCOUNT,
        Action.APOLLO_UPDATE_CONTACT,
        Action.APOLLO_UPDATE_DEAL
    ],

    App.BANNERBEAR: [
        Action.BANNERBEAR_GET_ACCOUNT_INFO,
        Action.BANNERBEAR_GET_AVAILABLE_FONTS,
        Action.BANNERBEAR_GET_SIGNED_BASES,
        Action.BANNERBEAR_GET_TEMPLATE_SET_DETAILS,
        Action.BANNERBEAR_JOIN_PDFS,
        Action.BANNERBEAR_LIST_IMAGES,
        Action.BANNERBEAR_LIST_TEMPLATES,
        Action.BANNERBEAR_LIST_VIDEOS
    ],

    App.BITQUERY: [
        Action.BITQUERY_COMBINED_DATABASE_QUERY,
        Action.BITQUERY_ALIASES_METRIC,
        Action.BITQUERY_ARCHIVE_DATABASE_QUERY,
        Action.BITQUERY_CONDITIONAL_METRICS_SNIPPET,
        Action.BITQUERY_COUNT_DISTINCT_METRIC,
        Action.BITQUERY_COUNT_METRIC,
        Action.BITQUERY_DATABASE_SELECTION,
        Action.BITQUERY_EARLY_ACCESS_PROGRAM_QUERY,
        Action.BITQUERY_MEMPOOL_SUBSCRIPTION,
        Action.BITQUERY_NETWORK_SELECTION,
        Action.BITQUERY_OPTIONS_QUERY,
        Action.BITQUERY_PRICE_ASYMMETRY_METRIC,
        Action.BITQUERY_QUANTILE_METRIC,
        Action.BITQUERY_REALTIME_DATABASE_QUERY,
        Action.BITQUERY_SELECT_BY_METRIC,
        Action.BITQUERY_STATISTICS_METRIC,
        Action.BITQUERY_SUM_METRIC,
        Action.BITQUERY_UNIQ_METRIC
    ],

    App.BOTSONIC: [
        Action.BOTSONIC_GET_ALL_BOTS,
        Action.BOTSONIC_GET_SPECIFIC_BOT,
        Action.BOTSONIC_CREATE_BOT,
        Action.BOTSONIC_UPDATE_BOT,
        Action.BOTSONIC_DELETE_BOT,
        Action.BOTSONIC_GET_BOT_API_KEY
    ],

    App.CAL: [
        Action.CAL_GET_BOOKING,
        Action.CAL_GET_ALL_BOOKINGS,
        Action.CAL_GET_ORGANIZATION_BOOKINGS,
        Action.CAL_GET_ORGANIZATION_TEAM_BOOKINGS,
        Action.CAL_GET_ORGANIZATION_USER_BOOKINGS,
        Action.CAL_CREATE_BOOKING,
        Action.CAL_CONFIRM_BOOKING,
        Action.CAL_CANCEL_BOOKING,
        Action.CAL_RESCHEDULE_BOOKING,
        Action.CAL_REASSIGN_BOOKING_TO_HOST,
        Action.CAL_REASSIGN_BOOKING_AUTO,
        Action.CAL_MARK_BOOKING_ABSENT,
        Action.CAL_DECLINE_BOOKING,
        Action.CAL_GET_ADD_TO_CALENDAR_LINKS,
        Action.CAL_GET_EVENT_TYPE,
        Action.CAL_GET_ALL_EVENT_TYPES,
        Action.CAL_GET_TEAM_EVENT_TYPES,
        Action.CAL_GET_TEAM_EVENT_TYPE,
        Action.CAL_CREATE_EVENT_TYPE,
        Action.CAL_FIND_AVAILABLE_SLOTS,
        Action.CAL_GET_MY_PROFILE,
        Action.CAL_GET_ALL_USERS,
        Action.CAL_GET_MANAGED_USER,
        Action.CAL_GET_ALL_MANAGED_USERS,
        Action.CAL_GET_MEMBERSHIP,
        Action.CAL_GET_ALL_MEMBERSHIPS,
        Action.CAL_GET_USER_TEAM_MEMBERSHIPS,
        Action.CAL_CREATE_MEMBERSHIP,
        Action.CAL_UPDATE_MEMBERSHIP,
        Action.CAL_DELETE_MEMBERSHIP,
        Action.CAL_GET_MANAGED_ORGANIZATION,
        Action.CAL_GET_ALL_ORGANIZATIONS,
        Action.CAL_CREATE_SUB_ORGANIZATION,
        Action.CAL_GET_TEAMS,
        Action.CAL_GET_TEAM,
        Action.CAL_GET_ALL_TEAMS,
        Action.CAL_GET_ALL_TEAM_EVENT_TYPES,
        Action.CAL_GET_ORGANIZATION_ROUTING_FORMS,
        Action.CAL_GET_TEAM_ROUTING_FORMS,
        Action.CAL_GET_ORGANIZATION_TEAM_BOOKINGS_LEGACY,
        Action.CAL_GET_CALENDAR_BUSY_TIMES,
        Action.CAL_CHECK_CALENDAR_CONNECTION,
        Action.CAL_DISCONNECT_CALENDAR,
        Action.CAL_SYNC_CALENDAR_CREDENTIALS,
        Action.CAL_GET_ALL_CALENDARS,
        Action.CAL_GET_ALL_SCHEDULES,
        Action.CAL_GET_SCHEDULE,
        Action.CAL_GET_DEFAULT_SCHEDULE,
        Action.CAL_GET_TEAM_MEMBER_SCHEDULES,
        Action.CAL_GET_USER_OOO_ENTRIES,
        Action.CAL_GET_ORG_USERS_OOO_ENTRIES,
        Action.CAL_CREATE_OOO_ENTRY,
        Action.CAL_CHECK_TEAM_STRIPE_CONNECTION,
        Action.CAL_CHECK_STRIPE_CONNECTION,
        Action.CAL_SAVE_TEAM_STRIPE_CREDENTIALS,
        Action.CAL_SAVE_STRIPE_CREDENTIALS,
        Action.CAL_GET_TEAM_STRIPE_CONNECT_URL,
        Action.CAL_GET_STRIPE_CONNECT_URL,
        Action.CAL_LIST_CONFERENCING_APPLICATIONS,
        Action.CAL_LIST_TEAM_CONFERENCING_APPLICATIONS,
        Action.CAL_GET_DEFAULT_CONFERENCING_APPLICATION,
        Action.CAL_GET_TEAM_DEFAULT_CONFERENCING_APPLICATION,
        Action.CAL_SET_DEFAULT_CONFERENCING_APPLICATION,
        Action.CAL_SET_TEAM_DEFAULT_CONFERENCING_APPLICATION,
        Action.CAL_CREATE_PHONE_CALL,
        Action.CAL_GET_ALL_ATTRIBUTES,
        Action.CAL_GET_ATTRIBUTE,
        Action.CAL_CREATE_ATTRIBUTE,
        Action.CAL_ASSIGN_ATTRIBUTE_TO_USER,
        Action.CAL_GET_ALL_ATTRIBUTE_OPTIONS,
        Action.CAL_GET_ATTRIBUTE_OPTIONS_BY_ID,
        Action.CAL_GET_ATTRIBUTE_OPTIONS_BY_SLUG,
        Action.CAL_GET_USER_ATTRIBUTE_OPTIONS,
        Action.CAL_GET_ROUTING_FORM_RESPONSES,
        Action.CAL_UPDATE_ROUTING_FORM_RESPONSE,
        Action.CAL_GET_ALL_WEBHOOKS,
        Action.CAL_GET_WEBHOOK,
        Action.CAL_DELETE_ALL_WEBHOOKS,
        Action.CAL_REFRESH_API_KEY,
        Action.CAL_REFRESH_MANAGED_USER_TOKENS,
        Action.CAL_UPDATE_ORGANIZATION_DELEGATION_CREDENTIALS,
        Action.CAL_RESERVE_SLOT,
        Action.CAL_GET_RESERVED_SLOT,
        Action.CAL_GET_EVENT_TYPE_WEBHOOK,
        Action.CAL_GET_ALL_EVENT_TYPE_WEBHOOKS,
        Action.CAL_CREATE_OR_UPDATE_WEBHOOK
    ],

    App.CANVA: [
        Action.CANVA_REVOKE_OAUTH_TOKEN,
        Action.CANVA_LIST_BRAND_TEMPLATES,
        Action.CANVA_CREATE_DESIGN,
        Action.CANVA_CREATE_COMMENT_REPLY,
        Action.CANVA_CREATE_DESIGN_COMMENT,
        Action.CANVA_CREATE_FOLDER,
        Action.CANVA_DELETE_ASSET,
        Action.CANVA_EXCHANGE_OAUTH_TOKEN,
        Action.CANVA_GET_ASSET_UPLOAD_JOB,
        Action.CANVA_GET_CURRENT_USER,
        Action.CANVA_GET_DESIGN,
        Action.CANVA_GET_DESIGN_EXPORT_JOB,
        Action.CANVA_CREATE_DESIGN_EXPORT_JOB,
        Action.CANVA_CREATE_AUTOFILL_JOB,
        Action.CANVA_LIST_DESIGN_PAGES,
        Action.CANVA_LIST_FOLDER_ITEMS,
        Action.CANVA_LIST_DESIGNS,
        Action.CANVA_MOVE_ITEM_TO_FOLDER,
        Action.CANVA_DELETE_FOLDER,
        Action.CANVA_GET_APP_PUBLIC_KEYS,
        Action.CANVA_GET_ASSET,
        Action.CANVA_GET_DESIGN_COMMENT,
        Action.CANVA_GET_BRAND_TEMPLATE_DATASET,
        Action.CANVA_GET_BRAND_TEMPLATE,
        Action.CANVA_GET_AUTOFILL_JOB,
        Action.CANVA_GET_DESIGN_IMPORT_JOB,
        Action.CANVA_GET_FOLDER,
        Action.CANVA_UPDATE_ASSET,
        Action.CANVA_UPDATE_FOLDER,
        Action.CANVA_VALIDATE_OAUTH_TOKEN
    ],

    App.CLERK: [
        Action.CLERK_LIST_ALL_USERS,
        Action.CLERK_COUNT_USERS,
        Action.CLERK_RETRIEVE_USER,
        Action.CLERK_CREATE_USER,
        Action.CLERK_UPDATE_USER,
        Action.CLERK_DELETE_USER,
        Action.CLERK_LOCK_USER,
        Action.CLERK_UNLOCK_USER,
        Action.CLERK_BAN_USER,
        Action.CLERK_UNBAN_USER,
        Action.CLERK_VERIFY_USER_PASSWORD,
        Action.CLERK_VERIFY_TOTP_OR_BACKUP_CODE,
        Action.CLERK_DISABLE_USER_MFA,
        Action.CLERK_DISABLE_USER_BACKUP_CODES,
        Action.CLERK_DELETE_USER_TOTPS,
        Action.CLERK_DELETE_USER_PASSKEY,
        Action.CLERK_DELETE_USER_WEB3_WALLET,
        Action.CLERK_SET_USER_PROFILE_IMAGE,
        Action.CLERK_DELETE_USER_PROFILE_IMAGE,
        Action.CLERK_RETRIEVE_USER_ORGANIZATION_MEMBERSHIPS,
        Action.CLERK_RETRIEVE_USER_INVITATIONS,
        Action.CLERK_MERGE_AND_UPDATE_USER_METADATA,
        Action.CLERK_RETRIEVE_ORGANIZATION,
        Action.CLERK_GET_LIST_OF_ORGANIZATIONS,
        Action.CLERK_CREATE_ORGANIZATION,
        Action.CLERK_UPDATE_ORGANIZATION,
        Action.CLERK_DELETE_ORGANIZATION,
        Action.CLERK_UPLOAD_ORGANIZATION_LOGO,
        Action.CLERK_DELETE_ORGANIZATION_LOGO,
        Action.CLERK_MERGE_AND_UPDATE_ORGANIZATION_METADATA,
        Action.CLERK_LIST_INVITATIONS,
        Action.CLERK_RETRIEVE_ORGANIZATION_INVITATIONS,
        Action.CLERK_GET_ORGANIZATION_INVITATIONS_FOR_CURRENT_INSTANCE,
        Action.CLERK_RETRIEVE_ORGANIZATION_INVITATION_BY_ID,
        Action.CLERK_CREATE_INVITATION,
        Action.CLERK_CREATE_MULTIPLE_INVITATIONS,
        Action.CLERK_BULK_CREATE_AND_SEND_ORGANIZATION_INVITATIONS,
        Action.CLERK_CREATE_AND_SEND_ORGANIZATION_INVITATION,
        Action.CLERK_REVOKE_INVITATION,
        Action.CLERK_REVOKE_PENDING_ORGANIZATION_INVITATION,
        Action.CLERK_LIST_WAITLIST_ENTRIES,
        Action.CLERK_CREATE_WAITLIST_ENTRY,
        Action.CLERK_LIST_ALLOWLIST_IDENTIFIERS,
        Action.CLERK_ADD_IDENTIFIER_TO_ALLOWLIST,
        Action.CLERK_DELETE_IDENTIFIER_FROM_ALLOWLIST,
        Action.CLERK_LIST_BLOCKLIST_IDENTIFIERS,
        Action.CLERK_ADD_IDENTIFIER_TO_BLOCKLIST,
        Action.CLERK_DELETE_IDENTIFIER_FROM_BLOCKLIST,
        Action.CLERK_RETRIEVE_EMAIL_ADDRESS,
        Action.CLERK_CREATE_EMAIL_ADDRESS,
        Action.CLERK_DELETE_EMAIL_ADDRESS,
        Action.CLERK_UPDATE_EMAIL_ADDRESS,
        Action.CLERK_RETRIEVE_OAUTH_ACCESS_TOKEN
    ],

    App.CLOSE: [
        Action.CLOSE_GET_ORGANIZATION_DETAILS,
        Action.CLOSE_FILTER_LEADS,
        Action.CLOSE_LIST_OPPORTUNITIES,
        Action.CLOSE_LIST_CONTACTS,
        Action.CLOSE_FETCH_SINGLE_CONTACT,
        Action.CLOSE_RETRIEVE_SINGLE_LEAD,
        Action.CLOSE_LIST_LEADS,
        Action.CLOSE_RETRIEVE_OPPORTUNITY,
        Action.CLOSE_MERGE_LEADS,
        Action.CLOSE_CREATE_NEW_CONTACT,
        Action.CLOSE_CREATE_LEAD,
        Action.CLOSE_CREATE_OPPORTUNITY,
        Action.CLOSE_UPDATE_CONTACT,
        Action.CLOSE_UPDATE_LEAD,
        Action.CLOSE_UPDATE_OPPORTUNITY,
        Action.CLOSE_UPDATE_ORGANIZATION,
        Action.CLOSE_DELETE_OPPORTUNITY,
        Action.CLOSE_DELETE_LEAD,
        Action.CLOSE_DELETE_CONTACT
    ],

    App.EXA: [
        Action.EXA_GET_LLM_ANSWER,
        Action.EXA_SEARCH,
        Action.EXA_GET_CONTENTS,
        Action.EXA_FIND_SIMILAR_LINKS,
    ],

    App.FIGMA: [
        Action.FIGMA_GET_FILE_JSON,
        Action.FIGMA_GET_COMPONENT,
        Action.FIGMA_EXTRACT_DESIGN_TOKENS,
        Action.FIGMA_DESIGN_TOKENS_TO_TAILWIND,
        Action.FIGMA_RENDER_IMAGES_OF_FILE_NODES,
        Action.FIGMA_DOWNLOAD_FIGMA_IMAGES,
        Action.FIGMA_GET_FILE_COMPONENTS,
        Action.FIGMA_GET_FILE_COMPONENT_SETS,
        Action.FIGMA_GET_LOCAL_VARIABLES,
        Action.FIGMA_GET_PUBLISHED_VARIABLES,
        Action.FIGMA_CREATE_MODIFY_DELETE_VARIABLES,
        Action.FIGMA_EXTRACT_PROTOTYPE_INTERACTIONS,
        Action.FIGMA_DISCOVER_FIGMA_RESOURCES,
        Action.FIGMA_GET_CURRENT_USER,
        Action.FIGMA_GET_PROJECTS_IN_TEAM,
        Action.FIGMA_GET_FILES_IN_PROJECT,
        Action.FIGMA_GET_VERSIONS_OF_FILE,
        Action.FIGMA_GET_COMMENTS_IN_FILE,
        Action.FIGMA_ADD_COMMENT_TO_FILE,
        Action.FIGMA_DELETE_COMMENT,
        Action.FIGMA_CREATE_WEBHOOK,
        Action.FIGMA_GET_TEAM_WEBHOOKS,
        Action.FIGMA_GET_WEBHOOK,
        Action.FIGMA_DELETE_WEBHOOK,
        Action.FIGMA_DELETE_DEV_RESOURCE,
        Action.FIGMA_DETECT_BACKGROUND,
        Action.FIGMA_GET_ACTIVITY_LOGS,
        Action.FIGMA_GET_COMMENTS,
        Action.FIGMA_GET_COMPONENT_SET,
        Action.FIGMA_GET_DEV_RESOURCES,
        Action.FIGMA_GET_FILE_STYLES,
        Action.FIGMA_GET_IMAGE_FILLS,
        Action.FIGMA_GET_LIBRARY_ANALYTICS_COMPONENT_ACTION_DATA,
        Action.FIGMA_GET_LIBRARY_ANALYTICS_COMPONENT_USAGE_DATA,
        Action.FIGMA_GET_LIBRARY_ANALYTICS_STYLE_ACTION_DATA,
        Action.FIGMA_GET_LIBRARY_ANALYTICS_STYLE_USAGE_DATA,
        Action.FIGMA_GET_LIBRARY_ANALYTICS_VARIABLE_ACTION_DATA,
        Action.FIGMA_GET_LIBRARY_ANALYTICS_VARIABLE_USAGE_DATA,
        Action.FIGMA_GET_PAYMENTS,
        Action.FIGMA_GET_REACTIONS,
        Action.FIGMA_GET_STYLE,
        Action.FIGMA_GET_TEAM_COMPONENTS,
        Action.FIGMA_GET_TEAM_COMPONENT_SETS,
        Action.FIGMA_GET_TEAM_STYLES,
        Action.FIGMA_GET_VERSIONS,
        Action.FIGMA_GET_WEBHOOK_REQUESTS,
        Action.FIGMA_RENDER_IMAGES,
        Action.FIGMA_UPDATE_WEBHOOK,
        Action.FIGMA_UPDATE_DEV_RESOURCES
    ],

    App.FIREFILES: [
        Action.FIREFILES_DELETE_TRANSCRIPT,
        Action.FIREFILES_UPLOAD_AUDIO,
        Action.FIREFILES_ADD_TO_LIVE,
        Action.FIREFILES_SET_USER_ROLE,
        Action.FIREFILES_QUERY_USERS,
        Action.FIREFILES_QUERY_BITE_DETAILS,
        Action.FIREFILES_CREATE_BITE,
        Action.FIREFILES_QUERY_AI_APPS_OUTPUTS,
        Action.FIREFILES_QUERY_TRANSCRIPTS,
        Action.FIREFILES_QUERY_TRANSCRIPT_DETAILS,
        Action.FIREFILES_QUERY_USER_DETAILS,
        Action.FIREFILES_QUERY_BITES,
    ],

    App.FOLK: [
        Action.FOLK_GET_CURRENT_USER,
        Action.FOLK_GET_USER,
        Action.FOLK_LIST_PEOPLE_IN_WORKSPACE,
        Action.FOLK_GET_NOTE,
        Action.FOLK_LIST_NOTES_IN_WORKSPACE,
        Action.FOLK_GET_COMPANY,
        Action.FOLK_LIST_GROUP_CUSTOM_FIELDS_FOR_ENTITY_TYPE,
        Action.FOLK_GET_DEAL,
        Action.FOLK_RETRIEVE_REMINDER,
        Action.FOLK_LIST_REMINDERS_IN_WORKSPACE,
        Action.FOLK_GET_PERSON,
        Action.FOLK_LIST_USERS,
        Action.FOLK_LIST_WORKSPACE_GROUPS,
        Action.FOLK_LIST_DEALS_IN_WORKSPACE_GROUP,
        Action.FOLK_LIST_COMPANIES,
        Action.FOLK_CREATE_PERSON,
        Action.FOLK_CREATE_NOTE_IN_WORKSPACE,
        Action.FOLK_CREATE_COMPANY,
        Action.FOLK_CREATE_INTERACTION,
        Action.FOLK_CREATE_DEAL_IN_WORKSPACE,
        Action.FOLK_CREATE_REMINDER,
        Action.FOLK_DELETE_NOTE,
        Action.FOLK_DELETE_COMPANY,
        Action.FOLK_DELETE_DEAL,
        Action.FOLK_DELETE_REMINDER,
        Action.FOLK_DELETE_PERSON,
        Action.FOLK_UPDATE_NOTE,
        Action.FOLK_UPDATE_COMPANY,
        Action.FOLK_UPDATE_DEAL,
        Action.FOLK_UPDATE_PERSON,
        Action.FOLK_UPDATE_REMINDER,
    ],

    App.FRONT: [
        Action.FRONT_GET_MESSAGE,
        Action.FRONT_GET_MESSAGE_SEEN_STATUS,
        Action.FRONT_MARK_MESSAGE_SEEN,
        Action.FRONT_CREATE_MESSAGE,
        Action.FRONT_CREATE_MESSAGE_REPLY,
        Action.FRONT_IMPORT_MESSAGE,
        Action.FRONT_RECEIVE_CUSTOM_MESSAGES,
        Action.FRONT_LIST_CONVERSATIONS,
        Action.FRONT_GET_CONVERSATION,
        Action.FRONT_LIST_CONVERSATION_MESSAGES,
        Action.FRONT_LIST_CONVERSATION_EVENTS,
        Action.FRONT_LIST_CONVERSATION_INBOXES,
        Action.FRONT_SEARCH_CONVERSATIONS,
        Action.FRONT_CREATE_DISCUSSION_CONVERSATION,
        Action.FRONT_UPDATE_CONVERSATION,
        Action.FRONT_UPDATE_CONVERSATION_ASSIGNEE,
        Action.FRONT_UPDATE_CONVERSATION_REMINDERS,
        Action.FRONT_ADD_CONVERSATION_FOLLOWERS,
        Action.FRONT_DELETE_CONVERSATION_FOLLOWERS,
        Action.FRONT_LIST_CONVERSATION_FOLLOWERS,
        Action.FRONT_ADD_CONVERSATION_TAG,
        Action.FRONT_REMOVE_CONVERSATION_TAG,
        Action.FRONT_ADD_CONVERSATION_LINK,
        Action.FRONT_REMOVE_CONVERSATION_LINKS,
        Action.FRONT_LIST_CONTACTS,
        Action.FRONT_GET_CONTACT,
        Action.FRONT_CREATE_CONTACT,
        Action.FRONT_UPDATE_CONTACT,
        Action.FRONT_DELETE_CONTACT,
        Action.FRONT_MERGE_CONTACTS,
        Action.FRONT_LIST_ACCOUNT_CONTACTS,
        Action.FRONT_ADD_CONTACT_TO_ACCOUNT,
        Action.FRONT_REMOVE_CONTACT_FROM_ACCOUNT,
    ],

    App.BIGQUERY: [
        Action.BIGQUERY_GET_TABLE,
        Action.BIGQUERY_LIST_DATASETS,
        Action.BIGQUERY_LIST_BIGQUERY_MODELS,
        Action.BIGQUERY_GET_QUERY_RESULTS,
        Action.BIGQUERY_LIST_TABLES,
        Action.BIGQUERY_GET_ROUTINE_RESOURCE,
        Action.BIGQUERY_LIST_ROUTINES,
        Action.BIGQUERY_LIST_TABLE_DATA,
        Action.BIGQUERY_GET_DATASET,
        Action.BIGQUERY_LIST_ROW_ACCESS_POLICIES,
        Action.BIGQUERY_LIST_JOBS,
        Action.BIGQUERY_GET_JOB_INFORMATION,
        Action.BIGQUERY_LIST_PROJECTS,
        Action.BIGQUERY_GET_MODEL,
        Action.BIGQUERY_GET_PROJECT_SERVICE_ACCOUNT,
        Action.BIGQUERY_INSERT_DATA,
        Action.BIGQUERY_GET_ROW_ACCESS_POLICY,
        Action.BIGQUERY_SET_IAM_POLICY,
        Action.BIGQUERY_CANCEL_BIGQUERY_JOB,
        Action.BIGQUERY_CREATE_TABLE,
        Action.BIGQUERY_GET_IAM_POLICY,
        Action.BIGQUERY_CREATE_ROUTINE,
        Action.BIGQUERY_CREATE_DATASET,
        Action.BIGQUERY_UNDELETE_DATASET,
        Action.BIGQUERY_TEST_IAM_PERMISSIONS,
        Action.BIGQUERY_START_ASYNC_JOB,
        Action.BIGQUERY_EXECUTE_SQL_QUERY,
        Action.BIGQUERY_UPDATE_DATASET,
        Action.BIGQUERY_UPDATE_ROUTINE,
        Action.BIGQUERY_UPDATE_TABLE,
        Action.BIGQUERY_DELETE_JOB_METADATA,
        Action.BIGQUERY_DELETE_ROUTINE,
        Action.BIGQUERY_DELETE_DATASET,
        Action.BIGQUERY_DELETE_TABLE,
        Action.BIGQUERY_DELETE_BIGQUERY_MODEL,
        Action.BIGQUERY_PATCH_MODEL_FIELDS,
    ],

    App.HACKERNEWS: [
        Action.HACKERNEWS_GET_MAX_ITEM_ID,
        Action.HACKERNEWS_GET_USER,
        Action.HACKERNEWS_GET_SHOW_STORIES,
        Action.HACKERNEWS_GET_UPDATES,
        Action.HACKERNEWS_GET_BEST_STORIES,
        Action.HACKERNEWS_GET_TOP_STORIES,
        Action.HACKERNEWS_GET_NEW_STORIES,
        Action.HACKERNEWS_GET_JOB_STORIES,
        Action.HACKERNEWS_GET_ASK_STORIES,
        Action.HACKERNEWS_GET_ITEM,
    ],

    App.HUBSPOT: [
        Action.HUBSPOT_CREATE_BATCH_TICKETS,
        Action.HUBSPOT_CREATE_PRODUCT_BATCH,
        Action.HUBSPOT_CREATE_PRODUCT_OBJECT,
        Action.HUBSPOT_GET_PIPELINE_STAGE_AUDIT,
        Action.HUBSPOT_LIST_PRODUCTS_WITH_PAGING,
        Action.HUBSPOT_UPDATE_PRODUCT,
        Action.HUBSPOT_ARCHIVE_PRODUCT_BY_ID,
        Action.HUBSPOT_CREATE_COMPANY_BATCH,
        Action.HUBSPOT_CREATE_CONTACT_BATCH,
        Action.HUBSPOT_CREATE_DEAL_BATCH,
        Action.HUBSPOT_SEARCH_CONTACTS,
        Action.HUBSPOT_SEARCH_COMPANIES,
        Action.HUBSPOT_SEARCH_DEALS,
        Action.HUBSPOT_CREATE_CUSTOM_PROPERTY,
        Action.HUBSPOT_CREATE_PIPELINE,
        Action.HUBSPOT_GET_CONTACT_BY_ID,
        Action.HUBSPOT_GET_COMPANY_BY_ID,
        Action.HUBSPOT_GET_DEAL_BY_ID,
        Action.HUBSPOT_CREATE_MARKETING_EMAIL,
        Action.HUBSPOT_CREATE_WORKFLOW,
        Action.HUBSPOT_ARCHIVE_BATCH_CONTACTS,
        Action.HUBSPOT_ARCHIVE_BATCH_COMPANIES,
        Action.HUBSPOT_ARCHIVE_BATCH_DEALS,
        Action.HUBSPOT_MERGE_CONTACTS,
        Action.HUBSPOT_MERGE_COMPANIES,
        Action.HUBSPOT_MERGE_DEALS,
        Action.HUBSPOT_LIST_ALL_PROPERTIES,
        Action.HUBSPOT_LIST_OWNERS,
        Action.HUBSPOT_GET_ALL_PIPELINES,
        Action.HUBSPOT_CREATE_ASSOCIATION_DEFINITION,
        Action.HUBSPOT_GDPR_DELETE_CONTACT,
        Action.HUBSPOT_RETRIEVE_ALL_OBJECT_SCHEMAS,
        Action.HUBSPOT_RETRIEVE_ALL_PIPELINES_FOR_OBJECT_TYPE,
        Action.HUBSPOT_RETRIEVE_BATCH_DEALS_BY_IDS,
        Action.HUBSPOT_RETRIEVE_CALLING_SETTINGS_FOR_APP,
        Action.HUBSPOT_RETRIEVE_COMPANY_BY_ID,
        Action.HUBSPOT_RETRIEVE_DEAL_BY_ID,
        Action.HUBSPOT_RETRIEVE_EXISTING_OBJECT_SCHEMA,
        Action.HUBSPOT_RETRIEVE_LINE_ITEMS_LIST,
        Action.HUBSPOT_RETRIEVE_LINE_ITEM_BY_ID,
        Action.HUBSPOT_RETRIEVE_OWNERS,
    ],

    App.INTERCOM: [
        Action.INTERCOM_ATTACH_CONTACT_TO_COMPANY,
        Action.INTERCOM_ADD_SUBSCRIPTION_TO_CONTACT,
        Action.INTERCOM_ADD_TAG_TO_CONTACT,
        Action.INTERCOM_CREATE_ARTICLE,
        Action.INTERCOM_CREATE_COLLECTION,
        Action.INTERCOM_CREATE_NOTE,
        Action.INTERCOM_CREATE_OR_UPDATE_COMPANY,
        Action.INTERCOM_DELETE_ARTICLE,
        Action.INTERCOM_DELETE_COLLECTION,
        Action.INTERCOM_DELETE_COMPANY,
        Action.INTERCOM_DELETE_CONTACT,
        Action.INTERCOM_DETACH_CONTACT_FROM_COMPANY,
        Action.INTERCOM_GET_CONTACT,
        Action.INTERCOM_IDENTIFY_ADMIN,
        Action.INTERCOM_LIST_ALL_ACTIVITY_LOGS,
        Action.INTERCOM_LIST_ALL_ADMINS,
        Action.INTERCOM_LIST_ALL_ARTICLES,
        Action.INTERCOM_LIST_ALL_COLLECTIONS,
        Action.INTERCOM_LIST_ALL_COMPANIES,
        Action.INTERCOM_LIST_ALL_HELP_CENTERS,
        Action.INTERCOM_LIST_ALL_NOTES,
        Action.INTERCOM_LIST_ATTACHED_COMPANIES_FOR_CONTACT,
        Action.INTERCOM_LIST_ATTACHED_CONTACTS,
        Action.INTERCOM_LIST_ATTACHED_SEGMENTS_FOR_COMPANIES,
        Action.INTERCOM_LIST_ATTACHED_SEGMENTS_FOR_CONTACT,
        Action.INTERCOM_LIST_SUBSCRIPTIONS_FOR_CONTACT,
        Action.INTERCOM_LIST_TAGS_ATTACHED_TO_CONTACT,
        Action.INTERCOM_MERGE_LEAD_AND_USER,
        Action.INTERCOM_REMOVE_SUBSCRIPTION_FROM_CONTACT,
        Action.INTERCOM_REMOVE_TAG_FROM_CONTACT,
        Action.INTERCOM_RETRIEVE_ADMIN,
        Action.INTERCOM_RETRIEVE_ARTICLE,
        Action.INTERCOM_RETRIEVE_COLLECTION,
        Action.INTERCOM_RETRIEVE_COMPANY_BY_ID,
        Action.INTERCOM_RETRIEVE_HELP_CENTER,
        Action.INTERCOM_RETRIEVE_COMPANIES,
        Action.INTERCOM_SCROLL_OVER_ALL_COMPANIES,
        Action.INTERCOM_SEARCH_FOR_ARTICLES,
        Action.INTERCOM_SET_ADMIN_TO_AWAY,
        Action.INTERCOM_UPDATE_ARTICLE,
        Action.INTERCOM_UPDATE_COLLECTION,
        Action.INTERCOM_UPDATE_COMPANY,
        Action.INTERCOM_UPDATE_CONTACT,
    ],

    App.KERNEL: [
        Action.KERNEL_GET_BROWSER_SESSION_DETAILS,
        Action.KERNEL_GET_DEPLOYMENT_DETAILS,
        Action.KERNEL_LIST_ACTIVE_BROWSER_SESSIONS,
        Action.KERNEL_GET_INVOCATION_STATUS,
        Action.KERNEL_LIST_APPLICATIONS,
        Action.KERNEL_CREATE_BROWSER_SESSION,
        Action.KERNEL_INVOKE_ACTION,
        Action.KERNEL_DELETE_PERSISTENT_BROWSER_SESSION,
    ],

    App.LOOPS: [
        Action.LOOPS_LIST_MAILING_LISTS,
        Action.LOOPS_FIND_CONTACT,
        Action.LOOPS_TEST_API_KEY_VALIDITY,
        Action.LOOPS_LIST_TRANSACTIONAL_EMAILS,
        Action.LOOPS_LIST_CONTACT_PROPERTIES,
        Action.LOOPS_SEND_EVENT,
        Action.LOOPS_CREATE_CONTACT,
        Action.LOOPS_DELETE_CONTACT,
        Action.LOOPS_CREATE_CONTACT_PROPERTY,
        Action.LOOPS_SEND_TRANSACTIONAL_EMAIL,
        Action.LOOPS_UPDATE_OR_CREATE_CONTACT,
    ],

    App.MAILCHIMP: [
        Action.MAILCHIMP_GET_CAMPAIGN_INFO,
        Action.MAILCHIMP_GET_LISTS_INFO,
        Action.MAILCHIMP_LIST_CAMPAIGNS,
        Action.MAILCHIMP_LIST_RECENT_ACTIVITY,
        Action.MAILCHIMP_SEARCH_MEMBERS,
        Action.MAILCHIMP_SEND_CAMPAIGN,
        Action.MAILCHIMP_ADD_AUTOMATION,
        Action.MAILCHIMP_ADD_BATCH_WEBHOOK,
        Action.MAILCHIMP_ADD_CAMPAIGN,
        Action.MAILCHIMP_ADD_CAMPAIGN_FEEDBACK,
        Action.MAILCHIMP_ADD_CAMPAIGN_FOLDER,
        Action.MAILCHIMP_ADD_CART,
        Action.MAILCHIMP_ADD_PRODUCT,
        Action.MAILCHIMP_ADD_PRODUCT_IMAGE,
        Action.MAILCHIMP_ADD_PRODUCT_VARIANT,
        Action.MAILCHIMP_ADD_PROMO_CODE,
        Action.MAILCHIMP_ADD_PROMO_RULE,
        Action.MAILCHIMP_ADD_SEGMENT,
    ],

    App.MEETGEEK: [
        Action.MEETGEEK_GET_TEAMS_OF_USER,
        Action.MEETGEEK_GET_TRANSCRIPT_SENTENCES_BY_MEETING_ID,
        Action.MEETGEEK_GET_HIGHLIGHTS_BY_MEETING_ID,
        Action.MEETGEEK_GET_SUMMARY_BY_MEETING_ID,
        Action.MEETGEEK_GET_PAGINATED_TEAM_MEETINGS,
        Action.MEETGEEK_GET_PAGINATED_PAST_MEETINGS,
        Action.MEETGEEK_GET_MEETING_DETAILS,
        Action.MEETGEEK_UPLOAD_FILE_FOR_ANALYSIS,
    ],

    App.NETLIFY: [
        Action.NETLIFY_GET_SITE_DEV_SERVER_HOOK,
        Action.NETLIFY_LIST_PAYMENT_METHODS_FOR_USER,
        Action.NETLIFY_SHOW_SERVICE_INSTANCE,
        Action.NETLIFY_GET_SINGLE_DNS_ZONE,
        Action.NETLIFY_SHOW_SITE_TLS_CERTIFICATE,
        Action.NETLIFY_LIST_SITES_FOR_ACCOUNT,
        Action.NETLIFY_LIST_DEPLOY_KEYS,
        Action.NETLIFY_LIST_SITE_SNIPPETS,
        Action.NETLIFY_GET_SITE_ASSET_INFO,
        Action.NETLIFY_GET_SITE_DEV_SERVER,
        Action.NETLIFY_LIST_ACCOUNT_TYPES_FOR_USER,
        Action.NETLIFY_GET_HOOK_DETAILS,
        Action.NETLIFY_GET_ACCOUNT_BUILD_STATUS,
        Action.NETLIFY_GET_DNS_RECORDS_FOR_SITE,
        Action.NETLIFY_LIST_BUILD_HOOKS_FOR_SITE,
        Action.NETLIFY_GET_SITE_BUILD,
        Action.NETLIFY_LIST_DEPLOYS_FOR_SITE,
        Action.NETLIFY_GET_SPLIT_TEST_DETAILS,
        Action.NETLIFY_LIST_FORM_SUBMISSION,
        Action.NETLIFY_SEARCH_SITE_FUNCTIONS,
        Action.NETLIFY_GET_PUBLIC_SIGNATURE_URL_FOR_SITE_ASSET,
        Action.NETLIFY_GET_CURRENT_USER,
        Action.NETLIFY_GET_DNS_ZONES,
        Action.NETLIFY_GET_SITE_DEPLOY,
        Action.NETLIFY_LIST_FORMS_FOR_SITE,
        Action.NETLIFY_GET_ENVIRONMENT_VARIABLE_FOR_ACCOUNT,
        Action.NETLIFY_LIST_SITE_SUBMISSIONS,
        Action.NETLIFY_GET_ENVIRONMENT_VARIABLES_FOR_SITE,
        Action.NETLIFY_SHOW_OAUTH_TICKET,
        Action.NETLIFY_GET_SITE_SNIPPET,
        Action.NETLIFY_LIST_FORM_SUBMISSIONS,
        Action.NETLIFY_LIST_SITE_FILES,
        Action.NETLIFY_GET_ACCOUNT_MEMBER_DETAILS,
        Action.NETLIFY_GET_ALL_CERTIFICATES_FOR_SITE,
        Action.NETLIFY_GET_DEPLOY_KEY,
        Action.NETLIFY_GET_INDIVIDUAL_DNS_RECORD,
        Action.NETLIFY_LIST_SITES,
        Action.NETLIFY_SHOW_SERVICE_DETAILS,
        Action.NETLIFY_LIST_DEPLOYED_BRANCHES_FOR_SITE,
        Action.NETLIFY_LIST_SERVICE_INSTANCES_FOR_SITE,
        Action.NETLIFY_GET_DEPLOY_DETAILS,
        Action.NETLIFY_LIST_ACCOUNTS_FOR_USER,
        Action.NETLIFY_LIST_SITE_BUILDS,
        Action.NETLIFY_GET_SITE_METADATA,
        Action.NETLIFY_LIST_ACCOUNT_AUDIT_EVENTS,
        Action.NETLIFY_LIST_SITE_DEV_SERVERS,
        Action.NETLIFY_GET_ENVIRONMENT_VARIABLES,
        Action.NETLIFY_LIST_HOOK_TYPES,
        Action.NETLIFY_GET_SITE_BUILD_HOOK,
        Action.NETLIFY_GET_ALL_DNS_RECORDS_FOR_SINGLE_DNS_ZONE,
        Action.NETLIFY_LIST_MEMBERS_FOR_ACCOUNT,
        Action.NETLIFY_GET_ACCOUNT_INFORMATION,
        Action.NETLIFY_GET_SPLIT_TESTS_FOR_SITE,
        Action.NETLIFY_SHOW_SERVICE_MANIFEST,
        Action.NETLIFY_GET_SITE_FILE_BY_PATH_NAME,
        Action.NETLIFY_GET_LIST_OF_SERVICES,
        Action.NETLIFY_LIST_HOOKS_BY_SITE_ID,
        Action.NETLIFY_LIST_SITE_ASSETS,
        Action.NETLIFY_LIST_SITE_DEV_SERVER_HOOKS,
    ],

    App.NEWSDATA: [
        Action.NEWSDATA_GET_NEWS_SOURCES,
        Action.NEWSDATA_GET_LATEST_NEWS,
        Action.NEWSDATA_GET_CRYPTO_NEWS,
        Action.NEWSDATA_GET_NEWS_ARCHIVE,
    ],

    App.PEOPLEDATALABS: [
        Action.PEOPLEDATALABS_PERSON_SEARCH
    ],
    
    App.OPENROUTER: [
        Action.OPENROUTER_GET_CREDITS,
        Action.OPENROUTER_LIST_AVAILABLE_PROVIDERS,
        Action.OPENROUTER_GET_CURRENT_API_KEY_INFO,
        Action.OPENROUTER_LIST_AVAILABLE_MODELS,
        Action.OPENROUTER_LIST_ENDPOINTS_FOR_MODEL,
        Action.OPENROUTER_GET_API_KEY_DETAILS,
        Action.OPENROUTER_GET_GENERATION,
        Action.OPENROUTER_LIST_API_KEYS,
        Action.OPENROUTER_CREATE_COINBASE_CHARGE,
        Action.OPENROUTER_CREATE_API_KEY,
        Action.OPENROUTER_EXCHANGE_OAUTH_CODE,
        Action.OPENROUTER_SEND_CHAT_COMPLETION,
        Action.OPENROUTER_SEND_COMPLETION,
        Action.OPENROUTER_DELETE_API_KEY,
        Action.OPENROUTER_UPDATE_API_KEY,
    ],

    App.PINECONE: [
        Action.PINECONE_LIST_INDEXES,
        Action.PINECONE_DESCRIBE_IMPORT,
        Action.PINECONE_LIST_IMPORTS,
        Action.PINECONE_LIST_COLLECTIONS,
        Action.PINECONE_LIST_VECTOR_IDS,
        Action.PINECONE_DESCRIBE_INDEX,
        Action.PINECONE_DESCRIBE_COLLECTION,
        Action.PINECONE_FETCH_VECTORS,
        Action.PINECONE_CREATE_COLLECTION,
        Action.PINECONE_QUERY_VECTORS,
        Action.PINECONE_GET_INDEX_STATS,
        Action.PINECONE_UPSERT_VECTORS,
        Action.PINECONE_START_IMPORT,
        Action.PINECONE_DELETE_VECTORS,
        Action.PINECONE_UPDATE_VECTOR,
        Action.PINECONE_CREATE_INDEX,
        Action.PINECONE_DELETE_INDEX,
        Action.PINECONE_DELETE_COLLECTION,
        Action.PINECONE_CANCEL_IMPORT_OPERATION,
        Action.PINECONE_CONFIGURE_INDEX,
    ],

    App.PLACES: [
        Action.PLACES_GET_PLACE_DETAILS,
        Action.PLACES_SEARCH_NEARBY_PLACES,
        Action.PLACES_TEXT_SEARCH_PLACES,
        Action.PLACES_AUTOCOMPLETE_PLACES,
        Action.PLACES_GET_PLACE_PHOTOS,
        Action.PLACES_SEARCH_PLACES_BY_CATEGORY,
        Action.PLACES_GET_PLACE_REVIEWS,
        Action.PLACES_GET_OPENING_HOURS,
        Action.PLACES_REVERSE_GEOCODE,
        Action.PLACES_GEOCODE_ADDRESS,
        Action.PLACES_VALIDATE_ADDRESS,
    ],

    App.POSTHOG: [
        Action.POSTHOG_LIST_PROJECTS,
        Action.POSTHOG_LIST_PROJECT_GROUP_TYPES,
        Action.POSTHOG_LIST_ORGANIZATIONS,
        Action.POSTHOG_ADD_DASHBOARD_COLLABORATORS,
        Action.POSTHOG_ADD_ORGANIZATION_MEMBER_ROLE,
        Action.POSTHOG_ADD_PROJECT_MEMBER_ROLES,
        Action.POSTHOG_ASSIGN_FEATURE_FLAG_ROLE_ACCESS,
        Action.POSTHOG_BOOKMARK_PROJECT_ACTIVITY_NOTIFICATION,
        Action.POSTHOG_BULK_CREATE_ORGANIZATION_INVITES,
        Action.POSTHOG_CANCEL_PROJECT_INSIGHTS,
        Action.POSTHOG_CHECK_PIPELINE_DESTINATION_UPDATES,
        Action.POSTHOG_CHECK_PIPELINE_IMPORT_APP_UPDATES,
        Action.POSTHOG_CHECK_PIPELINE_PLUGIN_UPDATE_STATUS,
        Action.POSTHOG_CHECK_PROJECT_DEMO_DATA_GENERATION_STATUS,
        Action.POSTHOG_DUPLICATE_COHORT_TO_STATIC,
        Action.POSTHOG_CREATE_NOTEBOOK,
        Action.POSTHOG_CREATE_PROJECT_INSIGHTS,
        Action.POSTHOG_CREATE_DASHBOARD_FROM_TEMPLATE,
        Action.POSTHOG_CREATE_ORGANIZATION_DOMAIN,
        Action.POSTHOG_CREATE_EXPERIMENT_EXPOSURE_COHORT,
        Action.POSTHOG_CREATE_FEATURE_FLAG,
        Action.POSTHOG_CREATE_FEATURE_FLAG_DASHBOARD,
        Action.POSTHOG_CREATE_FRONTEND_APP_PIPELINE_CONFIG,
        Action.POSTHOG_CREATE_FUNNEL_ANALYSIS_FOR_PERSONS,
        Action.POSTHOG_CREATE_ORGANIZATION,
        Action.POSTHOG_CREATE_PROJECT_EXPERIMENT,
        Action.POSTHOG_CREATE_ORGANIZATION_INVITE,
        Action.POSTHOG_CREATE_ORGANIZATION_ROLE,
        Action.POSTHOG_CREATE_ORGANIZATION_PROXY_RECORD,
        Action.POSTHOG_CREATE_PERSON_FUNNEL_CORRELATION,
        Action.POSTHOG_CREATE_PERSON_PATH,
        Action.POSTHOG_CREATE_PIPELINE_DESTINATION_CONFIG,
        Action.POSTHOG_CREATE_PIPELINE_DESTINATION_CONFIG_JOB,
        Action.POSTHOG_CREATE_PIPELINE_IMPORT_APPS_CONFIG_JOB,
        Action.POSTHOG_CREATE_PLUGIN_JOB_CONFIGURATION,
        Action.POSTHOG_CREATE_PROJECT_ACTION,
        Action.POSTHOG_CREATE_PROJECT_COHORTS,
        Action.POSTHOG_CREATE_PROJECT_DASHBOARD,
        Action.POSTHOG_CREATE_PROJECT_PIPELINE_APP_CONFIGS,
        Action.POSTHOG_CREATE_PROJECT_PIPELINE_FRONTEND_APP_JOB,
        Action.POSTHOG_CREATE_PROJECT_PIPELINE_TRANSFORMATION_CONFIG,
        Action.POSTHOG_CREATE_PROJECT_PLUGIN_CONFIGURATION,
        Action.POSTHOG_CREATE_PROJECT_SUBSCRIPTION,
        Action.POSTHOG_CREATE_PROJECT_SURVEYS,
        Action.POSTHOG_CREATE_PROJECT_TIMING_INSIGHTS,
        Action.POSTHOG_CREATE_PROJECT_QUERY,
        Action.POSTHOG_CREATE_RETENTION_INSIGHTS,
        Action.POSTHOG_CREATE_SESSION_RECORDING_IN_PLAYLIST,
        Action.POSTHOG_CREATE_SESSION_RECORDING_PLAYLISTS,
        Action.POSTHOG_CREATE_SESSION_RECORDING_SUMMARY,
        Action.POSTHOG_CREATE_STATIC_COHORT_FOR_FEATURE_FLAG,
        Action.POSTHOG_MANAGE_PROJECT_ANNOTATIONS,
        Action.POSTHOG_GENERATE_PROJECT_FUNNEL_INSIGHTS,
        Action.POSTHOG_DELETE_ORGANIZATION,
        Action.POSTHOG_DELETE_ORGANIZATION_PROJECT,
        Action.POSTHOG_DELETE_PERSON,
        Action.POSTHOG_DELETE_SESSION_RECORDING,
        Action.POSTHOG_DELETE_SURVEY,
        Action.POSTHOG_ENABLE_PROJECT_EARLY_ACCESS_FEATURE,
        Action.POSTHOG_FETCH_BATCH_EXPORT_DETAILS,
        Action.POSTHOG_FETCH_EXPORT_UNSUBSCRIBE_SETTINGS,
        Action.POSTHOG_FETCH_FRONTEND_APP_CONFIG_STATUS,
        Action.POSTHOG_FETCH_ORGANIZATION_DETAILS,
        Action.POSTHOG_FETCH_ORGANIZATION_PIPELINE_APP_REPOSITORIES,
        Action.POSTHOG_FETCH_PIPELINE_DESTINATION_DETAILS,        
    ],

    App.QUICKCHART: [
        Action.QUICKCHART_CREATE_CHART,
        Action.QUICKCHART_CREATE_QR_CODE,
        Action.QUICKCHART_CREATE_SHORT_URL,
        Action.QUICKCHART_CREATE_CHART_POST
    ],

    App.RESEND: [
        Action.RESEND_RETRIEVE_BROADCAST,
        Action.RESEND_LIST_AUDIENCES,
        Action.RESEND_LIST_API_KEYS,
        Action.RESEND_LIST_CONTACTS,
        Action.RESEND_RETRIEVE_CONTACT,
        Action.RESEND_RETRIEVE_AUDIENCE,
        Action.RESEND_LIST_BROADCASTS,
        Action.RESEND_RETRIEVE_DOMAIN,
        Action.RESEND_LIST_DOMAINS,
        Action.RESEND_RETRIEVE_EMAIL,
        Action.RESEND_CANCEL_EMAIL,
        Action.RESEND_SEND_BROADCAST,
        Action.RESEND_CREATE_API_KEY,
        Action.RESEND_CREATE_AUDIENCE,
        Action.RESEND_CREATE_CONTACT,
        Action.RESEND_CREATE_BROADCAST,
        Action.RESEND_CREATE_DOMAIN,
        Action.RESEND_VERIFY_DOMAIN,
        Action.RESEND_SEND_BATCH_EMAILS,
        Action.RESEND_SEND_EMAIL,
        Action.RESEND_DELETE_API_KEY,
        Action.RESEND_DELETE_CONTACT,
        Action.RESEND_DELETE_BROADCAST,
        Action.RESEND_DELETE_AUDIENCE,
        Action.RESEND_DELETE_DOMAIN,
        Action.RESEND_UPDATE_CONTACT,
        Action.RESEND_UPDATE_EMAIL,
        Action.RESEND_UPDATE_DOMAIN,
    ],

    App.SCRAPINGDOG: [
        Action.SCRAPINGDOG_SCRAPE_GOOGLE_VIDEOS_SEARCH_RESULTS,
        Action.SCRAPINGDOG_GET_AMAZON_AUTOCOMPLETE_SUGGESTIONS,
        Action.SCRAPINGDOG_GET_GOOGLE_NEWS_SEARCH_RESULTS,
        Action.SCRAPINGDOG_GET_GOOGLE_MAPS_REVIEWS,
        Action.SCRAPINGDOG_RETRIEVE_INSTAGRAM_PROFILE_POSTS,
        Action.SCRAPINGDOG_SCRAPE_GOOGLE_IMAGES_RESULTS,
        Action.SCRAPINGDOG_GET_GOOGLE_PATENT_DETAILS,
        Action.SCRAPINGDOG_SCRAPE_LINKEDIN_POST,
        Action.SCRAPINGDOG_GET_INSTAGRAM_PROFILE_INFORMATION,
        Action.SCRAPINGDOG_GET_GOOGLE_JOBS_SEARCH_RESULTS,
        Action.SCRAPINGDOG_SCRAPE_GOOGLE_SCHOLAR_SEARCH_RESULTS,
        Action.SCRAPINGDOG_SCRAPE_ZILLOW_SEARCH_RESULTS,
        Action.SCRAPINGDOG_SCRAPE_GOOGLE_LOCAL_RESULTS,
        Action.SCRAPINGDOG_GET_GOOGLE_PATENTS_SEARCH_RESULTS,
        Action.SCRAPINGDOG_SCRAPE_X_PROFILE_BY_PROFILE_ID,
        Action.SCRAPINGDOG_SCRAPE_WEBPAGE,
        Action.SCRAPINGDOG_SCRAPE_GOOGLE_FINANCE_DATA,
        Action.SCRAPINGDOG_GET_WALMART_PRODUCT_REVIEWS,
        Action.SCRAPINGDOG_SCRAPE_WALMART_SEARCH_RESULTS,
        Action.SCRAPINGDOG_SCRAPE_AMAZON_PRODUCT_REVIEWS,
        Action.SCRAPINGDOG_GET_GOOGLE_SHOPPING_RESULTS,
        Action.SCRAPINGDOG_GET_GOOGLE_MAPS_POSTS_FOR_LOCATION,
        Action.SCRAPINGDOG_GET_GOOGLE_SCHOLAR_AUTHOR_DATA,
        Action.SCRAPINGDOG_SCRAPE_LINKEDIN_COMPANY_PROFILE,
        Action.SCRAPINGDOG_GET_GOOGLE_AUTOCOMPLETE_SUGGESTIONS,
        Action.SCRAPINGDOG_GET_GOOGLE_SCHOLAR_PROFILES,
        Action.SCRAPINGDOG_SCRAPE_AMAZON_PRODUCT_DETAILS,
        Action.SCRAPINGDOG_SCRAPE_LINKEDIN_JOB_OVERVIEW,
        Action.SCRAPINGDOG_SCRAPE_LINKEDIN_JOBS,
        Action.SCRAPINGDOG_GET_GOOGLE_MAPS_PLACE_DETAILS,
        Action.SCRAPINGDOG_GET_YOUTUBE_CHANNEL_DATA,
        Action.SCRAPINGDOG_GET_GOOGLE_LENS_RESULTS,
        Action.SCRAPINGDOG_GET_ACCOUNT_USAGE_INFORMATION,
        Action.SCRAPINGDOG_GET_GOOGLE_SCHOLAR_AUTHOR_CITATION_DATA,
        Action.SCRAPINGDOG_TRIGGER_WEBHOOK_SCRAPING_REQUEST,
        Action.SCRAPINGDOG_SCRAPE_WALMART_PRODUCT_DATA,
        Action.SCRAPINGDOG_SCRAPE_AMAZON_SEARCH_RESULTS,
        Action.SCRAPINGDOG_SCRAPE_GOOGLE_NEWS_RESULTS,
        Action.SCRAPINGDOG_SCRAPE_BING_SEARCH_RESULTS,
        Action.SCRAPINGDOG_GET_GOOGLE_MAPS_PHOTOS,
        Action.SCRAPINGDOG_GET_GOOGLE_PRODUCT_DETAILS,
        Action.SCRAPINGDOG_FETCH_GOOGLE_AI_OVERVIEW_RESULTS,
        Action.SCRAPINGDOG_SCRAPE_GOOGLE_SEARCH_RESULTS,
        Action.SCRAPINGDOG_SCRAPE_PUBLIC_LINKEDIN_PERSON_PROFILE,
        Action.SCRAPINGDOG_GET_YOUTUBE_VIDEO_TRANSCRIPTS,
        Action.SCRAPINGDOG_SCRAPE_GOOGLE_SHORTS_RESULTS,
        Action.SCRAPINGDOG_SCRAPE_GOOGLE_MAPS_SEARCH_RESULTS,
        Action.SCRAPINGDOG_SEARCH_YOUTUBE_VIDEOS,
        Action.SCRAPINGDOG_GET_PARSED_INDEED_JOB_DATA,
        Action.SCRAPINGDOG_SCRAPE_YOUTUBE_COMMENTS,
        Action.SCRAPINGDOG_GET_GOOGLE_TRENDS_DATA,
        Action.SCRAPINGDOG_GET_GOOGLE_TRENDS_AUTOCOMPLETE_SUGGESTIONS,
        Action.SCRAPINGDOG_TAKE_SCREENSHOT_OF_WEBPAGE,
        Action.SCRAPINGDOG_GET_YELP_SEARCH_RESULTS,
        Action.SCRAPINGDOG_SCRAPE_TWEET,
        Action.SCRAPINGDOG_GET_GOOGLE_TRENDS_TRENDING_NOW_DATA,
        Action.SCRAPINGDOG_POST_REQUEST_SCRAPE,
    ],

    App.SENDGRID: [
        Action.SENDGRID_SEND_EMAIL,
        Action.SENDGRID_ADD_IP_TO_POOL,
        Action.SENDGRID_RETRIEVE_ALL_LISTS,
        Action.SENDGRID_ACTIVATE_TEMPLATE_VERSION,
        Action.SENDGRID_ADD_IP_TO_AUTHENTICATED_DOMAIN,
        Action.SENDGRID_ADD_BATCH_IPS_TO_POOL,
        Action.SENDGRID_ADD_RECIPIENT_TO_LIST,
        Action.SENDGRID_ADD_SENDGRID_IP,
        Action.SENDGRID_ADD_IPS_TO_ACCOUNT,
        Action.SENDGRID_ADD_IPS_TO_ALLOWLIST,
        Action.SENDGRID_ADD_OR_UPDATE_CONTACT,
        Action.SENDGRID_ADD_GLOBAL_SUPPRESSIONS,
        Action.SENDGRID_ADD_SUPPRESSIONS_TO_GROUP,
        Action.SENDGRID_APPROVE_ACCESS_REQUEST,
        Action.SENDGRID_ASSIGN_SUBUSERS_TO_IP,
        Action.SENDGRID_ASSOCIATE_DOMAIN_WITH_SUBUSER,
        Action.SENDGRID_ASSOCIATE_BRANDED_LINK_WITH_SUBUSER,
        Action.SENDGRID_SSO_AUTHENTICATE,
        Action.SENDGRID_AUTHENTICATE_DOMAIN,
        Action.SENDGRID_BIND_DOMAINS_TO_SUBUSER,
        Action.SENDGRID_BULK_DELETE_SINGLE_SENDS,
        Action.SENDGRID_CANCEL_SCHEDULED_SEND,
        Action.SENDGRID_GET_COMPLETED_STEPS,
        Action.SENDGRID_CREATE_ACCOUNT,
        Action.SENDGRID_CREATE_IP_POOL,
        Action.SENDGRID_CREATE_IP_POOL_WITH_ASSIGNMENTS,
        Action.SENDGRID_CREATE_SSO_CERTIFICATE,
        Action.SENDGRID_CREATE_SSO_INTEGRATION,
        Action.SENDGRID_CREATE_SSO_TEAMMATE,
        Action.SENDGRID_CREATE_API_KEY,
        Action.SENDGRID_CREATE_BATCH_ID,
        Action.SENDGRID_CREATE_BRANDED_LINK,
        Action.SENDGRID_CREATE_CAMPAIGN,
        Action.SENDGRID_CREATE_CUSTOM_FIELD,
        Action.SENDGRID_CREATE_LIST,
        Action.SENDGRID_CREATE_ALERT,
        Action.SENDGRID_CREATE_EVENT_WEBHOOK,
        Action.SENDGRID_CREATE_SUPPRESSION_GROUP,
        Action.SENDGRID_CREATE_TEMPLATE_VERSION,
        Action.SENDGRID_CREATE_PARSE_SETTING,
        Action.SENDGRID_CREATE_SEGMENT,
        Action.SENDGRID_CREATE_SENDER,
        Action.SENDGRID_CREATE_SENDER_IDENTITY,
        Action.SENDGRID_CREATE_TRANSACTIONAL_TEMPLATE,
        Action.SENDGRID_CREATE_CUSTOM_FIELD_DEFINITION,
        Action.SENDGRID_CREATE_DESIGN,
        Action.SENDGRID_CREATE_INTEGRATION,
        Action.SENDGRID_CREATE_CONTACTS_LIST,
        Action.SENDGRID_CREATE_CONTACTS_SEGMENT,
        Action.SENDGRID_CREATE_SINGLE_SEND,
        Action.SENDGRID_CREATE_SUBUSER,
        Action.SENDGRID_CREATE_VERIFIED_SENDER_REQUEST,
        Action.SENDGRID_DELETE_ACCOUNT,
        Action.SENDGRID_DELETE_ALERT,
        Action.SENDGRID_DELETE_AUTHENTICATED_DOMAIN,
        Action.SENDGRID_DELETE_IP_POOL,
        Action.SENDGRID_DELETE_SSO_CERTIFICATE,
        Action.SENDGRID_DELETE_SSO_INTEGRATION,
        Action.SENDGRID_DELETE_API_KEY,
        Action.SENDGRID_DELETE_BATCH_IPS_FROM_POOL,
        Action.SENDGRID_DELETE_BATCH_SUBUSERS_FROM_IP,
        Action.SENDGRID_DELETE_BOUNCE,
        Action.SENDGRID_DELETE_BRANDED_LINK,
        Action.SENDGRID_DELETE_CAMPAIGN,
        Action.SENDGRID_DELETE_SCHEDULED_SEND_CANCELLATION,
        Action.SENDGRID_DELETE_CONTACT_IDENTIFIER,
        Action.SENDGRID_DELETE_CUSTOM_FIELD,
        Action.SENDGRID_DELETE_DESIGN,
        Action.SENDGRID_DELETE_INVALID_EMAILS,
        Action.SENDGRID_DELETE_PENDING_TEAMMATE,
        Action.SENDGRID_DELETE_SEGMENT,
        Action.SENDGRID_DELETE_SINGLE_SEND,
        Action.SENDGRID_DELETE_SINGLE_SEND_SCHEDULE,
        Action.SENDGRID_DELETE_SPAM_REPORTS,
        Action.SENDGRID_DELETE_TEAMMATE,
        Action.SENDGRID_DELETE_VERIFIED_SENDER,
        Action.SENDGRID_GET_ALL_CATEGORIES,
        Action.SENDGRID_GET_ALL_FIELD_DEFINITIONS,
        Action.SENDGRID_GET_ALL_LISTS,
        Action.SENDGRID_GET_ALL_SINGLE_SENDS,
        Action.SENDGRID_GET_ALL_SINGLE_SENDS_STATS,
        Action.SENDGRID_GET_ALL_VERIFIED_SENDERS,
        Action.SENDGRID_GET_CONTACT_BY_ID,
        Action.SENDGRID_GET_LIST_BY_ID,
        Action.SENDGRID_GET_CONTACTS_BY_EMAILS,
        Action.SENDGRID_GET_BATCHED_CONTACTS_BY_IDS,
        Action.SENDGRID_EXPORT_CONTACTS,
        Action.SENDGRID_EXPORT_CONTACTS_STATUS,
        Action.SENDGRID_DUPLICATE_DESIGN,
        Action.SENDGRID_DUPLICATE_SINGLE_SEND,
        Action.SENDGRID_GET_AUTOMATION_STATS_BY_ID,
        Action.SENDGRID_GET_ALL_AUTOMATION_STATS,
        Action.SENDGRID_FILTER_MESSAGES_BY_MESSAGE_ID,
        Action.SENDGRID_GET_USER_PROFILE,
        Action.SENDGRID_GET_USER_ACCOUNT_INFORMATION,
    ],

    App.SPOTIFY: [
        Action.SPOTIFY_SAVE_AUDIOBOOKS_FOR_CURRENT_USER,
        Action.SPOTIFY_SAVE_EPISODES_FOR_CURRENT_USER,
        Action.SPOTIFY_SAVE_SHOWS_FOR_CURRENT_USER,
        Action.SPOTIFY_SEARCH_FOR_ITEM,
        Action.SPOTIFY_SEEK_TO_POSITION,
        Action.SPOTIFY_SET_PLAYBACK_VOLUME,
        Action.SPOTIFY_SET_REPEAT_MODE,
        Action.SPOTIFY_SKIP_TO_NEXT,
        Action.SPOTIFY_SKIP_TO_PREVIOUS,
        Action.SPOTIFY_START_RESUME_PLAYBACK,
        Action.SPOTIFY_TOGGLE_PLAYBACK_SHUFFLE,
        Action.SPOTIFY_TRANSFER_PLAYBACK,
        Action.SPOTIFY_UNFOLLOW_ARTISTS_OR_USERS,
        Action.SPOTIFY_UNFOLLOW_PLAYLIST,
        Action.SPOTIFY_UPDATE_PLAYLIST_ITEMS,
        Action.SPOTIFY_GET_PLAYLIST_ITEMS,
        Action.SPOTIFY_GET_USER_QUEUE,
        Action.SPOTIFY_GET_RECENTLY_PLAYED_TRACKS,
        Action.SPOTIFY_GET_RECOMMENDATIONS,
        Action.SPOTIFY_GET_SEVERAL_ALBUMS,
        Action.SPOTIFY_GET_SEVERAL_ARTISTS,
        Action.SPOTIFY_GET_SEVERAL_AUDIOBOOKS,
        Action.SPOTIFY_GET_SEVERAL_BROWSE_CATEGORIES,
        Action.SPOTIFY_GET_SEVERAL_CHAPTERS,
        Action.SPOTIFY_GET_SEVERAL_EPISODES,
        Action.SPOTIFY_GET_SEVERAL_SHOWS,
        Action.SPOTIFY_GET_SEVERAL_TRACKS,
        Action.SPOTIFY_GET_SEVERAL_TRACKS_AUDIO_FEATURES,
        Action.SPOTIFY_GET_SINGLE_BROWSE_CATEGORY,
        Action.SPOTIFY_GET_TRACK,
        Action.SPOTIFY_GET_TRACK_AUDIO_ANALYSIS,
        Action.SPOTIFY_GET_TRACK_AUDIO_FEATURES,
        Action.SPOTIFY_GET_USER_PROFILE,
        Action.SPOTIFY_GET_USER_SAVED_ALBUMS,
        Action.SPOTIFY_GET_USER_SAVED_AUDIOBOOKS,
        Action.SPOTIFY_GET_USER_SAVED_EPISODES,
        Action.SPOTIFY_GET_USER_SAVED_SHOWS,
        Action.SPOTIFY_GET_USER_SAVED_TRACKS,
        Action.SPOTIFY_GET_USER_TOP_ARTISTS,
        Action.SPOTIFY_GET_USER_TOP_TRACKS,
        Action.SPOTIFY_PAUSE_PLAYBACK,
        Action.SPOTIFY_REMOVE_PLAYLIST_ITEMS,
        Action.SPOTIFY_REMOVE_USER_SAVED_ALBUMS,
        Action.SPOTIFY_REMOVE_USER_SAVED_AUDIOBOOKS,
        Action.SPOTIFY_REMOVE_USER_SAVED_EPISODES,
        Action.SPOTIFY_REMOVE_USER_SAVED_SHOWS,
        Action.SPOTIFY_ADD_ITEMS_TO_PLAYLIST,
        Action.SPOTIFY_CREATE_PLAYLIST,
        Action.SPOTIFY_GET_ARTIST_TOP_TRACKS,
        Action.SPOTIFY_GET_PLAYLIST,
        Action.SPOTIFY_GET_SHOW,
        Action.SPOTIFY_GET_SHOW_EPISODES,
        Action.SPOTIFY_SAVE_ALBUMS_FOR_CURRENT_USER,
        Action.SPOTIFY_SAVE_TRACKS_FOR_CURRENT_USER,
        Action.SPOTIFY_ADD_ITEM_TO_PLAYBACK_QUEUE,
        Action.SPOTIFY_CHANGE_PLAYLIST_DETAILS,
        Action.SPOTIFY_CHECK_IF_USERS_FOLLOW_PLAYLIST,
        Action.SPOTIFY_CHECK_IF_USER_FOLLOWS_ARTISTS_OR_USERS,
        Action.SPOTIFY_CHECK_USER_SAVED_ALBUMS,
        Action.SPOTIFY_CHECK_USER_SAVED_AUDIOBOOKS,
        Action.SPOTIFY_CHECK_USER_SAVED_EPISODES,
        Action.SPOTIFY_CHECK_USER_SAVED_SHOWS,
        Action.SPOTIFY_CHECK_USER_SAVED_TRACKS,
        Action.SPOTIFY_FOLLOW_ARTISTS_OR_USERS,
        Action.SPOTIFY_FOLLOW_PLAYLIST,
        Action.SPOTIFY_GET_ALBUM,
        Action.SPOTIFY_GET_ALBUM_TRACKS,
        Action.SPOTIFY_GET_ARTIST,
        Action.SPOTIFY_GET_ARTIST_ALBUMS,
        Action.SPOTIFY_GET_AUDIOBOOK,
        Action.SPOTIFY_GET_ARTIST_RELATED_ARTISTS,
        Action.SPOTIFY_GET_AUDIOBOOK_CHAPTERS,
        Action.SPOTIFY_GET_AVAILABLE_DEVICES,
        Action.SPOTIFY_GET_AVAILABLE_GENRE_SEEDS,
        Action.SPOTIFY_GET_AVAILABLE_MARKETS,
        Action.SPOTIFY_GET_CHAPTER,
        Action.SPOTIFY_GET_CURRENT_USER_PLAYLISTS,
        Action.SPOTIFY_GET_CATEGORY_PLAYLISTS,
        Action.SPOTIFY_GET_CURRENTLY_PLAYING_TRACK,
        Action.SPOTIFY_GET_CURRENT_USER_PROFILE,
        Action.SPOTIFY_GET_EPISODE,
        Action.SPOTIFY_GET_FEATURED_PLAYLISTS,
        Action.SPOTIFY_GET_FOLLOWED_ARTISTS,
        Action.SPOTIFY_GET_PLAYBACK_STATE,
        Action.SPOTIFY_GET_USER_PLAYLISTS,
        Action.SPOTIFY_GET_NEW_RELEASES,
    ],

    App.STRIPE: [
        Action.STRIPE_CANCEL_SUBSCRIPTION,
        Action.STRIPE_CREATE_CUSTOMER,
        Action.STRIPE_CREATE_INVOICE,
        Action.STRIPE_CREATE_PAYMENT_INTENT,
        Action.STRIPE_CREATE_PRICE,
        Action.STRIPE_CREATE_PRODUCT,
        Action.STRIPE_CREATE_REFUND,
        Action.STRIPE_CREATE_SUBSCRIPTION,
        Action.STRIPE_DELETE_CUSTOMER,
        Action.STRIPE_LIST_CUSTOMER_PAYMENT_METHODS,
        Action.STRIPE_LIST_PAYMENT_LINKS,
        Action.STRIPE_LIST_REFUNDS,
        Action.STRIPE_LIST_SHIPPING_RATES,
        Action.STRIPE_LIST_TAX_RATES,
        Action.STRIPE_RETRIEVE_CHARGE_DETAILS,
        Action.STRIPE_RETRIEVE_PAYMENT_INTENT,
        Action.STRIPE_RETRIEVE_REFUND,
        Action.STRIPE_SEARCH_CUSTOMERS,
        Action.STRIPE_UPDATE_PAYMENT_INTENT,
        Action.STRIPE_UPDATE_SUBSCRIPTION,
        Action.STRIPE_CONFIRM_PAYMENT_INTENT,
        Action.STRIPE_LIST_CHARGES,
        Action.STRIPE_LIST_COUPONS,
        Action.STRIPE_LIST_CUSTOMERS,
        Action.STRIPE_LIST_INVOICES,
        Action.STRIPE_LIST_PAYMENT_INTENTS,
        Action.STRIPE_LIST_PRODUCTS,
        Action.STRIPE_LIST_SUBSCRIPTIONS,
        Action.STRIPE_LIST_TAX_CODES,
        Action.STRIPE_RETRIEVE_BALANCE,
        Action.STRIPE_RETRIEVE_CUSTOMER,
        Action.STRIPE_RETRIEVE_SUBSCRIPTION,
        Action.STRIPE_UPDATE_CUSTOMER,
    ],

    App.SUPABASE: [
        Action.SUPABASE_EXECUTE_PROJECT_DATABASE_QUERY,
        Action.SUPABASE_CREATE_ORGANIZATION,
        Action.SUPABASE_CREATE_NEW_PROJECT,
        Action.SUPABASE_LIST_ALL_ORGANIZATIONS,
        Action.SUPABASE_LIST_ALL_PROJECTS,
        Action.SUPABASE_CREATE_PROJECT_API_KEY,
        Action.SUPABASE_DELETE_API_KEY,
        Action.SUPABASE_GET_THIRD_PARTY_INTEGRATION,
        Action.SUPABASE_LIST_THIRD_PARTY_AUTH_INTEGRATIONS,
        Action.SUPABASE_DELETE_THIRD_PARTY_AUTH_CONFIG,
        Action.SUPABASE_UPDATE_API_KEY,
        Action.SUPABASE_ACTIVATE_CUSTOM_HOSTNAME,
        Action.SUPABASE_ACTIVATE_VANITY_SUBDOMAIN,
        Action.SUPABASE_AUTHORIZE_USER_OAUTH,
        Action.SUPABASE_CHECK_VANITY_SUBDOMAIN_AVAILABILITY,
        Action.SUPABASE_ENABLE_DATABASE_WEBHOOKS,
        Action.SUPABASE_GET_VANITY_SUBDOMAIN_CONFIG,
        Action.SUPABASE_GET_CUSTOM_HOSTNAME_CONFIG,
        Action.SUPABASE_RETRIEVE_NETWORK_BANS,
        Action.SUPABASE_RETRIEVE_NETWORK_RESTRICTIONS,
        Action.SUPABASE_GET_PGSODIUM_CONFIG,
        Action.SUPABASE_GET_SSL_ENFORCEMENT_CONFIG,
        Action.SUPABASE_REMOVE_READ_REPLICA,
        Action.SUPABASE_REMOVE_NETWORK_BANS,
        Action.SUPABASE_SETUP_READ_REPLICA,
        Action.SUPABASE_UPDATE_NETWORK_RESTRICTIONS,
        Action.SUPABASE_UPGRADE_POSTGRESQL_VERSION,
        Action.SUPABASE_UPDATE_PGSODIUM_ROOT_KEY,
        Action.SUPABASE_CREATE_SSO_PROVIDER,
        Action.SUPABASE_CREATE_THIRD_PARTY_AUTH,
        Action.SUPABASE_CREATE_DATABASE_BRANCH,
        Action.SUPABASE_CREATE_EDGE_FUNCTION,
        Action.SUPABASE_REVERIFY_CUSTOM_HOSTNAME,
        Action.SUPABASE_DELETE_PROJECT,
        Action.SUPABASE_DELETE_DATABASE_BRANCH,
        Action.SUPABASE_DELETE_EDGE_FUNCTION,
        Action.SUPABASE_DELETE_CUSTOM_HOSTNAME,
        Action.SUPABASE_DELETE_VANITY_SUBDOMAIN,
        Action.SUPABASE_DEPLOY_EDGE_FUNCTION,
        Action.SUPABASE_DISABLE_PREVIEW_BRANCHING,
        Action.SUPABASE_DISABLE_READONLY_MODE,
        Action.SUPABASE_EXCHANGE_AUTH_CODE,
        Action.SUPABASE_GENERATE_TYPESCRIPT_TYPES,
        Action.SUPABASE_GET_SQL_SNIPPET,
        Action.SUPABASE_GET_SSO_PROVIDER_BY_UUID,
        Action.SUPABASE_GET_ORGANIZATION_INFO,
        Action.SUPABASE_GET_PROJECT_AUTH_CONFIG,
        Action.SUPABASE_GET_PROJECT_POSTGREST_CONFIG,
        Action.SUPABASE_GET_PROJECT_POSTGRES_CONFIG,
        Action.SUPABASE_GET_PROJECT_SERVICE_HEALTH_STATUS,
        Action.SUPABASE_GET_PROJECT_SUPAVISOR_CONFIGURATION,
        Action.SUPABASE_GET_DATABASE_BRANCH_CONFIG,
        Action.SUPABASE_GET_PROJECT_API_KEYS,
        Action.SUPABASE_GET_PROJECT_PGBOUNCER_CONFIG,
        Action.SUPABASE_GET_PROJECT_UPGRADE_ELIGIBILITY,
        Action.SUPABASE_GET_PROJECT_UPGRADE_STATUS,
        Action.SUPABASE_LIST_PROJECT_DATABASE_BACKUPS,
        Action.SUPABASE_LIST_ALL_BUCKETS,
        Action.SUPABASE_LIST_ALL_SSO_PROVIDERS,
        Action.SUPABASE_LIST_SQL_SNIPPETS_FOR_USER,
        Action.SUPABASE_LIST_ALL_DATABASE_BRANCHES,
        Action.SUPABASE_LIST_ALL_FUNCTIONS,
        Action.SUPABASE_LIST_ALL_SECRETS,
        Action.SUPABASE_LIST_MEMBERS_OF_ORGANIZATION,
        Action.SUPABASE_REMOVE_SSO_PROVIDER,
        Action.SUPABASE_RESET_DATABASE_BRANCH,
        Action.SUPABASE_RESTORE_DATABASE_PITR_BACKUP,
        Action.SUPABASE_RETRIEVE_FUNCTION,
        Action.SUPABASE_RETRIEVE_FUNCTION_BODY,
        Action.SUPABASE_GET_PROJECT_READONLY_MODE_STATUS,
        Action.SUPABASE_UPDATE_SSO_PROVIDER_BY_UUID,
        Action.SUPABASE_UPDATE_PROJECT_POSTGREST_CONFIG,
        Action.SUPABASE_UPDATE_PROJECT_POSTGRES_CONFIG,
        Action.SUPABASE_UPDATE_DATABASE_POOLER_CONFIG,
        Action.SUPABASE_UPDATE_FUNCTION,
        Action.SUPABASE_UPDATE_DATABASE_BRANCH_CONFIG,
        Action.SUPABASE_UPDATE_PROJECT_CUSTOM_HOSTNAME_CONFIGURATION,
        Action.SUPABASE_UPDATE_SSL_ENFORCEMENT_CONFIG,
    ],

    App.TAVILY: [
        Action.TAVILY_SEARCH_DATA,
        Action.TAVILY_EXTRACT_CONTENT,
    ],

    App.TYPEFORM: [
        Action.TYPEFORM_RETRIEVE_WORKSPACES,
        Action.TYPEFORM_RETRIEVE_THEMES,
        Action.TYPEFORM_RETRIEVE_WORKSPACE,
        Action.TYPEFORM_RETRIEVE_CUSTOM_FORM_MESSAGES,
        Action.TYPEFORM_RETRIEVE_SINGLE_WEBHOOK,
        Action.TYPEFORM_RETRIEVE_IMAGES_COLLECTION,
        Action.TYPEFORM_RETRIEVE_FORM,
        Action.TYPEFORM_RETRIEVE_RESPONSES_FOR_FORM,
        Action.TYPEFORM_RETRIEVE_THEME,
        Action.TYPEFORM_RETRIEVE_ACCOUNT_WORKSPACES,
        Action.TYPEFORM_RETRIEVE_FORMS,
        Action.TYPEFORM_RETRIEVE_WEBHOOKS,
        Action.TYPEFORM_RETRIEVE_IMAGE,
        Action.TYPEFORM_CREATE_FORM,
        Action.TYPEFORM_CREATE_THEME,
        Action.TYPEFORM_CREATE_IMAGE,
        Action.TYPEFORM_CREATE_WORKSPACE,
        Action.TYPEFORM_CREATE_ACCOUNT_WORKSPACE,
        Action.TYPEFORM_CREATE_OR_UPDATE_WEBHOOK,
        Action.TYPEFORM_UPDATE_CUSTOM_MESSAGES_FOR_FORMS,
        Action.TYPEFORM_UPDATE_FORM,
        Action.TYPEFORM_UPDATE_THEME,
        Action.TYPEFORM_UPDATE_WORKSPACE,
        Action.TYPEFORM_PATCH_UPDATE_FORM,
        Action.TYPEFORM_PARTIAL_UPDATE_THEME,
        Action.TYPEFORM_DELETE_THEME,
        Action.TYPEFORM_DELETE_FORM,
        Action.TYPEFORM_DELETE_WEBHOOK,
        Action.TYPEFORM_DELETE_RESPONSES_TO_FORM,
        Action.TYPEFORM_DELETE_WORKSPACE,
        Action.TYPEFORM_DELETE_IMAGE,
    ],

    App.VERCEL: [
        Action.VERCEL_ADD_ENVIRONMENT_VARIABLE,
        Action.VERCEL_CHECK_CACHE_ARTIFACT_EXISTS,
        Action.VERCEL_CHECK_DOMAIN_AVAILABILITY,
        Action.VERCEL_CHECK_DOMAIN_PRICE,
        Action.VERCEL_CREATE_AUTH_TOKEN,
        Action.VERCEL_CREATE_EDGE_CONFIG,
        Action.VERCEL_CREATE_DEPLOYMENT,
        Action.VERCEL_DELETE_AUTH_TOKEN,
        Action.VERCEL_DELETE_DEPLOYMENT,
        Action.VERCEL_DELETE_ENVIRONMENT_VARIABLE,
        Action.VERCEL_DELETE_PROJECT,
        Action.VERCEL_DEPLOY_EDGE_FUNCTION,
        Action.VERCEL_GET_DEPLOYMENT_DETAILS,
        Action.VERCEL_GET_DEPLOYMENT_EVENTS,
        Action.VERCEL_GET_DEPLOYMENT_LOGS,
        Action.VERCEL_GET_DOMAIN_TRANSFER_INFO,
        Action.VERCEL_GET_EDGE_CONFIG,
        Action.VERCEL_GET_EDGE_CONFIG_ITEM,
        Action.VERCEL_GET_PROJECT,
        Action.VERCEL_LIST_ALIASES,
        Action.VERCEL_LIST_DEPLOYMENTS,
        Action.VERCEL_LIST_AUTH_TOKENS,
        Action.VERCEL_LIST_DEPLOYMENT_CHECKS,
        Action.VERCEL_LIST_EDGE_CONFIGS,
        Action.VERCEL_LIST_ENVIRONMENT_VARIABLES,
        Action.VERCEL_UPDATE_EDGE_CONFIG_ITEMS,
        Action.VERCEL_UPDATE_PROJECT,
        Action.VERCEL_CREATE_EDGE_CONFIG_TOKEN,
    ],

    App.WTTR: [
        Action.WTTR_GET_WEATHER_DATA
    ],

    App.ZOOM: [
        Action.ZOOM_CREATE_MEETING,
        Action.ZOOM_GET_MEETING,
        Action.ZOOM_GET_MEETING_SUMMARY,
        Action.ZOOM_GET_MEETING_RECORDINGS,
        Action.ZOOM_LIST_RECORDINGS,
        Action.ZOOM_LIST_MEETINGS,
        Action.ZOOM_ADD_MEETING_REGISTRANT,
        Action.ZOOM_GET_WEBINAR,
        Action.ZOOM_LIST_WEBINARS,
        Action.ZOOM_GET_PAST_MEETING_PARTICIPANTS,
        Action.ZOOM_UPDATE_MEETING,
        Action.ZOOM_DELETE_MEETING_RECORDINGS,
    ]
}

class ServiceType(str, Enum):
    """Enumeration of supported Google services for webhook triggers."""
    GMAIL = "gmail"
    DRIVE = "drive"
    CALENDAR = "calendar"
    DOCS = "docs"
    FIRECRAWL = "firecrawl"
    SERPAPI = "serpapi"
    GITHUB = "github"

class EventType(str, Enum):
    """Enumeration of webhook event types for different services."""
    # Gmail events
    GMAIL_NEW_MESSAGE = "gmail.new_message"
    GMAIL_MESSAGE_DELETED = "gmail.message_deleted"
    GMAIL_MESSAGE_UPDATED = "gmail.message_updated"
    
    # Drive events
    DRIVE_FILE_CREATED = "drive.file_created"
    DRIVE_FILE_MODIFIED = "drive.file_modified"
    DRIVE_FILE_DELETED = "drive.file_deleted"
    DRIVE_FILE_TRASHED = "drive.file_trashed"
    DRIVE_FILE_RESTORED = "drive.file_restored"
    
    # Calendar events
    CALENDAR_EVENT_CREATED = "calendar.event_created"
    CALENDAR_EVENT_UPDATED = "calendar.event_updated"
    CALENDAR_EVENT_DELETED = "calendar.event_deleted"
    CALENDAR_SYNC = "calendar.sync"

    GITHUB_PUSH = "github.push"
    GITHUB_PULL_REQUEST = "github.pull_request"
    GITHUB_ISSUES = "github.issues"
    GITHUB_WATCH = "github.watch"
    GITHUB_FOLLOW = "github.follow"

NO_AUTH_PROVIDERS = {"hackernews", "quickchart", "wttr"}
